@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyddion.c 28738 2025-10-30 09:07:30Z yeti-dn $
+ *  $Id: gwyddion.c 29498 2026-02-17 19:04:21Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -373,6 +373,8 @@ gwyddion_startup(GApplication *gapplication)
     timer_checkpoint(gwyapp, "gtk_init()");
 
     gwy_ui_init();
+    // FIXME: This is awkward. The price for not using gwy_app_init().
+    g_type_class_peek(GWY_TYPE_FILE);
     g_set_application_name(PACKAGE_NAME);
 
     gwy_app_set_window_icon();
