@@ -1,5 +1,5 @@
 /*
- *  $Id: splash.c 27936 2025-05-09 09:14:17Z yeti-dn $
+ *  $Id: splash.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -28,7 +28,7 @@
 #include "libgwyddion/macros.h"
 #include "libgwyddion/utils.h"
 #include "libgwyddion/version.h"
-#include "libgwyddion/gwycontainer.h"
+#include "libgwyddion/dict.h"
 #include "libgwyapp/sanity.h"
 
 typedef struct {
