@@ -1,5 +1,5 @@
 /*
- *  $Id: toolbox-editor.c 28772 2025-11-03 18:02:12Z yeti-dn $
+ *  $Id: toolbox-editor.c 29226 2026-01-15 09:58:34Z yeti-dn $
  *  Copyright (C) 2016-2018 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -1817,8 +1817,8 @@ create_gwy_icon_list(void)
     GWY_ICON_GRADIENT_HORIZONTAL,
     GWY_ICON_GRADIENT_VERTICAL,
     GWY_ICON_GRAIN_BOUNDING_BOX,
+    GWY_ICON_GRAIN_CIRCUMCIRCLE,
     GWY_ICON_GRAIN_CORRELATION,
-    GWY_ICON_GRAIN_EXSCRIBED_CIRCLE,
     GWY_ICON_GRAIN_INSCRIBED_BOX,
     GWY_ICON_GRAIN_INSCRIBED_CIRCLE,
     GWY_ICON_GRAINS,
