@@ -1,5 +1,5 @@
 /*
- *  $Id: toolbox.c 28819 2025-11-06 15:59:52Z yeti-dn $
+ *  $Id: toolbox.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -132,9 +132,10 @@ dummy_submenu_marker(void)
 
 static void
 toolbox_start_group(GwyAppToolboxBuilder *builder,
-                    const GwyToolboxGroupSpec *gspec)
+                    const GwyToolboxGroupSpec *gspec,
+                    guint *groupno)
 {
-    GwyContainer *settings;
+    GwyDict *settings;
     GtkWidget *expander;
     gboolean visible = TRUE;
     gchar *s, *key;
@@ -151,7 +152,7 @@ toolbox_start_group(GwyAppToolboxBuilder *builder,
     key = g_strconcat("/app/toolbox/visible/", g_quark_to_string(gspec->id), NULL);
     quark = g_quark_from_string(key);
     g_free(key);
-    gwy_container_gis_boolean(settings, quark, &visible);
+    gwy_dict_gis_boolean(settings, quark, &visible);
 
     translated_name = gspec->translatable ? _(gspec->name) : gspec->name;
     s = g_strconcat("<small>", translated_name, "</small>", NULL);
@@ -163,6 +164,8 @@ toolbox_start_group(GwyAppToolboxBuilder *builder,
     gtk_container_add(GTK_CONTAINER(expander), builder->group);
     gtk_expander_set_expanded(GTK_EXPANDER(expander), visible);
     gtk_box_pack_start(builder->box, expander, FALSE, FALSE, 0);
+    gtk_box_reorder_child(builder->box, expander, *groupno);
+    (*groupno)++;
     g_signal_connect_after(expander, "activate", G_CALLBACK(gwy_app_toolbox_showhide), NULL);
     builder->pos = 0;
 }
@@ -492,9 +495,6 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
     const GwyToolboxGroupSpec *gspec;
     const GwyToolboxItemSpec *ispec;
     GtkWidget *important_widget = NULL;
-    GtkExpander *expander;
-    GArray *group, *item;
-    guint i, j;
 
     gwy_clear1(builder);
     builder.width = spec->width >= 8 ? spec->width : 8;
@@ -506,12 +506,13 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
     gwy_tool_func_foreach(gather_tools, builder.unseen_tools);
     remove_seen_unseen_tools(&builder, spec);
 
-    group = spec->group;
-    for (i = 0; i < group->len; i++) {
+    GArray *group = spec->group;
+    guint groupno = 1;
+    for (guint i = 0; i < group->len; i++) {
         gspec = &g_array_index(group, GwyToolboxGroupSpec, i);
-        toolbox_start_group(&builder, gspec);
-        item = gspec->item;
-        for (j = 0; j < item->len; j++) {
+        toolbox_start_group(&builder, gspec, &groupno);
+        GArray *item = gspec->item;
+        for (guint j = 0; j < item->len; j++) {
             ispec = &g_array_index(item, GwyToolboxItemSpec, j);
             /* When the construction fails remove the item also from the spec so *if* we edit and save the spec it is
              * corrected. */
@@ -539,7 +540,7 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
      * Otherwise we get CRITICAL GTK+ error gtk_widget_event: assertion 'WIDGET_REALIZED_FOR_EVENT (widget, event)'
      * failed */
     if (important_widget) {
-        expander = GTK_EXPANDER(gtk_widget_get_ancestor(important_widget, GTK_TYPE_EXPANDER));
+        GtkExpander *expander = GTK_EXPANDER(gtk_widget_get_ancestor(important_widget, GTK_TYPE_EXPANDER));
         if (!gtk_expander_get_expanded(GTK_EXPANDER(expander))) {
             gulong *p = g_new(gulong, 1);
 
@@ -921,10 +922,10 @@ create_edit_menu(GtkAccelGroup *accel_group)
 
     GtkWidget *menu = build_simple_menu(menu_items, G_N_ELEMENTS(menu_items), "<edit>", accel_group);
 
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     gboolean enable_edit = FALSE, enable_logging;
 
-    gwy_container_gis_boolean_by_name(settings, "/app/edit-accelerators", &enable_edit);
+    gwy_dict_gis_boolean_by_name(settings, "/app/edit-accelerators", &enable_edit);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_items[7].widget), enable_edit);
     enable_edit_accelerators(enable_edit);
 
@@ -937,14 +938,14 @@ create_edit_menu(GtkAccelGroup *accel_group)
 static void
 gwy_app_toolbox_showhide(GtkWidget *expander)
 {
-    GwyContainer *settings;
+    GwyDict *settings;
     gboolean visible;
     GQuark quark;
 
     settings = gwy_app_settings_get();
     quark = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(expander), "key"));
     visible = gtk_expander_get_expanded(GTK_EXPANDER(expander));
-    gwy_container_set_boolean(settings, quark, visible);
+    gwy_dict_set_boolean(settings, quark, visible);
 }
 
 static void
@@ -1103,28 +1104,28 @@ delete_app_window(void)
 static void
 action_undo(void)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     if (data)
-        gwy_app_undo_undo_container(data);
+        gwy_app_undo_undo_dict(data);
 }
 
 static void
 action_redo(void)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     if (data)
-        gwy_app_undo_redo_container(data);
+        gwy_app_undo_redo_dict(data);
 }
 
 static void
 remove_all_logs(void)
 {
     GwyFile *file;
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &file, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &file, 0);
     g_return_if_fail(file);
 
     g_object_ref(file);
@@ -1137,7 +1138,7 @@ toggle_edit_accelerators(GtkCheckMenuItem *item)
 {
     gboolean active = gtk_check_menu_item_get_active(item);
 
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(), "/app/edit-accelerators", active);
+    gwy_dict_set_boolean_by_name(gwy_app_settings_get(), "/app/edit-accelerators", active);
     enable_edit_accelerators(active);
 }
 
@@ -1146,7 +1147,7 @@ toggle_logging_enabled(GtkCheckMenuItem *item)
 {
     gboolean active = gtk_check_menu_item_get_active(item);
 
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(), "/app/log/disable", !active);
+    gwy_dict_set_boolean_by_name(gwy_app_settings_get(), "/app/log/disable", !active);
     gwy_log_set_enabled(active);
 }
 
@@ -1171,29 +1172,29 @@ static void
 edit_default_mask_color(void)
 {
     GwyRGBA color = { 1.0, 0.0, 0.0, 0.5 };
-    GwyContainer *settings = gwy_app_settings_get();
-    gwy_rgba_get_from_container(&color, settings, "/mask");
+    GwyDict *settings = gwy_app_settings_get();
+    gwy_rgba_get_from_dict(&color, settings, "/mask");
 
     /* The mask colour helper function now works with RGBA boxed directly stored in the file, but settings have it
      * component-wise. Create a temporary Container as a workaround. */
-    GwyContainer *container = gwy_container_new();
+    GwyDict *container = gwy_dict_new();
     GQuark key = gwy_file_key_image_mask_color(0);
-    gwy_container_set_boxed(container, GWY_TYPE_RGBA, key, &color);
+    gwy_dict_set_boxed(container, GWY_TYPE_RGBA, key, &color);
     gwy_mask_color_selector_run(_("Change Default Mask Color"), NULL, NULL, container, key);
     GwyRGBA newcolor = color;
-    gwy_container_gis_boxed(container, GWY_TYPE_RGBA, key, &newcolor);
+    gwy_dict_gis_boxed(container, GWY_TYPE_RGBA, key, &newcolor);
     g_object_unref(container);
     if (!gwy_serializable_boxed_equal(GWY_TYPE_RGBA, &newcolor, &color))
-        gwy_rgba_store_to_container(&newcolor, settings, "/mask");
+        gwy_rgba_store_to_dict(&newcolor, settings, "/mask");
 }
 
 static void
 action_display_3d(void)
 {
-    GwyContainer *data;
+    GwyDict *data;
     gint id;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     g_return_if_fail(data);
