@@ -1,5 +1,5 @@
 /*
- *  $Id: app-graph-window.c 29094 2026-01-06 17:53:17Z yeti-dn $
+ *  $Id: app-graph-window.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -61,7 +61,7 @@ static void       show_meta_browser  (GwyAppGraphWindow *window);
 static void       meta_destroyed     (GwyAppGraphWindow *window);
 static void       show_log_browser   (GwyAppGraphWindow *window);
 static void       log_destroyed      (GwyAppGraphWindow *window);
-static void       item_changed       (GwyContainer *container,
+static void       item_changed       (GwyDict *container,
                                       GQuark key,
                                       GwyAppGraphWindow *window);
 static void       object_notify      (GObject *object,
@@ -226,7 +226,7 @@ gwy_app_graph_window_get_id(GwyAppGraphWindow *window)
 }
 
 static void
-item_changed(GwyContainer *container, GQuark key, GwyAppGraphWindow *window)
+item_changed(GwyDict *container, GQuark key, GwyAppGraphWindow *window)
 {
     GwyAppGraphWindowPrivate *priv = window->priv;
     GwyFileKeyParsed parsed;
@@ -289,7 +289,7 @@ initial_setup(GwyAppGraphWindow *window)
     GwyDataKind data_kind = priv->data_kind;
     gint id = priv->id;
     GwyFileKeyParsed parsed = { .data_kind = data_kind, .id = id, .piece = GWY_FILE_PIECE_NONE, .suffix = NULL };
-    GwyContainer *container = GWY_CONTAINER(priv->file);
+    GwyDict *container = GWY_DICT(priv->file);
 
     item_changed(container, gwy_file_form_key(&parsed), window);
     parsed.piece = GWY_FILE_PIECE_VIEW;
@@ -410,7 +410,7 @@ update_window_title(GwyAppGraphWindow *window)
     GwyAppGraphWindowPrivate *priv = window->priv;
     gchar *basename;
     const gchar *filename;
-    if (gwy_container_gis_string(GWY_CONTAINER(priv->file), gwy_file_key_filename(), &filename))
+    if (gwy_dict_gis_string(GWY_DICT(priv->file), gwy_file_key_filename(), &filename))
         basename = g_path_get_basename(filename);
     else
         basename = g_strdup(_("Untitled"));
@@ -449,7 +449,7 @@ save_size(GwyAppGraphWindow *window, const GdkRectangle *allocation)
  * windows with size in settings (not in the file), etc. */
 void
 _gwy_restore_window_size(GtkWindow *window,
-                         GwyContainer *container, const gchar *prefix)
+                         GwyDict *container, const gchar *prefix)
 {
     if (!container || !prefix)
         return;
@@ -460,15 +460,15 @@ _gwy_restore_window_size(GtkWindow *window,
 
     gdouble relsize;
     strcpy(key + len, "/relative-size");
-    if (!gwy_container_gis_double_by_name(container, key, &relsize))
+    if (!gwy_dict_gis_double_by_name(container, key, &relsize))
         return;
 
     gint w, h;
     strcpy(key + len, "/width");
-    if (!gwy_container_gis_int32_by_name(container, key, &w))
+    if (!gwy_dict_gis_int32_by_name(container, key, &w))
         return;
     strcpy(key + len, "/height");
-    if (!gwy_container_gis_int32_by_name(container, key, &h))
+    if (!gwy_dict_gis_int32_by_name(container, key, &h))
         return;
 
     if (w <= 0 || h <= 0 || relsize <= 0.0)
@@ -488,9 +488,9 @@ _gwy_restore_window_size(GtkWindow *window,
 }
 
 /**
- * SECTION: app-image-window
+ * SECTION: app-graph-window
  * @title: GwyAppGraphWindow
- * @short_description: Windows for data shown as images
+ * @short_description: Windows for data shown as graphs
  *
  * #GwyAppGraphWindow wraps #GwyGraphWindow and updates it to changes in the file.
  **/
