@@ -1,5 +1,5 @@
 /*
- *  $Id: app-image-window.c 29071 2026-01-02 17:13:37Z yeti-dn $
+ *  $Id: app-image-window.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025-2026 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -82,7 +82,7 @@ static void       zoom_in                  (GwyDataWindow *window);
 static void       zoom_out                 (GwyDataWindow *window);
 static void       realsquare_toggled       (GwyAppImageWindow *window,
                                             GtkCheckMenuItem *item);
-static void       item_changed             (GwyContainer *container,
+static void       item_changed             (GwyDict *container,
                                             GQuark key,
                                             GwyAppImageWindow *window);
 static void       update_color_mapping     (GwyAppImageWindow *window);
@@ -146,7 +146,7 @@ dispose(GObject *object)
     gwy_set_member_object(window, NULL, GWY_TYPE_FIELD, &priv->object,
                           "data-changed", G_CALLBACK(object_changed), &priv->object_changed_id, 0,
                           NULL);
-    gwy_set_member_object(window, NULL, GWY_TYPE_FIELD, &priv->mask,
+    gwy_set_member_object(window, NULL, GWY_TYPE_NIELD, &priv->mask,
                           "data-changed", G_CALLBACK(mask_changed), &priv->mask_changed_id, 0,
                           NULL);
     g_clear_signal_handler(&priv->item_changed_id, priv->file);
@@ -268,7 +268,7 @@ gwy_app_image_window_get_id(GwyAppImageWindow *window)
 }
 
 static void
-item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
+item_changed(GwyDict *container, GQuark key, GwyAppImageWindow *window)
 {
     GwyAppImageWindowPrivate *priv = window->priv;
     GwyFileKeyParsed parsed;
@@ -295,8 +295,8 @@ item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
     GwyDataView *dataview = GWY_DATA_VIEW(gwy_data_window_get_data_view(datawindow));
     if (data_kind == GWY_FILE_IMAGE && piece == GWY_FILE_PIECE_MASK) {
         GwyMenuSensFlags sensflags = GWY_MENU_FLAG_IMAGE_MASK;
-        GwyField *mask = gwy_file_get_image_mask(file, id);
-        gwy_set_member_object(window, mask, GWY_TYPE_FIELD, &priv->object,
+        GwyNield *mask = gwy_file_get_image_mask(file, id);
+        gwy_set_member_object(window, mask, GWY_TYPE_NIELD, &priv->object,
                               "data-changed", G_CALLBACK(mask_changed), &priv->mask_changed_id, 0,
                               NULL);
         gwy_data_view_set_mask(dataview, mask);
@@ -304,13 +304,13 @@ item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
     }
     else if (data_kind == GWY_FILE_IMAGE && piece == GWY_FILE_PIECE_MASK_COLOR) {
         GwyRGBA color;
-        if (!gwy_container_gis_boxed(container, GWY_TYPE_RGBA, key, &color))
+        if (!gwy_dict_gis_boxed(container, GWY_TYPE_RGBA, key, &color))
             gwy_app_settings_get_default_mask_color(&color);
         gwy_data_view_set_mask_color(dataview, &color);
     }
     else if (data_kind == GWY_FILE_IMAGE && (piece == GWY_FILE_PIECE_NONE || piece == GWY_FILE_PIECE_PICTURE)) {
         GwyField *show = NULL, *field = gwy_file_get_image(file, id);
-        gwy_container_gis_object(container, gwy_file_key_image_picture(id), &show);
+        gwy_dict_gis_object(container, gwy_file_key_image_picture(id), &show);
         if (show)
             gwy_data_view_set_field(dataview, show);
         else if (field)
@@ -343,7 +343,7 @@ item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
         }
 
         GObject *object = NULL;
-        gwy_container_gis_object(container, key, &object);
+        gwy_dict_gis_object(container, key, &object);
         if (gwy_set_member_object(window, object, type, &priv->object,
                                   "data-changed", G_CALLBACK(object_changed), &priv->object_changed_id, 0,
                                   NULL))
@@ -353,13 +353,13 @@ item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
     }
     else if (piece == GWY_FILE_PIECE_PICTURE) {
         GwyField *preview = NULL;
-        gwy_container_gis_object(container, key, &preview);
+        gwy_dict_gis_object(container, key, &preview);
         gwy_data_view_set_field(dataview, preview);
     }
     else if (piece == GWY_FILE_PIECE_PALETTE) {
         GwyColorAxis *coloraxis = GWY_COLOR_AXIS(gwy_data_window_get_color_axis(datawindow));
         const gchar *name = NULL;
-        gwy_container_gis_string(container, key, &name);
+        gwy_dict_gis_string(container, key, &name);
         GwyGradient *gradient = name ? gwy_inventory_get_item(gwy_gradients(), name) : NULL;
         /* XXX: This is somewhat inconsistent. When someone sets the name to a non-existent gradient we set NULL here
          * because it does not exist. But if it is created later we do not notice. This would not happen if widgets
@@ -380,7 +380,7 @@ item_changed(GwyContainer *container, GQuark key, GwyAppImageWindow *window)
     }
     else if (piece == GWY_FILE_PIECE_REAL_SQUARE) {
         gboolean realsquare = FALSE;
-        gwy_container_gis_boolean(container, key, &realsquare);
+        gwy_dict_gis_boolean(container, key, &realsquare);
         gwy_data_view_set_real_square(dataview, realsquare);
     }
     else if (piece == GWY_FILE_PIECE_TITLE) {
@@ -415,7 +415,7 @@ update_color_mapping(GwyAppImageWindow *window)
     GwyDataWindow *datawindow = GWY_DATA_WINDOW(window);
     GwyDataView *dataview = GWY_DATA_VIEW(gwy_data_window_get_data_view(datawindow));
     GwyColorAxis *coloraxis = GWY_COLOR_AXIS(gwy_data_window_get_color_axis(datawindow));
-    GwyContainer *container = GWY_CONTAINER(priv->file);
+    GwyDict *container = GWY_DICT(priv->file);
 
     GwyColorMappingType color_mapping = GWY_COLOR_MAPPING_FULL;
     GwyColorAxisMapFunc map_func = NULL;
@@ -423,7 +423,7 @@ update_color_mapping(GwyAppImageWindow *window)
     GwyTicksStyle ticks_style = GWY_TICKS_STYLE_AUTO;
     gboolean show_labels = TRUE;
 
-    if (gwy_container_contains(container, gwy_file_key_image_picture(priv->id))) {
+    if (gwy_dict_contains(container, gwy_file_key_image_picture(priv->id))) {
         ticks_style = GWY_TICKS_STYLE_CENTER;
         show_labels = FALSE;
     }
@@ -480,7 +480,7 @@ initial_setup(GwyAppImageWindow *window)
     GwyDataKind data_kind = priv->data_kind;
     gint id = priv->id;
     GwyFileKeyParsed parsed = { .data_kind = data_kind, .id = id, .piece = GWY_FILE_PIECE_NONE, .suffix = NULL };
-    GwyContainer *container = GWY_CONTAINER(priv->file);
+    GwyDict *container = GWY_DICT(priv->file);
 
     item_changed(container, gwy_file_form_key(&parsed), window);
     for (guint i = 0; i < G_N_ELEMENTS(common_pieces); i++) {
@@ -597,7 +597,7 @@ create_view_menu(GwyAppImageWindow *window, GtkAccelGroup *accel_group)
             .data_kind = data_kind, .id = id, .piece = GWY_FILE_PIECE_REAL_SQUARE, .suffix = NULL
         };
         gboolean realsquare = FALSE;
-        if (gwy_container_gis_boolean(GWY_CONTAINER(priv->file), gwy_file_form_key(&parsed), &realsquare) && realsquare)
+        if (gwy_dict_gis_boolean(GWY_DICT(priv->file), gwy_file_form_key(&parsed), &realsquare) && realsquare)
             gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
         gtk_menu_shell_append(shell, item);
         g_signal_connect_swapped(item, "activate", G_CALLBACK(realsquare_toggled), window);
@@ -672,24 +672,24 @@ realsquare_toggled(GwyAppImageWindow *window, GtkCheckMenuItem *item)
     GQuark key = gwy_file_form_key(&parsed);
     gboolean active = gtk_check_menu_item_get_active(item);
     if (active)
-        gwy_container_set_boolean(GWY_CONTAINER(priv->file), key, TRUE);
+        gwy_dict_set_boolean(GWY_DICT(priv->file), key, TRUE);
     else
-        gwy_container_remove(GWY_CONTAINER(priv->file), key);
+        gwy_dict_remove(GWY_DICT(priv->file), key);
 }
 
 static void
 change_mask_color(GwyAppImageWindow *window)
 {
     GwyAppImageWindowPrivate *priv = window->priv;
-    GwyContainer *data = GWY_CONTAINER(priv->file);
+    GwyDict *data = GWY_DICT(priv->file);
 
     GwyRGBA rgba;
     GQuark quark = gwy_file_key_image_mask_color(priv->id);
-    if (!gwy_container_gis_boxed(data, GWY_TYPE_RGBA, quark, &rgba)) {
+    if (!gwy_dict_gis_boxed(data, GWY_TYPE_RGBA, quark, &rgba)) {
         gwy_app_settings_get_default_mask_color(&rgba);
-        gwy_container_set_boxed(data, GWY_TYPE_RGBA, quark, &rgba);
+        gwy_dict_set_boxed(data, GWY_TYPE_RGBA, quark, &rgba);
     }
-    gwy_mask_color_selector_run(NULL, NULL, NULL, GWY_CONTAINER(data), quark);
+    gwy_mask_color_selector_run(NULL, NULL, NULL, GWY_DICT(data), quark);
 }
 
 static void
@@ -818,7 +818,7 @@ update_window_title(GwyAppImageWindow *window)
     GwyAppImageWindowPrivate *priv = window->priv;
     gchar *basename, *dataname = gwy_file_get_display_title(priv->file, priv->data_kind, priv->id);
     const gchar *filename;
-    if (gwy_container_gis_string(GWY_CONTAINER(priv->file), gwy_file_key_filename(), &filename))
+    if (gwy_dict_gis_string(GWY_DICT(priv->file), gwy_file_key_filename(), &filename))
         basename = g_path_get_basename(filename);
     else
         basename = g_strdup(_("Untitled"));
@@ -842,9 +842,9 @@ maybe_add_xyz_preview(GwyAppImageWindow *window)
 {
     GwyAppImageWindowPrivate *priv = window->priv;
     GwySurface *surface = GWY_SURFACE(priv->object);
-    GwyContainer *container = GWY_CONTAINER(priv->file);
+    GwyDict *container = GWY_DICT(priv->file);
     GQuark key = gwy_file_key_xyz_picture(priv->id);
-    if (gwy_container_contains(container, key)) {
+    if (gwy_dict_contains(container, key)) {
         /* The caller does not do this when calling us. */
         item_changed(container, key, window);
         return;
@@ -854,7 +854,7 @@ maybe_add_xyz_preview(GwyAppImageWindow *window)
     gint res = GWY_ROUND(sqrt(gwy_surface_get_npoints(surface)));
     res = CLAMP(res, 2, 1024);
     gwy_preview_surface_to_field(surface, raster, res, res, GWY_PREVIEW_SURFACE_FILL);
-    gwy_container_pass_object(container, key, raster);
+    gwy_dict_pass_object(container, key, raster);
 }
 
 static void
@@ -872,9 +872,9 @@ update_xyz_preview(GwyAppImageWindow *window)
     GwySurface *surface = GWY_SURFACE(priv->object);
     GQuark key = gwy_file_key_xyz_picture(priv->id);
     GwyField *raster = NULL;
-    if (!gwy_container_gis_object(GWY_CONTAINER(priv->file), key, &raster)) {
+    if (!gwy_dict_gis_object(GWY_DICT(priv->file), key, &raster)) {
         raster = gwy_field_new(1, 1, 1.0, 1.0, TRUE);
-        gwy_container_pass_object(GWY_CONTAINER(priv->file), key, raster);
+        gwy_dict_pass_object(GWY_DICT(priv->file), key, raster);
     }
 
     GwyPreviewSurfaceFlags flags = GWY_PREVIEW_SURFACE_FILL;
@@ -949,7 +949,7 @@ save_size(GwyAppImageWindow *window, const GdkRectangle *allocation)
         GwyFileKeyParsed parsed = {
             .id = priv->id, .data_kind = priv->data_kind, .piece = GWY_FILE_PIECE_VIEW, .suffix = "scale"
         };
-        gwy_container_set_double(GWY_CONTAINER(priv->file), gwy_file_form_key(&parsed), zoom);
+        gwy_dict_set_double(GWY_DICT(priv->file), gwy_file_form_key(&parsed), zoom);
     }
     _gwy_save_widget_screen_size(dataview, allocation, priv->file, priv->data_kind, priv->id, !have_pixels);
 }
@@ -974,16 +974,16 @@ _gwy_save_widget_screen_size(GtkWidget *widget, const GdkRectangle *allocation,
         h = alloc.height;
     }
     gdouble relsize = MAX(w/scw, h/sch);
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
     GwyFileKeyParsed parsed = { .id = id, .data_kind = data_kind, .piece = GWY_FILE_PIECE_VIEW };
 
     parsed.suffix = "relative-size";
-    gwy_container_set_double(container, gwy_file_form_key(&parsed), relsize);
+    gwy_dict_set_double(container, gwy_file_form_key(&parsed), relsize);
     if (absolute_too) {
         parsed.suffix = "width";
-        gwy_container_set_int32(container, gwy_file_form_key(&parsed), w);
+        gwy_dict_set_int32(container, gwy_file_form_key(&parsed), w);
         parsed.suffix = "height";
-        gwy_container_set_int32(container, gwy_file_form_key(&parsed), h);
+        gwy_dict_set_int32(container, gwy_file_form_key(&parsed), h);
     }
 }
 
@@ -993,16 +993,16 @@ restore_zoom(GwyAppImageWindow *window)
     GwyAppImageWindowPrivate *priv = window->priv;
     /* Someone created us with plain g_object_new(). */
     g_return_if_fail(priv->file);
-    GwyContainer *container = GWY_CONTAINER(priv->file);
+    GwyDict *container = GWY_DICT(priv->file);
 
     GwyFileKeyParsed parsed = { .id = priv->id, .data_kind = priv->data_kind, .piece = GWY_FILE_PIECE_VIEW };
     gdouble scale, relsize;
 
     parsed.suffix = "relative-size";
-    if (!gwy_container_gis_double(container, gwy_file_form_key(&parsed), &relsize))
+    if (!gwy_dict_gis_double(container, gwy_file_form_key(&parsed), &relsize))
         return;
     parsed.suffix = "scale";
-    if (!gwy_container_gis_double(container, gwy_file_form_key(&parsed), &scale))
+    if (!gwy_dict_gis_double(container, gwy_file_form_key(&parsed), &scale))
         return;
     if (scale <= 0.0 || relsize <= 0.0)
         return;
