@@ -1,5 +1,5 @@
 /*
- *  $Id: data-browser--gui.c 28984 2025-12-12 16:49:05Z yeti-dn $
+ *  $Id: data-browser--gui.c 29508 2026-02-20 10:39:01Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -540,15 +540,15 @@ render_info(G_GNUC_UNUSED GtkTreeViewColumn *column,
     PieceInfo *info;
     gtk_tree_model_get(model, iter, 0, &info, -1);
     g_return_if_fail(info && info->proxy);
-    GwyContainer *container = GWY_CONTAINER(info->proxy->file);
+    GwyDict *container = GWY_DICT(info->proxy->file);
     GwyDataKind data_kind = info->parsed.data_kind;
     gint id = info->parsed.id;
     gchar *text = NULL;
 
     /* XXX: This could be abstracted to some render-info function and we would not need any ifs then. */
     if (data_kind == GWY_FILE_IMAGE) {
-        gboolean has_mask = gwy_container_contains(container, gwy_file_key_image_mask(id));
-        gboolean has_show = gwy_container_contains(container, gwy_file_key_image_picture(id));
+        gboolean has_mask = gwy_dict_contains(container, gwy_file_key_image_mask(id));
+        gboolean has_show = gwy_dict_contains(container, gwy_file_key_image_picture(id));
         text = g_strdup_printf("%s%s",
                                has_mask ? "M" : "",
                                has_show ? "P" : "");
@@ -854,6 +854,9 @@ extract_object_as_new(DataBrowser *browser)
     g_assert(info && info->parsed.data_kind == data_kind && info->proxy == proxy);
     GwyFile *newfile = gwy_file_new();
     gwy_data_browser_add(newfile);
+    // XXX: This is kind of stupid. A better way to do this would be to create a file which already has the data
+    // because then it can work like loading a file from disk.
+    gwy_file_set_visible(newfile, data_kind, info->parsed.id, TRUE);
     gwy_data_browser_copy_data(proxy->file, data_kind, info->parsed.id, newfile);
     g_object_unref(newfile);
 }
@@ -973,7 +976,7 @@ _gwy_data_browser_update_filename(void)
 
     FileProxy *proxy = browser->current_file;
     const gchar *filename;
-    if (gwy_container_gis_string(GWY_CONTAINER(proxy->file), gwy_file_key_filename(), &filename)) {
+    if (gwy_dict_gis_string(GWY_DICT(proxy->file), gwy_file_key_filename(), &filename)) {
         gchar *basename = g_path_get_basename(filename);
         gtk_label_set_text(GTK_LABEL(gui->filename), basename);
         g_free(basename);
@@ -1023,7 +1026,7 @@ create_message_log_window(FileProxy *proxy)
 {
     const gchar *filename;
     gchar *title;
-    if (gwy_container_gis_string(GWY_CONTAINER(proxy->file), gwy_file_key_filename(), &filename)) {
+    if (gwy_dict_gis_string(GWY_DICT(proxy->file), gwy_file_key_filename(), &filename)) {
         gchar *bname = g_path_get_basename(filename);
         title = g_strdup_printf(_("Messages for %s"), bname);
         g_free(bname);
@@ -1234,7 +1237,7 @@ void
 _gwy_data_browser_update_sensitivity_flags(GwyDataKind data_kind, const PieceInfo *info)
 {
     GwyFile *file = info ? info->proxy->file : NULL;
-    GwyContainer *container = file ? GWY_CONTAINER(file) : NULL;
+    GwyDict *container = file ? GWY_DICT(file) : NULL;
     gint id = info ? info->parsed.id : -1;
     GwyMenuSensFlags flags = 0, flag_mask = 0;
 
@@ -1244,10 +1247,11 @@ _gwy_data_browser_update_sensitivity_flags(GwyDataKind data_kind, const PieceInf
             flags |= GWY_MENU_FLAG_IMAGE;
 
             GwyField *field;
-            if (gwy_container_gis_object(container, gwy_file_key_image_picture(id), &field) && GWY_IS_FIELD(field))
+            if (gwy_dict_gis_object(container, gwy_file_key_image_picture(id), &field) && GWY_IS_FIELD(field))
                 flags |= GWY_MENU_FLAG_IMAGE_SHOW;
 
-            if ((field = gwy_file_get_image_mask(file, id)) && GWY_IS_FIELD(field))
+            GwyNield *nield;
+            if ((nield = gwy_file_get_image_mask(file, id)) && GWY_IS_NIELD(nield))
                 flags |= GWY_MENU_FLAG_IMAGE_MASK;
         }
     }
