@@ -1,5 +1,5 @@
 /*
- *  $Id: data-browser-aux.c 28698 2025-10-21 15:53:23Z yeti-dn $
+ *  $Id: data-browser-aux.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -27,7 +27,7 @@
 
 #include "libgwyddion/macros.h"
 #include "libgwyddion/utils.h"
-#include "libgwyddion/gwycontainer.h"
+#include "libgwyddion/dict.h"
 #include "libgwyui/gwyui.h"
 
 #include "libgwyapp/gwyapp.h"
@@ -88,7 +88,7 @@ _gwy_app_data_merge_copy_1(GQuark quark,
             if (!g_hash_table_lookup_extended(map[data_kind], idp, NULL, &id2p))
                 goto fail;
             quark = _gwy_app_get_page_data_key_for_id(GPOINTER_TO_INT(id2p), data_kind);
-            gwy_container_set_object((GwyContainer*)map[GWY_NPAGES], quark, g_value_get_object(gvalue));
+            gwy_dict_set_object((GwyDict*)map[GWY_NPAGES], quark, g_value_get_object(gvalue));
             return;
         }
     }
@@ -105,7 +105,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
                            gpointer user_data)
 {
     GHashTable **map = (GHashTable**)user_data;
-    GwyContainer *dest;
+    GwyDict *dest;
     const gchar *strkey;
     GwyAppKeyType type;
     gpointer idp, id2p;
@@ -136,7 +136,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
         goto fail;
 
     idp = GINT_TO_POINTER(id);
-    dest = (GwyContainer*)map[GWY_NPAGES];
+    dest = (GwyDict*)map[GWY_NPAGES];
 
     /* Visibilty */
     for (i = 0; i < G_N_ELEMENTS(page_data_keys); i++) {
@@ -148,7 +148,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
                 quark = _gwy_app_get_page_data_key_for_id(GPOINTER_TO_INT(id2p), data_kind);
                 g_snprintf(buf, sizeof(buf), "%s/visible", g_quark_to_string(quark));
                 if (g_value_get_boolean(gvalue))
-                    gwy_container_set_boolean_by_name(dest, buf, TRUE);
+                    gwy_dict_set_boolean_by_name(dest, buf, TRUE);
             }
             return;
         }
@@ -160,7 +160,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         quark = gwy_app_get_mask_key_for_id(id2);
-        gwy_container_set_object(dest, quark, g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, quark, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_SHOW:
@@ -168,7 +168,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         quark = gwy_file_key_image_picture(id2);
-        gwy_container_set_object(dest, quark, g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, quark, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_SPS_REF:
@@ -181,7 +181,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
         if (g_hash_table_lookup_extended(map[GWY_PAGE_SPECTRA], idp, NULL, &id2p)) {
             g_snprintf(buf, sizeof(buf), "/%d/data/sps-is", id2);
             id2 = GPOINTER_TO_INT(id2p);
-            gwy_container_set_int32_by_name(dest, buf, id2);
+            gwy_dict_set_int32_by_name(dest, buf, id2);
         }
         break;
 
@@ -189,14 +189,14 @@ _gwy_app_data_merge_copy_2(GQuark quark,
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_CHANNELS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_data_title_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_data_title_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_PALETTE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_CHANNELS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_data_palette_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_data_palette_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_MASK_COLOR:
@@ -204,7 +204,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/mask%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_SELECT:
@@ -212,14 +212,14 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/data/select%s", id2, strkey + len);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_RANGE_TYPE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_CHANNELS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_enum(dest, gwy_file_key_image_color_mapping(id2), g_value_get_int(gvalue));
+        gwy_dict_set_enum(dest, gwy_file_key_image_color_mapping(id2), g_value_get_int(gvalue));
         break;
 
         case KEY_IS_RANGE:
@@ -227,7 +227,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/base%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_REAL_SQUARE:
@@ -235,14 +235,14 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/data/realsquare", id2);
-        gwy_container_set_boolean_by_name(dest, buf, g_value_get_boolean(gvalue));
+        gwy_dict_set_boolean_by_name(dest, buf, g_value_get_boolean(gvalue));
         break;
 
         case KEY_IS_CHANNEL_META:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_CHANNELS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_data_meta_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_data_meta_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_CHANNEL_LOG:
@@ -250,7 +250,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/data/log", id2);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_DATA_VIEW_SCALE:
@@ -258,7 +258,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/data%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_GL_SETUP:
@@ -266,7 +266,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/3d/setup", id2);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_GL_LABEL:
@@ -274,7 +274,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/3d%s", id2, strkey + len);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_GL_PALETTE:
@@ -282,7 +282,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/3d/palette", id2);
-        gwy_container_set_string_by_name(dest, buf, g_value_dup_string(gvalue));
+        gwy_dict_set_string_by_name(dest, buf, g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_GL_MATERIAL:
@@ -290,7 +290,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/3d/material", id2);
-        gwy_container_set_string_by_name(dest, buf, g_value_dup_string(gvalue));
+        gwy_dict_set_string_by_name(dest, buf, g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_GL_VIEW_SCALE:
@@ -298,7 +298,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_GL_VIEW_SIZE:
@@ -306,7 +306,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), "/%d/%s", id2, strkey + len);
-        gwy_container_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
+        gwy_dict_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
         break;
 
         case KEY_IS_GRAPH_VIEW_SCALE:
@@ -314,7 +314,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), OLD_GRAPH_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_GRAPH_VIEW_SIZE:
@@ -322,35 +322,35 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), OLD_GRAPH_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
+        gwy_dict_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
         break;
 
         case KEY_IS_BRICK_TITLE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_VOLUMES], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_brick_title_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_brick_title_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_BRICK_PREVIEW:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_VOLUMES], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_brick_preview_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_brick_preview_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_BRICK_PREVIEW_PALETTE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_VOLUMES], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_brick_palette_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_brick_palette_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_BRICK_META:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_VOLUMES], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_brick_meta_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_brick_meta_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_BRICK_LOG:
@@ -358,7 +358,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), BRICK_PREFIX "/%d/log", id2);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_BRICK_VIEW_SCALE:
@@ -366,35 +366,35 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), BRICK_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_SURFACE_TITLE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_XYZS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_surface_title_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_surface_title_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_SURFACE_PREVIEW:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_XYZS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_surface_preview_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_surface_preview_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_SURFACE_PREVIEW_PALETTE:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_XYZS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_surface_palette_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_surface_palette_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_SURFACE_META:
         if (!g_hash_table_lookup_extended(map[GWY_PAGE_XYZS], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_surface_meta_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_surface_meta_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_SURFACE_LOG:
@@ -402,7 +402,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), SURFACE_PREFIX "/%d/log", id2);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_SURFACE_VIEW_SCALE:
@@ -410,7 +410,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), SURFACE_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         case KEY_IS_SURFACE_VIEW_SIZE:
@@ -418,28 +418,28 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), SURFACE_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
+        gwy_dict_set_int32_by_name(dest, buf, g_value_get_int(gvalue));
         break;
 
         case KEY_IS_LAWN_TITLE:
         if (!g_hash_table_lookup_extended(map[GWY_FILE_CMAP], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_lawn_title_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_lawn_title_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_LAWN_PREVIEW:
         if (!g_hash_table_lookup_extended(map[GWY_FILE_CMAP], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_lawn_preview_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_lawn_preview_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_LAWN_PREVIEW_PALETTE:
         if (!g_hash_table_lookup_extended(map[GWY_FILE_CMAP], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_string(dest, gwy_app_get_lawn_palette_key_for_id(id2), g_value_dup_string(gvalue));
+        gwy_dict_set_string(dest, gwy_app_get_lawn_palette_key_for_id(id2), g_value_dup_string(gvalue));
         break;
 
         case KEY_IS_LAWN_REAL_SQUARE:
@@ -447,14 +447,14 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), LAWN_PREFIX "/%d/preview/realsquare", id2);
-        gwy_container_set_boolean_by_name(dest, buf, g_value_get_boolean(gvalue));
+        gwy_dict_set_boolean_by_name(dest, buf, g_value_get_boolean(gvalue));
         break;
 
         case KEY_IS_LAWN_META:
         if (!g_hash_table_lookup_extended(map[GWY_FILE_CMAP], idp, NULL, &id2p))
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
-        gwy_container_set_object(dest, gwy_app_get_lawn_meta_key_for_id(id2), g_value_get_object(gvalue));
+        gwy_dict_set_object(dest, gwy_app_get_lawn_meta_key_for_id(id2), g_value_get_object(gvalue));
         break;
 
         case KEY_IS_LAWN_LOG:
@@ -462,7 +462,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), LAWN_PREFIX "/%d/log", id2);
-        gwy_container_set_object_by_name(dest, buf, g_value_get_object(gvalue));
+        gwy_dict_set_object_by_name(dest, buf, g_value_get_object(gvalue));
         break;
 
         case KEY_IS_LAWN_VIEW_SCALE:
@@ -470,7 +470,7 @@ _gwy_app_data_merge_copy_2(GQuark quark,
             goto fail;
         id2 = GPOINTER_TO_INT(id2p);
         g_snprintf(buf, sizeof(buf), LAWN_PREFIX "/%d%s", id2, strkey + len);
-        gwy_container_set_double_by_name(dest, buf, g_value_get_double(gvalue));
+        gwy_dict_set_double_by_name(dest, buf, g_value_get_double(gvalue));
         break;
 
         default:
@@ -489,22 +489,22 @@ fail:
 #if 0
 /* Preserve for reference. Make sure 1.x titles are converted upon import. */
 gchar*
-_gwy_app_figure_out_image_title(GwyContainer *data, gint channel)
+_gwy_app_figure_out_image_title(GwyDict *data, gint channel)
 {
     const gchar *title = NULL;
     gchar buf[32];
 
-    g_return_val_if_fail(GWY_IS_CONTAINER(data), NULL);
+    g_return_val_if_fail(GWY_IS_DICT(data), NULL);
     g_return_val_if_fail(channel >= 0, NULL);
 
-    gwy_container_gis_string(data, gwy_app_get_data_title_key_for_id(channel), &title);
+    gwy_dict_gis_string(data, gwy_app_get_data_title_key_for_id(channel), &title);
     if (!title) {
         g_snprintf(buf, sizeof(buf), "/%d/data/untitled", channel);
-        gwy_container_gis_string_by_name(data, buf, &title);
+        gwy_dict_gis_string_by_name(data, buf, &title);
     }
     /* Support 1.x titles */
     if (!title)
-        gwy_container_gis_string_by_name(data, "/filename/title", &title);
+        gwy_dict_gis_string_by_name(data, "/filename/title", &title);
 
     if (title)
         return g_strdup(title);
@@ -518,7 +518,7 @@ void
 _gwy_app_update_gl_window_title(GwyGLWindow *glwindow, gint id)
 {
     GtkWidget *glview;
-    GwyContainer *data;
+    GwyDict *data;
     gchar *title, *ctitle;
 
     glview = gwy_gl_window_get_gl_view(glwindow);
