@@ -1,5 +1,5 @@
 /*
- *  $Id: data-browser.c 29094 2026-01-06 17:53:17Z yeti-dn $
+ *  $Id: data-browser.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025-2026 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -168,8 +168,8 @@ connect_piece(PieceInfo *info, gdouble timestamp)
         info->key = gwy_file_form_key(&info->parsed);
 
     FileProxy *proxy = info->proxy;
-    GwyContainer *container = GWY_CONTAINER(proxy->file);
-    if (!gwy_container_gis_object(container, info->key, &info->object)) {
+    GwyDict *container = GWY_DICT(proxy->file);
+    if (!gwy_dict_gis_object(container, info->key, &info->object)) {
         /* Main objects must exist. Other things are optional. */
         if (info->parsed.piece == GWY_FILE_PIECE_NONE)
             g_critical("Connecting to non-existent object %s.", g_quark_to_string(info->key));
@@ -388,10 +388,10 @@ file_item_changed(GwyFile *file, GQuark key, FileProxy *proxy)
         return;
     }
 
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
     GwyFilePiece piece = parsed.piece;
     gint id = parsed.id;
-    gboolean item_present = gwy_container_contains(container, key);
+    gboolean item_present = gwy_dict_contains(container, key);
     /* Info exists and item is present: Item was replaced with a different object. We could check if the object
      * really differs or someone is pulling a fast one. But generally, disconnect, update object, reconnect. Update
      * all kinds of stuff (watchers). Windows will update themselves? Tools need updating.
@@ -504,9 +504,9 @@ gwy_data_browser_add(GwyFile *file)
     g_return_if_fail(gwy_file_get_id(file) == GWY_FILE_ID_NONE);
     g_object_ref(file);
 
-    GwyContainer *container = GWY_CONTAINER(file);
-    if (gwy_container_is_being_constructed(container))
-        gwy_container_finish_construction(container);
+    GwyDict *container = GWY_DICT(file);
+    if (gwy_dict_is_being_constructed(container))
+        gwy_dict_finish_construction(container);
 
     gint id;
     ensure_browser();
@@ -627,10 +627,10 @@ gwy_data_browser_copy_data(GwyFile *source,
     if (gwy_log_get_enabled()) {
         GwyFileKeyParsed parsed = { .id = id, .data_kind = data_kind, .piece = GWY_FILE_PIECE_LOG, .suffix = NULL };
         GwyStringList *datalog;
-        if (gwy_container_gis_object(GWY_CONTAINER(source), gwy_file_form_key(&parsed), &datalog)) {
+        if (gwy_dict_gis_object(GWY_DICT(source), gwy_file_form_key(&parsed), &datalog)) {
             datalog = gwy_string_list_copy(datalog);
             parsed.id = newid;
-            gwy_container_pass_object(GWY_CONTAINER(dest), gwy_file_form_key(&parsed), datalog);
+            gwy_dict_pass_object(GWY_DICT(dest), gwy_file_form_key(&parsed), datalog);
         }
         /* This will create a new log if needed. Do not pass oldid here because that requests forking the log and
          * we have already done it here.
@@ -674,41 +674,41 @@ gwy_data_browser_find_object(GObject *object,
 }
 
 static void
-ensure_volume_preview(GwyContainer *container, gint id)
+ensure_volume_preview(GwyDict *container, gint id)
 {
     GQuark key = gwy_file_key_volume_picture(id);
     GwyField *preview;
-    if (gwy_container_gis_object(container, key, &preview))
+    if (gwy_dict_gis_object(container, key, &preview))
         return;
 
     GwyBrick *brick = gwy_file_get_volume(GWY_FILE(container), id);
-    gwy_container_pass_object(container, key, _gwy_app_create_brick_preview_field(brick));
+    gwy_dict_pass_object(container, key, _gwy_app_create_brick_preview_field(brick));
 }
 
 static void
-ensure_xyz_preview(GwyContainer *container, gint id)
+ensure_xyz_preview(GwyDict *container, gint id)
 {
     GQuark key = gwy_file_key_xyz_picture(id);
     GwyField *preview;
-    if (gwy_container_gis_object(container, key, &preview))
+    if (gwy_dict_gis_object(container, key, &preview))
         return;
 
     GwySurface *surface = gwy_file_get_xyz(GWY_FILE(container), id);
     GwyField *raster = gwy_field_new(1, 1, 1.0, 1.0, FALSE);
     gwy_preview_surface_to_field(surface, raster, SURFACE_PREVIEW_MAX_SIZE, SURFACE_PREVIEW_MAX_SIZE, 0);
-    gwy_container_pass_object(container, key, raster);
+    gwy_dict_pass_object(container, key, raster);
 }
 
 static void
-ensure_cmap_preview(GwyContainer *container, gint id)
+ensure_cmap_preview(GwyDict *container, gint id)
 {
     GQuark key = gwy_file_key_cmap_picture(id);
     GwyField *preview;
-    if (gwy_container_gis_object(container, key, &preview))
+    if (gwy_dict_gis_object(container, key, &preview))
         return;
 
     GwyLawn *lawn = gwy_file_get_cmap(GWY_FILE(container), id);
-    gwy_container_pass_object(container, key, _gwy_app_create_lawn_preview_field(lawn));
+    gwy_dict_pass_object(container, key, _gwy_app_create_lawn_preview_field(lawn));
 }
 
 static FileProxy*
@@ -719,7 +719,7 @@ embrace_file(GwyFile *file)
     proxy->qpieces = g_hash_table_new(g_direct_hash, g_direct_equal);
 
     gdouble timestamp = get_timestamp_now();
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
 
     for (guint data_kind = 0; data_kind < GWY_FILE_N_KINDS; data_kind++) {
         if (browser.gui_enabled) {
@@ -1377,7 +1377,7 @@ gwy_data_browser_get_current(GwyAppWhat what,
         return;
 
     FileProxy *proxy = browser.current_file;
-    GwyContainer *container = proxy ? GWY_CONTAINER(proxy->file) : NULL;
+    GwyDict *container = proxy ? GWY_DICT(proxy->file) : NULL;
     va_list ap;
 
     va_start(ap, what);
@@ -1401,7 +1401,7 @@ gwy_data_browser_get_current(GwyAppWhat what,
                     GObject **target = va_arg(ap, GObject**);
                     *target = NULL;
                     if (key)
-                        gwy_container_gis_object(container, key, target);
+                        gwy_dict_gis_object(container, key, target);
                 }
                 found = TRUE;
             }
@@ -1409,11 +1409,11 @@ gwy_data_browser_get_current(GwyAppWhat what,
         if (found)
             continue;
 
-        if (what == GWY_APP_CONTAINER) {
+        if (what == GWY_APP_FILE) {
             GwyFile **target = va_arg(ap, GwyFile**);
             *target = (proxy ? proxy->file : NULL);
         }
-        else if (what == GWY_APP_CONTAINER_ID) {
+        else if (what == GWY_APP_FILE_ID) {
             gint *target = va_arg(ap, gint*);
             *target = (proxy ? gwy_file_get_id(proxy->file) : GWY_FILE_ID_NONE);
         }
