@@ -1,5 +1,5 @@
 /*
- *  $Id: data-chooser.c 29075 2026-01-02 17:49:31Z yeti-dn $
+ *  $Id: data-chooser.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -20,7 +20,7 @@
 #include <gtk/gtk.h>
 
 #include "libgwyddion/macros.h"
-#include "libgwyddion/gwycontainer.h"
+#include "libgwyddion/dict.h"
 #include "libgwyui/utils.h"
 
 #include "libgwyapp/data-browser.h"
@@ -251,7 +251,7 @@ gwy_data_chooser_init(GwyDataChooser *chooser)
     GtkTreeIter iter;
     Proxy *proxy;
 
-    chooser->store = gtk_list_store_new(MODEL_NCOLUMNS, GWY_TYPE_CONTAINER, G_TYPE_INT, G_TYPE_POINTER);
+    chooser->store = gtk_list_store_new(MODEL_NCOLUMNS, GWY_TYPE_DICT, G_TYPE_INT, G_TYPE_POINTER);
     chooser->filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(chooser->store), NULL);
     filter = GTK_TREE_MODEL_FILTER(chooser->filter);
     gtk_tree_model_filter_set_visible_func(filter, gwy_data_chooser_is_visible, chooser, NULL);
@@ -945,7 +945,7 @@ gwy_data_chooser_get_data_kind(GwyDataChooser *chooser)
  *     GQuark quark;
  *     <!-- Hello, gtk-doc! -->
  *     quark = gwy_app_get_data_key_for_id(id);
- *     field = gwy_container_get_object(data, quark);
+ *     field = gwy_dict_get_object(data, quark);
  *     model = GWY_FIELD(user_data);
  *     return !gwy_field_is_incompatible(field, model,
  *                                                GWY_DATA_MISMATCH_RES
