@@ -1,5 +1,5 @@
 /*
- *  $Id: file-ops.c 28818 2025-11-06 15:52:22Z yeti-dn $
+ *  $Id: file-ops.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -295,12 +295,12 @@ static void
 set_filename(GwyFile *file, const gchar *filename)
 {
     GQuark quark = gwy_file_key_filename();
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
 
-    if (gwy_container_contains(container, quark))
+    if (gwy_dict_contains(container, quark))
         return;
 
-    gwy_container_set_const_string(container, quark, (const guchar*)filename);
+    gwy_dict_set_const_string(container, quark, (const guchar*)filename);
 }
 
 static void
@@ -425,7 +425,7 @@ gwy_app_file_write(GwyFile *data,
 
     /* If the @data is the current container, make thumbnail from the current channel.
      * FIXME: Needs new data browser functions to do this less hackishly. */
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &container,
+    gwy_data_browser_get_current(GWY_APP_FILE, &container,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     if (data != container)
@@ -518,7 +518,7 @@ gwy_app_file_save(void)
     GwyFileOperationType saveops;
     GwyFile *data;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     g_return_if_fail(data);
     const gchar *name = gwy_file_get_format_name(data);
     const gchar *filename_sys = gwy_file_get_filename_sys(data);
@@ -548,7 +548,7 @@ gwy_app_file_save_as(void)
     gint response;
     GwyFile *data;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     g_return_if_fail(data);
     const gchar *old_filename_sys = gwy_file_get_filename_sys(data);
 
@@ -593,7 +593,7 @@ gwy_app_file_close(void)
 {
     GwyFile *current_data;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &current_data, NULL);
+    gwy_data_browser_get_current(GWY_APP_FILE, &current_data, NULL);
     g_return_if_fail(current_data);
     gwy_data_browser_remove(current_data);
 }
