@@ -1,6 +1,6 @@
 #pragma once
 /*
- *  $Id: file.h 28779 2025-11-04 17:00:29Z yeti-dn $
+ *  $Id: file.h 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -19,7 +19,7 @@
 #ifndef __GWYAPP_FILE_H__
 #define __GWYAPP_FILE_H__
 
-#include <libgwyddion/gwycontainer.h>
+#include <libgwyddion/dict.h>
 #include <libgwyddion/field.h>
 #include <libgwyddion/brick.h>
 #include <libgwyddion/spectra.h>
@@ -104,12 +104,12 @@ typedef struct _GwyFileClass        GwyFileClass;
 typedef struct _GwyFilePrivate      GwyFilePrivate;
 
 struct _GwyFile {
-    GwyContainer parent_instance;
+    GwyDict parent_instance;
     GwyFilePrivate *priv;
 };
 
 struct _GwyFileClass {
-    GwyContainerClass parent_class;
+    GwyDictClass parent_class;
 
     /*< private >*/
     void (*reserved1)(void);
@@ -180,11 +180,11 @@ GwyField*           gwy_file_get_image          (GwyFile *file,
                                                  gint id);
 void                gwy_file_set_image_mask     (GwyFile *file,
                                                  gint id,
-                                                 GwyField *field);
+                                                 GwyNield *mask);
 void                gwy_file_pass_image_mask    (GwyFile *file,
                                                  gint id,
-                                                 GwyField *field);
-GwyField*           gwy_file_get_image_mask     (GwyFile *file,
+                                                 GwyNield *mask);
+GwyNield*           gwy_file_get_image_mask     (GwyFile *file,
                                                  gint id);
 void                gwy_file_set_graph          (GwyFile *file,
                                                  gint id,
@@ -254,8 +254,8 @@ gboolean            gwy_file_get_visible        (GwyFile *file,
 void                gwy_file_pass_meta          (GwyFile *file,
                                                  GwyDataKind data_kind,
                                                  gint id,
-                                                 GwyContainer *meta);
-GwyContainer*       gwy_file_get_meta           (GwyFile *file,
+                                                 GwyDict *meta);
+GwyDict*       gwy_file_get_meta           (GwyFile *file,
                                                  GwyDataKind data_kind,
                                                  gint id);
 void                gwy_file_set_palette        (GwyFile *file,
