@@ -1,5 +1,5 @@
 /*
- *  $Id: filelist.c 28818 2025-11-06 15:52:22Z yeti-dn $
+ *  $Id: filelist.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -536,7 +536,7 @@ cell_renderer_thumb(G_GNUC_UNUSED GtkTreeViewColumn *column,
 static GtkWidget*
 filter_construct(Controls *controls)
 {
-    GwyContainer *settings;
+    GwyDict *settings;
     GtkWidget *hbox, *label, *entry, *check, *button, *image;
     const gchar *glob;
 
@@ -549,7 +549,7 @@ filter_construct(Controls *controls)
 
     if (!controls->glob)
         controls->glob = g_string_new(NULL);
-    if (gwy_container_gis_string_by_name(settings, "/app/file/recent/glob", &glob))
+    if (gwy_dict_gis_string_by_name(settings, "/app/file/recent/glob", &glob))
         g_string_assign(controls->glob, glob);
 
     entry = gtk_entry_new();
@@ -572,7 +572,7 @@ filter_construct(Controls *controls)
 #else
     controls->casesens = TRUE;
 #endif
-    gwy_container_gis_boolean_by_name(settings, "/app/file/recent/case-sensitive", &controls->casesens);
+    gwy_dict_gis_boolean_by_name(settings, "/app/file/recent/case-sensitive", &controls->casesens);
 
     check = gtk_check_button_new_with_mnemonic(_("Case _sensitive"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), controls->casesens);
@@ -595,12 +595,12 @@ static void
 filter_apply(GtkEntry *entry, Controls *controls)
 {
     GPatternSpec *oldpattern;
-    GwyContainer *settings;
+    GwyDict *settings;
     gchar *s, *t;
 
     settings = gwy_app_settings_get();
     g_string_assign(controls->glob, gtk_entry_get_text(entry));
-    gwy_container_set_string_by_name(settings, "/app/file/recent/glob", g_strdup(controls->glob->str));
+    gwy_dict_set_string_by_name(settings, "/app/file/recent/glob", g_strdup(controls->glob->str));
 
     oldpattern = controls->pattern;
 
@@ -636,11 +636,11 @@ static void
 filter_case_changed(GtkToggleButton *check,
                     Controls *controls)
 {
-    GwyContainer *settings;
+    GwyDict *settings;
 
     settings = gwy_app_settings_get();
     controls->casesens = gtk_toggle_button_get_active(check);
-    gwy_container_set_boolean_by_name(settings, "/app/file/recent/case-sensitive", controls->casesens);
+    gwy_dict_set_boolean_by_name(settings, "/app/file/recent/case-sensitive", controls->casesens);
 
     filter_apply(GTK_ENTRY(controls->filter_glob), controls);
 }
@@ -825,7 +825,7 @@ gwy_app_recent_file_list_update(GwyFile *data,
 {
     gboolean free_utf8 = FALSE, free_sys = FALSE;
 
-    g_return_if_fail(!data || GWY_IS_CONTAINER(data));
+    g_return_if_fail(!data || GWY_IS_DICT(data));
 
     if (!gcontrols.store)
         return;
@@ -1186,7 +1186,7 @@ update_thumbnail(GwyRecentFile *rf,
     GPtrArray *option_keys, *option_values;
     guint i;
 
-    g_return_if_fail(GWY_CONTAINER(data));
+    g_return_if_fail(GWY_DICT(data));
 
     for (i = 0; i < G_N_ELEMENTS(ids); i++)
         ids[i] = -1;
@@ -1285,8 +1285,8 @@ update_thumbnail(GwyRecentFile *rf,
     else if (data_kind == GWY_FILE_XYZ) {
         surface = gwy_file_get_xyz(data, ids[data_kind]);
         g_return_if_fail(GWY_IS_SURFACE(surface));
-        gwy_surface_get_xrange(surface, &xmin, &xreal);
-        gwy_surface_get_yrange(surface, &ymin, &yreal);
+        gwy_surface_xrange(surface, &xmin, &xreal);
+        gwy_surface_yrange(surface, &ymin, &yreal);
         xreal -= xmin;
         yreal -= ymin;
         siunit = gwy_surface_get_unit_xy(surface);
