@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyappfilechooser.c 29059 2026-01-02 14:27:52Z yeti-dn $
+ *  $Id: gwyappfilechooser.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -308,7 +308,7 @@ gwy_app_file_chooser_select_type(GwyAppFileChooser *chooser)
     if (!gtk_tree_model_get_iter_first(model, &first))
         return;
 
-    ok = gwy_container_gis_string(gwy_app_settings_get(), chooser->type_key, &name);
+    ok = gwy_dict_gis_string(gwy_app_settings_get(), chooser->type_key, &name);
     if (!ok) {
         gtk_tree_selection_select_iter(selection, &first);
         return;
@@ -346,11 +346,11 @@ _gwy_app_file_chooser_get_selected_type(GwyAppFileChooser *chooser)
     gtk_tree_model_get(model, &iter, COLUMN_FILETYPE, &s, -1);
     if (!*s) {
         g_free(s);
-        gwy_container_remove(gwy_app_settings_get(), chooser->type_key);
+        gwy_dict_remove(gwy_app_settings_get(), chooser->type_key);
         s = NULL;
     }
     else
-        gwy_container_set_string(gwy_app_settings_get(), chooser->type_key, g_strdup(s));
+        gwy_dict_set_string(gwy_app_settings_get(), chooser->type_key, g_strdup(s));
 
     return s;
 }
@@ -414,7 +414,7 @@ gwy_app_file_chooser_expanded(GwyAppFileChooser *chooser,
     gchar *key;
 
     key = g_strconcat(chooser->prefix, "/expanded", NULL);
-    gwy_container_set_boolean_by_name(gwy_app_settings_get(), key, gtk_expander_get_expanded(expander));
+    gwy_dict_set_boolean_by_name(gwy_app_settings_get(), key, gtk_expander_get_expanded(expander));
     g_free(key);
 }
 
@@ -465,7 +465,7 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
     gtk_expander_set_use_underline(GTK_EXPANDER(chooser->expander), TRUE);
     gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(chooser), chooser->expander);
     key = g_strconcat(chooser->prefix, "/expanded", NULL);
-    gwy_container_gis_boolean_by_name(gwy_app_settings_get(), key, &expanded);
+    gwy_dict_gis_boolean_by_name(gwy_app_settings_get(), key, &expanded);
     g_free(key);
     gtk_expander_set_expanded(GTK_EXPANDER(chooser->expander), expanded);
     g_signal_connect_swapped(chooser->expander, "notify::expanded",
@@ -536,7 +536,7 @@ gwy_app_file_chooser_add_type_list(GwyAppFileChooser *chooser)
 static void
 construct_loadable_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GtkToggleButton *toggle;
     gchar *key;
 
@@ -544,7 +544,7 @@ construct_loadable_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
     chooser->loadable_check = gtk_check_button_new_with_mnemonic(_("Show only loadable files"));
     toggle = GTK_TOGGLE_BUTTON(chooser->loadable_check);
     key = g_strconcat(chooser->prefix, "/filter", NULL);
-    gwy_container_gis_boolean_by_name(settings, key, &chooser->only_loadable);
+    gwy_dict_gis_boolean_by_name(settings, key, &chooser->only_loadable);
     g_free(key);
     gtk_toggle_button_set_active(toggle, chooser->only_loadable);
     gtk_box_pack_start(vbox, chooser->loadable_check, FALSE, FALSE, 0);
@@ -554,7 +554,7 @@ construct_loadable_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
 static void
 construct_glob_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GtkWidget *hbox, *label, *entry, *check, *button;
     const gchar *glob;
     gchar *key;
@@ -569,7 +569,7 @@ construct_glob_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
         chooser->glob = g_string_new(NULL);
 
     key = g_strconcat(chooser->prefix, "/glob/pattern", NULL);
-    if (gwy_container_gis_string_by_name(settings, key, &glob))
+    if (gwy_dict_gis_string_by_name(settings, key, &glob))
         g_string_assign(chooser->glob, glob);
     g_free(key);
 
@@ -594,7 +594,7 @@ construct_glob_filter(GwyAppFileChooser *chooser, GtkBox *vbox)
     chooser->glob_casesens = TRUE;
 #endif
     key = g_strconcat(chooser->prefix, "/glob/case-sensitive", NULL);
-    gwy_container_gis_boolean_by_name(settings, key, &chooser->glob_casesens);
+    gwy_dict_gis_boolean_by_name(settings, key, &chooser->glob_casesens);
     g_free(key);
 
     check = gtk_check_button_new_with_mnemonic(_("Case _sensitive"));
@@ -617,13 +617,13 @@ glob_entry_clear(G_GNUC_UNUSED GtkWidget *button, GwyAppFileChooser *chooser)
 static void
 glob_entry_updated(GtkEntry *entry, GwyAppFileChooser *chooser)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GPatternSpec *oldpattern;
     gchar *key, *s, *t;
 
     g_string_assign(chooser->glob, gtk_entry_get_text(entry));
     key = g_strconcat(chooser->prefix, "/glob/pattern", NULL);
-    gwy_container_set_const_string_by_name(settings, key, chooser->glob->str);
+    gwy_dict_set_const_string_by_name(settings, key, chooser->glob->str);
     g_free(key);
 
     oldpattern = chooser->pattern;
@@ -656,12 +656,12 @@ glob_entry_updated(GtkEntry *entry, GwyAppFileChooser *chooser)
 static void
 glob_case_changed(GtkToggleButton *check, GwyAppFileChooser *chooser)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     gchar *key;
 
     chooser->glob_casesens = gtk_toggle_button_get_active(check);
     key = g_strconcat(chooser->prefix, "/glob/case-sensitive", NULL);
-    gwy_container_set_boolean_by_name(settings, key, chooser->glob_casesens);
+    gwy_dict_set_boolean_by_name(settings, key, chooser->glob_casesens);
     g_free(key);
 
     gwy_app_file_chooser_update_expander(chooser);
@@ -709,13 +709,13 @@ static void
 loadable_filter_toggled(GwyAppFileChooser *chooser,
                         GtkToggleButton *check)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     gboolean active;
     gchar *key;
 
     active = gtk_toggle_button_get_active(check);
     key = g_strconcat(chooser->prefix, "/filter", NULL);
-    gwy_container_set_boolean_by_name(settings, key, active);
+    gwy_dict_set_boolean_by_name(settings, key, active);
     g_free(key);
     chooser->only_loadable = active;
 
@@ -735,7 +735,7 @@ enforce_refilter(GwyAppFileChooser *chooser)
 static void
 gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GtkListStore *store;
     GtkIconView *preview;
     GtkCellLayout *layout;
@@ -794,7 +794,7 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
 
     setting = FALSE;
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/plane-level", &setting);
+    gwy_dict_gis_boolean_by_name(settings, "/app/file/preview/plane-level", &setting);
     button = gtk_toggle_button_new();
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
     gtk_widget_set_can_focus(button, FALSE);
@@ -806,7 +806,7 @@ gwy_app_file_chooser_add_preview(GwyAppFileChooser *chooser)
     g_signal_connect_swapped(button, "toggled", G_CALLBACK(plane_level_changed), chooser);
 
     setting = FALSE;
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level", &setting);
+    gwy_dict_gis_boolean_by_name(settings, "/app/file/preview/row-level", &setting);
     button = gtk_toggle_button_new();
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), setting);
     gtk_widget_set_can_focus(button, FALSE);
@@ -831,8 +831,8 @@ static void
 plane_level_changed(GwyAppFileChooser *chooser,
                     GtkToggleButton *button)
 {
-    GwyContainer *settings = gwy_app_settings_get();
-    gwy_container_set_boolean_by_name(settings, "/app/file/preview/plane-level", gtk_toggle_button_get_active(button));
+    GwyDict *settings = gwy_app_settings_get();
+    gwy_dict_set_boolean_by_name(settings, "/app/file/preview/plane-level", gtk_toggle_button_get_active(button));
     if (chooser->full_preview_id) {
         g_source_remove(chooser->full_preview_id);
         chooser->full_preview_id = 0;
@@ -844,8 +844,8 @@ static void
 row_level_changed(GwyAppFileChooser *chooser,
                   GtkToggleButton *button)
 {
-    GwyContainer *settings = gwy_app_settings_get();
-    gwy_container_set_boolean_by_name(settings, "/app/file/preview/row-level", gtk_toggle_button_get_active(button));
+    GwyDict *settings = gwy_app_settings_get();
+    gwy_dict_set_boolean_by_name(settings, "/app/file/preview/row-level", gtk_toggle_button_get_active(button));
     if (chooser->full_preview_id) {
         g_source_remove(chooser->full_preview_id);
         chooser->full_preview_id = 0;
@@ -1005,13 +1005,13 @@ add_channel_thumbnails(GwyAppFileChooser *chooser,
                        GString *str)
 {
     gboolean row_level = FALSE, plane_level = FALSE;
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GdkPixbuf *pixbuf;
     guint i;
     gint id;
 
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/plane-level", &plane_level);
-    gwy_container_gis_boolean_by_name(settings, "/app/file/preview/row-level", &row_level);
+    gwy_dict_gis_boolean_by_name(settings, "/app/file/preview/plane-level", &plane_level);
+    gwy_dict_gis_boolean_by_name(settings, "/app/file/preview/row-level", &row_level);
 
     for (i = 0; ids[i] != -1; i++) {
         id = ids[i];
@@ -1138,7 +1138,7 @@ ensure_brick_preview(GwyFile *file, gint id)
 {
     GQuark pquark = gwy_file_key_volume_picture(id);
     GwyField *preview;
-    if (gwy_container_gis_object(GWY_CONTAINER(file), pquark, &preview) && GWY_IS_FIELD(preview))
+    if (gwy_dict_gis_object(GWY_DICT(file), pquark, &preview) && GWY_IS_FIELD(preview))
         return;
 
     GwyBrick *brick = gwy_file_get_volume(file, id);
@@ -1146,7 +1146,7 @@ ensure_brick_preview(GwyFile *file, gint id)
         return;
 
     preview = _gwy_app_create_brick_preview_field(brick);
-    gwy_container_pass_object(GWY_CONTAINER(file), pquark, preview);
+    gwy_dict_pass_object(GWY_DICT(file), pquark, preview);
 }
 
 static void
@@ -1192,8 +1192,8 @@ describe_xyz(GwyFile *file, gint id, GString *str)
     g_free(s);
 
     gdouble xmin, xmax, ymin, ymax;
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
+    gwy_surface_yrange(surface, &ymin, &ymax);
     xmax -= xmin;
     ymax -= ymin;
     unit = gwy_surface_get_unit_xy(surface);
@@ -1279,7 +1279,7 @@ ensure_lawn_preview(GwyFile *file, gint id)
 {
     GQuark pquark = gwy_file_key_cmap_picture(id);
     GwyField *preview;
-    if (gwy_container_gis_object(GWY_CONTAINER(file), pquark, &preview) && GWY_IS_FIELD(preview))
+    if (gwy_dict_gis_object(GWY_DICT(file), pquark, &preview) && GWY_IS_FIELD(preview))
         return;
 
     GwyLawn *lawn = gwy_file_get_cmap(file, id);
@@ -1287,7 +1287,7 @@ ensure_lawn_preview(GwyFile *file, gint id)
         return;
 
     preview = _gwy_app_create_lawn_preview_field(lawn);
-    gwy_container_pass_object(GWY_CONTAINER(file), pquark, preview);
+    gwy_dict_pass_object(GWY_DICT(file), pquark, preview);
 }
 
 static void
