@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyplaintool.c 28818 2025-11-06 15:52:22Z yeti-dn $
+ *  $Id: gwyplaintool.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2006-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -23,8 +23,8 @@
 #include <gtk/gtk.h>
 
 #include "libgwyddion/macros.h"
-#include "libgwyddion/gwycontainer.h"
-#include "libgwyddion/elliptic.h"
+#include "libgwyddion/dict.h"
+#include "libgwyddion/shaped.h"
 #include "libgwyui/utils.h"
 
 #include "libgwyapp/menu.h"
@@ -69,16 +69,16 @@ static void gwy_plain_tool_data_switched           (GwyTool *tool,
                                                     GwyDataView *data_view);
 static void reconnect_container                    (GwyPlainTool *plain_tool,
                                                     GwyDataView *data_view);
-static void data_item_changed                      (GwyContainer *container,
+static void data_item_changed                      (GwyDict *container,
                                                     GQuark quark,
                                                     GwyPlainTool *plain_tool);
-static void mask_item_changed                      (GwyContainer *container,
+static void mask_item_changed                      (GwyDict *container,
                                                     GQuark quark,
                                                     GwyPlainTool *plain_tool);
-static void show_item_changed                      (GwyContainer *container,
+static void show_item_changed                      (GwyDict *container,
                                                     GQuark quark,
                                                     GwyPlainTool *plain_tool);
-static void selection_item_changed                 (GwyContainer *container,
+static void selection_item_changed                 (GwyDict *container,
                                                     GQuark quark,
                                                     GwyPlainTool *plain_tool);
 static void data_changed                           (GwyPlainTool *plain_tool);
@@ -291,7 +291,7 @@ reconnect_container(GwyPlainTool *tool, GwyDataView *data_view)
         return;
     }
     g_return_if_fail(kind == GWY_FILE_IMAGE);
-    tool->container = g_object_ref(GWY_CONTAINER(file));
+    tool->container = g_object_ref(GWY_DICT(file));
 
     GString *str = tool->str;
     GQuark quark;
@@ -300,7 +300,7 @@ reconnect_container(GwyPlainTool *tool, GwyDataView *data_view)
     g_string_assign(str, ITEM_CHANGED);
     g_string_append(str, g_quark_to_string(quark));
     tool->data_item_id = g_signal_connect(tool->container, str->str, G_CALLBACK(data_item_changed), tool);
-    if (gwy_container_gis_object(tool->container, quark, &tool->field)) {
+    if (gwy_dict_gis_object(tool->container, quark, &tool->field)) {
         g_object_ref(tool->field);
         tool->data_id = g_signal_connect_swapped(tool->field, "data-changed", G_CALLBACK(data_changed), tool);
     }
@@ -309,7 +309,7 @@ reconnect_container(GwyPlainTool *tool, GwyDataView *data_view)
     g_string_assign(str, ITEM_CHANGED);
     g_string_append(str, g_quark_to_string(quark));
     tool->mask_item_id = g_signal_connect(tool->container, str->str, G_CALLBACK(mask_item_changed), tool);
-    if (gwy_container_gis_object(tool->container, quark, &tool->mask_field)) {
+    if (gwy_dict_gis_object(tool->container, quark, &tool->mask_field)) {
         g_object_ref(tool->mask_field);
         tool->mask_id = g_signal_connect_swapped(tool->mask_field, "data-changed", G_CALLBACK(mask_changed), tool);
     }
@@ -318,21 +318,21 @@ reconnect_container(GwyPlainTool *tool, GwyDataView *data_view)
     g_string_assign(str, ITEM_CHANGED);
     g_string_append(str, g_quark_to_string(quark));
     tool->show_item_id = g_signal_connect(tool->container, str->str, G_CALLBACK(show_item_changed), tool);
-    if (gwy_container_gis_object(tool->container, quark, &tool->show_field)) {
+    if (gwy_dict_gis_object(tool->container, quark, &tool->show_field)) {
         g_object_ref(tool->show_field);
         tool->show_id = g_signal_connect_swapped(tool->show_field, "data-changed", G_CALLBACK(show_changed), tool);
     }
 }
 
 static void
-data_item_changed(GwyContainer *container,
+data_item_changed(GwyDict *container,
                   GQuark quark,
                   GwyPlainTool *tool)
 {
     g_clear_signal_handler(&tool->data_id, tool->field);
     g_clear_object(&tool->field);
 
-    if (gwy_container_gis_object(container, quark, &tool->field)) {
+    if (gwy_dict_gis_object(container, quark, &tool->field)) {
         g_object_ref(tool->field);
         tool->data_id = g_signal_connect_swapped(tool->field, "data-changed", G_CALLBACK(data_changed), tool);
         data_changed(tool);
@@ -344,14 +344,14 @@ data_item_changed(GwyContainer *container,
 }
 
 static void
-mask_item_changed(GwyContainer *container,
+mask_item_changed(GwyDict *container,
                   GQuark quark,
                   GwyPlainTool *tool)
 {
     g_clear_signal_handler(&tool->mask_id, tool->mask_field);
     g_clear_object(&tool->mask_field);
 
-    if (gwy_container_gis_object(container, quark, &tool->mask_field)) {
+    if (gwy_dict_gis_object(container, quark, &tool->mask_field)) {
         g_object_ref(tool->mask_field);
         tool->mask_id = g_signal_connect_swapped(tool->mask_field, "data-changed", G_CALLBACK(mask_changed), tool);
     }
@@ -360,14 +360,14 @@ mask_item_changed(GwyContainer *container,
 }
 
 static void
-show_item_changed(GwyContainer *container,
+show_item_changed(GwyDict *container,
                   GQuark quark,
                   GwyPlainTool *tool)
 {
     g_clear_signal_handler(&tool->show_id, tool->show_field);
     g_clear_object(&tool->show_field);
 
-    if (gwy_container_gis_object(container, quark, &tool->show_field)) {
+    if (gwy_dict_gis_object(container, quark, &tool->show_field)) {
         g_object_ref(tool->show_field);
         tool->show_id = g_signal_connect_swapped(tool->show_field, "data-changed", G_CALLBACK(show_changed), tool);
     }
@@ -376,7 +376,7 @@ show_item_changed(GwyContainer *container,
 }
 
 static void
-selection_item_changed(GwyContainer *container,
+selection_item_changed(GwyDict *container,
                        GQuark quark,
                        GwyPlainTool *tool)
 {
@@ -384,7 +384,7 @@ selection_item_changed(GwyContainer *container,
     g_clear_signal_handler(&tool->selection_fid, tool->selection);
     g_clear_object(&tool->selection);
 
-    if (gwy_container_gis_object(container, quark, &tool->selection))
+    if (gwy_dict_gis_object(container, quark, &tool->selection))
         g_object_ref(tool->selection);
     else {
         /* FIXME: This is not enough. The selection is created here with the default properties, which may not be
@@ -395,7 +395,7 @@ selection_item_changed(GwyContainer *container,
          * selection, we need to set it up afresh. And there is no tool virtual method for that. Fix it when rewriting
          * the tool classes… */
         tool->selection = g_object_new(gwy_vector_layer_get_selection_type(tool->layer), NULL);
-        gwy_container_set_object(tool->container, quark, tool->selection);
+        gwy_dict_set_object(tool->container, quark, tool->selection);
     }
     tool->selection_cid = g_signal_connect(tool->selection, "changed", G_CALLBACK(selection_changed), tool);
     tool->selection_fid = g_signal_connect(tool->selection, "finished", G_CALLBACK(selection_finished), tool);
@@ -653,7 +653,7 @@ selection_reconnect(GwyPlainTool *plain_tool)
                                                      G_CALLBACK(selection_item_changed), plain_tool);
     g_free(sigdetail);
 
-    if (gwy_container_gis_object(plain_tool->container, key, &plain_tool->selection)) {
+    if (gwy_dict_gis_object(plain_tool->container, key, &plain_tool->selection)) {
         g_object_ref(plain_tool->selection);
         plain_tool->selection_cid = g_signal_connect(plain_tool->selection, "changed",
                                                      G_CALLBACK(selection_changed), plain_tool);
@@ -662,7 +662,7 @@ selection_reconnect(GwyPlainTool *plain_tool)
     }
     else {
         plain_tool->selection = g_object_new(gwy_vector_layer_get_selection_type(plain_tool->layer), NULL);
-        gwy_container_set_object(plain_tool->container, key, plain_tool->selection);
+        gwy_dict_set_object(plain_tool->container, key, plain_tool->selection);
     }
     gwy_vector_layer_set_selection(plain_tool->layer, plain_tool->selection);
 
@@ -795,7 +795,7 @@ gwy_plain_tool_get_z_average(GwyField *field,
         return gwy_field_get_val(field, col, row);
 
     values = g_new(gdouble, (2*radius + 1)*(2*radius + 1));
-    n = gwy_field_circular_area_extract(field, col, row, radius - 0.5, values);
+    n = gwy_field_circular_area_extract(field, col, row, radius - 0.5, values, NULL, NULL);
     avg = 0.0;
     if (n) {
         for (i = 0; i < n; i++)
