@@ -1,5 +1,5 @@
 /*
- *  $Id: help.c 28779 2025-11-04 17:00:29Z yeti-dn $
+ *  $Id: help.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -444,12 +444,12 @@ finish:
 static gchar*
 get_user_guide_settings_base(void)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     const gchar *settingsugbase = NULL;
     guint len;
     gchar *base;
 
-    if (!gwy_container_gis_string_by_name(settings, "/app/help/user-guide-base", &settingsugbase))
+    if (!gwy_dict_gis_string_by_name(settings, "/app/help/user-guide-base", &settingsugbase))
         return NULL;
 
     base = g_strdup(settingsugbase);
