@@ -1,5 +1,5 @@
 /*
- *  $Id: log.c 28755 2025-11-03 10:26:01Z yeti-dn $
+ *  $Id: log.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -135,7 +135,7 @@ gwy_log_add_full(GwyFile *file,
             targetlog = gwy_string_list_new();
         }
 
-        gwy_container_pass_object(GWY_CONTAINER(file), newquark, targetlog);
+        gwy_dict_pass_object(GWY_DICT(file), newquark, targetlog);
     }
 
     if (!function)
@@ -291,23 +291,23 @@ gwy_log_add_import(GwyFile *file,
      * But just in case there is one, preserve it. */
     GValue savedval;
     gwy_clear1(savedval);
-    GwyContainer *settings = gwy_app_settings_get();
-    if (gwy_container_contains(settings, quark))
-        savedval = gwy_container_get_value(settings, quark);
+    GwyDict *settings = gwy_app_settings_get();
+    if (gwy_dict_contains(settings, quark))
+        savedval = gwy_dict_get_value(settings, quark);
 
     /* Eats myfilename. */
-    gwy_container_set_string(settings, quark, myfilename);
+    gwy_dict_set_string(settings, quark, myfilename);
 
     gchar *qualname = g_strconcat("file::", filetype, NULL);
     gwy_log_add_full(file, data_kind, -1, id, qualname, NULL);
     g_free(qualname);
 
     if (G_VALUE_TYPE(&savedval)) {
-        gwy_container_set_value(settings, quark, &savedval);
+        gwy_dict_set_value(settings, quark, &savedval);
         g_value_unset(&savedval);
     }
     else
-        gwy_container_remove(settings, quark);
+        gwy_dict_remove(settings, quark);
 }
 
 static GwyStringList*
@@ -316,14 +316,14 @@ get_data_log(GwyFile *file,
              gboolean create)
 {
     GwyStringList *slog = NULL;
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
 
-    gwy_container_gis_object(container, quark, &slog);
+    gwy_dict_gis_object(container, quark, &slog);
     if (slog || !create)
         return slog;
 
     slog = gwy_string_list_new();
-    gwy_container_pass_object(container, quark, slog);
+    gwy_dict_pass_object(container, quark, slog);
 
     return slog;
 }
@@ -331,12 +331,12 @@ get_data_log(GwyFile *file,
 static gchar*
 format_args(const gchar *prefix)
 {
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     GPtrArray *values = g_ptr_array_new();
     gchar *retval;
     guint i;
 
-    gwy_container_foreach(settings, prefix, format_arg, values);
+    gwy_dict_foreach(settings, prefix, format_arg, values);
     g_ptr_array_add(values, NULL);
     retval = g_strjoinv(", ", (gchar**)values->pdata);
     for (i = 0; i < values->len-1; i++)
