@@ -1,5 +1,5 @@
 /*
- *  $Id: menu.c 29085 2026-01-05 18:28:15Z yeti-dn $
+ *  $Id: menu.c 29514 2026-02-22 13:41:48Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -540,6 +540,7 @@ gwy_app_menu_add_proc_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_image_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>Data Process</guimenu> menu.
  *
@@ -573,6 +574,7 @@ gwy_app_menu_add_graph_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_graph_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>Graph</guimenu> menu.
  *
@@ -606,6 +608,7 @@ gwy_app_menu_add_volume_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_volume_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>Volume Data</guimenu> menu.
  *
@@ -639,6 +642,7 @@ gwy_app_menu_add_xyz_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_xyz_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>XYZ Data</guimenu> menu.
  *
@@ -672,6 +676,7 @@ gwy_app_menu_add_curve_map_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_curve_map_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>Curve Maps</guimenu> menu.
  *
@@ -705,6 +710,7 @@ gwy_app_menu_add_synth_func(const gchar *name, gpointer user_data)
 /**
  * gwy_app_synth_menu:
  * @accel_group: Acceleration group to be associated with the menu.
+ * @sens_group: Sensitvity group for the menu.
  *
  * Constructs the application <guimenu>Curve Maps</guimenu> menu.
  *
@@ -769,14 +775,14 @@ void
 gwy_app_run_process_func_in_mode(const gchar *name,
                                  GwyRunModeFlags run)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
     gwy_debug("`%s'", name);
     if (!(run & gwy_process_func_get_run_types(name)))
         return;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    g_return_if_fail(data || !(gwy_process_func_get_sensitivity_mask(name) & GWY_MENU_FLAG_IMAGE));
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    g_return_if_fail(data);
     gwy_process_func_run(name, GWY_FILE(data), run);
     update_recent_func(GWY_FILE_IMAGE, name);
 }
@@ -840,14 +846,14 @@ void
 gwy_app_run_volume_func_in_mode(const gchar *name,
                                 GwyRunModeFlags run)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
     gwy_debug("`%s'", name);
     if (!(run & gwy_volume_func_get_run_types(name)))
         return;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    g_return_if_fail(data || !(gwy_volume_func_get_sensitivity_mask(name) & GWY_MENU_FLAG_IMAGE));
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    g_return_if_fail(data);
     gwy_volume_func_run(name, GWY_FILE(data), run);
     update_recent_func(GWY_FILE_VOLUME, name);
 }
@@ -892,14 +898,14 @@ void
 gwy_app_run_xyz_func_in_mode(const gchar *name,
                              GwyRunModeFlags run)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
     gwy_debug("`%s'", name);
     if (!(run & gwy_xyz_func_get_run_types(name)))
         return;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    g_return_if_fail(data || !(gwy_xyz_func_get_sensitivity_mask(name) & GWY_MENU_FLAG_IMAGE));
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    g_return_if_fail(data);
     gwy_xyz_func_run(name, GWY_FILE(data), run);
     update_recent_func(GWY_FILE_XYZ, name);
 }
@@ -944,14 +950,14 @@ void
 gwy_app_run_curve_map_func_in_mode(const gchar *name,
                                    GwyRunModeFlags run)
 {
-    GwyContainer *data;
+    GwyDict *data;
 
     gwy_debug("`%s'", name);
     if (!(run & gwy_curve_map_func_get_run_types(name)))
         return;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    g_return_if_fail(data || !(gwy_curve_map_func_get_sensitivity_mask(name) & GWY_MENU_FLAG_IMAGE));
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    g_return_if_fail(data);
     gwy_curve_map_func_run(name, GWY_FILE(data), run);
     update_recent_func(GWY_FILE_CMAP, name);
 }
@@ -996,15 +1002,14 @@ void
 gwy_app_run_synth_func_in_mode(const gchar *name,
                                GwyRunModeFlags run)
 {
-    GwyContainer *data;
-
     gwy_debug("`%s'", name);
     if (!(run & gwy_synth_func_get_run_modes(name)))
         return;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    g_return_if_fail(data);
-    gwy_synth_func_run(name, GWY_FILE(data), run);
+    // NB: Unlike other functions, synth functions can be run with no data.
+    GwyFile *data = NULL;
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    gwy_synth_func_run(name, data, run);
     // FIXME: Can we get synthetic data functions to the recent menu somehow? It would have to be able to contain
     // different function types.
     //update_recent_func(GWY_FILE_CMAP, name);
