@@ -1,5 +1,5 @@
 /*
- *  $Id: meta-browser.c 28734 2025-10-29 10:18:03Z yeti-dn $
+ *  $Id: meta-browser.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -22,7 +22,7 @@
 
 #include "libgwyddion/macros.h"
 #include "libgwyddion/utils.h"
-#include "libgwyddion/gwycontainer.h"
+#include "libgwyddion/dict.h"
 #include "libgwyui/utils.h"
 
 #include "libgwyapp/app.h"
@@ -48,7 +48,7 @@ struct _GwyMetaBrowserPrivate {
     GwyDataKind data_kind;
     gint id;
 
-    GwyContainer *meta;
+    GwyDict *meta;
     gulong changed_id;
 
     GtkListStore *store;
@@ -98,7 +98,7 @@ static void       add_line          (GQuark quark,
                                      gpointer user_data);
 static void       update_title      (GwyMetaBrowser *browser);
 static void       update_sensitivity(GwyMetaBrowser *browser);
-static void       item_changed      (GwyContainer *container,
+static void       item_changed      (GwyDict *container,
                                      GQuark quark,
                                      GwyMetaBrowser *browser);
 static void       add_new_item      (GwyMetaBrowser *browser);
@@ -230,14 +230,14 @@ gwy_meta_browser_new(GwyFile *file,
     priv->id = id;
 
 
-    if (!gwy_container_contains(GWY_CONTAINER(file), gwy_file_key_data(data_kind, id))) {
+    if (!gwy_dict_contains(GWY_DICT(file), gwy_file_key_data(data_kind, id))) {
         g_warning("Creating metadata browser for non-existent data.");
     }
 
-    GwyContainer *meta = priv->meta = gwy_file_get_meta(file, data_kind, id);
+    GwyDict *meta = priv->meta = gwy_file_get_meta(file, data_kind, id);
 
     if (!meta) {
-        priv->meta = meta = gwy_container_new();
+        priv->meta = meta = gwy_dict_new();
         gwy_file_pass_meta(file, data_kind, id, meta);
     }
     else {
@@ -265,10 +265,10 @@ fill_list_store(GwyMetaBrowser *browser)
 {
     GwyMetaBrowserPrivate *priv = browser->priv;
     GtkListStore *store = priv->store;
-    GwyContainer *meta = priv->meta;
+    GwyDict *meta = priv->meta;
 
     GArray *fixlist = g_array_new(FALSE, FALSE, sizeof(FixupData));
-    gwy_container_foreach(meta, NULL, add_line, fixlist);
+    gwy_dict_foreach(meta, NULL, add_line, fixlist);
     /* Commit UTF-8 fixes found by add_line() */
     guint n = fixlist->len;
     for (guint i = 0; i < n; i++) {
@@ -276,13 +276,13 @@ fill_list_store(GwyMetaBrowser *browser)
 
         if (fd->isok || fd->value) {
             if (!fd->isok)
-                gwy_container_set_string(meta, fd->quark, fd->value);
+                gwy_dict_set_string(meta, fd->quark, fd->value);
 
             GtkTreeIter iter;
             gtk_list_store_insert_with_values(store, &iter, G_MAXINT, META_KEY, fd->quark, -1);
         }
         else
-            gwy_container_remove(meta, fd->quark);
+            gwy_dict_remove(meta, fd->quark);
     }
     g_array_free(fixlist, TRUE);
 }
@@ -476,12 +476,12 @@ cell_edited(GtkCellRendererText *renderer,
     if (col == META_KEY) {
         if (validate_key(text)) {
             quark = g_quark_from_string(text);
-            gwy_container_rename(priv->meta, oldkey, quark, FALSE);
+            gwy_dict_rename(priv->meta, oldkey, quark, FALSE);
         }
     }
     else if (col == META_VALUE) {
         if (pango_parse_markup(text, -1, 0, NULL, NULL, NULL, NULL))
-            gwy_container_set_string(priv->meta, oldkey, g_strdup(text));
+            gwy_dict_set_string(priv->meta, oldkey, g_strdup(text));
     }
 }
 
@@ -510,7 +510,7 @@ render_value(G_GNUC_UNUSED GtkTreeViewColumn *column,
     GQuark quark;
 
     gtk_tree_model_get(model, iter, META_KEY, &quark, -1);
-    g_object_set(renderer, "text", gwy_container_get_string(priv->meta, quark), NULL);
+    g_object_set(renderer, "text", gwy_dict_get_string(priv->meta, quark), NULL);
 }
 
 static void
@@ -554,7 +554,7 @@ add_line(GQuark quark,
 }
 
 static void
-item_changed(GwyContainer *container,
+item_changed(GwyDict *container,
              GQuark quark,
              GwyMetaBrowser*browser)
 {
@@ -567,7 +567,7 @@ item_changed(GwyContainer *container,
 
     GtkTreeIter iter;
     if (find_key(browser, quark, &iter)) {
-        if (gwy_container_contains(container, quark))
+        if (gwy_dict_contains(container, quark))
             gwy_list_store_row_changed(store, &iter, NULL, -1);
         else
             gtk_list_store_remove(store, &iter);
@@ -594,7 +594,7 @@ add_new_item(GwyMetaBrowser *browser)
     if (!quark)
         quark = g_quark_from_static_string(_("New item"));
 
-    if (gwy_container_contains(priv->meta, quark)) {
+    if (gwy_dict_contains(priv->meta, quark)) {
         if (find_key(browser, quark, &iter))
             focus_iter(browser, &iter);
     }
@@ -603,7 +603,7 @@ add_new_item(GwyMetaBrowser *browser)
             s = g_strdup(whatever[g_random_int() % G_N_ELEMENTS(whatever)]);
         else
             s = g_strdup("");
-        gwy_container_set_string(priv->meta, quark, s);
+        gwy_dict_set_string(priv->meta, quark, s);
     }
 
     update_sensitivity(browser);
@@ -623,7 +623,7 @@ delete_item(GwyMetaBrowser *browser)
         return;
 
     gtk_tree_model_get(model, &iter, META_KEY, &quark, -1);
-    gwy_container_remove(priv->meta, quark);
+    gwy_dict_remove(priv->meta, quark);
     update_sensitivity(browser);
 }
 
@@ -723,7 +723,7 @@ save_items(GwyMetaBrowser *browser)
         do {
             GQuark name;
             gtk_tree_model_get(model, &iter, META_KEY, &name, -1);
-            const gchar *value = gwy_container_get_string(priv->meta, name);
+            const gchar *value = gwy_dict_get_string(priv->meta, name);
             g_string_append_printf(str_to_save, "%s %s\n", g_quark_to_string(name), value);
         } while (gtk_tree_model_iter_next(model, &iter));
     }
