@@ -1,5 +1,5 @@
 /*
- *  $Id: module-file.c 28988 2025-12-12 17:18:30Z yeti-dn $
+ *  $Id: module-file.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -25,7 +25,7 @@
 
 #include "libgwyddion/macros.h"
 #include "libgwyddion/utils.h"
-#include "libgwyddion/gwycontainer.h"
+#include "libgwyddion/dict.h"
 #include "libgwyddion/field.h"
 #include "libgwyui/gwygraphmodel.h"
 
@@ -85,8 +85,8 @@ call_stack_pop(GwyFileFuncInfo *func_info)
  * @name: Name of function to register.  It should be a valid identifier and if a module registers only one function,
  *        module and function names should be the same.
  * @description: File type description (will be used in file type selectors).
- * @detect_file: Detection function.  It may be %NULL, files of such a type can can be then loaded and saved only on
- *               explict user request.
+ * @detect: Detection function.  It may be %NULL, files of such a type can can be then loaded and saved only on
+ *          explict user request.
  * @load_file: File load/import function.
  * @save_file: File save function.
  * @export_file: File export function.
@@ -232,9 +232,9 @@ gwy_file_func_run_load(const gchar *name,
     call_stack_pop(func_info);
 
     if (file) {
-        GwyContainer *container = GWY_CONTAINER(file);
-        if (gwy_container_is_being_constructed(container))
-            gwy_container_finish_construction(container);
+        GwyDict *container = GWY_DICT(file);
+        if (gwy_dict_is_being_constructed(container))
+            gwy_dict_finish_construction(container);
     }
 
     return file;
