@@ -1,5 +1,5 @@
 /*
- *  $Id: module-utils-file.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: module-utils-file.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2007-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -58,19 +58,19 @@ gboolean
 gwy_check_nonsquare_image(GwyFile *file,
                           gint id)
 {
-    GwyField *dfield = gwy_file_get_image(file, id);
-    g_return_val_if_fail(GWY_IS_FIELD(dfield), FALSE);
+    GwyField *field = gwy_file_get_image(file, id);
+    g_return_val_if_fail(GWY_IS_FIELD(field), FALSE);
 
-    gdouble xmeasure = gwy_field_get_dx(dfield);
-    gdouble ymeasure = gwy_field_get_dy(dfield);
+    gdouble xmeasure = gwy_field_get_dx(field);
+    gdouble ymeasure = gwy_field_get_dy(field);
     gdouble q = xmeasure/ymeasure;
     gboolean nonsquare = (q > G_SQRT2 || q < 1.0/G_SQRT2);
 
     GQuark key = gwy_file_key_image_real_square(id);
     if (nonsquare)
-        gwy_container_set_boolean(GWY_CONTAINER(file), key, TRUE);
+        gwy_dict_set_boolean(GWY_DICT(file), key, TRUE);
     else
-        gwy_container_remove(GWY_CONTAINER(file), key);
+        gwy_dict_remove(GWY_DICT(file), key);
 
     return nonsquare;
 }
@@ -126,12 +126,12 @@ gboolean
 gwy_image_title_fall_back(GwyFile *file,
                           gint id)
 {
-    GwyField *dfield = gwy_file_get_image(file, id);
-    g_return_val_if_fail(GWY_IS_FIELD(dfield), FALSE);
+    GwyField *field = gwy_file_get_image(file, id);
+    g_return_val_if_fail(GWY_IS_FIELD(field), FALSE);
     if (gwy_file_get_title(file, GWY_FILE_IMAGE, id))
         return TRUE;
 
-    const gchar *title = guess_title_from_units(gwy_field_get_unit_z(dfield));
+    const gchar *title = guess_title_from_units(gwy_field_get_unit_z(field));
     if (!title)
         return FALSE;
 
@@ -170,11 +170,13 @@ gwy_xyz_title_fall_back(GwyFile *file,
     return TRUE;
 }
 
+// XXX: The transfer annotation looks logically correct to me (the mask is always passed including ownership if it
+// exists, but there may not be any mask). I hope gi understands it the same way.
 /**
- * gwy_app_channel_remove_bad_data:
- * @dfield: A data field.  The values of bad data points are ignored and might be even left uninitialized.
- * @mfield: A mask field containing 1.0 in place of good data points, 0.0 in place of bad points.  It will be inverted
- *          to become the mask of bad points.
+ * gwy_remove_bad_image_data:
+ * @field: A data field.  The values of bad data points are ignored and might be even left uninitialized.
+ * @mask: (transfer full) (nullable):
+ *        A number field containing positive values in place of bad data points, non-positive in place of good points.
  *
  * Replaces bad data points with some neutral values.
  *
@@ -182,76 +184,76 @@ gwy_xyz_title_fall_back(GwyFile *file,
  * neutral values upon import, leaving the user to decide how to proceed further.  This helper function performs such
  * replacement.
  *
- * Returns: The number of bad data points replaced.  If zero is returned, all points are good and there is no need for
- *          masking.
+ * When the mask is empty and the function returns %NULL, it also calls g_object_unref() on the mask. Usually, it
+ * means you use the function like
+ * |[
+ * if ((mask = gwy_remove_bad_image_data(field, mask))) {
+ *     // Set the the mask on an image, for example.
+ * }
+ * else {
+ *     // Just forget mask.
+ * }
+ * ]|
+ *
+ * For convenient chaining, @mask can also already be %NULL, meaning there are no bad data. The function then simply
+ * returns %NULL too.
+ *
+ * Returns: (transfer full) (nullable):
+ *          Either @mask itself if any data were marked as bad, or %NULL if @mask was empty.
  **/
-guint
-gwy_app_channel_remove_bad_data(GwyField *dfield, GwyField *mfield)
+GwyNield*
+gwy_remove_bad_image_data(GwyField *field, GwyNield *mask)
 {
-    gdouble *m = gwy_field_get_data(mfield);
-    guint i, mcount, n;
+    if (!mask)
+        return NULL;
 
-    n = gwy_field_get_xres(dfield) * gwy_field_get_yres(dfield);
-    mcount = 0;
-    for (i = 0; i < n; i++) {
-        if (m[i] <= 0.0) {
-            m[i] = 1.0;
-            mcount++;
-        }
-        else
-            m[i] = 0.0;
+    if (gwy_nield_count(mask)) {
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 0.25);
+        return mask;
     }
 
-    if (mcount)
-        gwy_field_laplace_solve(dfield, mfield, -1, 0.25);
-
-    gwy_field_set_xreal(mfield, gwy_field_get_xreal(dfield));
-    gwy_field_set_yreal(mfield, gwy_field_get_yreal(dfield));
-    gwy_unit_assign(gwy_field_get_unit_xy(mfield), gwy_field_get_unit_xy(dfield));
-
-    gwy_debug("mcount = %u", mcount);
-
-    return mcount;
+    g_object_unref(mask);
+    return NULL;
 }
 
 /**
- * gwy_app_channel_mask_of_nans:
- * @dfield: A data field possibly containing NaNs and infinities.
+ * gwy_mask_nans_in_field:
+ * @field: A data field possibly containing NaNs and infinities.
  * @removebad: Automatically remove the invalid values.
  *
  * Creates a mask corresponding to not-a-number and infinite values in a data field.
  *
- * NaNs and infinities are not normally allowed in Gwyddion so this function should be used upon import if the source
- * file format can represent such values.
+ * Abnormal values should always be removed from data upon import. See the discussion in gwy_isnan().
  *
- * The invalid values can be automatically removed using the same method as gwy_app_channel_remove_bad_data().
+ * The invalid values can be automatically removed using the same method as gwy_remove_bad_image_data().
  *
- * Returns: A newly created data field with 1.0 in pixels corresponding to a NaN or infinity in @dfield.  If no such
+ * Returns: (transfer full) (nullable):
+ *          A newly created number field with 1 in pixels corresponding to a NaN or infinity in @field.  If no such
  *          pixels are present, %NULL is returned.
  **/
-GwyField*
-gwy_app_channel_mask_of_nans(GwyField *dfield,
-                             gboolean removebad)
+GwyNield*
+gwy_mask_nans_in_field(GwyField *field,
+                       gboolean removebad)
 {
-    GwyField *mask = NULL;
-    guint k, n = dfield->xres*dfield->yres;
-    gdouble *d = gwy_field_get_data(dfield), *m = NULL;
+    guint n = gwy_field_get_xres(field) * gwy_field_get_yres(field);
+    gdouble *d = gwy_field_get_data(field);
+    GwyNield *mask = NULL;
+    gint *m = NULL;
 
-    for (k = 0; k < n; k++) {
+    for (guint k = 0; k < n; k++) {
         if (gwy_isnan(d[k]) || gwy_isinf(d[k])) {
             if (G_UNLIKELY(!mask)) {
-                mask = gwy_field_new_alike(dfield, TRUE);
-                m = gwy_field_get_data(mask);
-                gwy_unit_clear(gwy_field_get_unit_z(mask));
+                mask = gwy_field_new_nield_alike(field);
+                m = gwy_nield_get_data(mask);
             }
-            m[k] = 1.0;
+            m[k] = 1;
         }
     }
 
     if (!mask || !removebad)
         return mask;
 
-    gwy_field_laplace_solve(dfield, mask, -1, 0.25);
+    gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 0.25);
 
     return mask;
 }
@@ -670,7 +672,7 @@ gwy_enforce_graph_abscissae_order(GwyFile *file)
 {
     g_return_val_if_fail(GWY_IS_FILE(file), 0);
     guint nfailures = 0;
-    gwy_container_foreach(GWY_CONTAINER(file), NULL, enforce_one_graph_order, &nfailures);
+    gwy_dict_foreach(GWY_DICT(file), NULL, enforce_one_graph_order, &nfailures);
     return nfailures;
 }
 
@@ -720,196 +722,6 @@ gwy_enforce_graph_abscissae_order(GwyFile *file)
  * </programlisting></informalexample>
  **/
 
-/**
- * gwy_get_gboolean8:
- * @ppv: Pointer to a pointer to boolean (stored as a signle byte) in a memory buffer.
- *
- * Reads a boolean value stored as a signle byte from a binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gboolean value read from the buffer.
- **/
-
-/**
- * gwy_get_gint16_le:
- * @ppv: Pointer to a pointer to a little-endian signed 16bit integer in a memory buffer.
- *
- * Reads a signed 16bit integer value from a little-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint16 value read from the buffer.
- **/
-
-/**
- * gwy_get_gint16_be:
- * @ppv: Pointer to a pointer to a big-endian signed 16bit integer in a memory buffer.
- *
- * Reads a signed 16bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint16 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint16_le:
- * @ppv: Pointer to a pointer to a little-endian unsigned 16bit integer in a memory buffer.
- *
- * Reads an unsigned 16bit integer value from a little-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The #guint16 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint16_be:
- * @ppv: Pointer to a pointer to a big-endian unsigned 16bit integer in a memory buffer.
- *
- * Reads an unsigned 16bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #guint16 value read from the buffer.
- **/
-
-/**
- * gwy_get_gint32_le:
- * @ppv: Pointer to a pointer to a little-endian signed 32bit integer in a memory buffer.
- *
- * Reads a signed 32bit integer value from a little-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint32 value read from the buffer.
- **/
-
-/**
- * gwy_get_gint32_be:
- * @ppv: Pointer to a pointer to a big-endian signed 32bit integer in a memory buffer.
- *
- * Reads a signed 32bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint32 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint32_le:
- * @ppv: Pointer to a pointer to a little-endian unsigned 32bit integer in a memory buffer.
- *
- * Reads an unsigned 32bit integer value from a little-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The #guint32 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint32_be:
- * @ppv: Pointer to a pointer to a big-endian unsigned 32bit integer in a memory buffer.
- *
- * Reads an unsigned 32bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #guint32 value read from the buffer.
- **/
-
-/**
- * gwy_get_gint64_le:
- * @ppv: Pointer to a pointer to a little-endian signed 64bit integer in a memory buffer.
- *
- * Reads a signed 64bit integer value from a little-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint64 value read from the buffer.
- **/
-
-/**
- * gwy_get_gint64_be:
- * @ppv: Pointer to a pointer to a big-endian signed 64bit integer in a memory buffer.
- *
- * Reads a signed 64bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #gint64 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint64_le:
- * @ppv: Pointer to a pointer to a little-endian unsigned 64bit integer in a memory buffer.
- *
- * Reads an unsigned 64bit integer value from a little-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The #guint64 value read from the buffer.
- **/
-
-/**
- * gwy_get_guint64_be:
- * @ppv: Pointer to a pointer to a big-endian unsigned 64bit integer in a memory buffer.
- *
- * Reads an unsigned 64bit integer value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The #guint64 value read from the buffer.
- **/
-
-/**
- * gwy_get_gfloat_le:
- * @ppv: Pointer to a pointer to a little-endian single-precision IEEE float in a memory buffer.
- *
- * Reads a single-precision IEEE float value from a little-endian binary data buffer, moving the buffer pointer to
- * point just after the value.
- *
- * Returns: The #gfloat value read from the buffer.
- **/
-
-/**
- * gwy_get_gfloat_be:
- * @ppv: Pointer to a pointer to a big-endian single-precision IEEE float in a memory buffer.
- *
- * Reads a single-precision IEEE float value from a big-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The #gfloat value read from the buffer.
- **/
-
-/**
- * gwy_get_gdouble_le:
- * @ppv: Pointer to a pointer to a little-endian double-precision IEEE float in a memory buffer.
- *
- * Reads a double-precision IEEE float value from a little-endian binary data buffer, moving the buffer pointer to
- * point just after the value.
- *
- * Returns: The #gdouble value read from the buffer.
- **/
-
-/**
- * gwy_get_gdouble_be:
- * @ppv: Pointer to a pointer to a big-endian double-precision IEEE float in a memory buffer.
- *
- * Reads a double-precision IEEE float value from a big-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The #gdouble value read from the buffer.
- **/
-
-/**
- * gwy_get_pascal_real_le:
- * @ppv: Pointer to a pointer to a little-endian six-byte Pascal Real in a memory buffer.
- *
- * Reads a six-byte Pascale Real value from a little-endian binary data buffer, moving the buffer pointer to point
- * just after the value.
- *
- * Returns: The floating point value read from the buffer as a #gdouble.
- **/
-
-/**
- * gwy_get_pascal_real_be:
- * @ppv: Pointer to a pointer to a big-endian six-byte Pascal Real in a memory buffer.
- *
- * Reads a six-byte Pascale Real value from a big-endian binary data buffer, moving the buffer pointer to point just
- * after the value.
- *
- * Returns: The floating point value read from the buffer as a #gdouble.
- **/
-
 /**
  * GWY_TEXT_HEADER_ERROR:
  *
