@@ -1,5 +1,5 @@
 /*
- *  $Id: module-utils-synth.c 28818 2025-11-06 15:52:22Z yeti-dn $
+ *  $Id: module-utils-synth.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -234,7 +234,7 @@ gwy_synth_use_dimensions_template(GwyParamTable *partable)
      _gwy_param_table_in_update(partable, TRUE);
 
     if (gwy_param_table_exists(partable, first_id + GWY_DIMS_PARAM_ZUNIT)) {
-        gwy_field_get_min_max(template_, &min, &max);
+        gwy_field_min_max(template_, &min, &max);
         /* The height control has a high precision.  We are more likely to run into trouble when the template is
          * relatively flat. */
         if (max == min) {
@@ -528,10 +528,10 @@ gwy_synth_add_image_to_file(GwyField *result,
 
     if (id != -1 && do_replace) {
         GQuark quark = gwy_file_key_image(id);
-        GwyContainer *container = GWY_CONTAINER(file);
+        GwyDict *container = GWY_DICT(file);
 
         gwy_app_undo_qcheckpointv(container, 1, &quark);
-        gwy_container_set_object(container, quark, result);
+        gwy_dict_set_object(container, quark, result);
         gwy_log_add_synth(file, GWY_FILE_IMAGE, id, id);
         dataid.datano = gwy_file_get_id(file);
         dataid.id = id;
