@@ -1,5 +1,5 @@
 /*
- *  $Id: module-utils.c 29090 2026-01-06 15:45:59Z yeti-dn $
+ *  $Id: module-utils.c 29561 2026-03-03 08:44:12Z yeti-dn $
  *  Copyright (C) 2007-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -646,10 +646,10 @@ gwy_preview_surface_to_field(GwySurface *surface,
     GwyField *densitymap = NULL;
     guint xres, yres;
 
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
     xrange_normal = (xmin < xmax);
 
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
+    gwy_surface_yrange(surface, &ymin, &ymax);
     yrange_normal = (ymin < ymax);
 
     if (!xrange_normal) {
@@ -921,7 +921,7 @@ gwy_require_square_image(GwyField *field, GwyFile *data, gint id,
  **/
 GtkWidget*
 gwy_create_preview(GwyField *field,
-                   GwyField *mask,
+                   GwyNield *mask,
                    gint size)
 {
     GtkWidget *widget = gwy_data_view_new();
@@ -942,13 +942,15 @@ gwy_create_preview(GwyField *field,
     return widget;
 }
 
+#include "gwyappinternal.h"
+
 /* FIXME GTK3: The function is, in some form, generally useful. The implementation is extremely transitional and
  * just allows replacing gwy_app_sync_FOOBAR_items() in modules when setting up previews to make them run. The
  * no-reset behaviour may be misguiged and need to be changed. */
 /**
  * gwy_setup_data_view:
  * @dataview: Preview data view, usually created by gwy_create_preview().
- * @data: File with the data to preview.
+ * @data: (nullable): File with the data to preview.
  * @data_kind: Data kind (either image or with image preview).
  * @id: The id of image in @data.
  * @items: Flags indicating the items to set up.
@@ -958,6 +960,9 @@ gwy_create_preview(GwyField *field,
  * The function sets values to match to the file, but does not unset values to match the file. Meaning, it will not
  * destroy your previous setup. On the other hand, if you use it as a data switching helper, you will probably have to
  * unset any items like gradients first. Otherwise they can keep previous values when they should be unset.
+ *
+ * For covnenience in modules which may or may not be run on existing data, @data can be null and the function is
+ * no-op in such case.
  **/
 void
 gwy_setup_data_view(GwyDataView *dataview,
@@ -966,13 +971,16 @@ gwy_setup_data_view(GwyDataView *dataview,
                     gint id,
                     GwyFileItemFlags items)
 {
+    g_printerr("view %p, data %p, kind %s, id %d, items 0x%x\n",
+               dataview, data, _gwy_data_kind_name(data_kind), id, items);
     g_return_if_fail(GWY_IS_DATA_VIEW(dataview));
+    if (!data || id < 0)
+        return;
     g_return_if_fail(GWY_IS_FILE(data));
-    g_return_if_fail(id >= 0);
     g_return_if_fail(data_kind == GWY_FILE_IMAGE || data_kind == GWY_FILE_VOLUME
                      || data_kind == GWY_FILE_XYZ || data_kind == GWY_FILE_CMAP);
 
-    GwyContainer *container = GWY_CONTAINER(data);
+    GwyDict *container = GWY_DICT(data);
     if (items & GWY_FILE_ITEM_PALETTE) {
         const gchar *name = gwy_file_get_palette(data, data_kind, id);
         GwyGradient *gradient;
@@ -983,7 +991,7 @@ gwy_setup_data_view(GwyDataView *dataview,
     if ((items & GWY_FILE_ITEM_MASK_COLOR) && data_kind == GWY_FILE_IMAGE) {
         GQuark quark = gwy_file_key_image_mask_color(id);
         GwyRGBA color;
-        if (!gwy_container_gis_boxed(container, GWY_TYPE_RGBA, quark, &color))
+        if (!gwy_dict_gis_boxed(container, GWY_TYPE_RGBA, quark, &color))
             gwy_app_settings_get_default_mask_color(&color);
 
         gwy_data_view_set_mask_color(dataview, &color);
@@ -994,8 +1002,8 @@ gwy_setup_data_view(GwyDataView *dataview,
             .id = id, .data_kind = data_kind, .piece = GWY_FILE_PIECE_COLOR_MAPPING, .suffix = NULL
         };
         GwyColorMappingType mapping = GWY_COLOR_MAPPING_FULL;
-        if (!gwy_container_gis_enum(container, gwy_file_form_key(&parsed), &mapping))
-            gwy_container_gis_enum_by_name(gwy_app_settings_get(), "/app/default-range-type", &mapping);
+        if (!gwy_dict_gis_enum(container, gwy_file_form_key(&parsed), &mapping))
+            gwy_dict_gis_enum_by_name(gwy_app_settings_get(), "/app/default-range-type", &mapping);
         gwy_data_view_set_color_mapping(dataview, mapping);
         items &= ~GWY_FILE_ITEM_COLOR_MAPPING;
     }
@@ -1008,8 +1016,8 @@ gwy_setup_data_view(GwyDataView *dataview,
         parsed.suffix = "max";
         GQuark quark_max = gwy_file_form_key(&parsed);
         gdouble min, max;
-        if (gwy_container_gis_double(container, quark_min, &min)
-            && gwy_container_gis_double(container, quark_max, &max))
+        if (gwy_dict_gis_double(container, quark_min, &min)
+            && gwy_dict_gis_double(container, quark_max, &max))
             gwy_data_view_set_fixed_color_range(dataview, min, max);
         items &= ~GWY_FILE_ITEM_RANGE;
     }
@@ -1018,7 +1026,7 @@ gwy_setup_data_view(GwyDataView *dataview,
             .id = id, .data_kind = data_kind, .piece = GWY_FILE_PIECE_REAL_SQUARE, .suffix = NULL
         };
         gboolean realsquare = FALSE;
-        if (gwy_container_gis_boolean(container, gwy_file_form_key(&parsed), &realsquare))
+        if (gwy_dict_gis_boolean(container, gwy_file_form_key(&parsed), &realsquare))
             gwy_data_view_set_real_square(dataview, realsquare);
         items &= ~GWY_FILE_ITEM_REAL_SQUARE;
     }
@@ -1115,6 +1123,28 @@ gwy_create_preview_vector_layer(GwyDataView *dataview,
     return selection;
 }
 
+/**
+ * gwy_compactify_quarks:
+ * @quarks: Array of quarks, possibly with holes (zeros).
+ * @n: The number of quarks in @quarks.
+ *
+ * Moves all nonzero quarks to the beginning of an array.
+ *
+ * Returns: The number of non-zero values.
+ **/
+guint
+gwy_compactify_quarks(GQuark *quarks,
+                      guint n)
+{
+    g_return_val_if_fail(quarks, 0);
+    guint nn = 0;
+    for (guint i = 0; i < n; i++) {
+        if (quarks[i])
+            quarks[nn++] = quarks[i];
+    }
+    return nn;
+}
+
 static void
 active_page_changed(GtkNotebook *notebook, G_GNUC_UNUSED GtkWidget *page, gint pageno, GwyParams *params)
 {
@@ -1439,7 +1469,7 @@ gwy_select_in_filtered_inventory_treeeview(GtkTreeView *treeview,
  * is made to do something reasonable even when all values are positive or negative.
  *
  * Usually @fullmin and @fullmax are simply the minimun and maximum, whereas @dispmin and @dispmax come from
- * a function like gwy_field_get_autorange(). Although the full range might also be used.
+ * a function like gwy_field_autorange(). Although the full range might also be used.
  **/
 void
 gwy_set_gradient_for_residuals(GwyGradient *gradient,
