@@ -1,5 +1,5 @@
 /*
- *  $Id: param-def.c 28873 2025-11-18 14:59:29Z yeti-dn $
+ *  $Id: param-def.c 29342 2026-01-24 03:12:22Z yeti-dn $
  *  Copyright (C) 2021-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -45,33 +45,34 @@ struct _GwyParamDefPrivate {
 #endif
 };
 
-static void   gwy_param_def_finalize    (GObject *gobject);
-static void   gwy_param_def_append      (GwyParamDef *pardef,
-                                         gint id,
-                                         const gchar *name,
-                                         const gchar *desc,
-                                         GwyParamDefItem *item);
-static void   gwy_param_def_append_enum (GwyParamDef *pardef,
-                                         gint id,
-                                         const gchar *name,
-                                         const gchar *desc,
-                                         GType gtype,
-                                         const GwyEnum *values,
-                                         gint nvalues,
-                                         gint default_value);
-static void   gwy_param_def_append_flags(GwyParamDef *pardef,
-                                         gint id,
-                                         const gchar *name,
-                                         const gchar *desc,
-                                         GType gtype,
-                                         const GwyEnum *values,
-                                         gint nvalues,
-                                         guint default_value);
-static gchar* rectify_string            (const gchar *value,
-                                         GwyParamStringFlags flags,
-                                         GwyRectifyStringFunc rectify);
-static gint   find_param_def            (GwyParamDefPrivate *priv,
-                                         gint id);
+static void   finalize      (GObject *gobject);
+static void   append_def    (GwyParamDef *pardef,
+                             gint id,
+                             const gchar *name,
+                             const gchar *desc,
+                             GwyParamDefItem *item);
+static void   append_enum   (GwyParamDef *pardef,
+                             gint id,
+                             const gchar *name,
+                             const gchar *desc,
+                             GType gtype,
+                             const GwyEnum *values,
+                             GwyEnum *free_me,
+                             gint nvalues,
+                             gint default_value);
+static void   append_flags  (GwyParamDef *pardef,
+                             gint id,
+                             const gchar *name,
+                             const gchar *desc,
+                             GType gtype,
+                             const GwyEnum *values,
+                             gint nvalues,
+                             guint default_value);
+static gchar* rectify_string(const gchar *value,
+                             GwyParamStringFlags flags,
+                             GwyRectifyStringFunc rectify);
+static gint   find_param_def(GwyParamDefPrivate *priv,
+                             gint id);
 
 static GObjectClass *parent_class = NULL;
 
@@ -84,7 +85,7 @@ gwy_param_def_class_init(GwyParamDefClass *klass)
 
     parent_class = gwy_param_def_parent_class;
 
-    gobject_class->finalize = gwy_param_def_finalize;
+    gobject_class->finalize = finalize;
 
     g_type_class_add_private(klass, sizeof(GwyParamDefPrivate));
 }
@@ -99,7 +100,7 @@ gwy_param_def_init(GwyParamDef *pardef)
 }
 
 static void
-gwy_param_def_finalize(GObject *gobject)
+finalize(GObject *gobject)
 {
     GwyParamDef *pardef = (GwyParamDef*)gobject;
     GwyParamDefPrivate *priv = pardef->priv;
@@ -108,6 +109,8 @@ gwy_param_def_finalize(GObject *gobject)
     for (i = 0; i < priv->ndefs; i++) {
         if (priv->defs[i].type == GWY_PARAM_STRING)
             g_free(priv->defs[i].def.s.default_value);
+        else if (priv->defs[i].type == GWY_PARAM_ENUM)
+            g_free(priv->defs[i].def.e.free_me);
     }
     g_free(priv->ids);
     g_free(priv->defs);
@@ -263,7 +266,7 @@ gwy_param_def_add_gwyenum(GwyParamDef *pardef,
                           gint nvalues,
                           gint default_value)
 {
-    gwy_param_def_append_enum(pardef, id, name, desc, 0, values, nvalues, default_value);
+    append_enum(pardef, id, name, desc, 0, values, NULL, nvalues, default_value);
 }
 
 /**
@@ -292,7 +295,53 @@ gwy_param_def_add_gwyflags(GwyParamDef *pardef,
                            gint nvalues,
                            guint default_value)
 {
-    gwy_param_def_append_flags(pardef, id, name, desc, 0, values, nvalues, default_value);
+    append_flags(pardef, id, name, desc, 0, values, nvalues, default_value);
+}
+
+static const GwyEnum*
+find_standard_enum(GType enum_gtype, const gchar **desc)
+{
+    static const GwyEnum dummy_enum[] = { { "???", 0 }, { NULL, 0 } };
+    const GwyEnum *values = NULL;
+
+    g_return_val_if_fail(enum_gtype, NULL);
+
+    if (enum_gtype == GWY_TYPE_MASKING_TYPE) {
+        values = gwy_masking_type_get_enum();
+        *desc = _("_Masking");
+    }
+    else if (enum_gtype == GWY_TYPE_INTERPOLATION_TYPE) {
+        values = gwy_interpolation_type_get_enum();
+        *desc = _("_Interpolation type");
+    }
+    else if (enum_gtype == GWY_TYPE_ORIENTATION) {
+        values = gwy_orientation_get_enum();
+        *desc = _("_Direction");
+    }
+    else if (enum_gtype == GWY_TYPE_MERGE_TYPE) {
+        values = gwy_merge_type_get_enum();
+        *desc = _("Combine with existing mask");
+    }
+    else if (enum_gtype == GWY_TYPE_WINDOWING_TYPE) {
+        values = gwy_windowing_type_get_enum();
+        *desc = _("_Windowing type");
+    }
+    else if (enum_gtype == GWY_TYPE_DISTANCE_TRANSFORM_TYPE) {
+        values = gwy_distance_transform_type_get_enum();
+        *desc = _("_Distance type");
+    }
+    else if (enum_gtype == GWY_TYPE_GRAPH_CURVE_TYPE) {
+        values = gwy_graph_curve_type_get_enum();
+        *desc = _("Plot _style");
+    }
+    else {
+        /* We could play with GEnumClass here but why.  It should be implemented if it is used. */
+        *desc = g_type_name(enum_gtype);
+        g_warning("Enum %s is unimplemented.  Should be?", *desc);
+        values = dummy_enum;
+    }
+
+    return values;
 }
 
 /**
@@ -322,57 +371,77 @@ gwy_param_def_add_enum(GwyParamDef *pardef,
                        GType enum_gtype,
                        gint default_value)
 {
-    static const GwyEnum dummy_enum[] = { { "???", 0 }, { NULL, 0 } };
-    const GwyEnum *values = NULL;
-    const gchar *standard_desc = NULL;
-
     g_return_if_fail(enum_gtype);
-    if (enum_gtype == GWY_TYPE_MASKING_TYPE) {
-        values = gwy_masking_type_get_enum();
-        standard_desc = _("_Masking");
+
+    const gchar *standard_desc = NULL;
+    const GwyEnum *values = find_standard_enum(enum_gtype, &standard_desc);
+    append_enum(pardef, id, name, desc ? desc : standard_desc, enum_gtype, values, NULL, -1, default_value);
+}
+
+/**
+ * gwy_param_def_add_enum_subset:
+ * @pardef: A set of parameter definitions.
+ * @id: Parameter identifier.
+ * @name: Parameter name for settings.  It can be %NULL for derived parameters not stored in settings.
+ * @desc: Parameter description which will be used for a label in GUI.  May be %NULL for the default label.
+ * @enum_gtype: Type of the enum, for instance %GWY_TYPE_MASKING_TYPE.
+ * @values: Array with enum values to select from the standard enum.
+ * @nvalues: The number of values in @values.
+ * @default_value: Default value of the parameter.
+ *
+ * Defines a new parameter with enumerated values from a subset of standard Gwyddion enum.
+ *
+ * This function is useful when the function uses a standard enum, but not all values make sense or are supported.
+ * A typical example is #GwyMergeType, for which usually only some operations are meaningful. The values in @values
+ * must exist in the standard enum and not repeat. See gwy_param_def_add_enum() for supported enums.
+ *
+ * See the introduction for @name and @desc lifetime rules.
+ *
+ * See gwy_param_def_add_gwyenum() for enums defined by a #GwyEnum table.
+ **/
+void
+gwy_param_def_add_enum_subset(GwyParamDef *pardef,
+                              gint id,
+                              const gchar *name,
+                              const gchar *desc,
+                              GType enum_gtype,
+                              const gint *values,
+                              guint nvalues,
+                              gint default_value)
+{
+    g_return_if_fail(enum_gtype);
+    g_return_if_fail(values || !nvalues);
+
+    const gchar *standard_desc = NULL;
+    const GwyEnum *allvalues = find_standard_enum(enum_gtype, &standard_desc);
+    if (!desc)
+        desc = standard_desc;
+
+    guint nall = count_enum_values(allvalues, -1);
+    GwyEnum *subset = g_new0(GwyEnum, nall);
+    guint nsubset, i;
+    for (nsubset = i = 0; i < nall; i++) {
+        gint idx = find_enum_value(allvalues, nall, values[i]);
+        if (idx < 0) {
+            g_warning("Subset value %d is not in the standard enum of param %s (%s).",
+                      values[i], name ? name : "(anonymous)", desc ? desc : "");
+            continue;
+        }
+        subset[nsubset++] = allvalues[i];
     }
-    else if (enum_gtype == GWY_TYPE_INTERPOLATION_TYPE) {
-        values = gwy_interpolation_type_get_enum();
-        standard_desc = _("_Interpolation type");
-    }
-    else if (enum_gtype == GWY_TYPE_ORIENTATION) {
-        values = gwy_orientation_get_enum();
-        standard_desc = _("_Direction");
-    }
-    else if (enum_gtype == GWY_TYPE_MERGE_TYPE) {
-        values = gwy_merge_type_get_enum();
-        standard_desc = _("Combine with existing mask");
-    }
-    else if (enum_gtype == GWY_TYPE_WINDOWING_TYPE) {
-        values = gwy_windowing_type_get_enum();
-        standard_desc = _("_Windowing type");
-    }
-    else if (enum_gtype == GWY_TYPE_DISTANCE_TRANSFORM_TYPE) {
-        values = gwy_distance_transform_type_get_enum();
-        standard_desc = _("_Distance type");
-    }
-    else if (enum_gtype == GWY_TYPE_GRAPH_CURVE_TYPE) {
-        values = gwy_graph_curve_type_get_enum();
-        standard_desc = _("Plot _style");
-    }
-    else {
-        /* We could play with GEnumClass here but why.  It should be implemented if it is used. */
-        standard_desc = g_type_name(enum_gtype);
-        g_warning("Enum %s is unimplemented.  Should be?", standard_desc);
-        values = dummy_enum;
-    }
-    gwy_param_def_append_enum(pardef, id, name, desc ? desc : standard_desc, enum_gtype, values, -1, default_value);
+    append_enum(pardef, id, name, desc, enum_gtype, subset, subset, nsubset, default_value);
 }
 
 static void
-gwy_param_def_append_enum(GwyParamDef *pardef,
-                          gint id,
-                          const gchar *name,
-                          const gchar *desc,
-                          GType gtype,
-                          const GwyEnum *values,
-                          gint nvalues,
-                          gint default_value)
+append_enum(GwyParamDef *pardef,
+            gint id,
+            const gchar *name,
+            const gchar *desc,
+            GType gtype,
+            const GwyEnum *values,
+            GwyEnum *free_me,
+            gint nvalues,
+            gint default_value)
 {
     GwyParamDefItem item;
     GwyParamDefEnum *e = &item.def.e;
@@ -388,6 +457,7 @@ gwy_param_def_append_enum(GwyParamDef *pardef,
     item.type = GWY_PARAM_ENUM;
     e->gtype = gtype;
     e->table = values;
+    e->free_me = free_me;
     e->nvalues = nvalues = count_enum_values(values, nvalues);
     e->default_value_index = find_enum_value(values, nvalues, default_value);
     if (e->default_value_index < 0) {
@@ -396,18 +466,18 @@ gwy_param_def_append_enum(GwyParamDef *pardef,
         e->default_value_index = 0;
     }
 
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 static void
-gwy_param_def_append_flags(GwyParamDef *pardef,
-                           gint id,
-                           const gchar *name,
-                           const gchar *desc,
-                           GType gtype,
-                           const GwyEnum *values,
-                           gint nvalues,
-                           guint default_value)
+append_flags(GwyParamDef *pardef,
+             gint id,
+             const gchar *name,
+             const gchar *desc,
+             GType gtype,
+             const GwyEnum *values,
+             gint nvalues,
+             guint default_value)
 {
     GwyParamDefItem item;
     GwyParamDefFlags *f = &item.def.f;
@@ -457,7 +527,7 @@ gwy_param_def_append_flags(GwyParamDef *pardef,
                   name ? name : "(anonymous)", desc ? desc : "", default_value);
     }
 
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -499,7 +569,7 @@ gwy_param_def_add_int(GwyParamDef *pardef,
         g_warning("Int param %s (%s) default value %d is out of range [%d..%d].",
                   name ? name : "(anonymous)", desc ? desc : "", default_value, minimum, maximum);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -526,7 +596,7 @@ gwy_param_def_add_active_page(GwyParamDef *pardef,
     GwyParamDefItem item;
 
     item.type = GWY_PARAM_ACTIVE_PAGE;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -555,7 +625,7 @@ gwy_param_def_add_boolean(GwyParamDef *pardef,
     b->is_instant_updates = FALSE;
     b->seed_id = -1;
     item.type = GWY_PARAM_BOOLEAN;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -594,7 +664,7 @@ gwy_param_def_add_instant_updates(GwyParamDef *pardef,
     if (!desc)
         desc = _("I_nstant updates");
     item.type = GWY_PARAM_BOOLEAN;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -639,7 +709,7 @@ gwy_param_def_add_randomize(GwyParamDef *pardef,
 
     if (!desc)
         desc = _("Randomi_ze when re-run");
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -682,7 +752,7 @@ gwy_param_def_add_double(GwyParamDef *pardef,
         g_warning("Double param %s (%s) default value %.14g is out of range [%.14g..%.14g].",
                   name ? name : "(anonymous)", desc ? desc : "", default_value, minimum, maximum);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -738,7 +808,7 @@ gwy_param_def_add_angle(GwyParamDef *pardef,
         g_warning("Double param %s (%s) default value %.14g is out of range [%.14g..%.14g].",
                   name ? name : "(anonymous)", desc ? desc : "", default_value, d->minimum, d->maximum);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -780,7 +850,7 @@ gwy_param_def_add_percentage(GwyParamDef *pardef,
         g_warning("Double param %s (%s) default value %.14g is out of range [%.14g..%.14g].",
                   name ? name : "(anonymous)", desc ? desc : "", default_value, d->minimum, d->maximum);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -819,7 +889,7 @@ gwy_param_def_add_mask_color(GwyParamDef *pardef,
     c->is_mask = TRUE;
     c->has_alpha = TRUE;
     c->default_value = default_mask_color;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -854,7 +924,7 @@ gwy_param_def_add_color(GwyParamDef *pardef,
     c->is_mask = FALSE;
     c->has_alpha = has_alpha;
     c->default_value = _gwy_param_def_rectify_color(&item, default_value);
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -885,7 +955,7 @@ gwy_param_def_add_target_graph(GwyParamDef *pardef,
 
     item.type = GWY_PARAM_GRAPH_ID;
     di->is_target_graph = TRUE;
-    gwy_param_def_append(pardef, id, name, desc ? desc : _("Target _graph"), &item);
+    append_def(pardef, id, name, desc ? desc : _("Target _graph"), &item);
 }
 
 /**
@@ -916,7 +986,7 @@ gwy_param_def_add_graph_id(GwyParamDef *pardef,
 
     item.type = GWY_PARAM_GRAPH_ID;
     di->is_target_graph = FALSE;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -943,7 +1013,7 @@ gwy_param_def_add_image_id(GwyParamDef *pardef,
     GwyParamDefItem item;
 
     item.type = GWY_PARAM_IMAGE_ID;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -970,7 +1040,7 @@ gwy_param_def_add_volume_id(GwyParamDef *pardef,
     GwyParamDefItem item;
 
     item.type = GWY_PARAM_VOLUME_ID;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -997,7 +1067,7 @@ gwy_param_def_add_xyz_id(GwyParamDef *pardef,
     GwyParamDefItem item;
 
     item.type = GWY_PARAM_XYZ_ID;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1024,7 +1094,7 @@ gwy_param_def_add_curve_map_id(GwyParamDef *pardef,
     GwyParamDefItem item;
 
     item.type = GWY_PARAM_CURVE_MAP_ID;
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1061,7 +1131,7 @@ gwy_param_def_add_graph_curve(GwyParamDef *pardef,
     i->default_value = 0;
     if (!desc)
         desc = _("C_urve");
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1097,7 +1167,7 @@ gwy_param_def_add_lawn_curve(GwyParamDef *pardef,
     i->default_value = 0;
     if (!desc)
         desc = _("C_urve");
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1133,7 +1203,7 @@ gwy_param_def_add_lawn_segment(GwyParamDef *pardef,
     i->default_value = 0;
     if (!desc)
         desc = _("_Segment");
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1179,7 +1249,7 @@ gwy_param_def_add_report_type(GwyParamDef *pardef,
         g_warning("Report type param %s (%s) default value %u is not among allowed values.",
                   name ? name : "(anonymous)", desc ? desc : "", default_value);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1207,7 +1277,7 @@ gwy_param_def_add_hold_selection(GwyParamDef *pardef,
 
     if (!desc)
         desc = _("_Hold selection");
-    gwy_param_def_append_flags(pardef, id, name, desc, GWY_TYPE_HOLD_SELECTION_FLAGS,
+    append_flags(pardef, id, name, desc, GWY_TYPE_HOLD_SELECTION_FLAGS,
                                hold_flags, G_N_ELEMENTS(hold_flags), 0);
 }
 
@@ -1239,7 +1309,7 @@ gwy_param_def_add_seed(GwyParamDef *pardef,
     rs->randomize_id = -1;
     if (!desc)
         desc = _("R_andom seed");
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1278,7 +1348,7 @@ gwy_param_def_add_string(GwyParamDef *pardef,
         g_warning("String param %s (%s) default value \"%s\" does not rectify to itself but to \"%s\".",
                   name ? name : "(anonymous)", desc ? desc : "", default_value, s->default_value);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1310,7 +1380,7 @@ gwy_param_def_add_unit(GwyParamDef *pardef,
 
     item.type = GWY_PARAM_UNIT;
     si->default_value = g_intern_string(default_value);
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 /**
@@ -1348,7 +1418,7 @@ gwy_param_def_add_resource(GwyParamDef *pardef,
         g_warning("Resource param %s (%s) default value \"%s\" is not in the inventory.",
                   name ? name : "(anonymous)", desc ? desc : "", default_value);
     }
-    gwy_param_def_append(pardef, id, name, desc, &item);
+    append_def(pardef, id, name, desc, &item);
 }
 
 static gpointer
@@ -1404,15 +1474,15 @@ gwy_param_def_add_grain_groups(GwyParamDef *pardef,
 
     if (!desc)
         desc = _("Expanded groups");
-    gwy_param_def_append_flags(pardef, id, name, desc, 0, values, G_N_ELEMENTS(values)-1, default_value);
+    append_flags(pardef, id, name, desc, 0, values, G_N_ELEMENTS(values)-1, default_value);
 }
 
 static void
-gwy_param_def_append(GwyParamDef *pardef,
-                     gint id,
-                     const gchar *name,
-                     const gchar *desc,
-                     GwyParamDefItem *item)
+append_def(GwyParamDef *pardef,
+           gint id,
+           const gchar *name,
+           const gchar *desc,
+           GwyParamDefItem *item)
 {
     GwyParamDefPrivate *priv;
     gint i, len;
