@@ -1,5 +1,5 @@
 /*
- *  $Id: params.c 29075 2026-01-02 17:49:31Z yeti-dn $
+ *  $Id: params.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -445,7 +445,7 @@ gwy_params_load_from_settings(GwyParams *params)
 {
     GwyParamsPrivate *priv;
     GwyParamValue *values;
-    GwyContainer *settings;
+    GwyDict *settings;
     const gchar *modname;
     GString *str;
     GHashTable *data_ids;
@@ -490,61 +490,61 @@ gwy_params_load_from_settings(GwyParams *params)
         g_string_append(str, def->name);
         quark = g_quark_from_string(str->str);
         if (type == GWY_PARAM_BOOLEAN)
-            gwy_container_gis_boolean(settings, quark, &value->b);
+            gwy_dict_gis_boolean(settings, quark, &value->b);
         else if (type == GWY_PARAM_INT || type == GWY_PARAM_ACTIVE_PAGE) {
             gint32 v;
-            if (gwy_container_gis_int32(settings, quark, &v))
+            if (gwy_dict_gis_int32(settings, quark, &v))
                 set_int_value(value, def, v);
         }
         else if (type == GWY_PARAM_RANDOM_SEED) {
             gint32 v;
-            if (gwy_container_gis_int32(settings, quark, &v))
+            if (gwy_dict_gis_int32(settings, quark, &v))
                 set_random_seed_value(value, def, v);
             /* Do not randomize here.  We may not know yet whether or not.  But remember we may have to. */
         }
         else if (type == GWY_PARAM_ENUM) {
             gint32 v;
-            if (gwy_container_gis_int32(settings, quark, &v))
+            if (gwy_dict_gis_int32(settings, quark, &v))
                 set_enum_value(value, def, v);
         }
         else if (type == GWY_PARAM_FLAGS) {
             guint v;
-            if (gwy_container_gis_enum(settings, quark, &v))
+            if (gwy_dict_gis_enum(settings, quark, &v))
                 set_flags_value(value, def, v);
         }
         else if (type == GWY_PARAM_REPORT_TYPE) {
             guint v;
-            if (gwy_container_gis_enum(settings, quark, &v))
+            if (gwy_dict_gis_enum(settings, quark, &v))
                 set_report_type_value(value, def, v);
         }
         else if (type == GWY_PARAM_DOUBLE) {
             gdouble v;
-            if (gwy_container_gis_double(settings, quark, &v))
+            if (gwy_dict_gis_double(settings, quark, &v))
                 set_double_value(value, def, v);
         }
         else if (type == GWY_PARAM_STRING) {
             const gchar *v;
-            if (gwy_container_gis_string(settings, quark, &v))
+            if (gwy_dict_gis_string(settings, quark, &v))
                 set_string_value(value, def, v);
         }
         else if (param_type_is_curve_no(type)) {
             const gchar *v;
-            if (gwy_container_gis_string(settings, quark, &v))
+            if (gwy_dict_gis_string(settings, quark, &v))
                 set_curve_string_value(value, def, v);
         }
         else if (type == GWY_PARAM_UNIT) {
             const gchar *v;
-            if (gwy_container_gis_string(settings, quark, &v))
+            if (gwy_dict_gis_string(settings, quark, &v))
                 set_unit_value(value, def, v);
         }
         else if (type == GWY_PARAM_RESOURCE_NAME) {
             const gchar *v;
-            if (gwy_container_gis_string(settings, quark, &v))
+            if (gwy_dict_gis_string(settings, quark, &v))
                 set_resource_value(value, def, v);
         }
         else if (type == GWY_PARAM_COLOR) {
             GwyRGBA v;
-            if (gwy_rgba_get_from_container(&v, settings, str->str))
+            if (gwy_rgba_get_from_dict(&v, settings, str->str))
                 set_color_value(value, def, v);
         }
         else if (param_type_is_data_id(type)) {
@@ -598,7 +598,7 @@ gwy_params_save_to_settings(GwyParams *params)
 {
     GwyParamsPrivate *priv;
     GwyParamValue *values;
-    GwyContainer *settings;
+    GwyDict *settings;
     const gchar *modname;
     GString *str;
     guint i, n, pfxlen;
@@ -636,33 +636,33 @@ gwy_params_save_to_settings(GwyParams *params)
         g_string_append(str, def->name);
         quark = g_quark_from_string(str->str);
         if (type == GWY_PARAM_BOOLEAN)
-            gwy_container_set_boolean(settings, quark, value->b);
+            gwy_dict_set_boolean(settings, quark, value->b);
         else if (type == GWY_PARAM_INT || type == GWY_PARAM_ACTIVE_PAGE)
-            gwy_container_set_int32(settings, quark, value->i);
+            gwy_dict_set_int32(settings, quark, value->i);
         else if (type == GWY_PARAM_ENUM)
-            gwy_container_set_int32(settings, quark, value->i);
+            gwy_dict_set_int32(settings, quark, value->i);
         else if (type == GWY_PARAM_FLAGS)
-            gwy_container_set_enum(settings, quark, value->u);
+            gwy_dict_set_enum(settings, quark, value->u);
         else if (type == GWY_PARAM_REPORT_TYPE)
-            gwy_container_set_enum(settings, quark, value->rt);
+            gwy_dict_set_enum(settings, quark, value->rt);
         else if (type == GWY_PARAM_RANDOM_SEED)
-            gwy_container_set_int32(settings, quark, value->i);
+            gwy_dict_set_int32(settings, quark, value->i);
         else if (type == GWY_PARAM_DOUBLE)
-            gwy_container_set_double(settings, quark, value->d);
+            gwy_dict_set_double(settings, quark, value->d);
         else if (type == GWY_PARAM_STRING)
-            gwy_container_set_const_string(settings, quark, value->s ? value->s : "");
+            gwy_dict_set_const_string(settings, quark, value->s ? value->s : "");
         else if (param_type_is_curve_no(type))
-            gwy_container_set_const_string(settings, quark, value->cu.s ? value->cu.s : "");
+            gwy_dict_set_const_string(settings, quark, value->cu.s ? value->cu.s : "");
         else if (type == GWY_PARAM_UNIT)
-            gwy_container_set_const_string(settings, quark, value->si.s ? value->si.s : "");
+            gwy_dict_set_const_string(settings, quark, value->si.s ? value->si.s : "");
         else if (type == GWY_PARAM_RESOURCE_NAME) {
             if (value->s)
-                gwy_container_set_const_string(settings, quark, value->s);
+                gwy_dict_set_const_string(settings, quark, value->s);
             else
-                gwy_container_remove(settings, quark);
+                gwy_dict_remove(settings, quark);
         }
         else if (type == GWY_PARAM_COLOR)
-            gwy_rgba_store_to_container(&value->c, settings, str->str);
+            gwy_rgba_store_to_dict(&value->c, settings, str->str);
         else if (param_type_is_data_id(type)) {
             GwyAppDataId *dataid = g_hash_table_lookup(data_ids, GUINT_TO_POINTER(quark));
 
@@ -827,15 +827,15 @@ gwy_params_get_enum(GwyParams *params,
  * gwy_params_get_masking:
  * @params: A parameter value set.
  * @id: Parameter identifier.
- * @mask: Pointer to mask data field to update (can also be %NULL).
+ * @mask: Pointer to mask number field to update (can also be %NULL).
  *
  * Gets the value of a masking type enum parameter, consistently with a mask field.
  *
  * If @mask is %NULL the returned value is simply the parameter value.
  *
  * If @mask is a pointer then @mask and the return value can be modified.  The function will set @mask to %NULL if
- * masking is %GWY_MASK_IGNORE.  Conversely, it will return %GWY_MASK_IGNORE if @mask is a pointer to %NULL data
- * field.  In short, if a @mask argument is passed a non-ignore masking mode is guaranteed to coincide with non-%NULL
+ * masking is %GWY_MASK_IGNORE.  Conversely, it will return %GWY_MASK_IGNORE if @mask is a pointer to a %NULL number
+ * field. In short, if a @mask argument is passed a non-ignore masking mode is guaranteed to coincide with non-%NULL
  * mask.
  *
  * Returns: The masking enum parameter value.
@@ -843,7 +843,7 @@ gwy_params_get_enum(GwyParams *params,
 GwyMaskingType
 gwy_params_get_masking(GwyParams *params,
                        gint id,
-                       GwyField **mask)
+                       GwyNield **mask)
 {
     GwyMaskingType masking;
 
@@ -1317,7 +1317,7 @@ gwy_params_get_image(GwyParams *params,
 }
 
 /**
- * gwy_params_get_mask:
+ * gwy_params_get_image_mask:
  * @params: A parameter value set.
  * @id: Parameter identifier.
  *
@@ -1327,11 +1327,11 @@ gwy_params_get_image(GwyParams *params,
  *
  * Returns: The mask data field, or %NULL if the parameter is none (or the image no longer exists).
  **/
-GwyField*
+GwyNield*
 gwy_params_get_image_mask(GwyParams *params,
                           gint id)
 {
-    return get_data_object(params, id, GWY_PARAM_IMAGE_ID, gwy_file_key_image_mask, GWY_TYPE_FIELD);
+    return get_data_object(params, id, GWY_PARAM_IMAGE_ID, gwy_file_key_image_mask, GWY_TYPE_NIELD);
 }
 
 /**
@@ -1657,13 +1657,23 @@ set_boolean_value(GwyParamValue *pvalue, gboolean value)
     return FALSE;
 }
 
+static inline const gchar*
+name_for_warning(const GwyParamDefItem *def)
+{
+    if (def->name && *def->name)
+        return def->name;
+    if (def->desc && *def->desc)
+        return def->desc;
+    return "(anonymous)";
+}
+
 static gboolean
 set_int_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gint value)
 {
     gint goodvalue = _gwy_param_def_rectify_int(def, value);
 
     if (value != goodvalue) {
-        g_warning("Value %d is not in the range of int id=%d.", value, def->id);
+        g_warning("Value %d is not in the range of int %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->i == goodvalue)
         return FALSE;
@@ -1677,7 +1687,7 @@ set_random_seed_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gint va
     gint goodvalue = _gwy_param_def_rectify_random_seed(def, value);
 
     if (value != goodvalue) {
-        g_warning("Value %d is not in the range of random seed id=%d.", value, def->id);
+        g_warning("Value %d is not in the range of random seed %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->i == goodvalue)
         return FALSE;
@@ -1691,7 +1701,7 @@ set_double_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gdouble valu
     gdouble goodvalue = _gwy_param_def_rectify_double(def, value);
 
     if (fabs(value - goodvalue) > 1e-14*(fabs(value) + fabs(goodvalue))) {
-        g_warning("Value %.14g is not in the range of double id=%d.", value, def->id);
+        g_warning("Value %.14g is not in the range of double %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->d == goodvalue)
         return FALSE;
@@ -1706,7 +1716,7 @@ set_enum_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gint value)
 
     goodvalue = _gwy_param_def_rectify_enum(def, value);
     if (value != goodvalue) {
-        g_warning("Value %d is not in enum id=%d.", value, def->id);
+        g_warning("Value %d is not in enum %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->i == goodvalue)
         return FALSE;
@@ -1721,7 +1731,7 @@ set_flags_value(GwyParamValue *pvalue, const GwyParamDefItem *def, guint value)
 
     goodvalue = _gwy_param_def_rectify_flags(def, value);
     if (value != goodvalue) {
-        g_warning("Value %u is not in flags id=%d.", value, def->id);
+        g_warning("Value %u is not in flags %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->u == goodvalue)
         return FALSE;
@@ -1736,7 +1746,7 @@ set_report_type_value(GwyParamValue *pvalue, const GwyParamDefItem *def, GwyResu
 
     goodvalue = _gwy_param_def_rectify_report_type(def, value);
     if (value != goodvalue) {
-        g_warning("Value %u is not in report type id=%d.", value, def->id);
+        g_warning("Value %u is not in report type %s (id=%d).", value, name_for_warning(def), def->id);
     }
     if (pvalue->rt == goodvalue)
         return FALSE;
@@ -1771,7 +1781,7 @@ set_curve_int_value(GwyParamValue *pvalue, const GwyParamDefItem *def, gint valu
 {
     gint goodvalue = MAX(value, 0);
     if (value != goodvalue) {
-        g_warning("Value %d is not a valid curve number in id=%d.", value, def->id);
+        g_warning("Value %d is not a valid curve number in %s (id=%d).", value, name_for_warning(def), def->id);
         return FALSE;
     }
     pvalue->cu.use_string = FALSE;
@@ -1815,10 +1825,11 @@ set_color_value(GwyParamValue *pvalue, const GwyParamDefItem *def, GwyRGBA value
     GwyRGBA *rgba;
 
     if (value.r != goodvalue.r || value.g != goodvalue.g || value.b != goodvalue.b) {
-        g_warning("Color component values are not in the allowed range of color id=%d.", def->id);
+        g_warning("Color component values are not in the allowed range of color %s (id=%d).",
+                  name_for_warning(def), def->id);
     }
     if (def->def.c.has_alpha && value.a != goodvalue.a) {
-        g_warning("Alpha value is not in the allowed range of color id=%d.", def->id);
+        g_warning("Alpha value is not in the allowed range of color %s (id=%d).", name_for_warning(def), def->id);
     }
     rgba = &pvalue->c;
     if (rgba->r == goodvalue.r && rgba->g == goodvalue.b && rgba->b == goodvalue.b && rgba->a == goodvalue.a)
@@ -1843,7 +1854,8 @@ set_resource_value(GwyParamValue *pvalue, const GwyParamDefItem *def, const gcha
     const gchar *goodvalue = _gwy_param_def_rectify_resource(def, value);
 
     if (g_strcmp0(goodvalue, value)) {
-        g_warning("Resource name does not correspond to any item in the inventory for id=%d.", def->id);
+        g_warning("Resource name does not correspond to any item in the inventory for %s (id=%d).",
+                  name_for_warning(def), def->id);
     }
     /* The empty inventory case is odd and should not normally happen. */
     return gwy_assign_string(&pvalue->s, goodvalue);
@@ -1984,7 +1996,7 @@ get_data_object_for_id(GwyAppDataId dataid, GQuark (*get_key_func)(gint id), GTy
     if (dataid.datano < 0
         || dataid.id < 0
         || !(file = gwy_data_browser_get_file(dataid.datano))
-        || !gwy_container_gis_object(GWY_CONTAINER(file), get_key_func(dataid.id), &object)
+        || !gwy_dict_gis_object(GWY_DICT(file), get_key_func(dataid.id), &object)
         || !g_type_is_a(G_TYPE_FROM_INSTANCE(object), object_type))
         return NULL;
     return object;
