@@ -1,5 +1,5 @@
 /*
- *  $Id: resource-editor.c 27953 2025-05-09 16:45:29Z yeti-dn $
+ *  $Id: resource-editor.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -178,10 +178,10 @@ gwy_resource_editor_setup(GwyResourceEditor *editor)
     }
     klass->instance = editor;
 
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
     const gchar *name = klass->base_resource;
     gchar *key = g_strconcat(klass->settings_prefix, "/current", NULL);
-    gwy_container_gis_string_by_name(settings, key, &name);
+    gwy_dict_gis_string_by_name(settings, key, &name);
     g_free(key);
 
     GwyResourceEditorPrivate *priv = editor->priv;
@@ -282,9 +282,9 @@ unmap(GtkWidget *widget)
 
     GwyResource *resource;
     if ((resource = get_active(editor, NULL, NULL, NULL))) {
-        GwyContainer *settings = gwy_app_settings_get();
+        GwyDict *settings = gwy_app_settings_get();
         gchar *key = g_strconcat(klass->settings_prefix, "/current", NULL);
-        gwy_container_set_string_by_name(settings, key, g_strdup(gwy_resource_get_name(resource)));
+        gwy_dict_set_string_by_name(settings, key, g_strdup(gwy_resource_get_name(resource)));
         g_free(key);
     }
 
