@@ -1,5 +1,5 @@
 /*
- *  $Id: results-export.c 28734 2025-10-29 10:18:03Z yeti-dn $
+ *  $Id: results-export.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2017-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -557,7 +557,7 @@ gwy_results_export_set_actions_sensitive(GwyResultsExport *rexport,
 /**
  * gwy_results_fill_filename:
  * @results: Set of reported scalar values.
- * @id: Value identifier.
+ * @resid: Value identifier.
  * @file: Data container corresponding to a file.
  *
  * Fills data file name in a set of reported scalar values.
@@ -567,18 +567,18 @@ gwy_results_export_set_actions_sensitive(GwyResultsExport *rexport,
  **/
 void
 gwy_results_fill_filename(GwyResults *results,
-                          const gchar *id,
+                          const gchar *resid,
                           GwyFile *file)
 {
     g_return_if_fail(GWY_IS_RESULTS(results));
-    g_return_if_fail(id);
+    g_return_if_fail(resid);
     g_return_if_fail(GWY_IS_FILE(file));
 
     const gchar *name;
-    if (gwy_container_gis_string(GWY_CONTAINER(file), gwy_file_key_filename(), &name))
-        gwy_results_fill_values(results, id, name, NULL);
+    if (gwy_dict_gis_string(GWY_DICT(file), gwy_file_key_filename(), &name))
+        gwy_results_fill_values(results, resid, name, NULL);
     else
-        gwy_results_set_na(results, id, NULL);
+        gwy_results_set_na(results, resid, NULL);
 }
 
 /**
