@@ -1,5 +1,5 @@
 /*
- *  $Id: settings.c 28795 2025-11-05 08:58:49Z yeti-dn $
+ *  $Id: settings.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -34,34 +34,34 @@
 
 static gboolean create_config_dir_real       (const gchar *cfgdir,
                                               GError **error);
-static void     gwy_app_settings_set_defaults(GwyContainer *settings);
-static void     gwy_app_settings_gather      (GwyContainer *settings);
-static void     gwy_app_settings_apply       (GwyContainer *settings);
+static void     gwy_app_settings_set_defaults(GwyDict *settings);
+static void     gwy_app_settings_gather      (GwyDict *settings);
+static void     gwy_app_settings_apply       (GwyDict *settings);
 
 static const GwyRGBA default_mask_color = { 1.0, 0.0, 0.0, 0.5 };
 static const gchar *magic_header = "Gwyddion Settings 1.0\n";
 
-static GwyContainer *gwy_settings = NULL;
+static GwyDict *gwy_settings = NULL;
 
 /**
  * gwy_app_settings_get:
  *
  * Gets the Gwyddion settings.
  *
- * The program settings are in a #GwyContainer, which is normally loaded at program startup using a function like
+ * The program settings are in a #GwyDict, which is normally loaded at program startup using a function like
  * gwy_app_init() and saved at exit using a function like gwy_app_settings_save(). If you use settings, you should
  * load resources beforehand. Or, better, use gwy_app_init().
  *
  * For storing persistent module data manually you should use <literal>"/module/YOUR_MODULE_NAME/"</literal> prefix.
  * However, in common cases you should use #GwyParamDef and #GwyParams which can handle the dirty work themselves.
  *
- * Returns: The settings as a #GwyContainer.
+ * Returns: The settings as a #GwyDict.
  **/
-GwyContainer*
+GwyDict*
 gwy_app_settings_get(void)
 {
     if (!gwy_settings) {
-        gwy_settings = GWY_CONTAINER(gwy_container_new());
+        gwy_settings = GWY_DICT(gwy_dict_new());
         gwy_app_settings_set_defaults(gwy_settings);
         gwy_app_settings_apply(gwy_settings);
     }
@@ -97,7 +97,7 @@ gboolean
 gwy_app_settings_save(const gchar *filename,
                       GError **error)
 {
-    GwyContainer *settings;
+    GwyDict *settings;
     GPtrArray *pa;
     guint i;
     gboolean ok;
@@ -113,7 +113,7 @@ gwy_app_settings_save(const gchar *filename,
     gwy_debug("Saving text settings to `%s'", filename);
     settings = gwy_app_settings_get();
     gwy_app_settings_gather(settings);
-    g_return_val_if_fail(GWY_IS_CONTAINER(settings), FALSE);
+    g_return_val_if_fail(GWY_IS_DICT(settings), FALSE);
     fh = gwy_fopen(filename, "w");
     if (!fh) {
         g_set_error(error, GWY_APP_SETTINGS_ERROR, GWY_APP_SETTINGS_ERROR_FILE,
@@ -128,7 +128,7 @@ gwy_app_settings_save(const gchar *filename,
     }
 
     ok = TRUE;
-    pa = gwy_container_serialize_to_text(settings);
+    pa = gwy_dict_serialize_to_text(settings);
     for (i = 0; i < pa->len; i++) {
         if (fputs((gchar*)pa->pdata[i], fh) == EOF) {
             g_set_error(error, GWY_APP_SETTINGS_ERROR, GWY_APP_SETTINGS_ERROR_FILE,
@@ -157,13 +157,13 @@ gwy_app_settings_save(const gchar *filename,
  * Any existing settings are discarded. Consider gwy_app_settings_merge_string() for piecewise settings creation.
  *
  * Returns: Whether it succeeded.  In either case you can call gwy_app_settings_get() then to obtain either the loaded
- *          settings or the old ones (if failed), or an empty #GwyContainer.
+ *          settings or the old ones (if failed), or an empty #GwyDict.
  **/
 gboolean
 gwy_app_settings_load(const gchar *filename,
                       GError **error)
 {
-    GwyContainer *new_settings;
+    GwyDict *new_settings;
     GError *err = NULL;
     gchar *buffer = NULL;
     gsize size = 0;
@@ -190,7 +190,7 @@ gwy_app_settings_load(const gchar *filename,
         g_free(buffer);
         return FALSE;
     }
-    new_settings = gwy_container_deserialize_from_text(buffer + strlen(magic_header));
+    new_settings = gwy_dict_deserialize_from_text(buffer + strlen(magic_header));
     g_free(buffer);
     if (!new_settings) {
         g_set_error(error, GWY_APP_SETTINGS_ERROR, GWY_APP_SETTINGS_ERROR_CORRUPT,
@@ -204,7 +204,7 @@ gwy_app_settings_load(const gchar *filename,
 
     //FIXME: deleting "/module/logistic/thetas" stored in wrong
     //FIXME: format during 2.46 development cycle
-    gwy_container_remove_by_prefix(gwy_settings, "/module/logistic/thetas");
+    gwy_dict_remove_by_prefix(gwy_settings, "/module/logistic/thetas");
 
     return TRUE;
 }
@@ -229,7 +229,7 @@ gwy_app_settings_merge_string(const gchar *s,
                               gboolean overwrite,
                               GError **error)
 {
-    GwyContainer *settings, *new_settings;
+    GwyDict *settings, *new_settings;
     const gchar *s_to_parse;
     gchar *buffer = NULL;
 
@@ -241,7 +241,7 @@ gwy_app_settings_merge_string(const gchar *s,
 
     buffer = gwy_strkill(g_strdup(s), "\r");
     s_to_parse = (g_str_has_prefix(buffer, magic_header) ? buffer + strlen(magic_header) : buffer);
-    new_settings = gwy_container_deserialize_from_text(s_to_parse);
+    new_settings = gwy_dict_deserialize_from_text(s_to_parse);
     g_free(buffer);
     if (!new_settings) {
         g_set_error(error, GWY_APP_SETTINGS_ERROR, GWY_APP_SETTINGS_ERROR_CORRUPT,
@@ -249,7 +249,7 @@ gwy_app_settings_merge_string(const gchar *s,
         return FALSE;
     }
 
-    gwy_container_transfer(new_settings, settings, "/", "/", FALSE, overwrite);
+    gwy_dict_transfer(new_settings, settings, "/", "/", FALSE, overwrite);
     g_object_unref(new_settings);
 
     return TRUE;
@@ -327,7 +327,7 @@ create_config_dir_real(const gchar *cfgdir, GError **error)
 }
 
 static void
-gwy_app_settings_set_defaults(GwyContainer *settings)
+gwy_app_settings_set_defaults(GwyDict *settings)
 {
     static const gchar default_preferred_gradients[] =
         "BW1\n"
@@ -358,20 +358,20 @@ gwy_app_settings_set_defaults(GwyContainer *settings)
         "Silver\n"
         "Warmish-White";
 
-    if (!gwy_container_contains_by_name(settings, "/mask/alpha"))
-        gwy_rgba_store_to_container(&default_mask_color, settings, "/mask");
-    if (!gwy_container_contains_by_name(settings, "/app/gradients/preferred"))
-        gwy_container_set_const_string_by_name(settings, "/app/gradients/preferred", default_preferred_gradients);
-    if (!gwy_container_contains_by_name(settings, "/app/glmaterials/preferred"))
-        gwy_container_set_const_string_by_name(settings, "/app/glmaterials/preferred", default_preferred_gl_materials);
-    if (!gwy_container_contains_by_name(settings, "/app/toolbox/visible/graph"))
-        gwy_container_set_boolean_by_name(settings, "/app/toolbox/visible/graph", TRUE);
-    if (!gwy_container_contains_by_name(settings, "/app/toolbox/visible/proc"))
-        gwy_container_set_boolean_by_name(settings, "/app/toolbox/visible/proc", TRUE);
-    if (!gwy_container_contains_by_name(settings, "/app/toolbox/visible/tool"))
-        gwy_container_set_boolean_by_name(settings, "/app/toolbox/visible/tool", TRUE);
-    if (!gwy_container_contains_by_name(settings, "/app/toolbox/visible/zoom"))
-        gwy_container_set_boolean_by_name(settings, "/app/toolbox/visible/zoom", TRUE);
+    if (!gwy_dict_contains_by_name(settings, "/mask/alpha"))
+        gwy_rgba_store_to_dict(&default_mask_color, settings, "/mask");
+    if (!gwy_dict_contains_by_name(settings, "/app/gradients/preferred"))
+        gwy_dict_set_const_string_by_name(settings, "/app/gradients/preferred", default_preferred_gradients);
+    if (!gwy_dict_contains_by_name(settings, "/app/glmaterials/preferred"))
+        gwy_dict_set_const_string_by_name(settings, "/app/glmaterials/preferred", default_preferred_gl_materials);
+    if (!gwy_dict_contains_by_name(settings, "/app/toolbox/visible/graph"))
+        gwy_dict_set_boolean_by_name(settings, "/app/toolbox/visible/graph", TRUE);
+    if (!gwy_dict_contains_by_name(settings, "/app/toolbox/visible/proc"))
+        gwy_dict_set_boolean_by_name(settings, "/app/toolbox/visible/proc", TRUE);
+    if (!gwy_dict_contains_by_name(settings, "/app/toolbox/visible/tool"))
+        gwy_dict_set_boolean_by_name(settings, "/app/toolbox/visible/tool", TRUE);
+    if (!gwy_dict_contains_by_name(settings, "/app/toolbox/visible/zoom"))
+        gwy_dict_set_boolean_by_name(settings, "/app/toolbox/visible/zoom", TRUE);
 }
 
 static void
@@ -394,7 +394,7 @@ add_preferred_resource_name(G_GNUC_UNUSED gpointer key,
  **/
 /* TODO: refactor common resource code */
 static void
-gwy_app_settings_gather(GwyContainer *settings)
+gwy_app_settings_gather(GwyDict *settings)
 {
     GPtrArray *preferred;
     const gchar *name;
@@ -403,33 +403,33 @@ gwy_app_settings_gather(GwyContainer *settings)
     preferred = g_ptr_array_new();
     gwy_inventory_foreach(gwy_gradients(), &add_preferred_resource_name, preferred);
     g_ptr_array_add(preferred, NULL);
-    gwy_container_set_string_by_name(settings, "/app/gradients/preferred",
+    gwy_dict_set_string_by_name(settings, "/app/gradients/preferred",
                                      g_strjoinv("\n", (gchar**)preferred->pdata));
     g_ptr_array_set_size(preferred, 0);
     gwy_inventory_foreach(gwy_gl_materials(), &add_preferred_resource_name, preferred);
     g_ptr_array_add(preferred, NULL);
-    gwy_container_set_string_by_name(settings, "/app/glmaterials/preferred",
+    gwy_dict_set_string_by_name(settings, "/app/glmaterials/preferred",
                                      g_strjoinv("\n", (gchar**)preferred->pdata));
     g_ptr_array_free(preferred, TRUE);
 
     /* Default resources */
     name = gwy_inventory_get_default_item_name(gwy_gradients());
     if (name)
-        gwy_container_set_string_by_name(settings, "/app/gradients/default", g_strdup(name));
+        gwy_dict_set_string_by_name(settings, "/app/gradients/default", g_strdup(name));
     name = gwy_inventory_get_default_item_name(gwy_gl_materials());
     if (name)
-        gwy_container_set_string_by_name(settings, "/app/glmaterials/default", g_strdup(name));
+        gwy_dict_set_string_by_name(settings, "/app/glmaterials/default", g_strdup(name));
 }
 
 static void
-apply_resource_settings(GwyContainer *settings,
+apply_resource_settings(GwyDict *settings,
                         const gchar *prefix, const gchar *name, GwyInventory *inventory)
 {
     const gchar *s;
     gchar *key;
 
     key = g_strconcat(prefix, "/preferred", NULL);
-    if (gwy_container_gis_string_by_name(settings, key, &s)) {
+    if (gwy_dict_gis_string_by_name(settings, key, &s)) {
         if (inventory) {
             gchar **preferred = g_strsplit(s, "\n", 0);
             for (gchar **p = preferred; *p; p++) {
@@ -445,7 +445,7 @@ apply_resource_settings(GwyContainer *settings,
     g_free(key);
 
     key = g_strconcat(prefix, "/default", NULL);
-    if (gwy_container_gis_string_by_name(settings, key, &s)) {
+    if (gwy_dict_gis_string_by_name(settings, key, &s)) {
         if (inventory)
             gwy_inventory_set_default_item_name(inventory, s);
         else
@@ -461,7 +461,7 @@ apply_resource_settings(GwyContainer *settings,
  * Applies initial settings to things that need it.
  **/
 static void
-gwy_app_settings_apply(GwyContainer *settings)
+gwy_app_settings_apply(GwyDict *settings)
 {
     gboolean disabled;
 
@@ -470,11 +470,11 @@ gwy_app_settings_apply(GwyContainer *settings)
     apply_resource_settings(settings, "/app/glmaterials", "GL material", gwy_gl_materials());
 
     /* Globally disabled OpenGL view axes */
-    if (gwy_container_gis_boolean_by_name(settings, "/app/3d/axes/disable", &disabled) && disabled)
+    if (gwy_dict_gis_boolean_by_name(settings, "/app/3d/axes/disable", &disabled) && disabled)
         gwy_gl_view_class_disable_axis_drawing(disabled);
 
     /* Globally disabled logging */
-    if (gwy_container_gis_boolean_by_name(settings, "/app/log/disable", &disabled) && disabled)
+    if (gwy_dict_gis_boolean_by_name(settings, "/app/log/disable", &disabled) && disabled)
         gwy_log_set_enabled(FALSE);
 }
 
@@ -572,7 +572,7 @@ gwy_app_settings_get_default_mask_color(GwyRGBA *color)
 {
     g_return_if_fail(color);
 
-    if (gwy_settings && gwy_rgba_get_from_container(color, gwy_settings, "/mask"))
+    if (gwy_settings && gwy_rgba_get_from_dict(color, gwy_settings, "/mask"))
         return;
     *color = default_mask_color;
 }
@@ -603,8 +603,8 @@ gwy_app_settings_error_quark(void)
  * @short_description: Application and module settings
  * @see_also: #GwyParamDef, #GwyParams -- a higher level module settings interface
  *
- * All application and module settings are stored in a one big #GwyContainer which can be obtained by
- * gwy_app_settings_get(). Then you can use #GwyContainer functions to get and save settings.
+ * All application and module settings are stored in a one big #GwyDict which can be obtained by
+ * gwy_app_settings_get(). Then you can use #GwyDict functions to get and save settings.
  *
  * The rest of the setting manipulating functions is normally useful only in the main application.
  **/
