@@ -1,5 +1,5 @@
 /*
- *  $Id: undo.c 28779 2025-11-04 17:00:29Z yeti-dn $
+ *  $Id: undo.c 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003-2006,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -56,21 +56,21 @@ typedef struct {
     gint modif;
 } GwyAppUndo;
 
-static void        undo_log_container              (GwyContainer *data);
-static void        redo_log_container              (GwyContainer *data);
+static void        undo_log_container              (GwyDict *data);
+static void        redo_log_container              (GwyDict *data);
 static void        gwy_app_undo_reuse_levels       (GwyAppUndoLevel *level,
                                                     GList *available);
-static void        gwy_app_undo_or_redo            (GwyContainer *data,
+static void        gwy_app_undo_or_redo            (GwyDict *data,
                                                     GwyAppUndoLevel *level);
 static GList*      gwy_list_split                  (GList *list,
                                                     guint n,
                                                     GList **tail);
-static void        gwy_app_undo_container_finalized(gpointer userdata,
+static void        gwy_app_undo_dict_finalized(gpointer userdata,
                                                     GObject *deceased_data);
 static void        gwy_app_undo_list_free          (GList *list);
 static gint        gwy_app_undo_compare_data       (gconstpointer a,
                                                     gconstpointer b);
-static GwyAppUndo* gwy_undo_get_for_data           (GwyContainer *data,
+static GwyAppUndo* gwy_undo_get_for_data           (GwyDict *data,
                                                     gboolean do_create);
 static void        gwy_app_log_undo_or_redo        (GwyFile *data,
                                                     GwyAppUndoLevel *level,
@@ -91,7 +91,7 @@ static gboolean undo_disabled = FALSE;
  * Returns: Undo level id (zero if undo/redo is disabled).  Not useful (yet).
  **/
 gulong
-gwy_app_undo_checkpoint(GwyContainer *data,
+gwy_app_undo_checkpoint(GwyDict *data,
                         ...)
 {
     va_list ap;
@@ -137,7 +137,7 @@ gwy_app_undo_checkpoint(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_app_undo_checkpointv(GwyContainer *data,
+gwy_app_undo_checkpointv(GwyDict *data,
                          guint n,
                          const gchar **keys)
 {
@@ -162,7 +162,7 @@ gwy_app_undo_checkpointv(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_app_undo_qcheckpoint(GwyContainer *data,
+gwy_app_undo_qcheckpoint(GwyDict *data,
                          ...)
 {
     va_list ap;
@@ -208,7 +208,7 @@ gwy_app_undo_qcheckpoint(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_app_undo_qcheckpointv(GwyContainer *data,
+gwy_app_undo_qcheckpointv(GwyDict *data,
                           guint n,
                           const GQuark *keys)
 {
@@ -222,23 +222,23 @@ gwy_app_undo_qcheckpointv(GwyContainer *data,
 }
 
 /**
- * gwy_app_undo_undo_container:
+ * gwy_app_undo_undo_dict:
  * @data: A data container.
  *
  * Performs undo on a data container.
  *
  * It must have undo available.
  *
- * In addition to what gwy_undo_undo_container() does, this function takes care
+ * In addition to what gwy_undo_undo_dict() does, this function takes care
  * of updating application controls state.
  **/
 void
-gwy_app_undo_undo_container(GwyContainer *data)
+gwy_app_undo_undo_dict(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
     undo_log_container(data);
-    gwy_undo_undo_container(data);
+    gwy_undo_undo_dict(data);
     appundo = gwy_undo_get_for_data(data, FALSE);
     if (!appundo)
         return;
@@ -248,23 +248,23 @@ gwy_app_undo_undo_container(GwyContainer *data)
 }
 
 /**
- * gwy_app_undo_redo_container:
+ * gwy_app_undo_redo_dict:
  * @data: A data container.
  *
  * Performs undo on a data container.
  *
  * It must have redo available.
  *
- * In addition to what gwy_undo_redo_container() does, this function takes care
+ * In addition to what gwy_undo_redo_dict() does, this function takes care
  * of updating application controls state.
  **/
 void
-gwy_app_undo_redo_container(GwyContainer *data)
+gwy_app_undo_redo_dict(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
     redo_log_container(data);
-    gwy_undo_redo_container(data);
+    gwy_undo_redo_dict(data);
     appundo = gwy_undo_get_for_data(data, FALSE);
     if (!appundo)
         return;
@@ -283,7 +283,7 @@ gwy_app_undo_redo_container(GwyContainer *data)
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_undo_checkpoint(GwyContainer *data,
+gwy_undo_checkpoint(GwyDict *data,
                     ...)
 {
     va_list ap;
@@ -324,7 +324,7 @@ gwy_undo_checkpoint(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_undo_qcheckpoint(GwyContainer *data,
+gwy_undo_qcheckpoint(GwyDict *data,
                      ...)
 {
     va_list ap;
@@ -368,7 +368,7 @@ gwy_undo_qcheckpoint(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_undo_checkpointv(GwyContainer *data,
+gwy_undo_checkpointv(GwyDict *data,
                      guint n,
                      const gchar **keys)
 {
@@ -377,7 +377,7 @@ gwy_undo_checkpointv(GwyContainer *data,
     if (!UNDO_LEVELS || undo_disabled)
         return 0;
 
-    g_return_val_if_fail(GWY_IS_CONTAINER(data), 0UL);
+    g_return_val_if_fail(GWY_IS_DICT(data), 0UL);
     if (!n) {
         g_warning("Nothing to save for undo, no undo level will be created.");
         return 0UL;
@@ -408,7 +408,7 @@ gwy_undo_checkpointv(GwyContainer *data,
  * Returns: Undo level id.  Not useful (yet).
  **/
 gulong
-gwy_undo_qcheckpointv(GwyContainer *data,
+gwy_undo_qcheckpointv(GwyDict *data,
                       guint n,
                       const GQuark *keys)
 {
@@ -422,7 +422,7 @@ gwy_undo_qcheckpointv(GwyContainer *data,
     if (!UNDO_LEVELS || undo_disabled)
         return 0;
 
-    g_return_val_if_fail(GWY_IS_CONTAINER(data), 0UL);
+    g_return_val_if_fail(GWY_IS_DICT(data), 0UL);
     for (i = j = 0; i < n; i++) {
         if (keys[i])
             j++;
@@ -451,7 +451,7 @@ gwy_undo_qcheckpointv(GwyContainer *data,
         memset(&item->value, 0, sizeof(GValue));
         /* This call itself creates a copy for non-objects; for objects it increases reference count.  However, if we
          * are saving nonexistence, item->value is left zero-filled. */
-        gwy_container_gis_value(data, item->key, &item->value);
+        gwy_dict_gis_value(data, item->key, &item->value);
         j++;
     }
     g_assert(j == level->nitems);
@@ -535,7 +535,7 @@ gwy_app_undo_reuse_levels(GwyAppUndoLevel *level,
 }
 
 /**
- * gwy_undo_undo_container:
+ * gwy_undo_undo_dict:
  * @data: A data container.
  *
  * Performs undo on a data container.
@@ -543,7 +543,7 @@ gwy_app_undo_reuse_levels(GwyAppUndoLevel *level,
  * It must have undo available.
  **/
 void
-gwy_undo_undo_container(GwyContainer *data)
+gwy_undo_undo_dict(GwyDict *data)
 {
     GwyAppUndo *appundo;
     GwyAppUndoLevel *level;
@@ -566,7 +566,7 @@ gwy_undo_undo_container(GwyContainer *data)
 }
 
 static void
-undo_log_container(GwyContainer *data)
+undo_log_container(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
@@ -579,7 +579,7 @@ undo_log_container(GwyContainer *data)
 }
 
 /**
- * gwy_undo_redo_container:
+ * gwy_undo_redo_dict:
  * @data: A data container.
  *
  * Performs undo on a data container.
@@ -587,7 +587,7 @@ undo_log_container(GwyContainer *data)
  * It must have redo available.
  **/
 void
-gwy_undo_redo_container(GwyContainer *data)
+gwy_undo_redo_dict(GwyDict *data)
 {
     GwyAppUndo *appundo;
     GwyAppUndoLevel *level;
@@ -610,7 +610,7 @@ gwy_undo_redo_container(GwyContainer *data)
 }
 
 static void
-redo_log_container(GwyContainer *data)
+redo_log_container(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
@@ -623,7 +623,7 @@ redo_log_container(GwyContainer *data)
 }
 
 static void
-gwy_app_undo_or_redo(GwyContainer *data,
+gwy_app_undo_or_redo(GwyDict *data,
                      GwyAppUndoLevel *level)
 {
     GValue value;
@@ -636,7 +636,7 @@ gwy_app_undo_or_redo(GwyContainer *data,
 
         /* This call itself creates a copy for non-objects; for objects it increases reference count.  However, if we
          * are restoring nonexistence, item->value is left zero-filled. */
-        app = gwy_container_gis_value(data, item->key, &value);
+        app = gwy_dict_gis_value(data, item->key, &value);
         undo = G_VALUE_TYPE(&item->value) != 0;
         if (undo && app) {
             if (G_VALUE_TYPE(&item->value) != G_VALUE_TYPE(&value)) {
@@ -652,27 +652,27 @@ gwy_app_undo_or_redo(GwyContainer *data,
                 object = g_value_get_object(&item->value);
                 gwy_debug("saved object: %p", object);
                 object = G_OBJECT(gwy_serializable_copy(GWY_SERIALIZABLE(object)));
-                gwy_container_pass_object(data, item->key, object);
+                gwy_dict_pass_object(data, item->key, object);
 
                 g_value_copy(&value, &item->value);
                 g_value_unset(&value);
             }
             else {
-                gwy_container_set_value(data, item->key, &item->value);
+                gwy_dict_set_value(data, item->key, &item->value);
                 g_value_copy(&item->value, &value);
                 g_value_unset(&value);
             }
         }
         else if (undo && !app) {
             gwy_debug("Restoring item <%s>", g_quark_to_string(item->key));
-            gwy_container_set_value(data, item->key, &item->value);
+            gwy_dict_set_value(data, item->key, &item->value);
             g_value_unset(&item->value);
         }
         else if (!undo && app) {
             gwy_debug("Deleting item <%s>", g_quark_to_string(item->key));
             g_value_init(&item->value, G_VALUE_TYPE(&value));
             g_value_copy(&value, &item->value);
-            gwy_container_remove(data, item->key);
+            gwy_dict_remove(data, item->key);
             g_value_unset(&value);
         }
         else
@@ -746,7 +746,7 @@ gwy_list_split(GList *list,
 }
 
 /**
- * gwy_undo_container_has_undo:
+ * gwy_undo_dict_has_undo:
  * @data: Data container to get undo infomation of.
  *
  * Returns whether there is any undo available for a container.
@@ -754,7 +754,7 @@ gwy_list_split(GList *list,
  * Returns: %TRUE if there is undo, %FALSE otherwise.
  **/
 gboolean
-gwy_undo_container_has_undo(GwyContainer *data)
+gwy_undo_dict_has_undo(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
@@ -763,7 +763,7 @@ gwy_undo_container_has_undo(GwyContainer *data)
 }
 
 /**
- * gwy_undo_container_has_redo:
+ * gwy_undo_dict_has_redo:
  * @data: Data container to get redo infomation of.
  *
  * Returns whether there is any redo available for a container.
@@ -771,7 +771,7 @@ gwy_undo_container_has_undo(GwyContainer *data)
  * Returns: %TRUE if there is redo, %FALSE otherwise.
  **/
 gboolean
-gwy_undo_container_has_redo(GwyContainer *data)
+gwy_undo_dict_has_redo(GwyDict *data)
 {
     GwyAppUndo *appundo;
 
@@ -780,14 +780,14 @@ gwy_undo_container_has_redo(GwyContainer *data)
 }
 
 /**
- * gwy_app_undo_container_finalized:
+ * gwy_app_undo_dict_finalized:
  * @userdata: Item from @container_list corresponding to finalized data.
- * @deceased_data: A #GwyContainer pointer (the object may not longer exits).
+ * @deceased_data: A #GwyDict pointer (the object may not longer exits).
  *
  * Removes all undo and redo information for a container.
  **/
 static void
-gwy_app_undo_container_finalized(gpointer userdata,
+gwy_app_undo_dict_finalized(gpointer userdata,
                                  GObject *deceased_data)
 {
     GList *item = (GList*)userdata;
@@ -844,7 +844,7 @@ gwy_app_undo_compare_data(gconstpointer a,
 }
 
 static GwyAppUndo*
-gwy_undo_get_for_data(GwyContainer *data,
+gwy_undo_get_for_data(GwyDict *data,
                       gboolean do_create)
 {
     GwyAppUndo *appundo;
@@ -859,7 +859,7 @@ gwy_undo_get_for_data(GwyContainer *data,
         appundo = g_new0(GwyAppUndo, 1);
         appundo->container = data;
         container_list = g_list_prepend(container_list, appundo);
-        g_object_weak_ref(G_OBJECT(data), gwy_app_undo_container_finalized, container_list);
+        g_object_weak_ref(G_OBJECT(data), gwy_app_undo_dict_finalized, container_list);
 
         return appundo;
     }
@@ -874,7 +874,7 @@ gwy_undo_get_for_data(GwyContainer *data,
 }
 
 static GList*
-gwy_undo_container_remove_from_list(GList *list,
+gwy_undo_dict_remove_from_list(GList *list,
                                     const gchar *prefix)
 {
     guint i, j, len;
@@ -914,14 +914,14 @@ gwy_undo_container_remove_from_list(GList *list,
 }
 
 /**
- * gwy_undo_container_remove:
+ * gwy_undo_dict_remove:
  * @data: A data container.
  * @prefix: Prefix to remove undo/redo information under.  Pass %NULL to remove undo/redo information altogether.
  *
  * Removes undo/redo information for a data container.
  **/
 void
-gwy_undo_container_remove(GwyContainer *data,
+gwy_undo_dict_remove(GwyDict *data,
                           const gchar *prefix)
 {
     GwyAppUndo *appundo;
@@ -943,28 +943,28 @@ gwy_undo_container_remove(GwyContainer *data,
         return;
     }
 
-    appundo->undo = gwy_undo_container_remove_from_list(appundo->undo, prefix);
-    appundo->redo = gwy_undo_container_remove_from_list(appundo->redo, prefix);
+    appundo->undo = gwy_undo_dict_remove_from_list(appundo->undo, prefix);
+    appundo->redo = gwy_undo_dict_remove_from_list(appundo->redo, prefix);
 }
 
 /**
- * gwy_app_undo_container_remove:
+ * gwy_app_undo_dict_remove:
  * @data: A data container managed by the data-browser.
  * @prefix: Prefix to remove undo/redo information under.  Pass %NULL to remove
  *          undo/redo information altogether.
  *
  * Removes undo/redo information for a data container.
  *
- * In addition to what gwy_undo_container_remove() does, this function takes
+ * In addition to what gwy_undo_dict_remove() does, this function takes
  * care of updating application controls state.
  **/
 void
-gwy_app_undo_container_remove(GwyContainer *data,
+gwy_app_undo_dict_remove(GwyDict *data,
                               const gchar *prefix)
 {
     GwyAppUndo *appundo;
 
-    gwy_undo_container_remove(data, prefix);
+    gwy_undo_dict_remove(data, prefix);
     appundo = gwy_undo_get_for_data(data, FALSE);
     if (!appundo)
         return;
@@ -996,7 +996,7 @@ gwy_undo_get_enabled(void)
  * conserve resources.
  *
  * If undo/redo is disabled undo information manipulating functions such as gwy_app_undo_qcheckpoint() become no-op
- * and gwy_undo_container_get_modified() always returns zero. Disabling undo also removes saved undo data of all
+ * and gwy_undo_dict_get_modified() always returns zero. Disabling undo also removes saved undo data of all
  * containers.
  **/
 void
@@ -1036,7 +1036,7 @@ gwy_undo_set_enabled(gboolean setting)
  * state.  Container-level functions only perform the actual undo or redo and can be used for local undo
  * implementation.
  *
- * Undo information for a #GwyContainer is automatically destroyed when the container is finalized.
+ * Undo information for a #GwyDict is automatically destroyed when the container is finalized.
  **/
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
