@@ -1,5 +1,5 @@
 /*
- *  $Id: validate.c 28818 2025-11-06 15:52:22Z yeti-dn $
+ *  $Id: validate.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2007-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -183,7 +183,7 @@ validate_item_pass1(GQuark key,
     errors = &info->errors;
     strkey = g_quark_to_string(key);
     check_ascii_key(strkey, key, errors);
-    if (strkey[0] != GWY_CONTAINER_PATHSEP)
+    if (strkey[0] != GWY_DICT_PATHSEP)
         *errors = g_slist_prepend(*errors, FAIL(GWY_DATA_ERROR_KEY_FORMAT, key, NULL));
 
     id = _gwy_app_analyse_data_key(strkey, &type, &len);
@@ -251,7 +251,7 @@ validate_item_pass1(GQuark key,
         case KEY_IS_BRICK_META:
         case KEY_IS_SURFACE_META:
         case KEY_IS_LAWN_META:
-        check_type(gvalue, GWY_TYPE_CONTAINER, key, errors);
+        check_type(gvalue, GWY_TYPE_DICT, key, errors);
         break;
 
         case KEY_IS_CHANNEL_LOG:
@@ -520,8 +520,8 @@ validate_item_pass3(GQuark key,
     PUSH(info->stack, typename);
     /* TODO GTK3 checking reference counts ceases to be useful once we remove unit setters from all data objects
      * because then units cannot be accidentally owned by multiple data objects. */
-    if (GWY_IS_CONTAINER(object))
-        gwy_container_foreach((GwyContainer*)object, NULL, &validate_item_pass3, info);
+    if (GWY_IS_DICT(object))
+        gwy_dict_foreach((GwyDict*)object, NULL, &validate_item_pass3, info);
     else if (GWY_IS_FIELD(object)) {
         GwyField *field = (GwyField*)object;
 
@@ -573,7 +573,7 @@ validate_item_pass3(GQuark key,
 
 G_GNUC_UNUSED
 static void
-gwy_data_correct(GwyContainer *data,
+gwy_data_correct(GwyDict *data,
                  GSList *failures)
 {
     GwyDataValidationFailure *failure;
@@ -586,7 +586,7 @@ gwy_data_correct(GwyContainer *data,
             continue;
 
         /* Everything else can be fixed by removal of the offending items. */
-        gwy_container_remove(data, failure->key);
+        gwy_dict_remove(data, failure->key);
     }
 }
 #endif
@@ -633,10 +633,10 @@ gwy_data_validate(GwyFile *data,
     info.xyzs = g_array_new(FALSE, FALSE, sizeof(gint));
     info.curve_maps = g_array_new(FALSE, FALSE, sizeof(gint));
 
-    gwy_container_foreach(data, NULL, &validate_item_pass1, &info);
-    gwy_container_foreach(data, NULL, &validate_item_pass2, &info);
+    gwy_dict_foreach(data, NULL, &validate_item_pass1, &info);
+    gwy_dict_foreach(data, NULL, &validate_item_pass2, &info);
     if (flags & GWY_DATA_VALIDATE_REF_COUNT)
-        gwy_container_foreach(data, NULL, &validate_item_pass3, &info);
+        gwy_dict_foreach(data, NULL, &validate_item_pass3, &info);
 
     if (flags & GWY_DATA_VALIDATE_CORRECT)
         gwy_data_correct(data, info.errors);
@@ -694,7 +694,7 @@ gwy_data_error_desrcibe(GwyDataError error)
  * @title: Validate
  * @short_description: Check data sanity and consistency
  *
- * A #GwyContainer can be used to represent all sorts of data.  However, Gwyddion, the application, follows certain
+ * A #GwyDict can be used to represent all sorts of data.  However, Gwyddion, the application, follows certain
  * conventions in data organization. Function gwy_data_validate() checks whether the data actually follows them. This
  * includes but is not limited to representability of keys in ASCII, conformance to the key naming convention, types
  * of objects and other items corresponding to expectation, string values being valid UTF-8 and no stray secondary
@@ -716,7 +716,7 @@ gwy_data_error_desrcibe(GwyDataError error)
 
 /**
  * GwyDataError:
- * @GWY_DATA_ERROR_KEY_FORMAT: Key format is invalid (e.g. does not start with %GWY_CONTAINER_PATHSEP).
+ * @GWY_DATA_ERROR_KEY_FORMAT: Key format is invalid (e.g. does not start with %GWY_DICT_PATHSEP).
  * @GWY_DATA_ERROR_KEY_CHARACTERS: Key contains unprintable characters or characters not representable in ASCII.
  * @GWY_DATA_ERROR_KEY_UNKNOWN: Key does not correspond to any data item known to this version of Gwyddion.
  * @GWY_DATA_ERROR_KEY_ID: Key corresponds to a data item with bogus id number.
