@@ -1,5 +1,5 @@
 /*
- *  $Id: arithmetic.c 28903 2025-11-24 15:49:51Z yeti-dn $
+ *  $Id: arithmetic.c 29269 2026-01-17 11:12:31Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -916,10 +916,9 @@ field_compatibility_check_common(GwyField *result,
                                  gdouble **op2data,
                                  gsize *n)
 {
-    GwyDataMismatchFlags flags = GWY_DATA_MISMATCH_RES;
-    g_return_val_if_fail(GWY_IS_FIELD(result), FALSE);
-    g_return_val_if_fail(!gwy_field_is_incompatible(result, operand1, flags), FALSE);
-    g_return_val_if_fail(!gwy_field_is_incompatible(result, operand2, flags), FALSE);
+    if (!_gwy_field_check_other(result, operand1, FALSE)
+        || !_gwy_field_check_other(result, operand2, FALSE))
+        return FALSE;
     *resdata = result->priv->data;
     *op1data = operand1->priv->data;
     *op2data = operand2->priv->data;
