@@ -1,6 +1,6 @@
 #pragma once
 /*
- *  $Id: brick.h 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: brick.h 29516 2026-02-22 17:31:25Z klapetek $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -123,6 +123,7 @@ gdouble         gwy_brick_get_xoffset            (GwyBrick *brick);
 gdouble         gwy_brick_get_yoffset            (GwyBrick *brick);
 gdouble         gwy_brick_get_zoffset            (GwyBrick *brick);
 const gdouble*  gwy_brick_get_data_const         (GwyBrick *brick);
+gdouble*        gwy_brick_get_data               (GwyBrick *brick);
 void            gwy_brick_invalidate             (GwyBrick *brick);
 void            gwy_brick_set_xreal              (GwyBrick *brick,
                                                   gdouble xreal);
@@ -143,8 +144,8 @@ GwyUnit*        gwy_brick_get_unit_x             (GwyBrick *brick);
 GwyUnit*        gwy_brick_get_unit_y             (GwyBrick *brick);
 GwyUnit*        gwy_brick_get_unit_z             (GwyBrick *brick);
 GwyUnit*        gwy_brick_get_unit_w             (GwyBrick *brick);
-gdouble         gwy_brick_get_min                (GwyBrick *brick);
-gdouble         gwy_brick_get_max                (GwyBrick *brick);
+gdouble         gwy_brick_min                    (GwyBrick *brick);
+gdouble         gwy_brick_max                    (GwyBrick *brick);
 void            gwy_brick_copy_units             (GwyBrick *brick,
                                                   GwyBrick *target);
 GwyValueFormat* gwy_brick_get_value_format_x     (GwyBrick *brick,
@@ -159,7 +160,6 @@ GwyValueFormat* gwy_brick_get_value_format_z     (GwyBrick *brick,
 GwyValueFormat* gwy_brick_get_value_format_w     (GwyBrick *brick,
                                                   GwyUnitFormatStyle style,
                                                   GwyValueFormat *format);
-gdouble*        gwy_brick_get_data               (GwyBrick *brick);
 gdouble         gwy_brick_itor                   (GwyBrick *brick,
                                                   gdouble pixpos);
 gdouble         gwy_brick_rtoi                   (GwyBrick *brick,
@@ -326,7 +326,7 @@ void            gwy_brick_transpose              (GwyBrick *brick,
                                                   gboolean xflipped,
                                                   gboolean yflipped,
                                                   gboolean zflipped);
-void            gwy_brick_flip                 (GwyBrick *brick,
+void            gwy_brick_flip                   (GwyBrick *brick,
                                                   gboolean xflipped,
                                                   gboolean yflipped,
                                                   gboolean zflipped);
@@ -344,8 +344,14 @@ void            gwy_brick_set_xy_plane           (GwyBrick *brick,
                                                   gint lev);
 void            gwy_brick_add_to_xy_planes       (GwyBrick *brick,
                                                   GwyField *plane);
+void            gwy_brick_multiply_xy_planes     (GwyBrick *brick,
+                                                  GwyField *plane);
 void            gwy_brick_add_to_z_lines         (GwyBrick *brick,
                                                   GwyLine *line);
+gint            gwy_brick_threshold              (GwyBrick *brick,
+                                                  gdouble threshold,
+                                                  gdouble below,
+                                                  gdouble above);
 
 G_END_DECLS
 
