@@ -1,5 +1,5 @@
 /*
- *  $Id: correct--laplace.c 28972 2025-12-10 18:40:27Z yeti-dn $
+ *  $Id: correct--laplace.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -762,9 +762,7 @@ build_sparse_iterators(LaplaceIterators *iterators,
     }
 
     // Initialise with the mean value of right hand sides, including multiplicity.
-    rhssum /= nrhs;
-    for (ipt = 0; ipt < len; ipt++)
-        iterators->z[ipt] = rhssum;
+    gwy_math_fill(iterators->z, len, rhssum/nrhs);
 }
 
 static void
@@ -1469,28 +1467,27 @@ laplace_solve_grains(GwyField *field,
                      GwyNield *mask,
                      gint grain_from,
                      gint grain_to,
-                     gdouble qprec)
+                     gdouble qprec,
+                     gboolean work_on_copy)
 {
-    gint maxgno;
-    guint *sizes = (guint*)gwy_nield_get_sizes(mask, &maxgno);
+    gint maxgno = gwy_nield_max(mask);
+    maxgno = MAX(maxgno, 0);
+    const guint *sizes = _gwy_nield_ensure_sizes(mask);
     grain_from = MAX(grain_from, 1);
     grain_to = MIN(grain_to, maxgno);
-    if (grain_from > grain_to) {
-        g_free(sizes);
+    if (grain_from > grain_to)
         return;
-    }
 
     gint xres = field->xres, yres = field->yres;
     for (gint grain_id = grain_from; grain_id < grain_to; grain_id++) {
         // The underspecified case. In all other cases, there are some non-interpolated pixels to latch on.
         if (sizes[grain_id] == xres*yres) {
-            g_free(sizes);
             gwy_field_clear(field);
             return;
         }
     }
 
-    GwyFieldPart *bboxes = (GwyFieldPart*)gwy_nield_get_bounding_boxes(mask, NULL);
+    const GwyFieldPart *bboxes = (const GwyFieldPart*)_gwy_nield_ensure_bboxes(mask);
 
     // Allocate everything at the maximum size to avoid reallocations.
     guint maxsize = 0, maxbboxsize = 0;
@@ -1501,6 +1498,7 @@ laplace_solve_grains(GwyField *field,
     gdouble *z = g_new(gdouble, maxbboxsize);
     LaplaceIterators *iterators = laplace_iterators_new(maxsize, 5);
     gdouble *data = field->priv->data;
+    gdouble *srcdata = work_on_copy ? g_memdup2(data, xres*yres*sizeof(gdouble)) : NULL;
     const gint *grains = mask->priv->data;
     for (gint grain_id = grain_from; grain_id <= grain_to; grain_id++) {
         if (!sizes[grain_id])
@@ -1508,7 +1506,7 @@ laplace_solve_grains(GwyField *field,
 
         GwyFieldPart bbox = bboxes[grain_id], origbbox = bbox;
         enlarge_field_part(&bbox, xres, yres);
-        extract_grain(grains, data, xres, &bbox, grain_id, levels, z);
+        extract_grain(grains, srcdata ? srcdata : data, xres, &bbox, grain_id, levels, z);
         if (!handle_tiny_grain(bbox.width, bbox.height, z, levels, sizes[grain_id], &origbbox)) {
             laplace_sparse(iterators, revindex, z, levels, bbox.width, bbox.height, 60*qprec, 20*qprec);
             laplace_dense(iterators, revindex, z, levels, bbox.width, bbox.height, 60*qprec, 30*qprec);
@@ -1520,26 +1518,42 @@ laplace_solve_grains(GwyField *field,
     g_free(z);
     g_free(levels);
     g_free(revindex);
-    g_free(sizes);
-    g_free(bboxes);
+    g_free(srcdata);
 
     gwy_field_invalidate(field);
 }
 
+// FIXME: The interpolation can possibly take O(|field|²) time when grains are diagonal lines, concentric circles or
+// anything similar which has ∑|bbox| = O(|field|²). In these cases the optimal strategy may not be maximal splitting.
+// However, even though we could do some merging (based on colouring) and get the pixel sets easily, it is not clear
+// how to do the geometry analysis so that we never spend |bbox| time. We would have to hope the bounding boxes of the
+// entire coloured sets are nicer? Probably not worth to investigate. Unlike other cases that we needed to handle
+// better because they actually occur often in practice (a slew of tiny grains for which we were doing an expensive
+// analysis), this one is purely adversarial.
+
 /**
  * gwy_field_laplace_solve:
  * @field: A two-dimensional data field.
  * @mask: A two-dimensional data field containing mask defining the areas to interpolate.
- * @grain_id: The id number of the grain to replace with the solution of Laplace equation, from 1 to @ngrains (see
- *            gwy_field_grain_numbers()).  Passing 0 means to replace the entire empty space outside grains while
- *            passing a negative value means to replace the entire masked area.
+ * @grain_id: The id number of the grain to replace with the solution of Laplace equation, from 1 to the maximum grain
+ *            number (see gwy_nield_max()). Additionally, non-positive values from #GwyLaplaceAllType enum can be
+ *            passed to interpolate all marked or unmarked regions.
  * @qprec: Speed-accuracy tuning parameter.  Pass 1.0 for the default that is fast and sufficiently precise.
  *
  * Replaces masked areas by the solution of Laplace equation.
  *
  * The boundary conditions on mask boundaries are Dirichlet with values given by pixels on the outer boundary of the
  * masked area.  Boundary conditions at field edges are Neumann conditions ∂z/∂n=0 where n denotes the normal to the
- * edge.  If entire area of @field is to be replaced the problem is underspecified; @field will be filled with zeros.
+ * edge. If entire area of @field is to be replaced the problem is underspecified, and the minimum-norm solution is
+ * used, i.e. @field will be filled with zeros.
+ *
+ * Normally, the grains should be contiguous as produced by gwy_nield_number_contiguous() and the function is more
+ * efficient in this case. However, it will proceed with non-contiguous and touching grains. The main difference is
+ * for the interpolation of a single grain, when other touching grains are not treated differrently from unmarked
+ * areas. In particular, the Dirichlet boundary condition is imposed over the contact with other grains, not Neumann.
+ *
+ * When @grain_id is non-positive, the current numbering does not matter. In particular, distinct touching grains
+ * behave as a single merged grain for @grain_id ≤ 0 (they are not interpolated individually in sequence).
  *
  * For the default value of @qprec the the result should be good enough for any image processing purposes with the
  * typical local error of order 10⁻⁵ for very large grains and possibly much smaller for small grains.  You can lower
@@ -1549,101 +1563,93 @@ laplace_solve_grains(GwyField *field,
  **/
 void
 gwy_field_laplace_solve(GwyField *field,
-                        GwyField *mask,
-                        gint grain_id,
-                        gdouble qprec)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, GWY_MASK_INCLUDE);
-    gwy_nield_number_contiguous(nield);
-    gwy_NIELD_laplace_solve(field, nield, grain_id, qprec);
-    g_clear_object(&nield);
-}
-
-/**
- * gwy_NIELD_laplace_solve:
- * @field: A two-dimensional data field.
- * @mask: A two-dimensional data field containing mask defining the areas to interpolate.
- * @grain_id: The id number of the grain to replace with the solution of Laplace equation, from 1 to @ngrains (see
- *            gwy_field_grain_numbers()).  Passing 0 means to replace the entire empty space outside grains while
- *            passing a negative value means to replace the entire masked area.
- * @qprec: Speed-accuracy tuning parameter.  Pass 1.0 for the default that is fast and sufficiently precise.
- *
- * Replaces masked areas by the solution of Laplace equation.
- *
- * The boundary conditions on mask boundaries are Dirichlet with values given by pixels on the outer boundary of the
- * masked area.  Boundary conditions at field edges are Neumann conditions ∂z/∂n=0 where n denotes the normal to the
- * edge.  If entire area of @field is to be replaced the problem is underspecified; @field will be filled with zeros.
- *
- * Normally, the grains should be contiguous as produced by gwy_nield_number_contiguous(). The function will proceed
- * with non-contiguous grains, but the execution may be inefficient and/or the result weird. If grains are touching
- * and @grain_id is negative, they behave as a single merged grain. When interpolating a single grain, touching grains
- * are not treated differrently from unmarked areas. In particular, the Dirichlet boundary condition is imposed over
- * the contact with other grains, not Neumann.
- *
- * For the default value of @qprec the the result should be good enough for any image processing purposes with the
- * typical local error of order 10⁻⁵ for very large grains and possibly much smaller for small grains.  You can lower
- * @qprec down to about 0.3 or even 0.2 if speed is crucial and some precision can be sacrificed.  Below that the
- * result just starts becoming somewhat worse for not much speed increase.  Conversely, you may wish to increase
- * @qprec up to 3 or even 5 if accuracy is important and you can afford the increased computation time.
- **/
-void
-gwy_NIELD_laplace_solve(GwyField *field,
                         GwyNield *mask,
                         gint grain_id,
                         gdouble qprec)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
+    if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
 
     GwyNield *nield;
     gint grain_from = 1, grain_to = G_MAXINT;
+    gboolean is_num_contiguous = NCTEST(mask, IS_NUM_CONTIGUOUS);
+    gboolean work_on_copy = FALSE;
 
     if (grain_id <= 0) {
+        if (grain_id == GWY_LAPLACE_ALL_GRAINS && is_num_contiguous)
+            grain_id = GWY_LAPLACE_MASKED;
+
         // To fill the entire marked or empty space, we renumber to standard contiguous grains.
         nield = gwy_nield_copy(mask);
-        if (grain_id == 0)
+        if (grain_id == GWY_LAPLACE_UNMASKED) {
             gwy_nield_invert(nield);
-        gwy_nield_number_contiguous(nield);
+            gwy_nield_number_contiguous(nield);
+        }
+        else if (grain_id == GWY_LAPLACE_ALL_GRAINS) {
+            gwy_nield_split_noncontiguous(nield);
+            // Really necessary only if grains actually touch. But well…
+            work_on_copy = TRUE;
+        }
+        else {
+            // Someone might be passing old-style ‘negative value means the entire’
+            g_warn_if_fail(grain_id == GWY_LAPLACE_MASKED);
+            gwy_nield_number_contiguous(nield);
+        }
     }
-    else {
+    else if (NCTEST(mask, IS_NUM_CONTIGUOUS)) {
+        // Fill a single grain, knowing the marking is contiguous. The easy case.
+        if (grain_id > gwy_nield_max(mask))
+            return;
+
         nield = g_object_ref(mask);
         grain_from = grain_to = grain_id;
     }
+    else {
+        // Fill a single grain. However, it may be scattered all over the field. Isolate and renumber it to contiguous
+        // pieces.
+        nield = gwy_nield_copy(mask);
+        if (!gwy_nield_isolate(nield, grain_id, NULL)) {
+            g_object_unref(nield);
+            return;
+        }
+        grain_from = 1;
+        grain_to = gwy_nield_number_contiguous(nield);
+    }
 
-    laplace_solve_grains(field, nield, grain_from, grain_to, qprec);
+    laplace_solve_grains(field, nield, grain_from, grain_to, qprec, work_on_copy);
     g_object_unref(nield);
 }
 
+// Interpolate segment [from, to] using the data outside, i.e. at from-1 and/or to+1.
 static void
 interpolate_segment(GwyLine *line, gint from, gint to)
 {
     gint res = line->res;
     gdouble *d = line->priv->data;
-    gdouble zl, zr;
 
     g_assert(to < res-1 || from > 0);
 
     if (from == 0) {
-        zr = d[to+1];
+        gdouble zr = d[to+1];
         gwy_math_linspace(d + from, to+1 - from, zr, 0.0);
     }
     else if (to == res-1) {
-        zl = d[from-1];
+        gdouble zl = d[from-1];
         gwy_math_linspace(d + from, to+1 - from, zl, 0.0);
     }
     else {
-        zl = d[from-1];
-        zr = d[to+1];
-        gwy_math_linspace(d + from, to+1 - from, zl, (zr - zl)/(to+2 - from));
+        gdouble zl = d[from-1], zr = d[to+1];
+        gdouble step = (zr - zl)/(to+2 - from);
+        gwy_math_linspace(d + from, to+1 - from, zl + step, step);
     }
 }
 
 /**
- * gwy_line_correct_laplace:
+ * gwy_line_laplace_solve:
  * @line: A data line.
  * @mask_line: Mask of places to be corrected.
  *
- * Fills missing values in a data line using Laplace data correction.
+ * Fills missing values in a data line using Laplace interpolation.
  *
  * Both data lines must have the same number of values.
  *
@@ -1654,8 +1660,8 @@ interpolate_segment(GwyLine *line, gint from, gint to)
  *          is filled with zeros.
  **/
 gboolean
-gwy_line_correct_laplace(GwyLine *line,
-                         GwyLine *mask_line)
+gwy_line_laplace_solve(GwyLine *line,
+                       GwyLine *mask_line)
 {
     gint start = -1, i, res;
     const gdouble *m;
@@ -1690,4 +1696,13 @@ gwy_line_correct_laplace(GwyLine *line,
     return TRUE;
 }
 
+/**
+ * GwyLaplaceAllType:
+ * @GWY_LAPLACE_UNMASKED: The entire unmasked area (non-positive grain numbers).
+ * @GWY_LAPLACE_MASKED: The entire masked area (positive grain numbers) as a single merged region.
+ * @GWY_LAPLACE_ALL_GRAINS: All grains, but individually. Where grains touch, they behave as exterior to each other.
+ *
+ * Type of special grain number values that can be passed to gwy_field_laplace_solve().
+ **/
+
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
