@@ -1,5 +1,5 @@
 /*
- *  $Id: correct.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: correct.c 29544 2026-02-25 10:28:00Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -21,14 +21,14 @@
 #include <glib/gi18n-lib.h>
 
 #include "libgwyddion/macros.h"
-#include "libgwyddion/elliptic.h"
+#include "libgwyddion/shaped.h"
 #include "libgwyddion/linestats.h"
 #include "libgwyddion/level.h"
 #include "libgwyddion/stats.h"
-#include "libgwyddion/grains.h"
 #include "libgwyddion/filters.h"
 #include "libgwyddion/correct.h"
 #include "libgwyddion/interpolation.h"
+#include "libgwyddion/watershed.h"
 #include "libgwyddion/types.h"
 
 #include "libgwyddion/omp.h"
@@ -66,7 +66,7 @@ static void    compute_fourier_coeffs    (gint nder,
                                           gdouble *ct);
 
 /**
- * gwy_field_mask_outliers:
+ * gwy_field_mark_outliers:
  * @field: A data field.
  * @mask: A data field to be filled with mask.
  * @thresh: Threshold deviation.
@@ -77,53 +77,18 @@ static void    compute_fourier_coeffs    (gint nder,
  * outliers detection if @thresh is 3.
  **/
 void
-gwy_field_mask_outliers(GwyField *field,
-                        GwyField *mask,
-                        gdouble thresh)
-{
-    gwy_field_mask_outliers2(field, mask, thresh, thresh);
-}
-
-/**
- * gwy_NIELD_mask_outliers:
- * @field: A data field.
- * @mask: A data field to be filled with mask.
- * @thresh: Threshold deviation.
- *
- * Creates mask of data that are above or below @thresh*sigma from average height.
- *
- * Sigma denotes root-mean square deviation of heights. This criterium corresponds to the usual Gaussian distribution
- * outliers detection if @thresh is 3.
- **/
-void
-gwy_NIELD_mask_outliers(GwyField *field,
+gwy_field_mark_outliers(GwyField *field,
                         GwyNield *mask,
                         gdouble thresh)
 {
-    gwy_NIELD_mask_outliers2(field, mask, thresh, thresh);
+    gwy_field_mark_outliers2(field, mask, thresh, thresh);
 }
 
 static void
 mark_outside_range(GwyField *field,
-                   GwyField *mask,
+                   GwyNield *mask,
                    gdouble threshold_low,
                    gdouble threshold_high)
-{
-    gsize n = (gsize)field->xres * (gsize)field->yres;
-    const gdouble *d = field->priv->data;
-    gdouble *m = mask->priv->data;
-
-    for (gsize i = 0; i < n; i++)
-        m[i] = !(d[i] >= threshold_low && d[i] <= threshold_high);
-
-    gwy_field_invalidate(mask);
-}
-
-static void
-mark_outside_range_NIELD(GwyField *field,
-                         GwyNield *mask,
-                         gdouble threshold_low,
-                         gdouble threshold_high)
 {
     gsize n = (gsize)field->xres * (gsize)field->yres;
     const gdouble *d = field->priv->data;
@@ -136,7 +101,7 @@ mark_outside_range_NIELD(GwyField *field,
 }
 
 /**
- * gwy_field_mask_outliers2:
+ * gwy_field_mark_outliers2:
  * @field: A data field.
  * @mask: A data field to be filled with mask.
  * @thresh_low: Lower threshold deviation.
@@ -147,91 +112,27 @@ mark_outside_range_NIELD(GwyField *field,
  * Data that are below @mean-@thresh_low*@sigma or above @mean+@thresh_high*@sigma are marked as outliers, where
  * @sigma denotes the root-mean square deviation of data values.
  *
- * See gwy_field_mask_outliers_iqr() for a slower but more robust version which uses rank-based statistics.
+ * See gwy_field_mark_outliers_iqr() for a slower but more robust version which uses rank-based statistics. See also
+ * gwy_nield_mark_range() for marking inside/oustide given range.
  **/
 void
-gwy_field_mask_outliers2(GwyField *field,
-                         GwyField *mask,
-                         gdouble thresh_low,
-                         gdouble thresh_high)
-{
-    if (!_gwy_field_check_mask(field, &mask, NULL))
-        return;
-
-    gdouble avg = gwy_field_get_avg(field), rms = gwy_field_get_rms(field);
-    gdouble criterium_low = avg - rms*thresh_low;
-    gdouble criterium_high = avg + rms*thresh_high;
-    mark_outside_range(field, mask, criterium_low, criterium_high);
-}
-
-/**
- * gwy_field_mask_outliers_iqr:
- * @field: A data field.
- * @mask: A data field to be filled with mask.
- * @thresh_low: Lower threshold deviation.
- * @thresh_high: Upper threshold deviation.
- *
- * Creates mask of data that are above or below multiples of the inter-quartile range.
- *
- * Data that are below @quartile_25-@thresh_low*@iqr or above @quartile_75+@thresh_high*@iqr are marked as outliers,
- * where @iqr denotes the inter-quartile range of data values. Note that zero thresholds already remove everything
- * outside the IQR.
- *
- * See gwy_field_mask_outliers2() for a faster but less robust version which uses mean and standard deviation.
- **/
-void
-gwy_field_mask_outliers_iqr(GwyField *field,
-                            GwyField *mask,
-                            gdouble thresh_low,
-                            gdouble thresh_high)
-{
-    if (!_gwy_field_check_mask(field, &mask, NULL))
-        return;
-
-    gint xres = field->xres, yres = field->yres;
-    gdouble *buf = g_memdup(field->priv->data, xres*yres*sizeof(gdouble));
-
-    gdouble p[2] = { 25, 75 }, pv[2];
-    gwy_math_percentiles(buf, xres*yres, GWY_PERCENTILE_INTERPOLATION_LINEAR, p, 2, pv);
-    g_free(buf);
-    gdouble iqr = fabs(pv[1] - pv[0]);
-    gdouble criterium_low = pv[0] - thresh_low*iqr;
-    gdouble criterium_high = pv[1] + thresh_high*iqr;
-    mark_outside_range(field, mask, criterium_low, criterium_high);
-}
-
-/**
- * gwy_NIELD_mask_outliers2:
- * @field: A data field.
- * @mask: A data field to be filled with mask.
- * @thresh_low: Lower threshold deviation.
- * @thresh_high: Upper threshold deviation.
- *
- * Creates mask of data that are above or below multiples of rms from average height.
- *
- * Data that are below @mean-@thresh_low*@sigma or above @mean+@thresh_high*@sigma are marked as outliers, where
- * @sigma denotes the root-mean square deviation of data values.
- *
- * See gwy_NIELD_mask_outliers_iqr() for a slower but more robust version which uses rank-based statistics.
- **/
-void
-gwy_NIELD_mask_outliers2(GwyField *field,
+gwy_field_mark_outliers2(GwyField *field,
                          GwyNield *mask,
                          gdouble thresh_low,
                          gdouble thresh_high)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
+    if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
 
     gdouble avg, rms;
-    gwy_field_get_stats(field, &avg, NULL, &rms, NULL, NULL);
+    gwy_field_stats(field, &avg, NULL, &rms, NULL, NULL);
     gdouble criterium_low = avg - rms*thresh_low;
     gdouble criterium_high = avg + rms*thresh_high;
-    mark_outside_range_NIELD(field, mask, criterium_low, criterium_high);
+    mark_outside_range(field, mask, criterium_low, criterium_high);
 }
 
 /**
- * gwy_NIELD_mask_outliers_iqr:
+ * gwy_field_mark_outliers_iqr:
  * @field: A data field.
  * @mask: A data field to be filled with mask.
  * @thresh_low: Lower threshold deviation.
@@ -243,15 +144,16 @@ gwy_NIELD_mask_outliers2(GwyField *field,
  * where @iqr denotes the inter-quartile range of data values. Note that zero thresholds already remove everything
  * outside the IQR.
  *
- * See gwy_NIELD_mask_outliers2() for a faster but less robust version which uses mean and standard deviation.
+ * See gwy_field_mark_outliers2() for a faster but less robust version which uses mean and standard deviation. See
+ * also gwy_nield_mark_range() for marking inside/oustide given range.
  **/
 void
-gwy_NIELD_mask_outliers_iqr(GwyField *field,
+gwy_field_mark_outliers_iqr(GwyField *field,
                             GwyNield *mask,
                             gdouble thresh_low,
                             gdouble thresh_high)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
+    if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
 
     gint xres = field->xres, yres = field->yres;
@@ -263,7 +165,7 @@ gwy_NIELD_mask_outliers_iqr(GwyField *field,
     gdouble iqr = fabs(pv[1] - pv[0]);
     gdouble criterium_low = pv[0] - thresh_low*iqr;
     gdouble criterium_high = pv[1] + thresh_high*iqr;
-    mark_outside_range_NIELD(field, mask, criterium_low, criterium_high);
+    mark_outside_range(field, mask, criterium_low, criterium_high);
 }
 
 /**
@@ -281,39 +183,15 @@ gwy_NIELD_mask_outliers_iqr(GwyField *field,
  **/
 void
 gwy_field_correct_average(GwyField *field,
-                          GwyField *mask)
+                          GwyNield *mask)
 {
     if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
     gint xres = field->xres, yres = field->yres;
-    gdouble avg = gwy_field_area_get_avg(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
+    gdouble avg = gwy_field_area_mean(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
     gwy_field_area_fill(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, avg);
 }
 
-/**
- * gwy_NIELD_correct_average:
- * @field: A data field.
- * @mask: Mask of places to be corrected.
- *
- * Fills data under mask with the average value of unmasked data.
- *
- * The function calculates the average value of all unmasked pixels in @field and then fills all the masked pixels
- * with this average value. It can be useful as the first rough step of replacement of data under the mask since it
- * is much faster than, for example, gwy_field_laplace_solve().
- *
- * If all data are masked the field is filled with zeroes.
- **/
-void
-gwy_NIELD_correct_average(GwyField *field,
-                          GwyNield *mask)
-{
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
-        return;
-    gint xres = field->xres, yres = field->yres;
-    gdouble avg = gwy_NIELD_area_avg(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
-    gwy_NIELD_area_fill(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, avg);
-}
-
 /**
  * gwy_field_unrotate_find_corrections:
  * @derdist: Angular derivation distribution (normally obrained from gwy_field_slope_distribution()).
@@ -338,7 +216,7 @@ gwy_field_unrotate_find_corrections(GwyLine *derdist,
     gdouble sint[G_N_ELEMENTS(symm)], cost[G_N_ELEMENTS(symm)];
     gint nder = derdist->res;
     const gdouble *der = derdist->priv->data;
-    gdouble avg = gwy_line_avg(derdist);
+    gdouble avg = gwy_line_mean(derdist);
 
     GwyPlaneSymmetry guess = GWY_SYMMETRY_AUTO;
     gdouble max = -G_MAXDOUBLE;
@@ -625,7 +503,7 @@ gwy_field_distort_internal(GwyField *source,
     g_return_if_fail(coords || invtrans);
     g_return_if_fail(!coords || !invtrans);
 
-    suplen = gwy_interpolation_get_support_size(interp);
+    suplen = gwy_interpolation_support_size(interp);
     g_return_if_fail(suplen > 0);
     sf = -((suplen - 1)/2);
     st = suplen/2;
@@ -745,7 +623,7 @@ gwy_field_affine(GwyField *source,
     bx = invtrans[4];
     by = invtrans[5];
 
-    suplen = gwy_interpolation_get_support_size(interp);
+    suplen = gwy_interpolation_support_size(interp);
     g_return_if_fail(suplen > 0);
     sf = -((suplen - 1)/2);
     st = suplen/2;
@@ -890,7 +768,8 @@ solve_transform_real(const gdouble *a1a2, const gdouble *a1a2_corr, gdouble *m)
  * @a1a2: (array fixed-size=4):
  *        Lattice vectors (or generally base vectors) in @source, as an array of four components: @x1, @y1, @x2 and
  *        @y2.
- * @a1a2_corr: (inout) (array fixed-size=4): Correct lattice vectors (or generally base vectors) @dest should have after the affine transform, in
+ * @a1a2_corr: (inout) (array fixed-size=4):
+ *             Correct lattice vectors (or generally base vectors) @dest should have after the affine transform, in
  *             the same form as @a1a2.
  * @invtrans: (array fixed-size=6):
  *            Inverse transform as an array of six values to be filled according to gwy_field_affine()
@@ -1101,16 +980,15 @@ guess_lattice(GwyField *dfield, gdouble *a1a2, gboolean is_psdf)
         GWY_GRAIN_CENTER_X,
         GWY_GRAIN_CENTER_Y,
     };
-    GwyField *smoothed = NULL, *mask;
+    GwyField *smoothed = NULL;
     gdouble *values[nquantities];
     LatticeMaximumInfo *maxima;
-    gint *grains;
-    guint i, j, k, ngrains;
+    guint i, j, k;
     gdouble dh, cphi, sphi, phi, l1, l2, d, x, y;
     gboolean ok = FALSE;
 
     /* Mark local maxima. */
-    mask = gwy_field_new_alike(dfield, FALSE);
+    GwyNield *mask = gwy_field_new_nield_alike(dfield);
     if (is_psdf) {
         smoothed = gwy_field_copy(dfield);
         gwy_field_filter_gaussian(smoothed, 1.2);
@@ -1118,15 +996,14 @@ guess_lattice(GwyField *dfield, gdouble *a1a2, gboolean is_psdf)
     }
 
     gwy_field_mark_extrema(dfield, mask, TRUE);
-    grains = g_new0(gint, dfield->xres*dfield->yres);
-    ngrains = gwy_field_number_grains(mask, grains);
-    g_clear_object(&mask);
+    gint ngrains = gwy_nield_number_contiguous(mask);
 
     /* Find the position and value of each. */
     for (i = 0; i < nquantities; i++)
         values[i] = g_new(gdouble, ngrains+1);
 
-    gwy_field_grains_get_quantities(dfield, values, quantities, nquantities, ngrains, grains);
+    gwy_nield_grain_quantities(mask, dfield, quantities, nquantities, values);
+    g_clear_object(&mask);
     g_clear_object(&smoothed);
 
     maxima = g_new(LatticeMaximumInfo, ngrains);
@@ -1488,54 +1365,156 @@ gwy_field_measure_lattice_psdf(GwyField *psdf2d, gdouble *a1a2)
     return TRUE;
 }
 
+static void
+mark_scars(GwyField *field, GwyNield *result, GwyField *buffer,
+           gdouble rms,
+           gdouble threshold_high, gdouble threshold_low, gdouble min_scar_len, gdouble max_scar_width,
+           gboolean negative)
+{
+    gint xres = field->xres, yres = field->yres;
+    const gdouble *d = field->priv->data;
+    gdouble *b = buffer->priv->data;
+    gint *m = result->priv->data;
+
+    /* Initial scar search. */
+    for (gint i = 0; i < yres - (max_scar_width + 1); i++) {
+        for (gint j = 0; j < xres; j++) {
+            const gdouble *row = d + i*xres + j;
+
+            if (negative) {
+                gdouble top = row[0];
+                gdouble bottom = row[xres];
+                gint k;
+                for (k = 1; k <= max_scar_width; k++) {
+                    top = MIN(row[0], row[xres*(k + 1)]);
+                    bottom = MAX(bottom, row[xres*k]);
+                    if (top - bottom >= threshold_low*rms)
+                        break;
+                }
+                if (k <= max_scar_width) {
+                    gdouble *brow = b + i*xres + j;
+
+                    while (k) {
+                        brow[k*xres] = fmax(brow[k*xres], (top - row[k*xres])/rms);
+                        k--;
+                    }
+                }
+            }
+            else {
+                gdouble bottom = row[0];
+                gdouble top = row[xres];
+                gint k;
+                for (k = 1; k <= max_scar_width; k++) {
+                    bottom = MAX(row[0], row[xres*(k + 1)]);
+                    top = MIN(top, row[xres*k]);
+                    if (top - bottom >= threshold_low*rms)
+                        break;
+                }
+                if (k <= max_scar_width) {
+                    gdouble *brow = b + i*xres + j;
+
+                    while (k) {
+                        brow[k*xres] = fmax(brow[k*xres], (row[k*xres] - bottom)/rms);
+                        k--;
+                    }
+                }
+            }
+        }
+    }
+
+    /* Expand high threshold to neighbouring low threshold. */
+    for (gint i = 0; i < yres; i++) {
+        gdouble *brow = b + i*xres;
+
+        for (gint j = 1; j < xres; j++) {
+            if (brow[j] >= threshold_low && brow[j-1] >= threshold_high)
+                brow[j] = threshold_high;
+        }
+        for (gint j = xres-1; j > 0; j--) {
+            if (brow[j-1] >= threshold_low && brow[j] >= threshold_high)
+                brow[j-1] = threshold_high;
+        }
+    }
+
+    /* Kill too short segments and set the integer mask. */
+    for (gint i = 0; i < yres; i++) {
+        gdouble *brow = b + i*xres;
+        gint *mrow = m + i*xres;
+
+        gint k = 0, j;
+        for (j = 0; j < xres; j++) {
+            if (brow[j] >= threshold_high) {
+                mrow[j] = 1;
+                k++;
+                continue;
+            }
+            if (k && k < min_scar_len) {
+                while (k) {
+                    mrow[j-k] = 0;
+                    k--;
+                }
+            }
+            mrow[j] = 0;
+            k = 0;
+        }
+        if (k && k < min_scar_len) {
+            while (k) {
+                mrow[j-k] = 0;
+                k--;
+            }
+        }
+    }
+}
+
 /**
  * gwy_field_mark_scars:
  * @field: A data field to find scars in.
- * @result: A data field to store the result to (it is resized to match @field).
+ * @result: A number field to store the result to (it is resized to match @field).
  * @threshold_high: Miminum relative step for scar marking, must be positive.
  * @threshold_low: Definite relative step for scar marking, must be at least equal to @threshold_high.
  * @min_scar_len: Minimum length of a scar, shorter ones are discarded (must be at least one).
  * @max_scar_width: Maximum width of a scar, must be at least one.
- * @negative: %TRUE to detect negative scars, %FALSE to positive.
+ * @sign: Sign(s) of features to mark.
  *
  * Find and marks scars in a data field.
  *
  * Scars are linear horizontal defects, consisting of shifted values. Zero or negative values in @result siginify
  * normal data, positive values siginify samples that are part of a scar.
+ *
+ * The function operates on rows. Use gwy_field_transpose() if you need a column-wise marking.
  **/
 void
 gwy_field_mark_scars(GwyField *field,
-                     GwyField *result,
+                     GwyNield *result,
                      gdouble threshold_high,
                      gdouble threshold_low,
                      gdouble min_scar_len,
                      gdouble max_scar_width,
-                     gboolean negative)
+                     GwySignFlags sign)
 {
-    gint i, j, k;
-
     g_return_if_fail(GWY_IS_FIELD(field));
-    g_return_if_fail(GWY_IS_FIELD(result));
+    g_return_if_fail(GWY_IS_NIELD(result));
 
     gint xres = field->xres, yres = field->yres;
-    const gdouble *d = field->priv->data;
-
-    gwy_field_resize(result, xres, yres);
-    gwy_field_clear(result);
-    gdouble *m = result->priv->data;
 
     min_scar_len = MAX(min_scar_len, 1);
     max_scar_width = MIN(max_scar_width, yres - 2);
     threshold_high = MAX(threshold_high, threshold_low);
-    if (min_scar_len > xres || max_scar_width < 1 || threshold_low <= 0.0)
+    sign &= GWY_SIGN_BOTH;
+
+    gwy_nield_resize(result, xres, yres);
+    gwy_nield_clear(result);
+
+    if (min_scar_len > xres || max_scar_width < 1 || threshold_low <= 0.0 || !sign)
         return;
 
-    /* compute `vertical rms' */
+    /* Compute ‘vertical rms’. */
+    const gdouble *d = field->priv->data;
     gdouble rms = 0.0;
-    for (i = 0; i < yres-1; i++) {
+    for (gint i = 0; i < yres-1; i++) {
         const gdouble *row = d + i*xres;
 
-        for (j = 0; j < xres; j++) {
+        for (gint j = 0; j < xres; j++) {
             gdouble z = row[j] - row[j + xres];
 
             rms += z*z;
@@ -1545,90 +1524,19 @@ gwy_field_mark_scars(GwyField *field,
     if (rms == 0.0)
         return;
 
-    /* initial scar search */
-    for (i = 0; i < yres - (max_scar_width + 1); i++) {
-        for (j = 0; j < xres; j++) {
-            gdouble top, bottom;
-            const gdouble *row = d + i*xres + j;
-
-            if (negative) {
-                top = row[0];
-                bottom = row[xres];
-                for (k = 1; k <= max_scar_width; k++) {
-                    top = MIN(row[0], row[xres*(k + 1)]);
-                    bottom = MAX(bottom, row[xres*k]);
-                    if (top - bottom >= threshold_low*rms)
-                        break;
-                }
-                if (k <= max_scar_width) {
-                    gdouble *mrow = m + i*xres + j;
-
-                    while (k) {
-                        mrow[k*xres] = fmax(mrow[k*xres], (top - row[k*xres])/rms);
-                        k--;
-                    }
-                }
-            }
-            else {
-                bottom = row[0];
-                top = row[xres];
-                for (k = 1; k <= max_scar_width; k++) {
-                    bottom = MAX(row[0], row[xres*(k + 1)]);
-                    top = MIN(top, row[xres*k]);
-                    if (top - bottom >= threshold_low*rms)
-                        break;
-                }
-                if (k <= max_scar_width) {
-                    gdouble *mrow = m + i*xres + j;
-
-                    while (k) {
-                        mrow[k*xres] = fmax(mrow[k*xres], (row[k*xres] - bottom)/rms);
-                        k--;
-                    }
-                }
-            }
-        }
+    GwyField *buffer = gwy_field_new_alike(field, TRUE);
+    if (sign == GWY_SIGN_BOTH) {
+        GwyNield *tmp = gwy_nield_new_alike(result);
+        mark_scars(field, tmp, buffer, rms, threshold_high, threshold_low, min_scar_len, max_scar_width, TRUE);
+        mark_scars(field, result, buffer, rms, threshold_high, threshold_low, min_scar_len, max_scar_width, FALSE);
+        gwy_nield_union(result, tmp);
+        g_object_unref(tmp);
     }
-    /* expand high threshold to neighbouring low threshold */
-    for (i = 0; i < yres; i++) {
-        gdouble *mrow = m + i*xres;
-
-        for (j = 1; j < xres; j++) {
-            if (mrow[j] >= threshold_low && mrow[j-1] >= threshold_high)
-                mrow[j] = threshold_high;
-        }
-        for (j = xres-1; j > 0; j--) {
-            if (mrow[j-1] >= threshold_low && mrow[j] >= threshold_high)
-                mrow[j-1] = threshold_high;
-        }
-    }
-    /* kill too short segments, clamping result along the way */
-    for (i = 0; i < yres; i++) {
-        gdouble *mrow = m + i*xres;
-
-        k = 0;
-        for (j = 0; j < xres; j++) {
-            if (mrow[j] >= threshold_high) {
-                mrow[j] = 1.0;
-                k++;
-                continue;
-            }
-            if (k && k < min_scar_len) {
-                while (k) {
-                    mrow[j-k] = 0.0;
-                    k--;
-                }
-            }
-            mrow[j] = 0.0;
-            k = 0;
-        }
-        if (k && k < min_scar_len) {
-            while (k) {
-                mrow[j-k] = 0.0;
-                k--;
-            }
-        }
+    else {
+        mark_scars(field, result, buffer, rms, threshold_high, threshold_low, min_scar_len, max_scar_width,
+                   sign & GWY_SIGN_NEGATIVE);
     }
+    g_object_unref(buffer);
 }
 
 /**
@@ -1645,7 +1553,6 @@ void
 gwy_field_subtract_row_shifts(GwyField *field,
                               GwyLine *shifts)
 {
-
     g_return_if_fail(GWY_IS_FIELD(field));
     g_return_if_fail(GWY_IS_LINE(shifts));
     gint xres = field->xres, yres = field->yres;
@@ -1677,7 +1584,7 @@ trimmed_mean_or_median(gdouble *array, guint n, gdouble p)
 static void
 zero_level_row_shifts(GwyLine *shifts)
 {
-    gwy_line_add(shifts, -gwy_line_avg(shifts));
+    gwy_line_add(shifts, -gwy_line_mean(shifts));
 }
 
 static void
@@ -1709,43 +1616,12 @@ slope_level_row_shifts(GwyLine *shifts)
  **/
 GwyLine*
 gwy_field_find_row_shifts_trimmed_mean(GwyField *field,
-                                       GwyField *mask,
-                                       GwyMaskingType masking,
-                                       gdouble trimfrac,
-                                       gint mincount)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_find_row_shifts_trimmed_mean(field, nield, masking, trimfrac, mincount);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_find_row_shifts_trimmed_mean:
- * @field: A data field.
- * @mask: (nullable): Mask of values to take values into account/exclude, or %NULL for full @field.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @trimfrac: Fraction of lowest values and highest values to discard when trimming.
- * @mincount: Minimum number of values in a row necessary for per-row calculation.  Rows which are essentially
- *            completely masked are not shifted with respect to a global value.  Pass a non-positive number to use an
- *            automatic minimum count.
- *
- * Finds row shifts to misaligned row correction using trimmed row means.
- *
- * For zero @trimfrac the function calculates row means.  For @trimfrac of 1/2 or larger it calculates row medians.
- * Values between correspond to trimmed means.
- *
- * Returns: (transfer full):
- *          A newly created data line containing the row shifts, for instance row means, medians or trimmed means.
- **/
-GwyLine*
-gwy_NIELD_find_row_shifts_trimmed_mean(GwyField *field,
                                        GwyNield *mask,
                                        GwyMaskingType masking,
                                        gdouble trimfrac,
                                        gint mincount)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return NULL;
 
     gint xres = field->xres, yres = field->yres;
@@ -1756,7 +1632,7 @@ gwy_NIELD_find_row_shifts_trimmed_mean(GwyField *field,
     GwyLine *shifts = gwy_line_new(yres, field->yreal, FALSE);
     shifts->off = field->yoff;
     gwy_field_copy_units_to_line(field, shifts);
-    gdouble total_median = gwy_NIELD_area_median(field, mask, masking, 0, 0, xres, yres);
+    gdouble total_median = gwy_field_area_median(field, mask, masking, 0, 0, xres, yres);
 
     const gdouble *d = field->priv->data;
     const gint *m = mask ? mask->priv->data : NULL;
@@ -1817,43 +1693,12 @@ gwy_NIELD_find_row_shifts_trimmed_mean(GwyField *field,
  **/
 GwyLine*
 gwy_field_find_row_shifts_trimmed_diff(GwyField *field,
-                                       GwyField *mask,
-                                       GwyMaskingType masking,
-                                       gdouble trimfrac,
-                                       gint mincount)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_find_row_shifts_trimmed_diff(field, nield, masking, trimfrac, mincount);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_find_row_shifts_trimmed_diff:
- * @field: A data field.
- * @mask: (nullable): Mask of values to take values into account/exclude, or %NULL for full @field.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @trimfrac: Fraction of lowest values and highest values to discard when trimming.
- * @mincount: Minimum number of values in a row necessary for per-row calculation.  Rows which are essentially
- *            completely masked are not shifted with respect to a global value.  Pass a non-positive number to use an
- *            automatic minimum count.
- *
- * Finds row shifts to misaligned row correction using trimmed means of row differences.
- *
- * For zero @trimfrac the function calculates row means.  For @trimfrac of 1/2 or larger it calculates row medians.
- * Values between correspond to trimmed means.
- *
- * Returns: (transfer full):
- *          A newly created data line containing the row shifts, for instance row means, medians or trimmed means.
- **/
-GwyLine*
-gwy_NIELD_find_row_shifts_trimmed_diff(GwyField *field,
                                        GwyNield *mask,
                                        GwyMaskingType masking,
                                        gdouble trimfrac,
                                        gint mincount)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return NULL;
     g_return_val_if_fail(trimfrac >= 0.0, NULL);
 
@@ -1927,38 +1772,12 @@ gwy_NIELD_find_row_shifts_trimmed_diff(GwyField *field,
  **/
 void
 gwy_field_row_level_poly(GwyField *field,
-                         GwyField *mask,
-                         GwyMaskingType masking,
-                         gint degree,
-                         GwyLine *shifts)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gwy_NIELD_row_level_poly(field, nield, masking, degree, shifts);
-    g_clear_object(&nield);
-}
-
-/**
- * gwy_NIELD_row_level_poly:
- * @field: A data field.
- * @mask: (nullable): Mask of values to take values into account/exclude, or %NULL for full @field.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @degree: Polynomial degree (0 is mean value, 1 is tilt, 2 is bow, etc.).
- * @shifts: (nullable):
- *          Data line where to store the subtracted mean values (constant terms of the polynomials), or %NULL.
- *          It will be resized to match the field vertical dimension.
- *
- * Levels misaligned rows of a data field by fitting and subtracting polynomials.
- *
- * This function does both the fitting and subtraction in one step.
- **/
-void
-gwy_NIELD_row_level_poly(GwyField *field,
                          GwyNield *mask,
                          GwyMaskingType masking,
                          gint degree,
                          GwyLine *shifts)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return;
     g_return_if_fail(degree >= 0);
 
@@ -1973,7 +1792,7 @@ gwy_NIELD_row_level_poly(GwyField *field,
     }
 
     gdouble xc = 0.5*(xres - 1);
-    gdouble avg = gwy_field_get_avg(field);
+    gdouble avg = gwy_field_mean(field);
     gdouble *d = field->priv->data;
     const gint *m = mask ? mask->priv->data : NULL;
 
