@@ -1,5 +1,5 @@
 /*
- *  $Id: correlation.c 28973 2025-12-10 18:45:40Z yeti-dn $
+ *  $Id: correlation.c 29544 2026-02-25 10:28:00Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -258,17 +258,17 @@ gwy_field_get_correlation_score(GwyField *field,
     if (kernel_col < 0 || kernel_row < 0 || kernel_col + kernel_width > kxres || kernel_row + kernel_height > kyres)
         return -1;
 
-    avg1 = gwy_field_area_get_avg(field, NULL, GWY_MASK_IGNORE,
-                                  col, row, kernel_width, kernel_height);
-    avg2 = gwy_field_area_get_avg(kernel_field, NULL, GWY_MASK_IGNORE,
-                                  kernel_col, kernel_row, kernel_width, kernel_height);
+    avg1 = gwy_field_area_mean(field, NULL, GWY_MASK_IGNORE,
+                               col, row, kernel_width, kernel_height);
+    avg2 = gwy_field_area_mean(kernel_field, NULL, GWY_MASK_IGNORE,
+                               kernel_col, kernel_row, kernel_width, kernel_height);
 
-    rms1 = gwy_field_area_get_rms(field, NULL, GWY_MASK_IGNORE,
-                                  col, row, kernel_width, kernel_height);
+    rms1 = gwy_field_area_rms(field, NULL, GWY_MASK_IGNORE,
+                              col, row, kernel_width, kernel_height);
     if (rms1 == 0.0)
         return 0.0;
-    rms2 = gwy_field_area_get_rms(kernel_field, NULL, GWY_MASK_IGNORE,
-                                  kernel_col, kernel_row, kernel_width, kernel_height);
+    rms2 = gwy_field_area_rms(kernel_field, NULL, GWY_MASK_IGNORE,
+                              kernel_col, kernel_row, kernel_width, kernel_height);
     if (rms2 == 0.0)
         return 0.0;
 
@@ -385,7 +385,7 @@ gwy_field_get_weighted_correlation_score(GwyField *field,
     data = field->priv->data;
     kdata = kernel_field->priv->data;
     wdata = weight_field->priv->data;
-    weightsum = gwy_field_get_sum(weight_field);
+    weightsum = gwy_field_sum(weight_field);
 
     avg1 = avg2 = 0.0;
     for (i = 0; i < kernel_height; i++) {   /* row */
@@ -504,8 +504,8 @@ gwy_field_correlate(GwyField *field, GwyField *kernel_field,
              * negative direction */
             xoff = (kxres - 1)/2;
             yoff = (kyres - 1)/2;
-            kavg = gwy_field_get_avg(kernel_field);
-            krms = gwy_field_get_rms(kernel_field);
+            kavg = gwy_field_mean(kernel_field);
+            krms = gwy_field_rms(kernel_field);
             avg = gwy_field_copy(field);
             rms = gwy_field_copy(field);
             calculate_normalization(avg, rms, kxres, kyres);
@@ -639,8 +639,8 @@ gwy_field_correlate_iteration(GwyComputationState *cstate)
 
     if (state->cs.state == GWY_COMPUTATION_STATE_INIT) {
         gwy_field_fill(state->score, -1);
-        state->kavg = gwy_field_get_avg(state->kernel_field);
-        state->krms = gwy_field_get_rms(state->kernel_field);
+        state->kavg = gwy_field_mean(state->kernel_field);
+        state->krms = gwy_field_rms(state->kernel_field);
         state->avg = gwy_field_copy(state->field);
         state->rms = gwy_field_copy(state->field);
         calculate_normalization(state->avg, state->rms, kxres, kyres);
@@ -697,106 +697,6 @@ gwy_field_correlate_finalize(GwyComputationState *cstate)
     g_free(state);
 }
 
-/**
- * gwy_field_crosscorrelate:
- * @field1: A data field.
- * @field2: A data field.
- * @x_dist: A data field to store x-distances to.
- * @y_dist: A data field to store y-distances to.
- * @score: Data field to store correlation scores to.
- * @search_width: Search area width.
- * @search_height: Search area height.
- * @window_width: Correlation window width.  This parameter is not actually used.  Pass zero.
- * @window_height: Correlation window height.  This parameter is not actually used.  Pass zero.
- *
- * Algorithm for matching two different images of the same object under changes.
- *
- * It does not use any special features for matching. It simply searches for all points (with their neighbourhood) of
- * @field1 within @field2. Parameters @search_width and @search_height determine maimum area where to search
- * for points. The area is cenetered in the @field2 at former position of points at @field1.
- **/
-void
-gwy_field_crosscorrelate(GwyField *field1,
-                         GwyField *field2, GwyField *x_dist,
-                         GwyField *y_dist, GwyField *score,
-                         gint search_width, gint search_height,
-                         G_GNUC_UNUSED gint window_width,
-                         G_GNUC_UNUSED gint window_height)
-{
-    gint xres, yres, i, j, m, n;
-    gint imax, jmax;
-    gdouble cormax, lscore;
-    gdouble zm, zp, z0, ipos, jpos;
-
-    g_return_if_fail(field1 != NULL && field2 != NULL);
-
-    xres = field1->xres;
-    yres = field1->yres;
-
-    g_return_if_fail(xres == field2->xres && yres == field2->yres);
-
-    gwy_field_clear(x_dist);
-    gwy_field_clear(y_dist);
-    gwy_field_clear(score);
-
-    /*iterate over all the points */
-    for (i = search_width/2; i < xres - search_width/2; i++) {
-        for (j = search_height/2; j < yres - search_height/2; j++) {
-            /*iterate over search area in the second field */
-            imax = i;
-            jmax = j;
-            cormax = -1;
-            for (m = (i - search_width); m < i; m++) {
-                for (n = (j - search_height); n < j; n++) {
-                    lscore = gwy_field_get_correlation_score(field1, field2,
-                                                             i-search_width/2, j-search_height/2, m, n,
-                                                             m + search_width, n + search_height);
-
-                    /* add a little to score at exactly same point - to prevent problems on flat data */
-                    if (m == (i - search_width/2) && n == (j - search_height/2))
-                        lscore *= 1.0001;
-
-                    if (cormax < lscore) {
-                        cormax = lscore;
-                        imax = m + search_width/2;
-                        jmax = n + search_height/2;
-                    }
-                }
-            }
-            score->priv->data[i + xres * j] = cormax;
-
-            z0 = cormax;
-            zm = gwy_field_get_correlation_score(field1, field2,
-                                                 i-search_width/2, j-search_height/2,
-                                                 imax - search_width/2 - 1, jmax - search_height/2,
-                                                 imax + search_width/2 - 1, jmax + search_height/2);
-            zp = gwy_field_get_correlation_score(field1, field2,
-                                                 i-search_width/2, j-search_height/2,
-                                                 imax - search_width/2 + 1, jmax - search_height/2,
-                                                 imax + search_width/2 + 1, jmax + search_height/2);
-
-            ipos = imax + (zm - zp)/(zm + zp - 2*z0)/2.0;
-            x_dist->priv->data[i + xres * j] = (ipos - i)*field1->xreal/field1->xres;
-
-            zm = gwy_field_get_correlation_score(field1, field2,
-                                                 i-search_width/2, j-search_height/2,
-                                                 imax - search_width/2, jmax - search_height/2 - 1,
-                                                 imax + search_width/2, jmax + search_height/2 - 1);
-            zp = gwy_field_get_correlation_score(field1, field2,
-                                                 i-search_width/2, j-search_height/2,
-                                                 imax - search_width/2, jmax - search_height/2 + 1,
-                                                 imax + search_width/2, jmax + search_height/2 + 1);
-
-            jpos = jmax + (zm - zp)/(zm + zp - 2*z0)/2.0;
-            y_dist->priv->data[i + xres * j] = (jpos - j)*field1->yreal/field1->yres;
-        }
-    }
-
-    gwy_field_invalidate(score);
-    gwy_field_invalidate(x_dist);
-    gwy_field_invalidate(y_dist);
-}
-
 /**
  * gwy_field_crosscorrelate_init:
  * @field1: A data field.
@@ -826,20 +726,15 @@ gwy_field_crosscorrelate_init(GwyField *field1,
                               gint window_width,
                               gint window_height)
 {
-    GwyCrossCorrelationState *state;
-    gint xres, yres;
+    if (!_gwy_field_check_other(field1, field2, FALSE)
+        || !_gwy_field_check_other(field1, x_dist, TRUE)
+        || !_gwy_field_check_other(field1, y_dist, TRUE)
+        || !_gwy_field_check_other(field1, score, TRUE))
+        return NULL;
 
-    g_return_val_if_fail(GWY_IS_FIELD(field1), NULL);
-    g_return_val_if_fail(GWY_IS_FIELD(field2), NULL);
-    xres = field1->xres;
-    yres = field1->yres;
-    g_return_val_if_fail(field2->xres == xres && field2->yres == yres, NULL);
-    g_return_val_if_fail(!x_dist || GWY_IS_FIELD(x_dist), NULL);
-    g_return_val_if_fail(!y_dist || GWY_IS_FIELD(y_dist), NULL);
-    g_return_val_if_fail(!score || GWY_IS_FIELD(score), NULL);
-
-    state = g_new0(GwyCrossCorrelationState, 1);
+    gint xres = field1->xres, yres = field1->yres;
 
+    GwyCrossCorrelationState *state = g_new0(GwyCrossCorrelationState, 1);
     state->cs.state = GWY_COMPUTATION_STATE_INIT;
     state->cs.fraction = 0.0;
     state->field1 = g_object_ref(field1);
@@ -950,7 +845,7 @@ gwy_field_crosscorrelate_iteration(GwyComputationState *cstate)
     mend = MIN(yres - winheight, row + searchheight - searchheight/2 - winheight/2);
     nfrom = MAX(0, col - searchwidth/2 - winwidth/2);
     nend = MIN(xres - winwidth, col + searchwidth - searchwidth/2 - winwidth/2);
-    weightsum = gwy_field_get_sum(weights);
+    weightsum = gwy_field_sum(weights);
     cormax = -G_MAXDOUBLE;
     m1 = row - winheight/2;
     n1 = col - winwidth/2;
@@ -1011,7 +906,7 @@ gwy_field_crosscorrelate_iteration(GwyComputationState *cstate)
             }
         }
 
-        if (gwy_math_refine_maximum(scores, &xmaximum, &ymaximum)) {
+        if (gwy_math_refine_maximum_2d(scores, &xmaximum, &ymaximum)) {
             ipos = colmax + xmaximum;
             jpos = rowmax + ymaximum;
         }
@@ -1229,7 +1124,7 @@ gwy_field_correlation_search(GwyField *dfield,
                              gdouble fill_value)
 {
     GwyField *kappa;
-    guint xres, yres, kxres, kyres, xsize, ysize, cstride;
+    guint xsize, ysize, cstride;
     guint extend_left, extend_right, extend_up, extend_down;
     guint i;
     gdouble kmu, ks2, ksigma2, wq, S2;
@@ -1241,18 +1136,13 @@ gwy_field_correlation_search(GwyField *dfield,
     GwyUnit *funit, *kunit;
 
     g_return_if_fail(GWY_IS_FIELD(dfield));
-    xres = dfield->xres;
-    yres = dfield->yres;
+    gint xres = dfield->xres, yres = dfield->yres;
 
     g_return_if_fail(GWY_IS_FIELD(kernel));
     g_return_if_fail(GWY_IS_FIELD(target));
-    kxres = kernel->xres;
-    kyres = kernel->yres;
-    if (kernel_weight) {
-        g_return_if_fail(GWY_IS_FIELD(kernel_weight));
-        g_return_if_fail(kernel_weight->xres == kxres);
-        g_return_if_fail(kernel_weight->yres == kyres);
-    }
+    gint kxres = kernel->xres, kyres = kernel->yres;
+    if (!_gwy_field_check_other(kernel, kernel_weight, TRUE))
+        return;
     ensure_defined_exterior(&exterior, &fill_value);
     if (!(extend_rect = _gwy_get_rect_extend_func(exterior)))
         return;
@@ -1325,13 +1215,13 @@ gwy_field_correlation_search(GwyField *dfield,
      */
 
     if (kernel_weight) {
-        if (gwy_field_get_min(kernel_weight) < 0.0) {
+        if (gwy_field_min(kernel_weight) < 0.0) {
             g_warning("Invalid negative values in kernel_weight.");
             gwy_field_clear(target);
             return;
         }
         else {
-            wq = gwy_field_get_sum(kernel_weight);
+            wq = gwy_field_sum(kernel_weight);
             if (!wq) {
                 gwy_field_clear(target);
                 return;
