@@ -1,6 +1,6 @@
 /*
- *  $Id: distance-transform.c 28903 2025-11-24 15:49:51Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: distance-transform.c 29449 2026-02-08 09:50:14Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -23,7 +23,7 @@
 #include "libgwyddion/macros.h"
 #include "libgwyddion/math.h"
 #include "libgwyddion/arithmetic.h"
-#include "libgwyddion/grains-nield.h"
+#include "libgwyddion/grains.h"
 #include "libgwyddion/distance-transform.h"
 
 #include "libgwyddion/int-list.h"
@@ -45,9 +45,9 @@ typedef struct {
     gint j, i;
 } ThinCandidate;
 
-typedef gboolean (*ErodeFunc)(guint *grain,
+typedef gboolean (*ErodeFunc)(guint *dists,
                               gint width, gint height,
-                              guint id,
+                              guint d,
                               const PixelQueue *inqueue,
                               PixelQueue *outqueue);
 
@@ -70,11 +70,12 @@ pixel_queue_add(PixelQueue *queue,
 
 // Set squared distance for all points that have an 8-neighbour outside and add them to the queue.
 static void
-distance_transform_first_step(guint *distances,
-                              guint xres, guint yres,
-                              IntList *queue,
-                              gboolean from_border)
+euclidean_distance_transform_first_step_merged(GwyNield *distances,
+                                               IntList *queue,
+                                               gboolean from_border)
 {
+    guint *ddata = (guint*)distances->priv->data;
+    gint xres = distances->xres, yres = distances->yres;
     gsize k = 0;
 
     queue->len = 0;
@@ -86,22 +87,70 @@ distance_transform_first_step(guint *distances,
             gboolean first_column = (j == 0);
             gboolean last_column = (j == xres-1);
 
-            if (!distances[k])
+            if (!ddata[k])
                 continue;
 
             if ((from_border && (first_row || first_column || last_row || last_column))
-                || (!first_row && !distances[k-xres])
-                || (!first_column && !distances[k-1])
-                || (!last_column && !distances[k+1])
-                || (!last_row && !distances[k+xres])) {
-                distances[k] = 1;
+                || (!first_row && !ddata[k-xres])
+                || (!first_column && !ddata[k-1])
+                || (!last_column && !ddata[k+1])
+                || (!last_row && !ddata[k+xres])) {
+                ddata[k] = 1;
                 int_list_add(queue, k);
             }
-            else if ((!first_row && !first_column && !distances[k-xres-1])
-                     || (!first_row && !last_column && !distances[k-xres+1])
-                     || (!last_row && !first_column && !distances[k+xres-1])
-                     || (!last_row && !last_column && !distances[k+xres+1])) {
-                distances[k] = 2;
+            else if ((!first_row && !first_column && !ddata[k-xres-1])
+                     || (!first_row && !last_column && !ddata[k-xres+1])
+                     || (!last_row && !first_column && !ddata[k+xres-1])
+                     || (!last_row && !last_column && !ddata[k+xres+1])) {
+                ddata[k] = 2;
+                int_list_add(queue, k);
+            }
+        }
+    }
+}
+
+// Field @distances must already be prefilled with SEDINF. However, we still use @grains to add boundaries which are
+// between different touching grains, not between SEDINF and zero.
+static void
+euclidean_distance_transform_first_step_split(GwyNield *grains,
+                                              GwyNield *distances,
+                                              IntList *queue,
+                                              gboolean from_border)
+{
+    guint *ddata = (guint*)distances->priv->data;
+    const gint *gdata = grains->priv->data;
+    gint xres = distances->xres, yres = distances->yres;
+    gsize k = 0;
+
+    queue->len = 0;
+    for (guint i = 0; i < yres; i++) {
+        gboolean first_row = (i == 0);
+        gboolean last_row = (i == yres-1);
+
+        for (guint j = 0; j < xres; j++, k++) {
+            gboolean first_column = (j == 0);
+            gboolean last_column = (j == xres-1);
+            gint gno = gdata[k];
+
+            if (!ddata[k]) {
+                g_assert(gno <= 0);
+                continue;
+            }
+
+            g_assert(gno >= 0);
+            if ((from_border && (first_row || first_column || last_row || last_column))
+                || (!first_row && gdata[k-xres] != gno)
+                || (!first_column && gdata[k-1] != gno)
+                || (!last_column && gdata[k+1] != gno)
+                || (!last_row && gdata[k+xres] != gno)) {
+                ddata[k] = 1;
+                int_list_add(queue, k);
+            }
+            else if ((!first_row && !first_column && gdata[k-xres-1] != gno)
+                     || (!first_row && !last_column && gdata[k-xres+1] != gno)
+                     || (!last_row && !first_column && gdata[k+xres-1] != gno)
+                     || (!last_row && !last_column && gdata[k+xres+1] != gno)) {
+                ddata[k] = 2;
                 int_list_add(queue, k);
             }
         }
@@ -109,219 +158,282 @@ distance_transform_first_step(guint *distances,
 }
 
 static void
-distance_transform_erode_sed(guint *distances, const guint *olddist,
-                             guint xres, guint yres,
-                             guint l,
-                             const IntList *inqueue,
-                             IntList *outqueue)
+euclidean_distance_transform_progress(GwyNield *distances, GwyNield *olddist,
+                                      guint l,
+                                      const IntList *inqueue,
+                                      IntList *outqueue)
 {
+    guint *ddata = (guint*)distances->priv->data;
+    const guint *oldd = (const guint*)olddist->priv->data;
+    guint xres = distances->xres, yres = distances->yres;
     guint hvsed2 = 2*l - 1, diag2 = 2*hvsed2;
-    guint q;
 
     outqueue->len = 0;
 
-    for (q = 0; q < inqueue->len; q++) {
+    for (guint q = 0; q < inqueue->len; q++) {
         guint k = inqueue->data[q], kk = k-xres-1;
         guint i = k/xres, j = k % xres;
         gboolean first_row = (i == 0);
         gboolean last_row = (i == yres-1);
         gboolean first_column = (j == 0);
         gboolean last_column = (j == xres-1);
-        guint d2hv = olddist[k] + hvsed2, d2d = olddist[k] + diag2;
+        guint d2hv = oldd[k] + hvsed2, d2d = oldd[k] + diag2;
 
-        if (!first_row && !first_column && (distances[kk] & ~QUEUED) > d2d) {
-            if (!(distances[kk] & QUEUED))
+        if (!first_row && !first_column && (ddata[kk] & ~QUEUED) > d2d) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2d;
+            ddata[kk] = QUEUED | d2d;
         }
         kk++;
-        if (!first_row && (distances[kk] & ~QUEUED) > d2hv) {
-            if (!(distances[kk] & QUEUED))
+        if (!first_row && (ddata[kk] & ~QUEUED) > d2hv) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2hv;
+            ddata[kk] = QUEUED | d2hv;
         }
         kk++;
-        if (!first_row && !last_column && (distances[kk] & ~QUEUED) > d2d) {
-            if (!(distances[kk] & QUEUED))
+        if (!first_row && !last_column && (ddata[kk] & ~QUEUED) > d2d) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2d;
+            ddata[kk] = QUEUED | d2d;
         }
         kk += xres-2;
-        if (!first_column && (distances[kk] & ~QUEUED) > d2hv) {
-            if (!(distances[kk] & QUEUED))
+        if (!first_column && (ddata[kk] & ~QUEUED) > d2hv) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2hv;
+            ddata[kk] = QUEUED | d2hv;
         }
         kk += 2;
-        if (!last_column && (distances[kk] & ~QUEUED) > d2hv) {
-            if (!(distances[kk] & QUEUED))
+        if (!last_column && (ddata[kk] & ~QUEUED) > d2hv) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2hv;
+            ddata[kk] = QUEUED | d2hv;
         }
         kk += xres-2;
-        if (!last_row && !first_column && (distances[kk] & ~QUEUED) > d2d) {
-            if (!(distances[kk] & QUEUED))
+        if (!last_row && !first_column && (ddata[kk] & ~QUEUED) > d2d) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2d;
+            ddata[kk] = QUEUED | d2d;
         }
         kk++;
-        if (!last_row && (distances[kk] & ~QUEUED) > d2hv) {
-            if (!(distances[kk] & QUEUED))
+        if (!last_row && (ddata[kk] & ~QUEUED) > d2hv) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2hv;
+            ddata[kk] = QUEUED | d2hv;
         }
         kk++;
-        if (!last_row && !last_column && (distances[kk] & ~QUEUED) > d2d) {
-            if (!(distances[kk] & QUEUED))
+        if (!last_row && !last_column && (ddata[kk] & ~QUEUED) > d2d) {
+            if (!(ddata[kk] & QUEUED))
                 int_list_add(outqueue, kk);
-            distances[kk] = QUEUED | d2d;
+            ddata[kk] = QUEUED | d2d;
         }
     }
 }
 
-/**
- * distance_transform_raw:
- * @distances: Array @xres*@yres with nonzeros within shapes.  If all non-zero values are %SEDINF you can pass %TRUE
- *             for @infinitised.
- * @workspace: Workspace of identical dimensions as @distances.
- * @xres: Width.
- * @yres: Height.
- * @inqueue: Pre-allocated queue used by the algorithm.
- * @outqueue: Second pre-allocated queue used by the algorithm.
- * @from_border: %TRUE to consider image edges to be grain boundaries.
- *
- * Performs distance transformation.
- *
- * When it finishes non-zero values in @distances are squared Euclidean distances from outside pixels (including
- * outside the field).
- *
- * Workspace objects @workspace, @inqueue and @outqueue do not carry any information.  They are allocated by the
- * caller to enable an efficient repeated use.
- **/
 static void
-distance_transform_raw(guint *distances, guint *workspace,
-                       guint xres, guint yres,
-                       IntList *inqueue, IntList *outqueue,
-                       gboolean from_border)
+clear_queued_flag(GwyNield *intdist, IntList *queue)
 {
-    guint l, q;
+    guint *ddata = (guint*)intdist->priv->data;
+    gssize *qdata = queue->data;
+    for (guint q = queue->len; q; q--, qdata++)
+        ddata[*qdata] &= ~QUEUED;
+}
 
-    distance_transform_first_step(distances, xres, yres, inqueue, from_border);
-
-    for (l = 2; inqueue->len; l++) {
-        gssize *qdata;
-
-        for (q = 0; q < inqueue->len; q++) {
-            gsize k = inqueue->data[q];
-            workspace[k] = distances[k];
-        }
-        distance_transform_erode_sed(distances, workspace, xres, yres, l, inqueue, outqueue);
-
-        qdata = outqueue->data;
-        for (q = outqueue->len; q; q--, qdata++)
-            distances[*qdata] &= ~QUEUED;
-
-        GWY_SWAP(IntList*, inqueue, outqueue);
+static void
+copy_queued(GwyNield *src, GwyNield *dest, IntList *queue)
+{
+    const gint *s = src->priv->data;
+    gint *d = dest->priv->data;
+    gssize *qdata = queue->data;
+    for (guint q = 0; q < queue->len; q++) {
+        gsize k = qdata[q];
+        d[k] = s[k];
     }
 }
 
 static void
-euclidean_distance_transform(GwyNield *nield, GwyField *distances, gboolean from_border)
+euclidean_distance_transform(GwyNield *nield, GwyField *distances,
+                             gboolean merged, gboolean from_border)
 {
     g_return_if_fail(GWY_IS_NIELD(nield));
     g_return_if_fail(GWY_IS_FIELD(distances));
 
     gint xres = nield->xres, yres = nield->yres;
     gsize n = (gsize)xres * (gsize)yres;
-    const gint *d = nield->priv->data;
-    guint *dist = g_new(guint, n);
-    guint *workspace = g_new(guint, n);
-
-    for (gsize k = 0; k < n; k++)
-        dist[k] = (d[k] > 0) ? SEDINF : 0;
+    GwyNield *intdist = gwy_nield_new_alike(nield);
+    GwyNield *workspace = gwy_nield_new_alike(nield);
+    gwy_nield_area_fill(intdist, nield, GWY_MASK_INCLUDE, 0, 0, xres, yres, SEDINF);
 
     guint inisize = (guint)(8*sqrt(n) + 16);
     IntList *inqueue = int_list_new(inisize);
     IntList *outqueue = int_list_new(inisize);
 
-    distance_transform_raw(dist, workspace, xres, yres, inqueue, outqueue, from_border);
+    if (merged)
+        euclidean_distance_transform_first_step_merged(intdist, inqueue, from_border);
+    else
+        euclidean_distance_transform_first_step_split(nield, intdist, inqueue, from_border);
+
+    for (guint l = 2; inqueue->len; l++) {
+        copy_queued(intdist, workspace, inqueue);
+        euclidean_distance_transform_progress(intdist, workspace, l, inqueue, outqueue);
+        clear_queued_flag(intdist, outqueue);
+        GWY_SWAP(IntList*, inqueue, outqueue);
+    }
 
     int_list_free(inqueue);
     int_list_free(outqueue);
 
     gdouble *f = distances->priv->data;
+    const gint *dist = intdist->priv->data;
     for (gsize k = 0; k < n; k++)
         f[k] = sqrt(dist[k]);
-    gwy_field_invalidate(distances);
 
-    g_free(workspace);
-    g_free(dist);
+    g_object_unref(workspace);
+    g_object_unref(intdist);
+
+    gwy_field_invalidate(distances);
 }
 
-/* Init @queue with all Von Neumann-neighbourhood boundary pixels. */
+/* Init @queue with all 4-connectivitivy boundary pixels:
+ * @grain: Grain numbering as in GwyNield.
+ * @dist: Buffer to fill with initial distance transform state (0, 1 or infinity). */
 static void
-init_erosion_4(guint *grain,
-               guint width, guint height,
-               gboolean from_border,
-               PixelQueue *queue)
+init_erosion_4_merged(const gint *grain, guint *dist,
+                      guint width, guint height,
+                      gboolean from_border,
+                      PixelQueue *queue)
 {
-    queue->len = 0;
     for (guint i = 0; i < height; i++) {
         gboolean ifirst = !i, ilast = (i == height-1);
         for (guint j = 0; j < width; j++) {
             gboolean jfirst = !j, jlast = (j == width-1);
             guint k = i*width + j;
-            if (!grain[k])
+            if (grain[k] <= 0) {
+                dist[k] = 0;
                 continue;
+            }
 
-            if ((!ifirst && !grain[k - width])
-                || (!jfirst && !grain[k-1])
-                || (!jlast && !grain[k+1])
-                || (!ilast && !grain[k + width])
+            if ((!ifirst && grain[k - width] <= 0)
+                || (!jfirst && grain[k-1] <= 0)
+                || (!jlast && grain[k+1] <= 0)
+                || (!ilast && grain[k + width] <= 0)
                 || (from_border && (ifirst || ilast || jfirst || jlast))) {
-                grain[k] = 1;
+                dist[k] = 1;
                 pixel_queue_add(queue, i, j);
             }
+            else
+                dist[k] = G_MAXUINT;
         }
     }
 }
 
-/* Init @queue with all Von Neumann-neighbourhood boundary pixels. */
 static void
-init_erosion_8(guint *grain,
-               gint width, gint height,
-               gboolean from_border,
-               PixelQueue *queue)
+init_erosion_4_split(const gint *grain, guint *dist,
+                     guint width, guint height,
+                     gboolean from_border,
+                     PixelQueue *queue)
 {
-    queue->len = 0;
     for (guint i = 0; i < height; i++) {
         gboolean ifirst = !i, ilast = (i == height-1);
         for (guint j = 0; j < width; j++) {
             gboolean jfirst = !j, jlast = (j == width-1);
             guint k = i*width + j;
-            if (!grain[k])
+            if (grain[k] <= 0) {
+                dist[k] = 0;
                 continue;
+            }
 
-            if ((!ifirst && !jfirst && !grain[k-1 - width])
-                || (!ifirst && !grain[k - width])
-                || (!ifirst && !jlast && !grain[k+1 - width])
-                || (!jfirst && !grain[k-1])
-                || (!jlast && !grain[k+1])
-                || (!ilast && !jfirst && !grain[k-1 + width])
-                || (!ilast && !grain[k + width])
-                || (!ilast && !jlast && !grain[k+1 + width])
+            gint gno = grain[k];
+            if ((!ifirst && grain[k - width] != gno)
+                || (!jfirst && grain[k-1] != gno)
+                || (!jlast && grain[k+1] != gno)
+                || (!ilast && grain[k + width] != gno)
                 || (from_border && (ifirst || ilast || jfirst || jlast))) {
-                grain[k] = 1;
+                dist[k] = 1;
                 pixel_queue_add(queue, i, j);
             }
+            else
+                dist[k] = G_MAXUINT;
+        }
+    }
+}
+
+/* Init @queue with all 8-connectivitivy boundary pixels:
+ * @grain: Grain numbering as in GwyNield.
+ * @dist: Buffer to fill with initial distance transform state (0, 1 or infinity). */
+static void
+init_erosion_8_merged(const gint *grain, guint *dist,
+                      gint width, gint height,
+                      gboolean from_border,
+                      PixelQueue *queue)
+{
+    for (guint i = 0; i < height; i++) {
+        gboolean ifirst = !i, ilast = (i == height-1);
+        for (guint j = 0; j < width; j++) {
+            gboolean jfirst = !j, jlast = (j == width-1);
+            guint k = i*width + j;
+            gint gno = grain[k];
+            if (gno <= 0) {
+                dist[k] = 0;
+                continue;
+            }
+
+            if ((!ifirst && !jfirst && grain[k-1 - width] <= 0)
+                || (!ifirst && grain[k - width] <= 0)
+                || (!ifirst && !jlast && grain[k+1 - width] <= 0)
+                || (!jfirst && grain[k-1] <= 0)
+                || (!jlast && grain[k+1] <= 0)
+                || (!ilast && !jfirst && grain[k-1 + width] <= 0)
+                || (!ilast && grain[k + width] <= 0)
+                || (!ilast && !jlast && grain[k+1 + width] <= 0)
+                || (from_border && (ifirst || ilast || jfirst || jlast))) {
+                dist[k] = 1;
+                pixel_queue_add(queue, i, j);
+            }
+            else
+                dist[k] = G_MAXUINT;
+        }
+    }
+}
+
+static void
+init_erosion_8_split(const gint *grain, guint *dist,
+                     gint width, gint height,
+                     gboolean from_border,
+                     PixelQueue *queue)
+{
+    for (guint i = 0; i < height; i++) {
+        gboolean ifirst = !i, ilast = (i == height-1);
+        for (guint j = 0; j < width; j++) {
+            gboolean jfirst = !j, jlast = (j == width-1);
+            guint k = i*width + j;
+            gint gno = grain[k];
+            if (gno <= 0) {
+                dist[k] = 0;
+                continue;
+            }
+
+            if ((!ifirst && !jfirst && grain[k-1 - width] != gno)
+                || (!ifirst && grain[k - width] != gno)
+                || (!ifirst && !jlast && grain[k+1 - width] != gno)
+                || (!jfirst && grain[k-1] != gno)
+                || (!jlast && grain[k+1] != gno)
+                || (!ilast && !jfirst && grain[k-1 + width] != gno)
+                || (!ilast && grain[k + width] != gno)
+                || (!ilast && !jlast && grain[k+1 + width] != gno)
+                || (from_border && (ifirst || ilast || jfirst || jlast))) {
+                dist[k] = 1;
+                pixel_queue_add(queue, i, j);
+            }
+            else
+                dist[k] = G_MAXUINT;
         }
     }
 }
 
 static gboolean
-erode_4(guint *grain,
+erode_4(guint *dists,
         gint width, gint height,
-        guint id,
+        guint d,
         const PixelQueue *inqueue,
         PixelQueue *outqueue)
 {
@@ -332,20 +444,20 @@ erode_4(guint *grain,
     for (m = inqueue->len; m; m--, ipt++) {
         gint i = ipt->i, j = ipt->j, k = i*width + j;
 
-        if (i && grain[k - width] == G_MAXUINT) {
-            grain[k - width] = id+1;
+        if (i && dists[k - width] == G_MAXUINT) {
+            dists[k - width] = d+1;
             pixel_queue_add(outqueue, i-1, j);
         }
-        if (j && grain[k - 1] == G_MAXUINT) {
-            grain[k - 1] = id+1;
+        if (j && dists[k - 1] == G_MAXUINT) {
+            dists[k - 1] = d+1;
             pixel_queue_add(outqueue, i, j-1);
         }
-        if (j < width-1 && grain[k + 1] == G_MAXUINT) {
-            grain[k + 1] = id+1;
+        if (j < width-1 && dists[k + 1] == G_MAXUINT) {
+            dists[k + 1] = d+1;
             pixel_queue_add(outqueue, i, j+1);
         }
-        if (i < height-1 && grain[k + width] == G_MAXUINT) {
-            grain[k + width] = id+1;
+        if (i < height-1 && dists[k + width] == G_MAXUINT) {
+            dists[k + width] = d+1;
             pixel_queue_add(outqueue, i+1, j);
         }
     }
@@ -354,9 +466,9 @@ erode_4(guint *grain,
 }
 
 static gboolean
-erode_8(guint *grain,
+erode_8(guint *dists,
         gint width, gint height,
-        guint id,
+        guint d,
         const PixelQueue *inqueue,
         PixelQueue *outqueue)
 {
@@ -366,36 +478,36 @@ erode_8(guint *grain,
     outqueue->len = 0;
     for (m = inqueue->len; m; m--, ipt++) {
         gint i = ipt->i, j = ipt->j, k = i*width + j;
-        if (i && j && grain[k - width - 1] == G_MAXUINT) {
-            grain[k - width - 1] = id+1;
+        if (i && j && dists[k - width - 1] == G_MAXUINT) {
+            dists[k - width - 1] = d+1;
             pixel_queue_add(outqueue, i-1, j-1);
         }
-        if (i && grain[k - width] == G_MAXUINT) {
-            grain[k - width] = id+1;
+        if (i && dists[k - width] == G_MAXUINT) {
+            dists[k - width] = d+1;
             pixel_queue_add(outqueue, i-1, j);
         }
-        if (i && j < width-1 && grain[k - width + 1] == G_MAXUINT) {
-            grain[k - width + 1] = id+1;
+        if (i && j < width-1 && dists[k - width + 1] == G_MAXUINT) {
+            dists[k - width + 1] = d+1;
             pixel_queue_add(outqueue, i-1, j+1);
         }
-        if (j && grain[k - 1] == G_MAXUINT) {
-            grain[k - 1] = id+1;
+        if (j && dists[k - 1] == G_MAXUINT) {
+            dists[k - 1] = d+1;
             pixel_queue_add(outqueue, i, j-1);
         }
-        if (j < width-1 && grain[k + 1] == G_MAXUINT) {
-            grain[k + 1] = id+1;
+        if (j < width-1 && dists[k + 1] == G_MAXUINT) {
+            dists[k + 1] = d+1;
             pixel_queue_add(outqueue, i, j+1);
         }
-        if (i < height-1 && j && grain[k + width - 1] == G_MAXUINT) {
-            grain[k + width - 1] = id+1;
+        if (i < height-1 && j && dists[k + width - 1] == G_MAXUINT) {
+            dists[k + width - 1] = d+1;
             pixel_queue_add(outqueue, i+1, j-1);
         }
-        if (i < height-1 && grain[k + width] == G_MAXUINT) {
-            grain[k + width] = id+1;
+        if (i < height-1 && dists[k + width] == G_MAXUINT) {
+            dists[k + width] = d+1;
             pixel_queue_add(outqueue, i+1, j);
         }
-        if (i < height-1 && j < width-1 && grain[k + width + 1] == G_MAXUINT) {
-            grain[k + width + 1] = id+1;
+        if (i < height-1 && j < width-1 && dists[k + width + 1] == G_MAXUINT) {
+            dists[k + width + 1] = d+1;
             pixel_queue_add(outqueue, i+1, j+1);
         }
     }
@@ -403,72 +515,123 @@ erode_8(guint *grain,
     return outqueue->len;
 }
 
-/* Perform a cityblock, chessboard or octagonal distance transform of given type using provided queues. */
-/* TODO: Change the argument to Nield (which includes the dimensions). */
+/* Perform a cityblock, chessboard or octagonal distance transform of given type using provided queues putting
+ * the result to @distances. It is possible to pass NULL @distances for an in-place transform.
+ *
+ * If @merged is TRUE, grains are not distinguished and tne entire masked area is transformed.
+ * If @merged is FALSE, borders of individual grains are distinguished (which matters if grains are touching). */
 guint
-_gwy_simple_dist_trans(guint *grain, guint width, guint height,
-                       gboolean from_border, GwyDistanceTransformType dtype,
+_gwy_simple_dist_trans(GwyNield *grains, GwyNield *distances,
+                       gboolean merged, gboolean from_border,
+                       GwyDistanceTransformType dtype,
                        PixelQueue *inqueue, PixelQueue *outqueue)
 {
-    ErodeFunc erode = NULL;
-    guint dist = 1;
+    g_return_val_if_fail(dtype == GWY_DISTANCE_TRANSFORM_CONN4
+                         || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48
+                         || dtype == GWY_DISTANCE_TRANSFORM_CONN8
+                         || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL84,
+                         0);
+    gboolean start_with_4 = (dtype == GWY_DISTANCE_TRANSFORM_CONN4 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48);
+    gboolean is_octagonal = (dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48
+                             || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL84);
+    guint width = grains->xres, height = grains->yres;
+    const gint *gdata = grains->priv->data;
+    GwyNield *workspace = distances ? distances : gwy_nield_new_alike(grains);
+    gint *ddata = workspace->priv->data;
 
     inqueue->len = outqueue->len = 0;
 
-    if (dtype == GWY_DISTANCE_TRANSFORM_CONN4 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48)
-        init_erosion_4(grain, width, height, from_border, inqueue);
-    else if (dtype == GWY_DISTANCE_TRANSFORM_CONN8 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL84)
-        init_erosion_8(grain, width, height, from_border, inqueue);
+    if (merged) {
+        if (start_with_4)
+            init_erosion_4_merged(gdata, ddata, width, height, from_border, inqueue);
+        else
+            init_erosion_8_merged(gdata, ddata, width, height, from_border, inqueue);
+    }
+    else {
+        if (start_with_4)
+            init_erosion_4_split(gdata, ddata, width, height, from_border, inqueue);
+        else
+            init_erosion_8_split(gdata, ddata, width, height, from_border, inqueue);
+    }
 
-    if (dtype == GWY_DISTANCE_TRANSFORM_CONN4 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL84)
-        erode = erode_4;
-    else if (dtype == GWY_DISTANCE_TRANSFORM_CONN8 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48)
-        erode = erode_8;
-
-    g_return_val_if_fail(erode, 0);
-
-    while (TRUE) {
-        if (!erode(grain, width, height, dist, inqueue, outqueue))
-            break;
+    // Once all the borders are correctly set up according to merged/split, further propagation can only encounter
+    // pixels belonging to the same grain (however it is defined). So the erosion function do not need to worry about
+    // the distinct grain treatment mode.
+    guint dist = 1;
+    ErodeFunc erode = (start_with_4 ? erode_4 : erode_8);
+    // We already did the first step.
+    if (is_octagonal)
+        erode = (erode == erode_4) ? erode_8 : erode_4;
+    while (erode(ddata, width, height, dist, inqueue, outqueue)) {
         GWY_SWAP(PixelQueue*, inqueue, outqueue);
         dist++;
-
-        if (dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL48 || dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL84)
+        if (is_octagonal)
             erode = (erode == erode_4) ? erode_8 : erode_4;
     }
 
+    if (!distances) {
+        gwy_nield_copy_data(workspace, grains);
+        g_object_unref(workspace);
+    }
+
     return dist;
 }
 
 static void
-average_octagonal_dt(GwyNield *nield, GwyField *distances, gboolean from_border)
+average_octagonal_dt(GwyNield *nield, GwyField *distances, gboolean merged, gboolean from_border)
 {
-    GwyField *tmp = gwy_field_new_alike(distances, FALSE);
-    gwy_nield_distance_transform(nield, distances, GWY_DISTANCE_TRANSFORM_OCTAGONAL48, from_border);
-    gwy_nield_distance_transform(nield, tmp, GWY_DISTANCE_TRANSFORM_OCTAGONAL84, from_border);
-    gwy_field_linear_combination(distances, 0.5, distances, 0.5, tmp, 0.0);
-    g_object_unref(tmp);
+    GwyNield *intdist = gwy_nield_new_alike(nield);
+    gsize n = (gsize)nield->xres * (gsize)nield->yres;
+
+    PixelQueue inqueue, outqueue;
+    gwy_clear1(inqueue);
+    gwy_clear1(outqueue);
+
+    _gwy_simple_dist_trans(nield, intdist, merged, from_border, GWY_DISTANCE_TRANSFORM_OCTAGONAL48,
+                           &inqueue, &outqueue);
+    gdouble *d = distances->priv->data;
+    const gint *dd = intdist->priv->data;
+    for (gsize i = 0; i < n; i++)
+        d[i] = dd[i];
+
+    _gwy_simple_dist_trans(nield, intdist, merged, from_border, GWY_DISTANCE_TRANSFORM_OCTAGONAL84,
+                           &inqueue, &outqueue);
+    g_free(inqueue.points);
+    g_free(outqueue.points);
+
+    dd = intdist->priv->data;
+    for (gsize i = 0; i < n; i++)
+        d[i] = 0.5*(dd[i] + d[i]);
+
+    g_object_unref(intdist);
 }
 
 /**
- * gwy_field_grain_simple_dist_trans:
+ * gwy_nield_distance_transform:
  * @nield: A number field with zeros in empty space and nonzeros in marked areas.
  * @distances: Output data field which will be resized and filled with the distances.
  * @dtype: Type of simple distance to use.
+ * @merged: %TRUE to only distinguish marked/unmarked; %FALSE to distinuish grain numbers.
  * @from_border: %TRUE to consider image edges to be grain boundaries.
  *
  * Performs a distance transform of a number field.
  *
- * For each non-zero value, a distance to the grain boundary will be calculated, measured in pixels. The function does
- * not distiguish grain numbers, only marked/unmarked areas.
+ * For each non-zero value, a distance to the grain boundary is calculated, measured in pixels. For unmarked pixels in
+ * @nield, the distance is set to zero.
  *
- * If the entire @nield is marked and @from_border is %FALSE the grain has no boundaries. In such case @distances is
- * filled with a huge positive value (like %G_MAXDOUBLE).
+ * If @merged is TRUE, there is no boundary between touching grains. The distance is calculated from unmarked area
+ * (and possibly from image edges). If @merged is %TRUE, regions filled with different numbers in @nield are
+ * considered individually, creating boundaries also where different grains touch.
+ *
+ * If the entire @nield is marked, @from_border is %FALSE and either @merged is %TRUE or @nield is filled with the
+ * same value, there are no boundaries to calculate the distance from. In such case @distances is filled with a huge
+ * positive value (like %G_MAXDOUBLE).
  **/
 void
 gwy_nield_distance_transform(GwyNield *nield,
                              GwyField *distances,
                              GwyDistanceTransformType dtype,
+                             gboolean merged,
                              gboolean from_border)
 {
     g_return_if_fail(GWY_IS_NIELD(nield));
@@ -480,52 +643,54 @@ gwy_nield_distance_transform(GwyNield *nield,
     gsize n = (gsize)xres * (gsize)yres;
     gint *g = nield->priv->data;
 
-    if (!from_border) {
-        /* Handle the infinite distance case once for all here so that all methods return consitently the same
-         * huge number and do not need special-casing. */
-        gboolean any_empty = FALSE;
-        for (gsize k = 0; k < n; k++) {
-            if (g[k] <= 0) {
-                any_empty = TRUE;
-                break;
-            }
+    /* Handle the infinite distance case once for all here so that all methods return consitently the same
+     * huge number and do not need special-casing. */
+    if (!from_border && gwy_nield_count(nield) == n) {
+        if (merged) {
+            gwy_field_fill(distances, G_MAXDOUBLE);
+            return;
         }
-        if (!any_empty) {
+
+        // The non-merged case is messier. We need to check the nield is filled with a single value. Otherwise there
+        // are boundaries.
+        gint gno = g[0];
+        gsize i = 1;
+        while (i < n && g[i] == gno)
+            i++;
+        if (i == n) {
             gwy_field_fill(distances, G_MAXDOUBLE);
             return;
         }
     }
 
     if (dtype == GWY_DISTANCE_TRANSFORM_EUCLIDEAN) {
-        euclidean_distance_transform(nield, distances, from_border);
+        euclidean_distance_transform(nield, distances, merged, from_border);
         return;
     }
     if (dtype == GWY_DISTANCE_TRANSFORM_OCTAGONAL) {
-        average_octagonal_dt(nield, distances, from_border);
+        average_octagonal_dt(nield, distances, merged, from_border);
         return;
     }
 
     /* The other distances are always integers. */
     g_return_if_fail(dtype <= GWY_DISTANCE_TRANSFORM_OCTAGONAL84);
 
-    PixelQueue *inqueue = g_new0(PixelQueue, 1);
-    PixelQueue *outqueue = g_new0(PixelQueue, 1);
-    guint *workspace = g_new(guint, n);
-    for (gsize k = 0; k < n; k++)
-        workspace[k] = (g[k] > 0) ? G_MAXUINT : 0;
+    PixelQueue inqueue, outqueue;
+    gwy_clear1(inqueue);
+    gwy_clear1(outqueue);
+    GwyNield *intdist = gwy_nield_new_alike(nield);
 
-    _gwy_simple_dist_trans(workspace, xres, yres, from_border, dtype, inqueue, outqueue);
+    _gwy_simple_dist_trans(nield, intdist, merged, from_border, dtype, &inqueue, &outqueue);
 
     gdouble *d = distances->priv->data;
+    const gint *w = intdist->priv->data;
     for (gsize k = 0; k < n; k++)
-        d[k] = workspace[k];
+        d[k] = w[k];
     gwy_field_invalidate(distances);
 
-    g_free(workspace);
-    g_free(inqueue->points);
-    g_free(outqueue->points);
-    g_free(inqueue);
-    g_free(outqueue);
+    g_object_unref(intdist);
+    g_free(inqueue.points);
+    g_free(outqueue.points);
 }
 
 /**
@@ -534,6 +699,7 @@ gwy_nield_distance_transform(GwyNield *nield,
  * @amount: How much the grains should be reduced, in pixels.  It is inclusive, i.e. pixels that are @amount far from
  *          the border will be removed.
  * @dtype: Type of simple distance to use.
+ * @merged: %TRUE to only distinguish marked/unmarked; %FALSE to distinuish grain numbers.
  * @from_border: %TRUE to consider image edges to be grain boundaries. %FALSE to reduce grains touching field
  *               boundaries only along the boundaries.
  *
@@ -546,6 +712,7 @@ void
 gwy_nield_shrink(GwyNield *nield,
                  gdouble amount,
                  GwyDistanceTransformType dtype,
+                 gboolean merged,
                  gboolean from_border)
 {
     g_return_if_fail(GWY_IS_NIELD(nield));
@@ -563,7 +730,7 @@ gwy_nield_shrink(GwyNield *nield,
 
     gsize n = (gsize)xres * (gsize)yres;
     GwyField *distances = gwy_field_new(xres, yres, xres, yres, FALSE);
-    gwy_nield_distance_transform(nield, distances, dtype, from_border);
+    gwy_nield_distance_transform(nield, distances, dtype, merged, from_border);
     gint *g = nield->priv->data;
     const gdouble *d = distances->priv->data;
     for (gsize k = 0; k < n; k++) {
@@ -597,7 +764,7 @@ compare_distant_points(gconstpointer pa, gconstpointer pb)
 }
 
 static void
-grow_without_merging(GwyNield *nield, GwyField *distances, gdouble amount)
+grow_without_touching(GwyNield *nield, GwyField *distances, gdouble amount)
 {
     if (!gwy_nield_number_contiguous(nield))
         return;
@@ -634,14 +801,16 @@ grow_without_merging(GwyNield *nield, GwyField *distances, gdouble amount)
     g_array_free(array, TRUE);
 }
 
+// FIXME: Some kind of @merged option might be useful also here. However, the grains can already touching in the
+// input, creating a bunch of ill-defined cases.
 /**
  * gwy_nield_grow:
  * @nield: A number field with zeros in empty space and nonzeros in grains.
  * @amount: How much the grains should be expanded, in pixels.  It is inclusive, i.e. exterior pixels that are @amount
  *          far from the border will be filled.
  * @dtype: Type of simple distance to use.
- * @prevent_merging: %TRUE to prevent grain merging, i.e. the growth stops where two grains would merge.  %FALSE to
- *                   simply expand the grains, without regard to grain connectivity.
+ * @prevent_touching: %TRUE to prevent grain touching, i.e. the growth stops where two grains would touch.  %FALSE to
+ *                    simply expand the grains, without regard to grain connectivity.
  *
  * Dilates a number field containing mask by specified amount using a distance measure.
  *
@@ -652,7 +821,7 @@ void
 gwy_nield_grow(GwyNield *nield,
                gdouble amount,
                GwyDistanceTransformType dtype,
-               gboolean prevent_merging)
+               gboolean prevent_touching)
 {
     g_return_if_fail(GWY_IS_NIELD(nield));
     g_return_if_fail(dtype <= GWY_DISTANCE_TRANSFORM_EUCLIDEAN);
@@ -665,10 +834,10 @@ gwy_nield_grow(GwyNield *nield,
     gsize n = (gsize)xres * (gsize)yres;
     GwyField *distances = gwy_field_new(xres, yres, xres, yres, FALSE);
     gwy_nield_invert(nield);
-    gwy_nield_distance_transform(nield, distances, dtype, FALSE);
+    gwy_nield_distance_transform(nield, distances, dtype, TRUE, FALSE);
     gwy_nield_invert(nield);
-    if (prevent_merging)
-        grow_without_merging(nield, distances, amount);
+    if (prevent_touching)
+        grow_without_touching(nield, distances, amount);
     else {
         const gdouble *d = distances->priv->data;
         gint *g = nield->priv->data;
@@ -716,7 +885,7 @@ compare_candidate(gconstpointer pa, gconstpointer pb)
 
 /**
  * gwy_nield_thin:
- * @field: A data field with zeros in empty space and nonzeros in grains.
+ * @nield: A number field with zeros in empty space and nonzeros in grains.
  *
  * Performs thinning of a data field containing mask.
  *
@@ -751,7 +920,7 @@ gwy_nield_thin(GwyNield *nield)
     gint xres = nield->xres, yres = nield->yres;
     gsize n = (gsize)xres * (gsize)yres;
     GwyField *distances = gwy_field_new(xres, yres, xres, yres, FALSE);
-    gwy_nield_distance_transform(nield, distances, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
+    gwy_nield_distance_transform(nield, distances, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, TRUE);
     gdouble *d = distances->priv->data;
     gint *g = nield->priv->data;
 
@@ -874,28 +1043,6 @@ gwy_nield_thin(GwyNield *nield)
     gwy_nield_invalidate(nield);
 }
 
-/**
- * gwy_distance_transform_type_get_enum:
- *
- * Returns #GwyEnum for #GwyDistanceTransformType enum type.
- *
- * Returns: %NULL-terminated #GwyEnum which must not be modified nor freed.
- **/
-const GwyEnum*
-gwy_distance_transform_type_get_enum(void)
-{
-    static const GwyEnum entries[] = {
-        { gwy_NC("distance", "City-block"),    GWY_DISTANCE_TRANSFORM_CITYBLOCK,   },
-        { gwy_NC("distance", "Chess"),         GWY_DISTANCE_TRANSFORM_CHESS,       },
-        { gwy_NC("distance", "Octagonal 4,8"), GWY_DISTANCE_TRANSFORM_OCTAGONAL48, },
-        { gwy_NC("distance", "Octagonal 8,4"), GWY_DISTANCE_TRANSFORM_OCTAGONAL84, },
-        { gwy_NC("distance", "Octagonal"),     GWY_DISTANCE_TRANSFORM_OCTAGONAL,   },
-        { gwy_NC("distance", "Euclidean"),     GWY_DISTANCE_TRANSFORM_EUCLIDEAN,   },
-        { NULL,                                0,                                  },
-    };
-    return entries;
-}
-
 /**
  * SECTION: distance-transform
  * @title: Distance transform
