@@ -1,5 +1,5 @@
 /*
- *  $Id: dwt.c 28972 2025-12-10 18:40:27Z yeti-dn $
+ *  $Id: dwt.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -408,9 +408,7 @@ gwy_field_dwt_denoise(GwyField *field,
     ulcol = field->xres/2; ulrow = field->xres/2;
     brcol = field->xres; brrow = field->xres;
 
-    median = gwy_field_area_get_median(field,
-                                       ulcol, ulrow,
-                                       brcol-ulcol, brrow-ulrow);
+    median = gwy_field_area_median(field, ulcol, ulrow, brcol-ulcol, brrow-ulrow);
     noise_variance = median/0.6745;
 
     if (type == GWY_DWT_DENOISE_UNIVERSAL)
@@ -576,19 +574,14 @@ remove_by_adaptive_threshold(GwyField *field,
             pbrcol = MIN(ulcol + j + size/2, brcol);
             pbrrow = MIN(ulrow + i + size/2, brrow);
 
-            rms = gwy_field_area_get_rms(field, NULL,
-                                         pulcol, pulrow,
-                                         pbrcol-pulcol, pbrrow-pulrow);
+            rms = gwy_field_area_rms(field, NULL, pulcol, pulrow, pbrcol-pulcol, pbrrow-pulrow);
             if ((rms*rms - noise_variance*noise_variance) > 0) {
                 rms = sqrt(rms*rms - noise_variance*noise_variance);
                 threshold = noise_variance*noise_variance/rms;
                 threshold *= multiple_threshold;
             }
             else {
-                gwy_field_area_get_min_max(field, NULL,
-                                           pulcol, pulrow,
-                                           pbrcol-pulcol, pbrrow-pulrow,
-                                           &min, &max);
+                gwy_field_area_min_max(field, NULL, pulcol, pulrow, pbrcol-pulcol, pbrrow-pulrow, &min, &max);
                 threshold = MAX(max, -min);
             }
 
@@ -622,14 +615,14 @@ remove_by_threshold(GwyField *field,
 
     n = (brrow-ulrow)*(brcol-ulcol);
 
-    rms = gwy_field_area_get_rms(field, NULL, ulcol, ulrow, brcol-ulcol, brrow-ulrow);
+    rms = gwy_field_area_rms(field, NULL, ulcol, ulrow, brcol-ulcol, brrow-ulrow);
     if ((rms*rms - noise_variance*noise_variance) > 0) {
         rms = sqrt(rms*rms - noise_variance*noise_variance);
         threshold = noise_variance*noise_variance/rms;
         threshold *= multiple_threshold;
     }
     else {
-        gwy_field_area_get_min_max(field, NULL, ulcol, ulrow, brcol-ulcol, brrow-ulrow, &min, &max);
+        gwy_field_area_min_max(field, NULL, ulcol, ulrow, brcol-ulcol, brrow-ulrow, &min, &max);
         threshold = MAX(max, -min);
     }
 
@@ -660,35 +653,6 @@ remove_by_threshold(GwyField *field,
 /**
  * gwy_field_dwt_mark_anisotropy:
  * @field: Data field to mark anisotropy of (must be square).
- * @mask: Output mask field.
- * @wt_coefs: Data line to store wavelet transform coefficients to.
- * @ratio: Anisotropy threshold.
- * @lowlimit: Size of minimal transform result block.
- *
- * Performs steps of the 2D image wavelet decomposition.
- *
- * The smallest low pass coefficients block is equal to @minsize. Run with
- * @minsize = @field->xres/2 to perform one step of decomposition
- * or @minsize = 4 to perform full decomposition (or anything between).
- **/
-void
-gwy_field_dwt_mark_anisotropy(GwyField *field,
-                              GwyField *mask,
-                              GwyLine *wt_coefs,
-                              gdouble ratio,
-                              gint lowlimit)
-{
-    gint xres = field->xres, yres = field->yres;
-    GwyNield *nield = gwy_nield_new(xres, yres);
-    gwy_NIELD_dwt_mark_anisotropy(field, nield, wt_coefs, ratio, lowlimit);
-    gwy_field_resize(mask, xres, yres);
-    gwy_field_area_fill_mask(mask, nield, 0, 0, xres, yres, 1.0, 0.0);
-    g_object_unref(nield);
-}
-
-/**
- * gwy_NIELD_dwt_mark_anisotropy:
- * @field: Data field to mark anisotropy of (must be square).
  * @mask: Number field to fill with the output mask.
  * @wt_coefs: Data line to store wavelet transform coefficients to.
  * @ratio: Anisotropy threshold.
@@ -700,13 +664,13 @@ gwy_field_dwt_mark_anisotropy(GwyField *field,
  * step of decomposition or @minsize = 4 to perform full decomposition (or anything between).
  **/
 void
-gwy_NIELD_dwt_mark_anisotropy(GwyField *field,
+gwy_field_dwt_mark_anisotropy(GwyField *field,
                               GwyNield *mask,
                               GwyLine *wt_coefs,
                               gdouble ratio,
                               gint lowlimit)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
+    if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
     g_return_if_fail(GWY_IS_LINE(wt_coefs));
 
@@ -870,7 +834,7 @@ find_anisotropy(GwyField *field,
     mcor = MIN(cor, 30);
     scor = MAX(cor, mcor/3.5);
 
-    rms = gwy_field_area_get_rms(field, NULL, GWY_MASK_IGNORE, ul, ul, br-ul, br-ul);
+    rms = gwy_field_area_rms(field, NULL, GWY_MASK_IGNORE, ul, ul, br-ul, br-ul);
 
     for (gint i = 0; i < br - ul; i++) {
         const gdouble *brdrow = brpos + i*field->xres;
