@@ -1,6 +1,6 @@
 /*
- *  $Id: extend.c 28969 2025-12-10 15:32:52Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: extend.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -476,7 +476,7 @@ rect_extend_laplace(const gdouble *in, guint inrowstride,
 
     for (guint i = 0; i < height; i++)
         gwy_assign(wdata + (extend_up + i)*extxres + extend_left, in + (ypos + i)*inrowstride + xpos, width);
-    gwy_NIELD_laplace_solve(workspace, mask, -1, 0.5);
+    gwy_field_laplace_solve(workspace, mask, GWY_LAPLACE_MASKED, 0.5);
     for (guint i = 0; i < extyres; i++)
         gwy_assign(out + i*outrowstride, wdata + i*extxres, extxres);
 
@@ -620,6 +620,9 @@ _gwy_get_rect_extend_func(GwyExteriorType exterior)
  *
  * Creates a new data field by extending another data field using the specified method of exterior handling.
  *
+ * If @exterior is not %GWY_EXTERIOR_UNDEFINED, the added pixels are filled with values, according to the exterior
+ * type. If it is undefined, the added pixels are simply left uninitialised.
+ *
  * Returns: (transfer full): A newly created data field.
  **/
 GwyField*
@@ -630,25 +633,24 @@ gwy_field_extend(GwyField *field,
                  gdouble fill_value,
                  gboolean keep_offsets)
 {
-    GwyField *target;
-    RectExtendFunc extend_rect;
-    guint col = 0, row = 0, width, height;
-    gdouble dx, dy;
-
     g_return_val_if_fail(GWY_IS_FIELD(field), NULL);
 
-    extend_rect = _gwy_get_rect_extend_func(exterior);
-    g_return_val_if_fail(extend_rect, NULL);
+    RectExtendFunc extend_rect = NULL;
+    if (exterior != GWY_EXTERIOR_UNDEFINED)
+        extend_rect = _gwy_get_rect_extend_func(exterior);
 
-    width = field->xres;
-    height = field->yres;
-    target = gwy_field_new(width + left + right, height + up + down, 1.0, 1.0, FALSE);
-    extend_rect(field->priv->data, field->xres, target->priv->data, target->xres,
-                col, row, width, height, field->xres, field->yres,
-                left, right, up, down, fill_value);
+    guint width = field->xres, height = field->yres, col = 0, row = 0;
+    GwyField *target = gwy_field_new(width + left + right, height + up + down, 1.0, 1.0, FALSE);
+    if (!extend_rect)
+        gwy_field_area_copy(field, target, 0, 0, width, height, left, up);
+    else {
+        extend_rect(field->priv->data, field->xres, target->priv->data, target->xres,
+                    col, row, width, height, field->xres, field->yres,
+                    left, right, up, down, fill_value);
+    }
 
-    dx = field->xreal/field->xres;
-    dy = field->yreal/field->yres;
+    gdouble dx = field->xreal/field->xres;
+    gdouble dy = field->yreal/field->yres;
     gwy_field_set_xreal(target, (width + left + right)*dx);
     gwy_field_set_yreal(target, (height + up + down)*dy);
     if (keep_offsets) {
@@ -664,18 +666,102 @@ gwy_field_extend(GwyField *field,
     return target;
 }
 
+/**
+ * gwy_nield_extend:
+ * @nield: A two-dimensional number field.
+ * @left: Number of pixels to extend to the left (towards lower column indices).
+ * @right: Number of pixels to extend to the right (towards higher column indices).
+ * @up: Number of pixels to extend up (towards lower row indices).
+ * @down: Number of pixels to extend down (towards higher row indices).
+ * @exterior: Exterior pixels handling.
+ * @fill_value: The value to use with %GWY_EXTERIOR_FIXED_VALUE exterior.
+ *
+ * Creates a new natural number field by extending another field using the specified method of exterior handling.
+ *
+ * Only simple exteriors not requiring interpolation can be used with this function. This excludes for instance
+ * %GWY_EXTERIOR_LAPLACE and %GWY_EXTERIOR_CONNECT.
+ *
+ * If @exterior is not %GWY_EXTERIOR_UNDEFINED, the added pixels are filled with values, according to the exterior
+ * type. If it is undefined, the added pixels are simply left uninitialised.
+ *
+ * Returns: (transfer full): A newly created number field.
+ **/
+GwyNield*
+gwy_nield_extend(GwyNield *nield,
+                 guint left, guint right,
+                 guint up, guint down,
+                 GwyExteriorType exterior,
+                 gint fill_value)
+{
+    g_return_val_if_fail(GWY_IS_NIELD(nield), NULL);
+
+    gint sup = up, sleft = left;
+    gint width = nield->xres, height = nield->yres;
+    gint xres = width + left + right, yres = height + up + down;
+    GwyNield *target = gwy_nield_new(xres, yres);
+    const gint *m = nield->priv->data;
+    gint *t = target->priv->data;
+
+    if (exterior == GWY_EXTERIOR_PERIODIC) {
+        gint minus_up = -sup % height + height;
+        gint minus_left = -sleft % width + width;
+        for (gint i = 0; i < yres; i++) {
+            gint isrc = (i + minus_up) % height;
+            for (gint j = 0; j < xres; j++) {
+                gint jsrc = (j + minus_left) % width;
+                t[i*xres + j] = m[isrc*width + jsrc];
+            }
+        }
+    }
+    else if (exterior == GWY_EXTERIOR_MIRROR) {
+        gint minus_up = -sup % (2*height) + 2*height;
+        gint minus_left = -sleft % (2*width) + 2*width;
+        for (gint i = 0; i < yres; i++) {
+            gint isrc = (i + minus_up) % (2*height);
+            if (isrc >= height)
+                isrc = 2*height-1 - isrc;
+            for (gint j = 0; j < xres; j++) {
+                gint jsrc = (j + minus_left) % (2*width);
+                if (jsrc >= width)
+                    jsrc = 2*width-1 - jsrc;
+                t[i*xres + j] = m[isrc*width + jsrc];
+            }
+        }
+    }
+    else if (exterior == GWY_EXTERIOR_BORDER) {
+        for (gint i = 0; i < yres; i++) {
+            gint isrc = CLAMP(i - sup, 0, height-1);
+            for (gint j = 0; j < xres; j++) {
+                gint jsrc = CLAMP(j - sleft, 0, width-1);
+                t[i*xres + j] = m[isrc*width + jsrc];
+            }
+        }
+    }
+    else {
+        g_warn_if_fail(exterior == GWY_EXTERIOR_FIXED_VALUE || exterior == GWY_EXTERIOR_UNDEFINED);
+        if (exterior != GWY_EXTERIOR_UNDEFINED && fill_value && left + right + up + down > 0)
+            gwy_nield_fill(target, fill_value);
+        gwy_nield_area_copy(nield, target, 0, 0, width, height, left, up);
+    }
+
+    return target;
+}
+
 /**
  * gwy_line_extend:
  * @line: A data line.
- * @left: Number of pixels to extend to the left (towards lower indices).
- * @right: Number of pixels to extend to the right (towards higher indices).
- * @exterior: Exterior pixels handling.
+ * @left: Number of values to extend to the left (towards lower indices).
+ * @right: Number of values to extend to the right (towards higher indices).
+ * @exterior: Exterior values handling.
  * @fill_value: The value to use with %GWY_EXTERIOR_FIXED_VALUE exterior.
  * @keep_offsets: %TRUE to set the offset of the new line using @line offset.  %FALSE to set offset of the new line
  *                to zero.
  *
  * Creates a new data line by extending another data line using the specified method of exterior handling.
  *
+ * If @exterior is not %GWY_EXTERIOR_UNDEFINED, the added values are filled with values, according to the exterior
+ * type. If it is undefined, the added values are simply left uninitialised.
+ *
  * Returns: (transfer full): A newly created data line.
  **/
 GwyLine*
@@ -686,23 +772,23 @@ gwy_line_extend(GwyLine *line,
                 gdouble fill_value,
                 gboolean keep_offsets)
 {
-    GwyLine *target;
-    RowExtendFunc extend_row;
-    guint col = 0, width;
-    gdouble dx;
-
     g_return_val_if_fail(GWY_IS_LINE(line), NULL);
 
-    extend_row = _gwy_get_row_extend_func(exterior);
-    g_return_val_if_fail(extend_row, NULL);
+    RowExtendFunc extend_row = NULL;
+    if (exterior != GWY_EXTERIOR_UNDEFINED)
+        extend_row = _gwy_get_row_extend_func(exterior);
 
-    width = line->res;
-    target = gwy_line_new(width + left + right, 1.0, FALSE);
-    extend_row(line->priv->data, target->priv->data,
-               col, width, line->res,
-               left, right, fill_value);
+    gint width = line->res, col = 0;
+    GwyLine *target = gwy_line_new(width + left + right, 1.0, FALSE);
+    if (!extend_row)
+        gwy_line_part_copy(line, target, 0, width, left);
+    else {
+        extend_row(line->priv->data, target->priv->data,
+                   col, width, line->res,
+                   left, right, fill_value);
+    }
 
-    dx = line->real/line->res;
+    gdouble dx = line->real/line->res;
     gwy_line_set_real(target, (width + left + right)*dx);
     if (keep_offsets)
         gwy_line_set_offset(target, line->off + col*dx - left*dx);
