@@ -1,7 +1,7 @@
 #pragma once
 /*
- *  $Id: field.h 28963 2025-12-09 16:07:48Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: field.h 29552 2026-02-28 14:14:24Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -22,7 +22,6 @@
 #include <libgwyddion/math.h>
 #include <libgwyddion/interpolation.h>
 #include <libgwyddion/line.h>
-#include <libgwyddion/nield.h>
 
 G_BEGIN_DECLS
 
@@ -59,6 +58,12 @@ struct _GwyFieldClass {
     void (*reserved2)(void);
 };
 
+G_END_DECLS
+
+#include <libgwyddion/nield.h>
+
+G_BEGIN_DECLS
+
 GType           gwy_field_get_type           (void)                                G_GNUC_CONST;
 GwyField*       gwy_field_new                (gint xres,
                                               gint yres,
@@ -67,6 +72,7 @@ GwyField*       gwy_field_new                (gint xres,
                                               gboolean nullme)                     G_GNUC_MALLOC;
 GwyField*       gwy_field_new_alike          (GwyField *model,
                                               gboolean nullme)                     G_GNUC_MALLOC;
+GwyNield*       gwy_field_new_nield_alike    (GwyField *field)                     G_GNUC_MALLOC;
 GwyField*       gwy_field_copy               (GwyField *field)                     G_GNUC_MALLOC;
 void            gwy_field_assign             (GwyField *destination,
                                               GwyField *source);
@@ -110,6 +116,10 @@ GwyField*       gwy_field_area_extract       (GwyField *field,
                                               gint height);
 void            gwy_field_copy_data          (GwyField *field,
                                               GwyField *target);
+void            gwy_field_copy_data_mask     (GwyField *field,
+                                              GwyField *target,
+                                              GwyNield *mask,
+                                              GwyMaskingType masking);
 void            gwy_field_area_copy          (GwyField *src,
                                               GwyField *dest,
                                               gint col,
@@ -120,6 +130,11 @@ void            gwy_field_area_copy          (GwyField *src,
                                               gint destrow);
 gdouble*        gwy_field_get_data           (GwyField *field);
 const gdouble*  gwy_field_get_data_const     (GwyField *field);
+gdouble*        gwy_field_get_data_with_size (GwyField *field,
+                                              gsize *out_len);
+void            gwy_field_set_data_with_size (GwyField *field,
+                                              gdouble *data,
+                                              gsize data_len);
 gint            gwy_field_get_xres           (GwyField *field);
 gint            gwy_field_get_yres           (GwyField *field);
 gdouble         gwy_field_get_xreal          (GwyField *field);
@@ -176,8 +191,8 @@ gdouble         gwy_field_get_dval_real      (GwyField *field,
 void            gwy_field_rotate             (GwyField *field,
                                               gdouble angle,
                                               GwyInterpolationType interpolation);
-GwyField*       gwy_field_new_rotated        (GwyField *dfield,
-                                              GwyField *exterior_mask,
+GwyField*       gwy_field_new_rotated        (GwyField *field,
+                                              GwyNield *exterior_mask,
                                               gdouble angle,
                                               GwyInterpolationType interp,
                                               GwyRotateResizeType resize);
@@ -206,14 +221,6 @@ void            gwy_field_add                (GwyField *field,
                                               gdouble value);
 void            gwy_field_abs                (GwyField *field);
 void            gwy_field_area_fill          (GwyField *field,
-                                              GwyField *mask,
-                                              GwyMaskingType mode,
-                                              gint col,
-                                              gint row,
-                                              gint width,
-                                              gint height,
-                                              gdouble value);
-void            gwy_NIELD_area_fill          (GwyField *field,
                                               GwyNield *mask,
                                               GwyMaskingType mode,
                                               gint col,
@@ -221,14 +228,18 @@ void            gwy_NIELD_area_fill          (GwyField *field,
                                               gint width,
                                               gint height,
                                               gdouble value);
+void            gwy_field_fill_mask          (GwyField *field,
+                                              GwyNield *mask,
+                                              gdouble unmasked,
+                                              gdouble masked);
 void            gwy_field_area_fill_mask     (GwyField *field,
                                               GwyNield *mask,
                                               gint col,
                                               gint row,
                                               gint width,
                                               gint height,
-                                              gdouble masked,
-                                              gdouble unmasked);
+                                              gdouble unmasked,
+                                              gdouble masked);
 void            gwy_field_area_clear         (GwyField *field,
                                               gint col,
                                               gint row,
@@ -251,27 +262,16 @@ void            gwy_field_area_abs           (GwyField *field,
                                               gint row,
                                               gint width,
                                               gint height);
-GwyLine*        gwy_field_get_profile        (GwyField *field,
+GwyLine*        gwy_field_profile            (GwyField *field,
                                               GwyLine* line,
-                                              gint scol,
-                                              gint srow,
-                                              gint ecol,
-                                              gint erow,
+                                              gint col1,
+                                              gint row1,
+                                              gint col2,
+                                              gint row2,
                                               gint res,
                                               gint thickness,
                                               GwyInterpolationType interpolation);
-GwyXY*          gwy_field_get_profile_mask   (GwyField *field,
-                                              gint *ndata,
-                                              GwyField *mask,
-                                              GwyMaskingType masking,
-                                              gdouble xfrom,
-                                              gdouble yfrom,
-                                              gdouble xto,
-                                              gdouble yto,
-                                              gint res,
-                                              gint thickness,
-                                              GwyInterpolationType interpolation);
-GwyXY*          gwy_NIELD_get_profile_mask   (GwyField *field,
+GwyXY*          gwy_field_profile_mask       (GwyField *field,
                                               GwyNield *mask,
                                               GwyMaskingType masking,
                                               gdouble xfrom,
@@ -282,6 +282,18 @@ GwyXY*          gwy_NIELD_get_profile_mask   (GwyField *field,
                                               gint thickness,
                                               GwyInterpolationType interpolation,
                                               gint *ndata);
+GwyXY*          gwy_field_row_profile        (GwyField *field,
+                                              GwyNield *mask,
+                                              GwyMaskingType masking,
+                                              gint row,
+                                              gint thickness,
+                                              gint *npoints);
+GwyXY*          gwy_field_column_profile     (GwyField *field,
+                                              GwyNield *mask,
+                                              GwyMaskingType masking,
+                                              gint col,
+                                              gint thickness,
+                                              gint *npoints);
 void            gwy_field_get_row            (GwyField *field,
                                               GwyLine* line,
                                               gint row);
@@ -314,13 +326,13 @@ void            gwy_field_set_column_part    (GwyField *field,
                                               gint col,
                                               gint from,
                                               gint to);
-gdouble         gwy_field_get_xder           (GwyField *field,
+gdouble         gwy_field_xder               (GwyField *field,
                                               gint col,
                                               gint row);
-gdouble         gwy_field_get_yder           (GwyField *field,
+gdouble         gwy_field_yder               (GwyField *field,
                                               gint col,
                                               gint row);
-gdouble         gwy_field_get_angder         (GwyField *field,
+gdouble         gwy_field_angder             (GwyField *field,
                                               gint col,
                                               gint row,
                                               gdouble theta);
