@@ -1,5 +1,5 @@
 /*
- *  $Id: filters--convdeconv.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: filters--convdeconv.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -23,6 +23,7 @@
 #include "libgwyddion/stats.h"
 #include "libgwyddion/linestats.h"
 #include "libgwyddion/grains.h"
+#include "libgwyddion/shaped.h"
 #include "libgwyddion/inttrans.h"
 #include "libgwyddion/simplefft.h"
 #include "libgwyddion/arithmetic.h"
@@ -37,7 +38,8 @@ typedef struct {
     fftw_complex *fmeas;       /* Precalculated, for P = ... */
     fftw_complex *fpsf;        /* P = ..., in each step */
     fftw_complex *cbuf;        /* FFT scratch buffer*/
-    GwyField *psf;         /* Real-space PSF */
+    GwyField *psf;             /* Real-space PSF */
+    GwyNield *mask;
     fftw_plan pplan;
     gdouble sigma_scale;
     guint cstride;
@@ -264,17 +266,14 @@ void
 gwy_field_fft_convolve(GwyField *field,
                        GwyField *kernel_field)
 {
+    if (!_gwy_field_check_other(field, kernel_field, FALSE))
+        return;
+
+    gint xres = field->xres, yres = field->yres;
     fftw_plan fplan, bplan;
     fftw_complex *fieldc, *kernelc;
     gdouble *rbuf;
-    guint i, xres, yres, n, cstride;
-
-    g_return_if_fail(GWY_IS_FIELD(field));
-    g_return_if_fail(GWY_IS_FIELD(kernel_field));
-    xres = field->xres;
-    yres = field->yres;
-    g_return_if_fail(kernel_field->xres == xres);
-    g_return_if_fail(kernel_field->yres == yres);
+    guint i, n, cstride;
 
     cstride = xres/2 + 1;
     n = xres*yres;
@@ -1382,10 +1381,10 @@ deconvolve_do(const fftw_complex *fproduct,
 
 /**
  * gwy_field_deconvolve_regularized:
- * @dfield: A data field.
- * @operand: One of the factors entering the convolution resulting in @dfield. It must have the same dimensions as
- *           @dfield and it is assumed it has also the same physical size.
- * @out: Data field where to put the result into.  It will be resized to match @dfield.  It can also be @dfield
+ * @field: A data field.
+ * @operand: One of the factors entering the convolution resulting in @field. It must have the same dimensions as
+ *           @field and it is assumed it has also the same physical size.
+ * @out: Data field where to put the result into.  It will be resized to match @field.  It can also be @field
  *       itself.
  * @sigma: Regularization parameter.
  *
@@ -1398,31 +1397,27 @@ deconvolve_do(const fftw_complex *fproduct,
  * recover (approximately) the image.  This means the deconvolution assumes continous convolution, not discrete sums.
  * Note that for the latter case this means the point spread function will be centered in @out.
  *
- * For recovery of transfer function, @dfield and @operand should be windowed beforehand if they are not periodic.
+ * For recovery of transfer function, @field and @operand should be windowed beforehand if they are not periodic.
  **/
 void
-gwy_field_deconvolve_regularized(GwyField *dfield,
+gwy_field_deconvolve_regularized(GwyField *field,
                                  GwyField *operand,
                                  GwyField *out,
                                  gdouble sigma)
 {
-    gint xres, yres, cstride;
+    if (!_gwy_field_check_other(field, operand, FALSE))
+        return;
+    g_return_if_fail(GWY_IS_FIELD(out));
+
+    gint xres = field->xres, yres = field->yres;
+    gint cstride = xres/2 + 1;
     gdouble lambda, msq;
     fftw_complex *ffield, *foper;
     fftw_plan fplan, bplan;
 
-    g_return_if_fail(GWY_IS_FIELD(dfield));
-    g_return_if_fail(GWY_IS_FIELD(operand));
-    g_return_if_fail(GWY_IS_FIELD(out));
-    xres = dfield->xres;
-    yres = dfield->yres;
-    g_return_if_fail(operand->xres == xres);
-    g_return_if_fail(operand->yres == yres);
-
-    cstride = xres/2 + 1;
     gwy_field_resize(out, xres, yres);
 
-    msq = gwy_field_get_mean_square(operand);
+    msq = gwy_field_mean_square(operand);
     if (!msq) {
         g_warning("Deconvolution by zero.");
         gwy_field_clear(out);
@@ -1438,7 +1433,7 @@ gwy_field_deconvolve_regularized(GwyField *dfield,
     gwy_fftw_execute(fplan);
     gwy_assign(foper, ffield, cstride*yres);
 
-    gwy_field_copy_data(dfield, out);
+    gwy_field_copy_data(field, out);
     gwy_fftw_execute(fplan);
     fftw_destroy_plan(fplan);
 
@@ -1454,16 +1449,16 @@ gwy_field_deconvolve_regularized(GwyField *dfield,
 
     /* NB: We normalize it as an integral.  So one recovers the convolution
      * with TRUE in ext-convolve! */
-    gwy_field_multiply(out, 1.0/(dfield->xreal * dfield->yreal));
+    gwy_field_multiply(out, 1.0/(field->xreal * field->yreal));
     gwy_field_fft_2d_center(out);
 
-    out->xreal = dfield->xreal;
-    out->yreal = dfield->yreal;
-    out->xoff = dfield->xoff;
-    out->yoff = dfield->yoff;
+    out->xreal = field->xreal;
+    out->yreal = field->yreal;
+    out->xoff = field->xoff;
+    out->yoff = field->yoff;
 
     gwy_field_invalidate(out);
-    set_transfer_function_units(operand, dfield, out);
+    set_transfer_function_units(operand, field, out);
 }
 
 static void
@@ -1475,12 +1470,8 @@ psf_sigmaopt_estimate_size(PSFSigmaOptData *sodata)
     fftw_complex *cbuf = sodata->cbuf;
     GwyField *psf = sodata->psf;
     gint xres = psf->xres, yres = psf->yres;
-    gint i, j, imin, jmin, imax, jmax, ext;
-    const gdouble *d = sodata->psf->priv->data;
-    guint n;
-    gdouble lambda, m;
+    guint n = yres*sodata->cstride;
 
-    n = yres*sodata->cstride;
     sodata->col = xres/3;
     sodata->row = yres/3;
     sodata->width = xres - 2*sodata->col;
@@ -1489,47 +1480,27 @@ psf_sigmaopt_estimate_size(PSFSigmaOptData *sodata)
     /* Use a fairly large but not yet insane sigma value 4.0 to estimate the width.  We want to err on the side of
      * size overestimation here.
      * XXX: We might want to use a proportional to 1/sqrt(xres*yres) here. */
-    lambda = 4.0 * sodata->sigma_scale;
+    gdouble lambda = 4.0 * sodata->sigma_scale;
     deconvolve_do(fmeas, fideal, fpsf, n, lambda);
     gwy_assign(cbuf, fpsf, n);
     gwy_fftw_execute(sodata->pplan);
     gwy_field_fft_2d_center(psf);
+    gwy_field_abs(psf);
 
-    imax = yres/2;
-    jmax = xres/2;
-    m = 0.0;
-    for (i = sodata->row; i < sodata->row + sodata->height; i++) {
-        for (j = sodata->col; j < sodata->col + sodata->width; j++) {
-            if (fabs(d[i*xres + j]) > m) {
-                m = fabs(d[i*xres + j]);
-                imax = i;
-                jmax = j;
-            }
-        }
-    }
+    gdouble xmax = xres/2, ymax = yres/2;
+    gwy_field_local_maximum(psf, &xmax, &ymax, xres/5 + 1, yres/5 + 1);
+    gint imax = GWY_ROUND(ymax), jmax = GWY_ROUND(xmax);
     gwy_debug("maximum at (%d,%d)", imax, jmax);
-    gwy_field_threshold(psf, 0.05*m, 0.0, 1.0);
-    g_return_if_fail(d[imax*xres + jmax] > 0.0);
-    gwy_field_grains_extract_grain(psf, jmax, imax);
 
-    imin = imax;
-    jmin = jmax;
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
-            if (d[i*xres + j] > 0.0) {
-                if (i < imin)
-                    imin = i;
-                if (i > imax)
-                    imax = i;
-                if (j < jmin)
-                    jmin = j;
-                if (j > jmax)
-                    jmax = j;
-            }
-        }
-    }
+    GwyNield *mask = sodata->mask;
+    gwy_nield_mark_by_threshold(mask, psf, 0.05*gwy_field_get_val(psf, jmax, imax), TRUE);
+    gint bbox[4];
+    gwy_nield_isolate_at(mask, imax, jmax, bbox);
+    gint jmin = bbox[0], imin = bbox[1];
+    jmax = jmin + bbox[2]-1;
+    imax = imin + bbox[3]-1;
 
-    ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
+    gint ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
     sodata->col = jmin - ext;
     sodata->row = imin - ext;
     sodata->width = jmax+1 - jmin + 2*ext;
@@ -1563,6 +1534,7 @@ psf_sigmaopt_prepare(GwyField *measured, GwyField *ideal,
     n = yres*sodata->cstride;
 
     sodata->psf = buf = gwy_field_new_alike(measured, FALSE);
+    sodata->mask = gwy_field_new_nield_alike(sodata->psf);
     sodata->fideal = g_new(fftw_complex, n);
     sodata->fmeas = g_new(fftw_complex, n);
     sodata->fpsf = g_new(fftw_complex, n);
@@ -1572,7 +1544,7 @@ psf_sigmaopt_prepare(GwyField *measured, GwyField *ideal,
 
     /* FFT(ideal) */
     gwy_field_copy_data(ideal, buf);
-    sodata->sigma_scale = gwy_field_get_mean_square(buf);
+    sodata->sigma_scale = gwy_field_mean_square(buf);
     sodata->sigma_scale *= xres*yres;
     gwy_fftw_execute(fplan);
     gwy_assign(sodata->fideal, sodata->cbuf, n);
@@ -1595,6 +1567,7 @@ psf_sigmaopt_free(PSFSigmaOptData *sodata)
     fftw_destroy_plan(sodata->pplan);
     fftw_free(sodata->cbuf);
     g_object_unref(sodata->psf);
+    g_object_unref(sodata->mask);
     g_free(sodata->fpsf);
     g_free(sodata->fideal);
     g_free(sodata->fmeas);
@@ -1621,16 +1594,16 @@ psf_sigmaopt_residuum(gdouble logsigma, gpointer user_data)
     gwy_fftw_execute(sodata->pplan);
     gwy_field_fft_2d_center(psf);
     gwy_field_area_abs(psf, sodata->row, sodata->col, sodata->width, sodata->height);
-    w = gwy_field_area_get_dispersion(psf, NULL, GWY_MASK_IGNORE,
-                                      sodata->row, sodata->col, sodata->width, sodata->height,
-                                      NULL, NULL);
+    w = gwy_field_area_dispersion(psf, NULL, GWY_MASK_IGNORE,
+                                  sodata->row, sodata->col, sodata->width, sodata->height,
+                                  NULL, NULL);
     w = sqrt(w);
     return w;
 }
 
 /**
  * gwy_field_find_regularization_sigma_for_psf:
- * @dfield: A data field with convolved noisy data.
+ * @field: A data field with convolved noisy data.
  * @ideal: A data field with ideal sharp data.
  *
  * Finds regularization parameter for point spread function calculation using regularized deconvolution.
@@ -1642,21 +1615,21 @@ psf_sigmaopt_residuum(gdouble logsigma, gpointer user_data)
  * Returns: Estimated regularization parameter.
  **/
 gdouble
-gwy_field_find_regularization_sigma_for_psf(GwyField *dfield,
+gwy_field_find_regularization_sigma_for_psf(GwyField *field,
                                             GwyField *ideal)
 {
     PSFSigmaOptData sodata;
     gdouble logsigma;
 
-    g_return_val_if_fail(GWY_IS_FIELD(dfield), 0.0);
+    g_return_val_if_fail(GWY_IS_FIELD(field), 0.0);
     g_return_val_if_fail(GWY_IS_FIELD(ideal), 0.0);
-    g_return_val_if_fail(!gwy_field_is_incompatible(dfield, ideal,
+    g_return_val_if_fail(!gwy_field_is_incompatible(field, ideal,
                                                     GWY_DATA_MISMATCH_RES
                                                     | GWY_DATA_MISMATCH_REAL
                                                     | GWY_DATA_MISMATCH_LATERAL),
                          0.0);
 
-    psf_sigmaopt_prepare(dfield, ideal, &sodata);
+    psf_sigmaopt_prepare(field, ideal, &sodata);
     logsigma = gwy_math_find_minimum_1d(psf_sigmaopt_residuum, log(1e-8), log(1e3), &sodata);
     psf_sigmaopt_free(&sodata);
     /* Experimentally determined fudge factor from large-scale simulations. */
@@ -1807,7 +1780,7 @@ conjgrad_make_equations(GwyField *ideal, GwyField *measured,
 
     /* The matrix and rhs data can be of wild orders of magnitude.  Scale them in sync to some reasonable range,
      * preferably a bit larger to have many orders of magnitude to go down. */
-    fnorm = sqrt(gwy_field_get_mean_square(rhs));
+    fnorm = sqrt(gwy_field_mean_square(rhs));
     if (fnorm > 0.0) {
         fnorm = 1e24/fnorm;
         gwy_field_multiply(rhs, fnorm);
@@ -1845,7 +1818,7 @@ psf_least_squares_conjgrad_iterate(GwyField *ffield,
     gwy_field_copy_data(vfield, ffield);
 
     conjgrad_matrix_multiply(fmat, fvec, vfield, buf, fplan, bplan, wfield);
-    fnorm0 = gwy_field_get_mean_square(ffield);
+    fnorm0 = gwy_field_mean_square(ffield);
 
     /* Iterate. */
     for (iter = 0; iter < maxiter; iter++) {
@@ -1860,7 +1833,7 @@ psf_least_squares_conjgrad_iterate(GwyField *ffield,
         /* Update residual f(j+1) = f(j) - n/d w(j) */
         conjgrad_update_field(ffield, ffield, numer/denom, wfield);
         /* Check norm of ffield and maybe stop iterations... */
-        fnorm = gwy_field_get_mean_square(ffield);
+        fnorm = gwy_field_mean_square(ffield);
         if (fnorm <= eps*fnorm0)
             break;
         /* Update gradient v(j+1) = f(j+1) - n/d v(j) */
@@ -1915,11 +1888,11 @@ psf_least_squares_warn(gint *want_txres, gint *want_tyres, gint border,
 
 /**
  * gwy_field_deconvolve_psf_leastsq:
- * @dfield: A data field.
- * @operand: Ideal sharp measurement (before convolution). It must have the same dimensions as @dfield and it is
+ * @field: A data field.
+ * @operand: Ideal sharp measurement (before convolution). It must have the same dimensions as @field and it is
  *           assumed it has also the same physical size.
  * @out: Output field for the transfer function.  Its dimensions are preserved and determine the transfer function
- *       support.  It must be smaller than half of @dfield.
+ *       support.  It must be smaller than half of @field.
  * @sigma: Regularization parameter.
  * @border: Number of pixel to extend and cut off the transfer function.
  *
@@ -1936,7 +1909,7 @@ psf_least_squares_warn(gint *want_txres, gint *want_tyres, gint border,
  * recover (approximately) the image.  This means the deconvolution assumes continous convolution, not discrete sums.
  * Note that for the latter case this means the point spread function will be centered in @out.
  *
- * Fields @dfield and @operand should be windowed beforehand if they are not periodic.
+ * Fields @field and @operand should be windowed beforehand if they are not periodic.
  **/
 void
 gwy_field_deconvolve_psf_leastsq(GwyField *measured,
@@ -1987,7 +1960,7 @@ gwy_field_deconvolve_psf_leastsq(GwyField *measured,
     /* Element matrix_00 is (unnormalised) ACF at zero distance, i.e. sum of squared data.  This is a good scaling
      * norm for the matrix we can use instead of actually calculating some matrix norm -- its elements are kind of
      * proportional to matrix_00 around the origin anyway, so this would add just some odd multiplicative constant. */
-    mnorm = gwy_field_get_mean_square(ideal);
+    mnorm = gwy_field_mean_square(ideal);
     /* We should multiply with the number of columns (not rows!) of matrix implementing the convolution operator
      * ideal*, see Golub's book. However, we then want to divide it by the square root of that to make sigma more or
      * less resolution-independent.  */
@@ -2065,14 +2038,14 @@ psf_conjgrad_residuum(gdouble logsigma, gpointer user_data)
     gwy_field_fft_2d_center(cgdata->tf);
 
     gwy_field_abs(cgdata->tf);
-    width = gwy_field_area_get_dispersion(cgdata->tf, NULL, GWY_MASK_IGNORE,
-                                          border, border, want_txres, want_tyres, NULL, NULL);
+    width = gwy_field_area_dispersion(cgdata->tf, NULL, GWY_MASK_IGNORE,
+                                      border, border, want_txres, want_tyres, NULL, NULL);
     return sqrt(width);
 }
 
 /**
  * gwy_field_find_regularization_sigma_leastsq:
- * @dfield: A data field with convolved noisy data.
+ * @field: A data field with convolved noisy data.
  * @ideal: A data field with ideal sharp data.
  * @width: Horizontal size of transfer function support.
  * @height: Vertical size of transfer function support.
@@ -2122,7 +2095,7 @@ gwy_field_find_regularization_sigma_leastsq(GwyField *measured,
     cgdata.rhs = gwy_field_new_alike(cgdata.tf, FALSE);
     fnorm = conjgrad_make_equations(ideal, measured, txres, tyres, cgdata.matrix, cgdata.rhs, cgdata.buf);
     /* See gwy_field_deconvolve_psf_leastsq() for explanation. */
-    cgdata.mnorm = gwy_field_get_mean_square(ideal);
+    cgdata.mnorm = gwy_field_mean_square(ideal);
     cgdata.mnorm *= xres*yres;
     cgdata.mnorm *= cbrt(want_txres*want_tyres);
     cgdata.mnorm *= fnorm;
