@@ -1,5 +1,5 @@
 /*
- *  $Id: filters.c 28906 2025-11-24 16:45:11Z yeti-dn $
+ *  $Id: filters.c 29544 2026-02-25 10:28:00Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -50,7 +50,7 @@ gwy_field_normalize(GwyField *field)
 
     g_return_if_fail(GWY_IS_FIELD(field));
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     if (min == max) {
         gwy_field_clear(field);
         return;
@@ -108,7 +108,7 @@ gwy_field_renormalize(GwyField *field,
         return;
     }
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     if (min == max) {
         gwy_field_fill(field, offset);
         return;
@@ -205,7 +205,7 @@ gwy_field_area_renormalize(GwyField *dfield,
         return;
     }
 
-    gwy_field_area_get_min_max(dfield, NULL, GWY_MASK_IGNORE, col, row, width, height, &min, &max);
+    gwy_field_area_min_max(dfield, NULL, GWY_MASK_IGNORE, col, row, width, height, &min, &max);
     if (min == max) {
         gwy_field_area_fill(dfield, NULL, GWY_MASK_IGNORE, col, row, width, height, offset);
         return;
@@ -247,20 +247,20 @@ gwy_field_area_renormalize(GwyField *dfield,
 /**
  * gwy_field_threshold:
  * @field: A data field.
- * @threshval: Threshold value.
- * @bottom: Lower replacement value.
- * @top: Upper replacement value.
+ * @threshold: Threshold value.
+ * @below: Lower replacement value.
+ * @above: Upper replacement value.
  *
  * Tresholds values of a data field.
  *
- * Values smaller than @threshold are set to value @bottom, values higher than @threshold or equal to it are set to
- * value @top.
+ * Values smaller than @threshold are set to value @below, values higher than @threshold or equal to it are set to
+ * value @above.
  *
  * Returns: The total number of values above threshold.
  **/
 gint
 gwy_field_threshold(GwyField *field,
-                    gdouble threshval, gdouble bottom, gdouble top)
+                    gdouble threshold, gdouble below, gdouble above)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0);
 
@@ -271,13 +271,13 @@ gwy_field_threshold(GwyField *field,
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
             reduction(+:tot) \
-            shared(d,n,threshval,bottom,top)
+            shared(d,n,threshold,below,above)
 #endif
     for (gsize i = 0; i < n; i++) {
-        if (d[i] < threshval)
-            d[i] = bottom;
+        if (d[i] < threshold)
+            d[i] = below;
         else {
-            d[i] = top;
+            d[i] = above;
             tot++;
         }
     }
@@ -285,17 +285,17 @@ gwy_field_threshold(GwyField *field,
     /* We can precompute stats */
     field->priv->cached = FCBIT(MIN) | FCBIT(MAX) | FCBIT(SUM) | FCBIT(RMS) | FCBIT(MED);
     if (tot == n)
-        FCVAL(field, MIN) = FCVAL(field, MAX) = top;
+        FCVAL(field, MIN) = FCVAL(field, MAX) = above;
     else if (tot == 0)
-        FCVAL(field, MIN) = FCVAL(field, MAX) = bottom;
+        FCVAL(field, MIN) = FCVAL(field, MAX) = below;
     else {
-        FCVAL(field, MIN) = MIN(top, bottom);
-        FCVAL(field, MAX) = MAX(top, bottom);
+        FCVAL(field, MIN) = MIN(above, below);
+        FCVAL(field, MAX) = MAX(above, below);
     }
-    FCVAL(field, SUM) = tot*top + (n - tot)*bottom;
-    FCVAL(field, RMS) = (top - bottom)*(top - bottom) * tot/(gdouble)n * (n - tot)/(gdouble)n;
+    FCVAL(field, SUM) = tot*above + (n - tot)*below;
+    FCVAL(field, RMS) = (above - below)*(above - below) * tot/(gdouble)n * (n - tot)/(gdouble)n;
     /* FIXME: may be incorrect for tot == n/2(?) */
-    FCVAL(field, MED) = tot > n/2 ? top : bottom;
+    FCVAL(field, MED) = tot > n/2 ? above : below;
 
     return tot;
 }
@@ -308,44 +308,40 @@ gwy_field_threshold(GwyField *field,
  * @row: Upper-left row coordinate.
  * @width: Area width (number of columns).
  * @height: Area height (number of rows).
- * @threshval: Threshold value.
- * @bottom: Lower replacement value.
- * @top: Upper replacement value.
+ * @threshold: Threshold value.
+ * @below: Lower replacement value.
+ * @above: Upper replacement value.
  *
  * Tresholds values of a rectangular part of a data field.
  *
- * Values smaller than @threshold are set to value @bottom, values higher than @threshold or equal to it are set to
- * value @top
+ * Values smaller than @threshold are set to value @below, values higher than @threshold or equal to it are set to
+ * value @above
  *
  * Returns: The total number of values above threshold.
  **/
 gint
 gwy_field_area_threshold(GwyField *field,
                          gint col, gint row, gint width, gint height,
-                         gdouble threshval, gdouble bottom, gdouble top)
+                         gdouble threshold, gdouble below, gdouble above)
 {
-    gint xres, i, j, tot = 0;
-    gdouble *d;
-
     if (!_gwy_field_check_area(field, col, row, width, height, TRUE))
         return 0;
 
-    d = field->priv->data;
-    xres = field->xres;
+    gdouble *d = field->priv->data;
+    gint xres = field->xres, tot = 0;
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
             reduction(+:tot) \
-            private(i,j) \
-            shared(d,width,height,xres,col,row,threshval,bottom,top)
+            shared(d,width,height,xres,col,row,threshold,below,above)
 #endif
-    for (i = 0; i < height; i++) {
+    for (gint i = 0; i < height; i++) {
         gdouble *drow = d + (row + i)*xres + col;
 
-        for (j = 0; j < width; j++) {
-            if (drow[j] < threshval)
-                drow[j] = bottom;
+        for (gint j = 0; j < width; j++) {
+            if (drow[j] < threshold)
+                drow[j] = below;
             else {
-                drow[j] = top;
+                drow[j] = above;
                 tot++;
             }
         }
@@ -498,20 +494,18 @@ gwy_field_area_gather(GwyField *field,
                       gint col, gint row,
                       gint width, gint height)
 {
-    gint xres, yres, m;
+    gint m;
     gint hs2p, hs2m, vs2p, vs2m;
     gdouble v;
 
     g_return_if_fail(hsize > 0 && vsize > 0);
-    if (!_gwy_field_check_area(field, col, row, width, height, FALSE))
+    if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
+        || !_gwy_field_check_other(field, result, FALSE))
         return;
-    xres = field->xres;
-    yres = field->yres;
-    g_return_if_fail(GWY_IS_FIELD(result));
-    g_return_if_fail(result->xres == xres && result->yres == yres);
+    gint xres = field->xres;
     if (buffer) {
-        g_return_if_fail(GWY_IS_FIELD(buffer));
-        g_return_if_fail(buffer->xres*buffer->yres >= width*height);
+        if (!_gwy_field_check_other(field, buffer, FALSE))
+            return;
         g_object_ref(buffer);
     }
     else
@@ -556,8 +550,7 @@ gwy_field_area_gather(GwyField *field,
     /* Top half */
     gdouble *r = result->priv->data;
     gdouble *drow = r + row*xres + col;
-    for (gint j = 0; j < width; j++)
-        drow[j] = 0.0;
+    gwy_clear(drow, width);
     m = MIN(vs2p, height-1);
     for (gint i = 0; i <= m; i++) {
         gdouble *srow = bdata + i*width;
@@ -594,8 +587,7 @@ gwy_field_area_gather(GwyField *field,
 
     /* Bottom half */
     drow = r + (height-1 + row)*xres + col;
-    for (gint j = 0; j < width; j++)
-        drow[j] = 0.0;
+    gwy_clear(drow, width);
     m = height-1 - MIN(vs2m, height-1);
     for (gint i = height-1; i >= m; i--) {
         gdouble *srow = bdata + i*width;
@@ -810,7 +802,7 @@ gwy_field_filter_canny(GwyField *field,
     gwy_field_invalidate(field);
 
     gdouble min, max;
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     threshold = min + (max - min)*threshold;
 
     /* We do not need sobel array more, so use sobel_horizontal to store data
@@ -1053,7 +1045,7 @@ gwy_field_filter_gauss_step(GwyField *field, gdouble sigma)
         }
     }
     g[0] = 0.0;
-    gs = gwy_field_get_sum(gauss);
+    gs = gwy_field_sum(gauss);
 
     /* Convolve with the Gaussian multiplied by rotated signum function. */
     gwy_field_clear(extfield);
@@ -1529,29 +1521,24 @@ gwy_field_filter_harris(GwyField *x_gradient,
                         gint neighbourhood,
                         gdouble alpha)
 {
+    if (!_gwy_field_check_other(result, x_gradient, FALSE)
+        || !_gwy_field_check_other(result, y_gradient, FALSE))
+        return;
+    g_return_if_fail(neighbourhood > 0);
+
     gdouble mult, sigma;
-    gint yres, xres, i, j;
+    gint i, j;
     GwyField *xx, *xy, *yy;
     gdouble *xxdata, *xydata, *yydata, *xg, *yg, *r;
-
-    g_return_if_fail(GWY_IS_FIELD(x_gradient));
-    g_return_if_fail(GWY_IS_FIELD(y_gradient));
-    g_return_if_fail(GWY_IS_FIELD(result));
-    yres = result->yres;
-    xres = result->xres;
-    g_return_if_fail(x_gradient->xres == xres);
-    g_return_if_fail(x_gradient->yres == yres);
-    g_return_if_fail(y_gradient->xres == xres);
-    g_return_if_fail(y_gradient->yres == yres);
-    g_return_if_fail(neighbourhood > 0);
+    gint yres = result->yres, xres = result->xres;
 
     if (2*neighbourhood >= MIN(xres, yres)) {
         gwy_field_clear(result);
         return;
     }
 
-    mult = (fabs(gwy_field_get_max(x_gradient) - gwy_field_get_min(x_gradient))
-            + fabs(gwy_field_get_max(y_gradient) - gwy_field_get_min(y_gradient)));
+    mult = (fabs(gwy_field_max(x_gradient) - gwy_field_min(x_gradient))
+            + fabs(gwy_field_max(y_gradient) - gwy_field_min(y_gradient)));
     mult = 1.0/(mult*mult);
 
     xx = result;
@@ -1618,19 +1605,4 @@ gwy_field_filter_harris(GwyField *x_gradient,
  * operations, e.g. value inversion, are also found in base #GwyField methods.
  **/
 
-/**
- * GwyMinMaxFilterType:
- * @GWY_MIN_MAX_FILTER_MINIMUM: Minimum filter, i.e. minimum of the surrounding values.
- * @GWY_MIN_MAX_FILTER_EROSION: Another name for the minimum filter.
- * @GWY_MIN_MAX_FILTER_MAXIMUM: Maximum filter, i.e. maximum of the surrounding values.
- * @GWY_MIN_MAX_FILTER_DILATION: Another name for the maximum filter.
- * @GWY_MIN_MAX_FILTER_OPENING: Morphological opening filter.
- * @GWY_MIN_MAX_FILTER_CLOSING: Morphological closing filter.
- * @GWY_MIN_MAX_FILTER_RANGE: Difference between maximum and minimum.
- * @GWY_MIN_MAX_FILTER_NORMALIZATION: Data value rescaled to the range between minimum and maximum.
- *
- * Type of operation based on morphological filters with flat structuring
- * elements.
- **/
-
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
