@@ -1,7 +1,7 @@
 #pragma once
 /*
- *  $Id: filters.h 28991 2025-12-12 18:00:46Z yeti-dn $
- *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
+ *  $Id: filters.h 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -27,12 +27,13 @@ G_BEGIN_DECLS
 typedef enum {
     GWY_MIN_MAX_FILTER_MINIMUM       = 0,
     GWY_MIN_MAX_FILTER_EROSION       = 0,
-    GWY_MIN_MAX_FILTER_MAXIMUM       = 1,
-    GWY_MIN_MAX_FILTER_DILATION      = 1,
-    GWY_MIN_MAX_FILTER_OPENING       = 2,
-    GWY_MIN_MAX_FILTER_CLOSING       = 3,
-    GWY_MIN_MAX_FILTER_RANGE         = 4,
-    GWY_MIN_MAX_FILTER_NORMALIZATION = 5,
+    GWY_MIN_MAX_FILTER_FROSION       = 1,
+    GWY_MIN_MAX_FILTER_MAXIMUM       = 2,
+    GWY_MIN_MAX_FILTER_DILATION      = 3,
+    GWY_MIN_MAX_FILTER_OPENING       = 4,
+    GWY_MIN_MAX_FILTER_CLOSING       = 5,
+    GWY_MIN_MAX_FILTER_RANGE         = 6,
+    GWY_MIN_MAX_FILTER_NORMALIZATION = 7,
 } GwyMinMaxFilterType;
 
 void     gwy_field_normalize                         (GwyField *field);
@@ -47,17 +48,17 @@ void     gwy_field_area_renormalize                  (GwyField *field,
                                                       gdouble range,
                                                       gdouble offset);
 gint     gwy_field_threshold                         (GwyField *field,
-                                                      gdouble threshval,
-                                                      gdouble bottom,
-                                                      gdouble top);
+                                                      gdouble threshold,
+                                                      gdouble below,
+                                                      gdouble above);
 gint     gwy_field_area_threshold                    (GwyField *field,
                                                       gint col,
                                                       gint row,
                                                       gint width,
                                                       gint height,
-                                                      gdouble threshval,
-                                                      gdouble bottom,
-                                                      gdouble top);
+                                                      gdouble threshold,
+                                                      gdouble below,
+                                                      gdouble above);
 gint     gwy_field_clamp                             (GwyField *field,
                                                       gdouble bottom,
                                                       gdouble top);
@@ -211,8 +212,11 @@ void     gwy_field_area_filter_maximum               (GwyField *field,
                                                       gint row,
                                                       gint width,
                                                       gint height);
+void     gwy_field_filter_min_max                    (GwyField *field,
+                                                      GwyNield *kernel,
+                                                      GwyMinMaxFilterType filtertype);
 void     gwy_field_area_filter_min_max               (GwyField *field,
-                                                      GwyField *kernel,
+                                                      GwyNield *kernel,
                                                       GwyMinMaxFilterType filtertype,
                                                       gint col,
                                                       gint row,
@@ -225,8 +229,25 @@ void     gwy_field_area_filter_disc_asf              (GwyField *field,
                                                       gint row,
                                                       gint width,
                                                       gint height);
+void     gwy_nield_filter_min_max                    (GwyNield *nield,
+                                                      GwyNield *kernel,
+                                                      GwyMinMaxFilterType filtertype);
+void     gwy_nield_area_filter_min_max               (GwyNield *nield,
+                                                      GwyNield *kernel,
+                                                      GwyMinMaxFilterType filtertype,
+                                                      gint col,
+                                                      gint row,
+                                                      gint width,
+                                                      gint height);
+void     gwy_nield_area_filter_disc_asf              (GwyNield *nield,
+                                                      gint radius,
+                                                      gboolean closing,
+                                                      gint col,
+                                                      gint row,
+                                                      gint width,
+                                                      gint height);
 gboolean gwy_field_area_filter_kth_rank              (GwyField *field,
-                                                      GwyField *kernel,
+                                                      GwyNield *kernel,
                                                       gint col,
                                                       gint row,
                                                       gint width,
@@ -239,7 +260,7 @@ void     gwy_line_part_filter_kth_rank               (GwyLine *line,
                                                       gint len,
                                                       gint k);
 gboolean gwy_field_area_filter_trimmed_mean          (GwyField *field,
-                                                      GwyField *kernel,
+                                                      GwyNield *kernel,
                                                       gint col,
                                                       gint row,
                                                       gint width,
@@ -272,18 +293,18 @@ void     gwy_field_filter_harris                     (GwyField *x_gradient,
                                                       GwyField *result,
                                                       gint neighbourhood,
                                                       gdouble alpha);
-void     gwy_field_deconvolve_regularized            (GwyField *dfield,
+void     gwy_field_deconvolve_regularized            (GwyField *field,
                                                       GwyField *operand,
                                                       GwyField *out,
                                                       gdouble sigma);
-void     gwy_field_deconvolve_psf_leastsq            (GwyField *dfield,
+void     gwy_field_deconvolve_psf_leastsq            (GwyField *field,
                                                       GwyField *operand,
                                                       GwyField *out,
                                                       gdouble sigma,
                                                       gint border);
-gdouble  gwy_field_find_regularization_sigma_for_psf (GwyField *dfield,
+gdouble  gwy_field_find_regularization_sigma_for_psf (GwyField *field,
                                                       GwyField *ideal);
-gdouble  gwy_field_find_regularization_sigma_leastsq (GwyField *dfield,
+gdouble  gwy_field_find_regularization_sigma_leastsq (GwyField *field,
                                                       GwyField *ideal,
                                                       gint width,
                                                       gint height,
