@@ -1,7 +1,7 @@
 /*
- *  $Id: fractals.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: fractals.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2004 Jindrich Bilek.
- *  Copyright (C) 2024-2025 David Nečas (Yeti).
+ *  Copyright (C) 2024-2026 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -76,7 +76,7 @@ gwy_field_fractal_partitioning(GwyField *field,
         rp = 1 << l;
         for (j = 0; j < (xnewres - 1)/rp - 1; j++) {
             for (i = 0; i < (xnewres - 1)/rp - 1; i++) {
-                rms = gwy_field_area_get_rms(buffer, NULL, GWY_MASK_IGNORE, i*rp, j*rp, rp, rp);
+                rms = gwy_field_area_rms(buffer, NULL, GWY_MASK_IGNORE, i*rp, j*rp, rp, rp);
                 yrdata[l-1] += rms * rms;
             }
         }
@@ -127,7 +127,7 @@ gwy_field_fractal_cubecounting(GwyField *field,
     gwy_line_resize(yresult, dimexp);
     gwy_line_clear(yresult);
 
-    gwy_field_get_min_max(buffer, &imin, &height);
+    gwy_field_min_max(buffer, &imin, &height);
     height -= imin;
 
     gdouble *xrdata = xresult->priv->data, *yrdata = yresult->priv->data;
@@ -196,7 +196,7 @@ gwy_field_fractal_triangulation(GwyField *field,
     gwy_line_resize(yresult, dimexp + 1);
     gwy_line_clear(yresult);
 
-    height = gwy_field_get_max(buffer) - gwy_field_get_min(buffer);
+    height = gwy_field_max(buffer) - gwy_field_min(buffer);
     dil = (gdouble)(1 << dimexp)/height;
     dil *= dil;
 
@@ -458,17 +458,17 @@ rg0(GwyRandGenSet *rngset, gdouble sigma)
  * points to correct and *z data
  */
 static gboolean
-fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
+fractal_correct(GwyField *field, GwyNield *mask, GwyLine *vars, gint k)
 {
     GwyRandGenSet *rngset;
     gint i, j, l, p, ii, jj, pp, n, xres, kk;
     gdouble sg, avh;
-    const gdouble *m = mask->priv->data;
+    const gint *m = mask->priv->data;
     gdouble *z = field->priv->data;
     gdouble *vdata = vars->priv->data;
 
     rngset = gwy_rand_gen_set_new(1);
-    avh = gwy_field_get_avg(field);
+    avh = gwy_field_mean(field);
 
     xres = field->xres;
 
@@ -483,7 +483,7 @@ fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
                 ii = (2*i + 1) * p;
                 jj = (2*j + 1) * p;
                 kk = ii*xres + jj;
-                if (m[kk] != 0) {
+                if (m[kk] > 0) {
                     if (l == 0)
                         z[kk] = avh;
                     else {
@@ -501,31 +501,31 @@ fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
                 kk = ii*xres + jj;
                 if (jj + p == n-1) {
                     if (ii + p == n-1) {
-                        if (m[kk + p*(xres+1)] != 0)
+                        if (m[kk + p*(xres+1)] > 0)
                             z[kk + p*(xres+1)] = z[kk + p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk + p*(xres-1)] != 0)
+                        if (m[kk + p*(xres-1)] > 0)
                             z[kk + p*(xres-1)] = z[kk + p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres-1)] != 0)
+                        if (m[kk - p*(xres-1)] > 0)
                             z[kk - p*(xres-1)] = z[kk - p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
                     }
                     else {
-                        if (m[kk - p*(xres-1)] != 0)
+                        if (m[kk - p*(xres-1)] > 0)
                             z[kk - p*(xres-1)] = z[kk - p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
                     }
                 }
                 else {
                     if ((ii + p) == n-1) {
-                        if (m[kk + p*(xres-1)] != 0)
+                        if (m[kk + p*(xres-1)] > 0)
                             z[kk + p*(xres-1)] = z[kk + p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
                     }
                     else {
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
                     }
                 }
@@ -539,108 +539,108 @@ fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
                 jj = (2*j + 1) * p;
                 kk = ii*xres + jj;
                 if (l == 0) {
-                    if (m[kk - p] != 0)
+                    if (m[kk - p] > 0)
                         z[kk - p] = (z[kk - p*(xres+1)] + z[kk + p*(xres-1)] + z[kk])/3 + rg0(rngset, sg);
-                    if (m[kk + p] != 0)
+                    if (m[kk + p] > 0)
                         z[kk + p] = (z[kk - p*(xres-1)] + z[kk + p*(xres+1)] + z[kk])/3 + rg0(rngset, sg);
-                    if (m[kk - p*xres] != 0)
+                    if (m[kk - p*xres] > 0)
                         z[kk - p*xres] = (z[kk - p*(xres+1)] + z[kk - p*(xres-1)] + z[kk])/3 + rg0(rngset, sg);
-                    if (m[kk + p*xres] != 0)
+                    if (m[kk + p*xres] > 0)
                         z[kk + p*xres] = (z[kk + p*(xres-1)] + z[kk + p*(xres+1)] + z[kk])/3 + rg0(rngset, sg);
                 }
                 else {
                     if (jj + p == n-1) {
                         if (ii + p == n-1) {
-                            if (m[kk + p*xres] != 0)
+                            if (m[kk + p*xres] > 0)
                                 z[kk + p*xres] = (z[kk] + z[kk + p*(xres+1)] + z[kk + p*(xres-1)])/3 + rg0(rngset, sg);
-                            if (m[kk + p] != 0)
+                            if (m[kk + p] > 0)
                                 z[kk + p] = (z[kk] + z[kk + p*(xres+1)] + z[kk - p*(xres-1)])/3 + rg0(rngset, sg);
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - p*(xres-1)]
                                                   + z[kk - 2*p*xres] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
                         }
                         if (ii + p != n && ii - p != 1) {
-                            if (m[kk + p] != 0)
+                            if (m[kk + p] > 0)
                                 z[kk + p] = (z[kk] + z[kk + p*(xres+1)] + z[kk - p*(xres-1)])/3 + rg0(rngset, sg);
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - p*(xres-1)]
                                                   + z[kk - 2*p*xres] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
                         }
                         if ((ii - p) == 0) {
-                            if (m[kk + p] != 0)
+                            if (m[kk + p] > 0)
                                 z[kk + p] = (z[kk] + z[kk - p*(xres-1)] + z[kk + p*(xres+1)])/3 + rg0(rngset, sg);
-                            if (m[kk - p*xres] != 0)
+                            if (m[kk - p*xres] > 0)
                                 z[kk - p*xres] = (z[kk] + z[kk - p*(xres+1)] + z[kk - p*(xres-1)])/3 + rg0(rngset, sg);
                         }
                     }
-                    if (jj + p != n-1 && jj - p != 0) {
+                    if (jj + p != n-1 && jj - p > 0) {
                         if (ii + p == n-1) {
-                            if (m[kk + p*xres] != 0)
+                            if (m[kk + p*xres] > 0)
                                 z[kk + p*xres] = (z[kk] + z[kk + p*(xres-1)] + z[kk + p*(xres+1)])/3 + rg0(rngset, sg);
-                            if (m[kk + p] != 0) {
+                            if (m[kk + p] > 0) {
                                 z[kk + p] = (z[kk] + z[kk + 2*p] + z[kk - p*(xres-1)]
                                              + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - 2*p*xres]
                                                   + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
                         }
-                        if (ii + p != n-1 && ii - p != 0) {
-                            if (m[kk + p] != 0) {
+                        if (ii + p != n-1 && ii - p > 0) {
+                            if (m[kk + p] > 0) {
                                 z[kk + p] = (z[kk] + z[kk + 2*p] + z[kk - p*(xres-1)]
                                              + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - 2*p*xres]
                                                   + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
                         }
                         if (ii - p == 0) {
-                            if (m[kk + p] != 0)
+                            if (m[kk + p] > 0)
                                 z[kk + p] = (z[kk] + z[kk + 2*p]
                                              + z[kk - p*(xres-1)] + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
-                            if (m[kk - p*xres] != 0)
+                            if (m[kk - p*xres] > 0)
                                 z[kk - p*xres] = (z[kk] + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/3 + rg0(rngset, sg);
                         }
                     }
                     if (jj - p == 0) {
                         if (ii + p == n-1) {
-                            if (m[kk + p*xres] != 0)
+                            if (m[kk + p*xres] > 0)
                                 z[kk + p*xres] = (z[kk] + z[kk + p*(xres-1)] + z[kk + p*(xres+1)])/3 + rg0(rngset, sg);
-                            if (m[kk + p] != 0) {
+                            if (m[kk + p] > 0) {
                                 z[kk + p] = (z[kk] + z[kk + 2*p]
                                              + z[kk - p*(xres-1)] + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - 2*p*xres]
                                                   + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p] != 0)
+                            if (m[kk - p] > 0)
                                 z[kk - p] = (z[kk] + z[kk - p*(xres+1)] + z[kk + p*(xres-1)])/3 + rg0(rngset, sg);
                         }
-                        if (ii + p != n-1 && ii - p != 0) {
-                            if (m[kk + p] != 0) {
+                        if (ii + p != n-1 && ii - p > 0) {
+                            if (m[kk + p] > 0) {
                                 z[kk + p] = (z[kk] + z[kk + 2*p]
                                              + z[kk - p*(xres-1)] + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p*xres] != 0) {
+                            if (m[kk - p*xres] > 0) {
                                 z[kk - p*xres] = (z[kk] + z[kk - 2*p*xres]
                                                   + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p] != 0)
+                            if (m[kk - p] > 0)
                                 z[kk - p] = (z[kk] + z[kk - p*(xres+1)] + z[kk + p*(xres-1)])/3 + rg0(rngset, sg);
                         }
                         if (ii - p == 0) {
-                            if (m[kk + p] != 0) {
+                            if (m[kk + p] > 0) {
                                 z[kk + p] = (z[kk] + z[kk + 2*p]
                                              + z[kk - p*(xres-1)] + z[kk + p*(xres+1)])/4 + rg0(rngset, sg);
                             }
-                            if (m[kk - p*xres] != 0)
+                            if (m[kk - p*xres] > 0)
                                 z[kk - p*xres] = (z[kk] + z[kk - p*(xres-1)] + z[kk - p*(xres+1)])/3 + rg0(rngset, sg);
-                            if (m[kk - p] != 0)
+                            if (m[kk - p] > 0)
                                 z[kk - p] = (z[kk] + z[kk - p*(xres+1)] + z[kk + p*(xres-1)])/3 + rg0(rngset, sg);
                         }
                     }
@@ -655,39 +655,39 @@ fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
                 kk = ii*xres + jj;
                 if (jj + p == n-1) {
                     if (ii + p == n-1) {
-                        if (m[kk + p*(xres+1)] != 0)
+                        if (m[kk + p*(xres+1)] > 0)
                             z[kk + p*(xres+1)] = z[kk + p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk + p*(xres-1)] != 0)
+                        if (m[kk + p*(xres-1)] > 0)
                             z[kk + p*(xres-1)] = z[kk + p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres-1)] != 0)
+                        if (m[kk - p*(xres-1)] > 0)
                             z[kk - p*(xres-1)] = z[kk - p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk] != 0)
+                        if (m[kk] > 0)
                             z[kk] = z[kk] + rg0(rngset, sg);
                     }
                     else {
-                        if (m[kk - p*(xres-1)] != 0)
+                        if (m[kk - p*(xres-1)] > 0)
                             z[kk - p*(xres-1)] = z[kk - p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk] != 0)
+                        if (m[kk] > 0)
                             z[kk] = z[kk] + rg0(rngset, sg);
                     }
                 }
                 else {
                     if (ii + p == n-1) {
-                        if (m[kk + p*(xres-1)] != 0)
+                        if (m[kk + p*(xres-1)] > 0)
                             z[kk + p*(xres-1)] = z[kk + p*(xres-1)] + rg0(rngset, sg);
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk] != 0)
+                        if (m[kk] > 0)
                             z[kk] = z[kk] + rg0(rngset, sg);
                     }
                     else {
-                        if (m[kk - p*(xres+1)] != 0)
+                        if (m[kk - p*(xres+1)] > 0)
                             z[kk - p*(xres+1)] = z[kk - p*(xres+1)] + rg0(rngset, sg);
-                        if (m[kk] != 0)
+                        if (m[kk] > 0)
                             z[kk] = z[kk] + rg0(rngset, sg);
                     }
                 }
@@ -708,46 +708,24 @@ fractal_correct(GwyField *field, GwyField *mask, GwyLine *vars, gint k)
  * @interpolation: Interpolation type.
  *
  * Replaces data under mask with interpolated values using fractal interpolation.
+ *
+ * The data should preferrably be square and with pixel size a power of 2. The function does not require it, but data
+ * not satisfying this condition are resampled back and forth using given interpolation.
  **/
 void
 gwy_field_fractal_correction(GwyField *field,
-                             GwyField *mask,
-                             GwyInterpolationType interpolation)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, GWY_MASK_INCLUDE);
-    gwy_NIELD_fractal_correction(field, nield, interpolation);
-    g_object_unref(nield);
-}
-
-/**
- * gwy_NIELD_fractal_correction:
- * @field: A data field.
- * @mask: Mask of places to be corrected.
- * @interpolation: Interpolation type.
- *
- * Replaces data under mask with interpolated values using fractal interpolation.
- **/
-void
-gwy_NIELD_fractal_correction(GwyField *field,
                              GwyNield *mask,
                              GwyInterpolationType interpolation)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, NULL))
+    if (!_gwy_field_check_mask(field, &mask, NULL))
         return;
 
-    g_return_if_fail(GWY_IS_FIELD(field));
-    g_return_if_fail(GWY_IS_FIELD(mask));
-
     gint xres = field->xres, yres = field->yres;
     gint dimexp = (gint)floor(log2(xres) + 0.5);
     gint xnewres = (1 << dimexp) + 1;
 
-    GwyField *buffer = gwy_field_copy(field);
-    GwyField *maskbuffer = gwy_field_new_alike(field, FALSE);
-    gwy_field_area_fill_mask(maskbuffer, mask, 0, 0, xres, yres, 1.0, 0.0);
-    gwy_field_resample(buffer, xnewres, xnewres, interpolation);
-    gwy_field_resample(maskbuffer, xnewres, xnewres, interpolation);
-
+    GwyField *buffer = gwy_field_new_resampled(field, xnewres, xnewres, interpolation);
+    GwyNield *maskbuffer = gwy_nield_new_resampled(mask, xnewres, xnewres);
     GwyLine *xresult = gwy_line_new(1, 1, FALSE);
     GwyLine *yresult = gwy_line_new(1, 1, FALSE);
 
