@@ -1,6 +1,6 @@
 /*
- *  $Id: grain-value.c 28968 2025-12-10 15:15:43Z yeti-dn $
- *  Copyright (C) 2007-2025 David Necas (Yeti).
+ *  $Id: grain-value.c 29554 2026-02-28 16:03:10Z yeti-dn $
+ *  Copyright (C) 2007-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -24,11 +24,7 @@
 #include "libgwyddion/expr.h"
 #include "libgwyddion/grain-value.h"
 
-/* We know they are usable as bits */
-enum {
-    MAXBUILTINS = 64,
-    GWY_GRAIN_QUANTITY_ID = MAXBUILTINS-1
-};
+#include "libgwyddion/internal.h"
 
 typedef struct {
     GwyGrainValueGroup group;
@@ -60,9 +56,11 @@ static void           resource_dump          (GwyResource *resource,
                                               GString *str);
 static GwyResource*   resource_parse         (const gchar *text);
 
+// FIXME: This table duplicates unit power information from grain-quantities.c. But there is no way to fill it
+// while keeping it const. Does keeping it const matter much?
 static const BuiltinGrainValueInfo grain_values[] = {
     {
-        N_("Grain number"), GWY_GRAIN_QUANTITY_ID,  /* Does not correspond to any bit */
+        N_("Grain number"), GWY_GRAIN_ID,
         {
             GWY_GRAIN_GROUP_ID,
             "id", "",
@@ -165,14 +163,6 @@ static const BuiltinGrainValueInfo grain_values[] = {
             2, 0, GWY_GRAIN_SAME_UNITS,
         }
     },
-    {
-        N_("Equivalent square side"), GWY_GRAIN_EQUIV_SQUARE_SIDE,
-        {
-            GWY_GRAIN_GROUP_AREA,
-            "<i>a</i><sub>eq</sub>", "a_eq",
-            1, 0, 0,
-        }
-    },
     {
         N_("Equivalent disc radius"), GWY_GRAIN_EQUIV_DISC_RADIUS,
         {
@@ -225,15 +215,15 @@ static const BuiltinGrainValueInfo grain_values[] = {
         }
     },
     {
-        N_("Projected boundary length"), GWY_GRAIN_FLAT_BOUNDARY_LENGTH,
+        N_("Perimeter"), GWY_GRAIN_PERIMETER,
         {
             GWY_GRAIN_GROUP_BOUNDARY,
-            "<i>L</i><sub>b0</sub>", "L_b0",
+            "<i>P</i>", "P",
             1, 0, 0,
         }
     },
     {
-        N_("Minimum bounding size"), GWY_GRAIN_MINIMUM_BOUND_SIZE,
+        N_("Minimum projection size"), GWY_GRAIN_MINIMUM_PROJECT_SIZE,
         {
             GWY_GRAIN_GROUP_BOUNDARY,
             "<i>D</i><sub>min</sub>", "D_min",
@@ -241,7 +231,7 @@ static const BuiltinGrainValueInfo grain_values[] = {
         }
     },
     {
-        N_("Minimum bounding direction"), GWY_GRAIN_MINIMUM_BOUND_ANGLE,
+        N_("Minimum projection direction"), GWY_GRAIN_MINIMUM_PROJECT_ANGLE,
         {
             GWY_GRAIN_GROUP_BOUNDARY,
             "<i>φ</i><sub>min</sub>", "phi_min",
@@ -249,7 +239,7 @@ static const BuiltinGrainValueInfo grain_values[] = {
         }
     },
     {
-        N_("Maximum bounding size"), GWY_GRAIN_MAXIMUM_BOUND_SIZE,
+        N_("Maximum projection size"), GWY_GRAIN_MAXIMUM_PROJECT_SIZE,
         {
             GWY_GRAIN_GROUP_BOUNDARY,
             "<i>D</i><sub>max</sub>", "D_max",
@@ -257,13 +247,21 @@ static const BuiltinGrainValueInfo grain_values[] = {
         }
     },
     {
-        N_("Maximum bounding direction"), GWY_GRAIN_MAXIMUM_BOUND_ANGLE,
+        N_("Maximum projection direction"), GWY_GRAIN_MAXIMUM_PROJECT_ANGLE,
         {
             GWY_GRAIN_GROUP_BOUNDARY,
             "<i>φ</i><sub>max</sub>", "phi_max",
             0, 0, GWY_GRAIN_IS_ANGLE,
         }
     },
+    {
+        N_("Feret length"), GWY_GRAIN_FERET_LENGTH,
+        {
+            GWY_GRAIN_GROUP_BOUNDARY,
+            "<i>L</i><sub>F</sub>", "L_F",
+            1, 0, 0,
+        }
+    },
     {
         N_("Maximum inscribed disc radius"), GWY_GRAIN_INSCRIBED_DISC_R,
         {
@@ -600,8 +598,8 @@ resource_dump(GwyResource *resource, GString *str)
 static gpointer
 ensure_builtin_names(G_GNUC_UNUSED gpointer arg)
 {
-    const gchar **names = g_new(const gchar*, MAXBUILTINS);
-    for (guint i = 0; i < MAXBUILTINS; i++) {
+    const gchar **names = g_new(const gchar*, N_GRAIN_QUANTITIES);
+    for (guint i = 0; i < N_GRAIN_QUANTITIES; i++) {
         GwyGrainValue *gvalue;
         if ((gvalue = gwy_grain_values_get_builtin_grain_value(i)))
             names[i] = gvalue->priv->data.symbol;
@@ -634,10 +632,10 @@ resolve_expressions(const gchar *expression,
     }
 
     if (!vars)
-        vars = freevars = g_new(guint, MAXBUILTINS);
+        vars = freevars = g_new(guint, N_GRAIN_QUANTITIES);
 
     names = g_once(&builtin_names_once, ensure_builtin_names, NULL);
-    ok = !gwy_expr_resolve_variables(expr, MAXBUILTINS, names, vars);
+    ok = !gwy_expr_resolve_variables(expr, N_GRAIN_QUANTITIES, names, vars);
 
     g_free(freevars);
     if (freeexpr)
@@ -658,6 +656,8 @@ resource_parse(const gchar *text)
     g_return_val_if_fail(klass, NULL);
 
     gwy_clear1(data);
+    data.group = GWY_GRAIN_GROUP_USER;
+
     p = str = g_strdup(text);
     while ((line = gwy_str_next_line(&p))) {
         g_strstrip(line);
@@ -958,9 +958,6 @@ gwy_grain_value_get_quantity(GwyGrainValue *gvalue)
     if (priv->data.group == GWY_GRAIN_GROUP_USER)
         return -1;
 
-    if (priv->data.group == GWY_GRAIN_GROUP_ID)
-        return GWY_GRAIN_QUANTITY_ID;
-
     return priv->builtin;
 }
 
@@ -1135,40 +1132,36 @@ gwy_grain_values_get_builtin_grain_value(GwyGrainQuantity quantity)
 }
 
 /**
- * gwy_grain_values_calculate:
- * @nvalues: Number of items in @gvalues.
- * @gvalues: Array of grain value objects.
- * @results: Array of length @nvalues of arrays of length @ngrains+1 of doubles to put the calculated values to.
+ * gwy_nield_grain_values:
+ * @nield: Number field with numbered grains.
  * @field: Data field used for marking.  For some values its values are not used, but its dimensions determine
- *              the dimensions of @grains.
- * @grains: Number field with numbered grains.
+ *         the dimensions of @grains.
+ * @gvalues: Array of grain value objects.
+ * @nvalues: Number of items in @gvalues.
+ * @results: Array of length @nvalues of arrays of length @ngrains+1 of doubles to put the calculated values to.
  *
  * Calculates a set of grain values.
  *
  * See also gwy_field_grains_get_quantities() for a simplier function for built-in grain values.
  **/
 void
-gwy_grain_values_calculate(GwyGrainValue **gvalues,
-                           gdouble **results,
-                           guint nvalues,
-                           GwyField *field,
-                           GwyNield *grains)
+gwy_nield_grain_values(GwyNield *nield,
+                       GwyField *field,
+                       GwyGrainValue **gvalues,
+                       guint nvalues,
+                       gdouble **results)
 {
-    g_return_if_fail(GWY_IS_FIELD(field));
-    g_return_if_fail(GWY_IS_NIELD(grains));
-    if (!nvalues)
+    if (!_gwy_nield_check_field(nield, field, FALSE) || !nvalues)
         return;
+    g_return_if_fail(gvalues);
+    g_return_if_fail(results);
 
-    guint vars[MAXBUILTINS];
-    GwyGrainQuantity builtins[MAXBUILTINS];
-    gdouble *quantities[MAXBUILTINS], *packed_quantities[MAXBUILTINS], *mapped[MAXBUILTINS+1];
-    GList *buffers = NULL;
     gboolean duplicates = FALSE;
-    gint ngrains = gwy_nield_max(grains);
+    gint ngrains = gwy_nield_max(nield);
 
-    /* Builtins */
-    gwy_clear(quantities, MAXBUILTINS);
-    gwy_clear(mapped, MAXBUILTINS+1);
+    /* Builtins. */
+    gdouble *quantities[N_GRAIN_QUANTITIES];
+    gwy_clear(quantities, N_GRAIN_QUANTITIES);
     for (guint i = 0; i < nvalues; i++) {
         GwyGrainValue *gvalue = gvalues[i];
         g_return_if_fail(GWY_IS_GRAIN_VALUE(gvalue));
@@ -1178,13 +1171,16 @@ gwy_grain_values_calculate(GwyGrainValue **gvalues,
             continue;
 
         guint q = priv->builtin;
+        g_assert(q < N_GRAIN_QUANTITIES);
         if (quantities[q])
             duplicates = TRUE;
         else
             quantities[q] = results[i];
     }
 
-    /* Expressions */
+    /* Expressions (user quantities). */
+    GList *buffers = NULL;
+    guint vars[N_GRAIN_QUANTITIES];
     GwyExpr *expr = gwy_expr_new();
     for (guint i = 0; i < nvalues; i++) {
         GwyGrainValue *gvalue = gvalues[i];
@@ -1194,11 +1190,8 @@ gwy_grain_values_calculate(GwyGrainValue **gvalues,
 
         gboolean resolved = resolve_expressions(priv->expression, vars, expr, NULL);
         g_return_if_fail(resolved);
-        for (guint q = 0; q < MAXBUILTINS; q++) {
-            if (!vars[q])
-                continue;
-
-            if (!quantities[q]) {
+        for (guint q = 0; q < N_GRAIN_QUANTITIES; q++) {
+            if (vars[q] && !quantities[q]) {
                 quantities[q] = g_new(gdouble, ngrains + 1);
                 buffers = g_list_prepend(buffers, quantities[q]);
             }
@@ -1206,23 +1199,19 @@ gwy_grain_values_calculate(GwyGrainValue **gvalues,
     }
 
     /* Pack into a flat array */
-    guint n = 0;
-    for (guint i = 0; i < MAXBUILTINS; i++) {
+    GwyGrainQuantity packed_builtins[N_GRAIN_QUANTITIES];
+    gdouble *packed_results[N_GRAIN_QUANTITIES];
+    guint npacked = 0;
+    for (guint i = 0; i < N_GRAIN_QUANTITIES; i++) {
         if (quantities[i]) {
-            if ((guint)i == GWY_GRAIN_QUANTITY_ID) {
-                for (gint j = 0; j <= ngrains; j++)
-                    quantities[i][j] = j;
-            }
-            else {
-                builtins[n] = i;
-                packed_quantities[n] = quantities[i];
-                n++;
-            }
+            packed_builtins[npacked] = i;
+            packed_results[npacked] = quantities[i];
+            npacked++;
         }
     }
 
     /* Calculate the built-in quantities */
-    gwy_nield_get_quantities(grains, field, builtins, n, packed_quantities);
+    gwy_nield_grain_quantities(nield, field, packed_builtins, npacked, packed_results);
 
     /* Calculate the user quantities */
     for (guint i = 0; i < nvalues; i++) {
@@ -1232,8 +1221,9 @@ gwy_grain_values_calculate(GwyGrainValue **gvalues,
             continue;
 
         resolve_expressions(priv->expression, vars, expr, NULL);
-        gwy_clear(mapped, MAXBUILTINS + 1);
-        for (guint q = 0; q < MAXBUILTINS; q++) {
+        gdouble *mapped[N_GRAIN_QUANTITIES];
+        gwy_clear(mapped, N_GRAIN_QUANTITIES);
+        for (guint q = 0; q < N_GRAIN_QUANTITIES; q++) {
             if (vars[q]) {
                 g_assert(quantities[q]);
                 mapped[vars[q]] = quantities[q];
