@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyddion.c 28903 2025-11-24 15:49:51Z yeti-dn $
+ *  $Id: gwyddion.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -71,7 +71,7 @@ gwy_init(void)
      * yet. However, it does force registration of the GTypes, which is necessary to get the GType from type name in
      * deserialisation. Otherwise GLib would have no idea the type exists. */
     g_type_class_peek(GWY_TYPE_UNIT);
-    g_type_class_peek(GWY_TYPE_CONTAINER);
+    g_type_class_peek(GWY_TYPE_DICT);
     g_type_class_peek(GWY_TYPE_INVENTORY);
     g_type_class_peek(GWY_TYPE_RESOURCE);
     g_type_class_peek(GWY_TYPE_STRING_LIST);
@@ -140,8 +140,8 @@ init_i18n(void)
  * Load external libgwyddion resources from disk.
  *
  * This function has to be called from the main thread and gwy_init() must be called first. However, most programs do
- * not use libgwyddion alone. If you use a higher-level Gwyddion library, its initialisation functions take care of
- * loading the resources.
+ * not use libgwyddion alone. If you use a higher-level Gwyddion library (libgwyui or libgwyapp), its initialisation
+ * functions take care of loading the resources.
  *
  * It is safe to call this function more than once. Subsequent calls are no-op. Resources are not reloaded from disk.
  **/
@@ -180,6 +180,31 @@ init_fftw(void)
     gwy_debug("FFTW3 system wisdom imported: %d", ok);
 }
 
+/**
+ * gwy_tune_algorithms:
+ * @key: Identification of the parameter to set.
+ * @value: String representation of new value of the parameter.
+ *
+ * Modifies internal tunable parameters of libgwyddion algorithms.
+ *
+ * Do not use this method in applications.
+ *
+ * The function enables the tuning of internal algorithm parameters or choosing a specific backend algorithm for
+ * operations which have multiple. It exists for testing and benchmarking. It is not defined what parameters might
+ * exist, what are the valid values and what effect changing them might have. Tests and benchmarks that use it are
+ * always bound to a specific version of Gwyddion.
+ **/
+void
+gwy_tune_algorithms(const gchar *key,
+                    const gchar *value)
+{
+    g_return_if_fail(key);
+    if (gwy_strequal(key, "rank-filter-method"))
+        _gwy_tune_rank_filter_method(value);
+    else
+        g_warning("Unknown tunable parameter %s.", key);
+}
+
 /**
  * SECTION:gwyddion
  * @title: gwyddion
