@@ -1,6 +1,6 @@
 #pragma once
 /*
- *  $Id: gwyddion.h 28903 2025-11-24 15:49:51Z yeti-dn $
+ *  $Id: gwyddion.h 29478 2026-02-14 13:56:53Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -28,9 +28,9 @@
 #include <libgwyddion/correlation.h>
 #include <libgwyddion/cwt.h>
 #include <libgwyddion/deserialize.h>
+#include <libgwyddion/dict.h>
 #include <libgwyddion/distance-transform.h>
 #include <libgwyddion/dwt.h>
-#include <libgwyddion/elliptic.h>
 #include <libgwyddion/enum.h>
 #include <libgwyddion/enums.h>
 #include <libgwyddion/error-list.h>
@@ -42,10 +42,8 @@
 #include <libgwyddion/gl-material.h>
 #include <libgwyddion/gradient.h>
 #include <libgwyddion/grains.h>
-#include <libgwyddion/grains-nield.h>
 #include <libgwyddion/grain-quantities.h>
 #include <libgwyddion/grain-value.h>
-#include <libgwyddion/gwycontainer.h>
 #include <libgwyddion/gwyfdcurvepreset.h>
 #include <libgwyddion/gwynlfit.h>
 #include <libgwyddion/gwynlfitpreset.h>
@@ -81,6 +79,7 @@
 #include <libgwyddion/serializable-utils.h>
 #include <libgwyddion/serialize.h>
 #include <libgwyddion/shape-fit-preset.h>
+#include <libgwyddion/shaped.h>
 #include <libgwyddion/simplefft.h>
 #include <libgwyddion/spectra.h>
 #include <libgwyddion/spline.h>
@@ -103,8 +102,10 @@
 
 G_BEGIN_DECLS
 
-void gwy_init          (void);
-void gwy_load_resources(void);
+void gwy_init           (void);
+void gwy_load_resources (void);
+void gwy_tune_algorithms(const gchar *key,
+                         const gchar *value);
 
 G_END_DECLS
 
