@@ -1,6 +1,6 @@
 /*
- *  $Id: hough.c 28903 2025-11-24 15:49:51Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: hough.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -21,9 +21,9 @@
 #include "libgwyddion/math.h"
 #include "libgwyddion/filters.h"
 #include "libgwyddion/stats.h"
-#include "libgwyddion/grains.h"
+#include "libgwyddion/watershed.h"
 #include "libgwyddion/arithmetic.h"
-#include "libgwyddion/elliptic.h"
+#include "libgwyddion/shaped.h"
 #include "libgwyddion/hough.h"
 
 #include "libgwyddion/internal.h"
@@ -78,22 +78,17 @@ gwy_field_hough_line(GwyField *dfield,
                      gint hwidth,
                      gboolean overlapping)
 {
-    gint k, col, row, xres, yres, rxres, ryres;
+    if (!_gwy_field_check_other(dfield, x_gradient, TRUE)
+        || !_gwy_field_check_other(dfield, y_gradient, TRUE))
+        return;
+    g_return_if_fail(GWY_IS_FIELD(result));
+
+    gint k, col, row;
     gdouble rho, theta, rhostep, thetastep, gradangle = 0;
 
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    rxres = gwy_field_get_xres(result); /*rho*/
-    ryres = gwy_field_get_yres(result); /*theta*/
-
-    if ((x_gradient && xres != gwy_field_get_xres(x_gradient))
-        || (x_gradient && yres != gwy_field_get_yres(x_gradient))
-        || (y_gradient && xres != gwy_field_get_xres(y_gradient))
-        || (y_gradient && yres != gwy_field_get_yres(y_gradient))) {
-        g_warning("Hough: input fields must be of same size (or null).\n");
-        return;
-    }
-
+    gint xres = dfield->xres, yres = dfield->yres;
+    gint rxres = result->xres; /*rho*/
+    gint ryres = result->yres; /*theta*/
 
     if (overlapping)
         thetastep = 2.0*G_PI/ryres;
@@ -146,31 +141,39 @@ gwy_field_hough_line_strenghten(GwyField *dfield,
                                 gint hwidth,
                                 gdouble threshold)
 {
-    GwyField *result, *water;
-    gdouble hmax, hmin, threshval, zdata[20];
-    gint i;
-    gdouble xdata[20], ydata[20];
-    gdouble dx;
+    if (!_gwy_field_check_other(dfield, x_gradient, TRUE)
+        || !_gwy_field_check_other(dfield, y_gradient, TRUE))
+        return;
 
-    result = gwy_field_new(3*hypot(dfield->xres, dfield->yres), 360, 0, 10, FALSE);
+    gdouble hmax, hmin, threshval, zdata[20];
+    gdouble xdata[20], ydata[20];
+
+    GwyField *result = gwy_field_new(3*hypot(dfield->xres, dfield->yres), 360, 0, 10, FALSE);
 
     gwy_field_hough_line(dfield, x_gradient, y_gradient, result, hwidth, FALSE);
 
-    water = gwy_field_copy(result);
-    gwy_field_grains_splash_water(result, water, 2, 0.005*(gwy_field_get_max(result) - gwy_field_get_min(result)));
+    GwyNield *water = gwy_field_new_nield_alike(result);
+    gwy_field_splash_water(result, water, NULL, 2, 0.005*(gwy_field_max(result) - gwy_field_min(result)));
 
     gwy_debug("%d %d, %g, %g",
               gwy_field_get_xres(result),
               gwy_field_get_yres(result),
-              gwy_field_get_min(result),
-              gwy_field_get_max(result));
+              gwy_field_min(result),
+              gwy_field_max(result));
 
-    gwy_field_get_min_max(water, &hmin, &hmax);
+    // XXX: This is bizarre, but I do not care. All of this stuff is undocumented something.
+    GwyField *doublewaterwhy = gwy_field_new_alike(result, FALSE);
+    gdouble *dww = doublewaterwhy->priv->data;
+    gint *w = water->priv->data;
+    for (gint i = 0; i < result->xres*result->yres; i++)
+        dww[i] = w[i];
+    g_object_unref(water);
+    gwy_field_min_max(doublewaterwhy, &hmin, &hmax);
 
     threshval = hmin + (hmax - hmin)*threshold;
-    gwy_field_get_local_maxima_list(water, xdata, ydata, zdata, 20, 10, threshval, TRUE);
-    dx = gwy_field_get_dx(result);
-    for (i = 0; i < 20; i++) {
+    gwy_field_get_local_maxima_list(doublewaterwhy, xdata, ydata, zdata, 20, 10, threshval, TRUE);
+    gdouble dx = gwy_field_get_dx(result);
+    for (gint i = 0; i < 20; i++) {
         if (zdata[i] > threshval) {
             gwy_debug("point: %g %g (of %d %d), xreal: %g  yreal: %g\n",
                       xdata[i], ydata[i], result->xres, result->yres, result->xreal, result->yreal);
@@ -179,7 +182,7 @@ gwy_field_hough_line_strenghten(GwyField *dfield,
                                   1);
         }
     }
-    g_object_unref(water);
+    g_object_unref(doublewaterwhy);
 }
 
 void
@@ -189,16 +192,12 @@ gwy_field_hough_circle(GwyField *dfield,
                        GwyField *result,
                        gdouble radius)
 {
-    g_return_if_fail(GWY_IS_FIELD(dfield));
+    if (!_gwy_field_check_other(dfield, x_gradient, TRUE)
+        || !_gwy_field_check_other(dfield, y_gradient, TRUE))
+        return;
     g_return_if_fail(GWY_IS_FIELD(result));
-    g_return_if_fail(!x_gradient || GWY_IS_FIELD(x_gradient));
-    g_return_if_fail(!y_gradient || GWY_IS_FIELD(y_gradient));
-    gint xres = dfield->xres, yres = dfield->yres;
-    if (x_gradient)
-        g_return_if_fail(x_gradient->xres == xres && x_gradient->yres == yres);
-    if (y_gradient)
-        g_return_if_fail(y_gradient->xres == xres && y_gradient->yres == yres);
 
+    gint xres = dfield->xres, yres = dfield->yres;
     gdouble angle = 0.0;
 
     gwy_field_fill(result, 0);
@@ -230,7 +229,9 @@ gwy_field_hough_circle_strenghten(GwyField *dfield,
 {
     enum { nmax = 200 };
 
-    g_return_if_fail(GWY_IS_FIELD(dfield));
+    if (!_gwy_field_check_other(dfield, x_gradient, TRUE)
+        || !_gwy_field_check_other(dfield, y_gradient, TRUE))
+        return;
 
     gdouble hmax, hmin, threshval;
     gdouble *xdata = g_new(gdouble, nmax), *ydata = g_new(gdouble, nmax), *zdata = g_new(gdouble, nmax);
@@ -239,7 +240,7 @@ gwy_field_hough_circle_strenghten(GwyField *dfield,
 
     gwy_field_hough_circle(dfield, x_gradient, y_gradient, result, radius);
 
-    gwy_field_get_min_max(result, &hmin, &hmax);
+    gwy_field_min_max(result, &hmin, &hmax);
     threshval = hmax + (hmax - hmin)*threshold;
     gwy_field_get_local_maxima_list(result, xdata, ydata, zdata, nmax, 2, threshval, TRUE);
 
