@@ -1,5 +1,5 @@
 /*
- *  $Id: interpolation.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: interpolation.c 29431 2026-02-03 00:36:52Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -119,7 +119,7 @@ gwy_interpolation_get_weights(gdouble x,
 }
 
 /**
- * gwy_interpolation_get_dval:
+ * gwy_interpolation_interpolate:
  * @x: requested value coordinate
  * @xa: x coordinate of first value
  * @ya: y coordinate of first value
@@ -134,10 +134,10 @@ gwy_interpolation_get_weights(gdouble x,
  * Returns: Interpolated value.
  **/
 gdouble
-gwy_interpolation_get_dval(gdouble x,
-                           gdouble xa, gdouble ya,
-                           gdouble xb, gdouble yb,
-                           GwyInterpolationType interpolation)
+gwy_interpolation_interpolate(gdouble x,
+                              gdouble xa, gdouble ya,
+                              gdouble xb, gdouble yb,
+                              GwyInterpolationType interpolation)
 {
     if (xa > xb) {
         GWY_SWAP(gdouble, xa, xb);
@@ -153,7 +153,7 @@ gwy_interpolation_get_dval(gdouble x,
 }
 
 /**
- * gwy_interpolation_get_dval_of_equidists:
+ * gwy_interpolation_interpolate_equidists:
  * @x: Possibily noninteger position in @data to get value at.
  * @data: (array fixed-size=4): Array of 4 values to interpolate between (see below).
  * @interpolation: Interpolation type to use.
@@ -173,7 +173,7 @@ gwy_interpolation_get_dval(gdouble x,
  * Returns: Interpolated value.
  **/
 gdouble
-gwy_interpolation_get_dval_of_equidists(gdouble x,
+gwy_interpolation_interpolate_equidists(gdouble x,
                                         const gdouble *data,
                                         GwyInterpolationType interpolation)
 {
@@ -231,7 +231,7 @@ gwy_interpolation_get_dval_of_equidists(gdouble x,
  * Interpolates a single data point in one dimension.
  *
  * The interpolation basis support size can be obtained generically with
- * gwy_interpolation_get_support_size().
+ * gwy_interpolation_support_size().
  *
  * Returns: Interpolated value.
  **/
@@ -244,7 +244,7 @@ gwy_interpolation_interpolate_1d(gdouble x,
     gdouble v;
 
     g_return_val_if_fail(x >= 0.0 && x <= 1.0, 0.0);
-    gint suplen = gwy_interpolation_get_support_size(interpolation);
+    gint suplen = gwy_interpolation_support_size(interpolation);
     if (G_UNLIKELY(suplen == 0))
         return 0.0;
     g_return_val_if_fail(suplen > 0, 0.0);
@@ -282,7 +282,7 @@ gwy_interpolation_interpolate_2d(gdouble x,
     gdouble v, vx;
 
     g_return_val_if_fail(x >= 0.0 && x <= 1.0 && y >= 0.0 && y <= 1.0, 0.0);
-    gint suplen = gwy_interpolation_get_support_size(interpolation);
+    gint suplen = gwy_interpolation_support_size(interpolation);
     if (G_UNLIKELY(suplen == 0))
         return 0.0;
     g_return_val_if_fail(suplen > 0, 0.0);
@@ -511,7 +511,7 @@ gwy_interpolation_has_interpolating_basis(GwyInterpolationType interpolation)
 }
 
 /**
- * gwy_interpolation_get_support_size:
+ * gwy_interpolation_support_size:
  * @interpolation: Interpolation type.
  *
  * Obtains the basis support size for an interpolation type.
@@ -519,7 +519,7 @@ gwy_interpolation_has_interpolating_basis(GwyInterpolationType interpolation)
  * Returns: The length of the support interval of the interpolation basis.
  **/
 gint
-gwy_interpolation_get_support_size(GwyInterpolationType interpolation)
+gwy_interpolation_support_size(GwyInterpolationType interpolation)
 {
     switch (interpolation) {
         case GWY_INTERPOLATION_ROUND:
@@ -667,7 +667,7 @@ gwy_interpolation_resample_block_1d(gint length,
     gdouble q, x0, x, v;
     gint i, ii, oldi, newi;
 
-    gint suplen = gwy_interpolation_get_support_size(interpolation);
+    gint suplen = gwy_interpolation_support_size(interpolation);
     g_return_if_fail(suplen > 0);
     gdouble w[suplen];
     gint sf = -((suplen - 1)/2);
@@ -709,7 +709,7 @@ calculate_weights_for_rescale(gint oldn,
     gint i, suplen;
     gdouble q, x0, x;
 
-    suplen = gwy_interpolation_get_support_size(interpolation);
+    suplen = gwy_interpolation_support_size(interpolation);
     q = (gdouble)oldn/newn;
     x0 = (q - 1.0)/2.0;
     for (i = 0; i < newn; i++) {
@@ -758,7 +758,7 @@ gwy_interpolation_resample_block_2d(gint width,
     gint i, ii, oldi, newi, j, jj, oldj, newj;
     gint suplen, sf, st;
 
-    suplen = gwy_interpolation_get_support_size(interpolation);
+    suplen = gwy_interpolation_support_size(interpolation);
     g_return_if_fail(suplen > 0);
     sf = -((suplen - 1)/2);
     st = suplen/2;
@@ -845,7 +845,7 @@ gwy_interpolation_shift_block_1d(gint length,
     gdouble d0, dn, v;
     gdouble *coeffs = NULL;
 
-    gint suplen = gwy_interpolation_get_support_size(interpolation);
+    gint suplen = gwy_interpolation_support_size(interpolation);
     g_return_if_fail(suplen > 0);
     gdouble w[suplen];
     gint sf = -((suplen - 1)/2);
