@@ -1,5 +1,5 @@
 /*
- *  $Id: inttrans.c 29099 2026-01-07 17:02:38Z yeti-dn $
+ *  $Id: inttrans.c 29423 2026-01-31 12:24:39Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -703,9 +703,9 @@ gwy_field_fft_2d_prepare(GwyField *dfield,
         gwy_field_plane_level(dfield, a, bx, by);
     }
     else if (level == 1)
-        gwy_field_add(dfield, -gwy_field_get_avg(dfield));
+        gwy_field_add(dfield, -gwy_field_mean(dfield));
     if (preserverms) {
-        a = gwy_field_get_rms(dfield);
+        a = gwy_field_rms(dfield);
         *rms = hypot(*rms, a);
     }
     gwy_field_fft_window(dfield, windowing);
@@ -754,12 +754,11 @@ gwy_field_area_fft_2d(GwyField *rin, GwyField *iin,
         return;
     }
 
-    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE))
+    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE)
+        || !_gwy_field_check_other(rin, iin, FALSE))
         return;
     g_return_if_fail(GWY_IS_FIELD(rout));
-    g_return_if_fail(GWY_IS_FIELD(iin));
     g_return_if_fail(GWY_IS_FIELD(iout));
-    g_return_if_fail(rin->xres == iin->xres && rin->yres == iin->yres);
     g_return_if_fail(level >= 0 && level <= 2);
     g_return_if_fail(width >= 2 && height >= 2);
 
@@ -993,21 +992,14 @@ gwy_field_fft_2d_raw(GwyField *rin,
                      GwyField *iout,
                      GwyTransformDirection direction)
 {
-    gint xres, yres;
+    if (!_gwy_field_check_other(rin, iin, FALSE))
+        return;
 
-    g_return_if_fail(GWY_IS_FIELD(rin));
     g_return_if_fail(GWY_IS_FIELD(rout));
-    xres = rin->xres;
-    yres = rin->yres;
-
-    g_return_if_fail(!iin || GWY_IS_FIELD(iin));
-    if (iin) {
-        g_return_if_fail(iin->xres == rin->xres);
-        g_return_if_fail(iin->yres == rin->yres);
-    }
     g_return_if_fail(!iout || GWY_IS_FIELD(iout));
-    /* We could also special-case R2R transforms, but they are not commonly
-     * needed in Gwyddion code. */
+    gint xres = rin->xres, yres = rin->yres;
+
+    /* We could also special-case R2R transforms, but they are not commonly needed in Gwyddion code. */
     g_return_if_fail(iin || iout);
 
     gwy_field_resize(rout, xres, yres);
@@ -1456,9 +1448,8 @@ gwy_field_fft_1d_raw(GwyField *rin,
 
 /**
  * gwy_field_area_xfft:
- * @ra: Real input data field.
- * @ia: Imaginary input data field.  It can be %NULL for real-to-complex transform which can be somewhat faster than
- *      complex-to-complex transform.
+ * @rin: Real input data field.
+ * @iin: Imaginary input data field.
  * @rout: Real output data field, it will be resized to area size.
  * @iout: Imaginary output data field, it will be resized to area size.
  * @col: Upper-left column coordinate.
@@ -1489,12 +1480,11 @@ gwy_field_area_xfft(GwyField *rin, GwyField *iin,
     gint k;
     GwyField *rbuf, *ibuf;
 
-    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE))
+    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE)
+        || !_gwy_field_check_other(rin, iin, FALSE))
         return;
     g_return_if_fail(GWY_IS_FIELD(rout));
-    g_return_if_fail(GWY_IS_FIELD(iin));
     g_return_if_fail(GWY_IS_FIELD(iout));
-    g_return_if_fail(rin->xres == iin->xres && rin->yres == rout->yres);
     g_return_if_fail(level >= 0 && level <= 2);
     g_return_if_fail(width >= 2);
 
@@ -1686,9 +1676,8 @@ gwy_field_xfft_real_do(GwyField *rin,
 
 /**
  * gwy_field_area_yfft:
- * @ra: Real input data field.
- * @ia: Imaginary input data field.  It can be %NULL for real-to-complex transform which can be somewhat faster than
- *      complex-to-complex transform.
+ * @rin: Real input data field.
+ * @iin: Imaginary input data field.
  * @rout: Real output data field, it will be resized to area size.
  * @iout: Imaginary output data field, it will be resized to area size.
  * @col: Upper-left column coordinate.
@@ -1718,12 +1707,11 @@ gwy_field_area_yfft(GwyField *rin, GwyField *iin,
     gint k;
     GwyField *rbuf, *ibuf;
 
-    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE))
+    if (!_gwy_field_check_area(rin, col, row, width, height, FALSE)
+        || !_gwy_field_check_other(rin, iin, FALSE))
         return;
     g_return_if_fail(GWY_IS_FIELD(rout));
-    g_return_if_fail(GWY_IS_FIELD(iin));
     g_return_if_fail(GWY_IS_FIELD(iout));
-    g_return_if_fail(rin->xres == iin->xres && rin->yres == rout->yres);
     g_return_if_fail(level >= 0 && level <= 2);
     g_return_if_fail(height >= 2);
 
@@ -2152,16 +2140,12 @@ gwy_field_fft_window(GwyField *field,
     yres = field->yres;
     data = field->priv->data;
     if (xres == yres) {
-        wx = wy = g_new(gdouble, xres);
-        for (i = 0; i < xres; i++)
-            wx[i] = 1.0;
+        wx = wy = gwy_math_fill(NULL, xres, 1.0);
         gwy_fft_window(xres, wx, windowing);
     }
     else {
-        wx = g_new(gdouble, xres + yres);
+        wx = gwy_math_fill(NULL, xres + yres, 1.0);
         wy = wx + xres;
-        for (i = 0; i < xres + yres; i++)
-            wx[i] = 1.0;
         gwy_fft_window(xres, wx, windowing);
         gwy_fft_window(yres, wy, windowing);
     }
@@ -2202,9 +2186,7 @@ gwy_field_fft_window_1d(GwyField *field,
     yres = field->yres;
     data = field->priv->data;
     wres = (orientation == GWY_ORIENTATION_VERTICAL ? yres : xres);
-    w = g_new(gdouble, wres);
-    for (i = 0; i < wres; i++)
-        w[i] = 1.0;
+    w = gwy_math_fill(NULL, wres, 1.0);
     gwy_fft_window(wres, w, windowing);
 
     if (orientation == GWY_ORIENTATION_VERTICAL) {
