@@ -1,6 +1,6 @@
 /*
- *  $Id: level.c 29016 2025-12-16 18:56:06Z yeti-dn $
- *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
+ *  $Id: level.c 29544 2026-02-25 10:28:00Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -117,57 +117,6 @@ gwy_field_fit_plane(GwyField *field,
  *
  * Fits a plane through a rectangular part of a data field with masking.
  *
- * The coefficients can be used for plane leveling using the same relation as in gwy_field_fit_plane(), counting
- * indices from area top left corner.
- **/
-void
-gwy_field_area_fit_plane(GwyField *field,
-                         GwyField *mask,
-                         GwyMaskingType masking,
-                         gint col, gint row,
-                         gint width, gint height,
-                         gdouble *pa, gdouble *pbx, gdouble *pby)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gwy_NIELD_area_fit_plane(field, nield, masking, col, row, width, height, pa, pbx, pby);
-    g_clear_object(&nield);
-}
-
-static void
-Rmatrix_to_x(gdouble sxx, gdouble sxy, gdouble syy,
-             gdouble *R)
-{
-    gdouble cphi = sqrt(sxx/(sxx + syy));
-    gdouble sphi = sqrt(syy/(sxx + syy));
-    if (sxy < 0.0)
-        sphi = -sphi;
-    R[0] = R[3] = cphi;
-    R[1] = sphi;
-    R[2] = -sphi;
-}
-
-static void
-matrix_vector(const gdouble *A, const gdouble *v, gdouble *vrot)
-{
-    vrot[0] = A[0]*v[0] + A[1]*v[1];
-    vrot[1] = A[2]*v[0] + A[3]*v[1];
-}
-
-/**
- * gwy_NIELD_area_fit_plane:
- * @field: A data field
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @a: (out) (optional): Where constant coefficient should be stored (or %NULL).
- * @bx: (out) (optional): Where x plane coefficient should be stored (or %NULL).
- * @by: (out) (optional): Where y plane coefficient should be stored (or %NULL).
- *
- * Fits a plane through a rectangular part of a data field with masking.
- *
  * The coefficients can be used for plane leveling using relation data[i,j] → data[i,j] - (a + by*i + bx*j), where
  * the integer indices start from (0, 0) at the top left corner of the are (not the image).
  *
@@ -179,7 +128,7 @@ matrix_vector(const gdouble *A, const gdouble *v, gdouble *vrot)
  * Returns: The rank of the normal matrix.
  **/
 gint
-gwy_NIELD_area_fit_plane(GwyField *field,
+gwy_field_area_fit_plane(GwyField *field,
                          GwyNield *mask,
                          GwyMaskingType masking,
                          gint col, gint row,
@@ -187,7 +136,7 @@ gwy_NIELD_area_fit_plane(GwyField *field,
                          gdouble *pa, gdouble *pbx, gdouble *pby)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, TRUE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return 0;
 
     if (!mask)
@@ -259,44 +208,7 @@ gwy_NIELD_area_fit_plane(GwyField *field,
         }
     }
 
-    /* The matrix now has the block form
-     * / n   0   0  \
-     * | 0  sxx sxy |
-     * \ 0  sxy syy /
-     *
-     * Distinguishing n=2 is not useful because ‘pixels in a straight line’ has many other possible confiurations.
-     * Handle it generically. */
-    gdouble det = sxx*syy - sxy*sxy;
-
-    /* There seems to be a theoretical non-degenerate limit |det/n³| ≥ 1/64, reached with 3-pixel configurations.
-     * So we have quite a good margin for catching the degenerate cases. */
-    if (fabs(det)/(n*n*n) > 0.01) {
-        bx = (sxz*syy - syz*sxy)/det;
-        by = (syz*sxx - sxz*sxy)/det;
-        retval = 3;
-    }
-    else {
-        gdouble R[4];
-        Rmatrix_to_x(sxx, sxy, syy, R);
-
-        /* Transform the system to make the degenerate component the last one. But we actually need only one element
-         * of the transformed matrix which is easy to calculate, so do it explicitly. Get the one element of rotated
-         * rhs by an explicit transformation. */
-        gdouble Arot00 = sxx + syy;
-
-        gdouble rhsrot[2], rhs[2] = { sxz, syz };
-        matrix_vector(R, rhs, rhsrot);
-
-        rhsrot[0] = rhsrot[0]/Arot00;
-        /* Set the undetermined linear component to zero, getting the minimum-norm solution. */
-        rhsrot[1] = 0.0;
-
-        GWY_SWAP(gdouble, R[1], R[2]);
-        matrix_vector(R, rhsrot, rhs);
-        bx = rhs[0];
-        by = rhs[1];
-        retval = 2;
-    }
+    retval = gwy_math_plane_coefficients(sxx, sxy, syy, sxz, syz, n, &bx, &by) + 1;
 
 end:
     a -= bx*xc + by*yc;
@@ -313,7 +225,7 @@ end:
 /**
  * gwy_field_fit_facet_plane:
  * @field: A data field.
- * @mfield: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
+ * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.
  * @a: (out) (optional): Where constant coefficient should be stored (or %NULL).
  * @bx: (out): Where x plane coefficient should be stored.
@@ -333,44 +245,11 @@ end:
  **/
 gboolean
 gwy_field_fit_facet_plane(GwyField *field,
-                          GwyField *mask,
-                          GwyMaskingType masking,
-                          gdouble *pa, gdouble *pbx, gdouble *pby)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gboolean retval = gwy_NIELD_fit_facet_plane(field, nield, masking, pa, pbx, pby);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_fit_facet_plane:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.
- * @a: (out) (optional): Where constant coefficient should be stored (or %NULL).
- * @bx: (out): Where x plane coefficient should be stored.
- * @by: (out): Where y plane coefficient should be stored.
- *
- * Calculates the inclination of a plane close to the dominant plane in a data field.
- *
- * The dominant plane is determined by taking into account larger local slopes with exponentially smaller weight.
- *
- * This is the basis of so-called facet levelling algorithm.  Usually, the plane found by this method is subtracted
- * using gwy_NIELD_plane_level() and the entire process is repeated until it converges.  A convergence criterion
- * may be sufficiently small values of the x and y plane coefficients.  Note that since gwy_NIELD_plane_level()
- * uses pixel-based lateral coordinates, the coefficients must be divided by gwy_NIELD_get_dx(field) and
- * gwy_NIELD_get_dy(field) to obtain physical plane coefficients.
- *
- * Returns: %TRUE if any plane was actually fitted; %FALSE if there was an insufficient number of unmasked pixels.
- **/
-gboolean
-gwy_NIELD_fit_facet_plane(GwyField *field,
                           GwyNield *mask,
                           GwyMaskingType masking,
                           gdouble *pa, gdouble *pbx, gdouble *pby)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return FALSE;
 
     const gdouble c = 1.0/20.0;
@@ -495,41 +374,12 @@ gwy_NIELD_fit_facet_plane(GwyField *field,
  **/
 gboolean
 gwy_field_facet_level(GwyField *field,
-                      GwyField *mask,
-                      GwyMaskingType masking,
-                      gint maxiter,
-                      GwySetFractionFunc set_fraction)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gboolean retval = gwy_NIELD_facet_level(field, nield, masking, maxiter, set_fraction);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_facet_level:
- * @field: A data field. It the procedure is cancelled it will be unchanged.
- * @mask: (nullable): Mask field specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.
- * @maxiter: Maximum number of levelling iterations. Pass a non-positive number for (a high) default.
- * @set_fraction: (scope call) (nullable): Function that sets progress fraction to output (or %NULL).
- *
- * Performs facet-levelling of a data field.
- *
- * The levelling consists of repeated computation of the dominant plane using gwy_NIELD_fit_facet_plane() and
- * subtraction of the dominant plane. Usually only several iterations are required for convergence.
- *
- * Returns: %TRUE if levelling has finished (either by converging or reaching the maximum number of iterations);
- *          %FALSE if it was cancelled or there was an insufficient number of unmasked pixels.
- **/
-gboolean
-gwy_NIELD_facet_level(GwyField *field,
                       GwyNield *mask,
                       GwyMaskingType masking,
                       gint maxiter,
                       GwySetFractionFunc set_fraction)
 {
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return FALSE;
 
     if (maxiter <= 0)
@@ -543,7 +393,7 @@ gwy_NIELD_facet_level(GwyField *field,
 
     for (i = 0; i < maxiter; i++) {
         gdouble bx, by, c;
-        if (!gwy_NIELD_fit_facet_plane(result, mask, masking, &c, &bx, &by))
+        if (!gwy_field_fit_facet_plane(result, mask, masking, &c, &bx, &by))
             break;
         gwy_field_plane_level(result, c, bx, by);
         bx /= dx;
@@ -1040,7 +890,7 @@ gwy_field_fit_legendre(GwyField *field,
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), NULL);
     return gwy_field_area_fit_legendre(field, 0, 0, field->xres, field->yres,
-                                            col_degree, row_degree, coeffs);
+                                       col_degree, row_degree, coeffs);
 }
 
 /**
@@ -1344,11 +1194,8 @@ gwy_field_subtract_poly_max(GwyField *field,
 /**
  * gwy_field_area_fit_poly:
  * @field: A data field.
- * @mask_field: (nullable):
- *              Mask of values to take values into account, or %NULL for full @field.  Values equal to 0.0 and
- *              below cause corresponding @field samples to be ignored, values equal to 1.0 and above cause
- *              inclusion of corresponding @field samples.  The behaviour for values inside (0.0, 1.0) is
- *              undefined (it may be specified in the future).
+ * @mask: (nullable):
+ *        Mask of values to take values into account, or %NULL for full @field.
  * @masking: Masking mode to use.
  * @col: Upper-left column coordinate.
  * @row: Upper-left row coordinate.
@@ -1369,49 +1216,6 @@ gwy_field_subtract_poly_max(GwyField *field,
  **/
 gdouble*
 gwy_field_area_fit_poly(GwyField *field,
-                        GwyField *mask_field,
-                        GwyMaskingType masking,
-                        gint col, gint row,
-                        gint width, gint height,
-                        gint nterms,
-                        const gint *term_powers,
-                        gdouble *coeffs)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask_field, masking);
-    gdouble *retval = gwy_NIELD_area_fit_poly(field, nield, masking, col, row, width, height,
-                                              nterms, term_powers, coeffs);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_fit_poly:
- * @field: A data field.
- * @mask: (nullable):
- *        Mask of values to take values into account, or %NULL for full @field.  Values equal to 0.0 and
- *        below cause corresponding @field samples to be ignored, values equal to 1.0 and above cause
- *        inclusion of corresponding @field samples.  The behaviour for values inside (0.0, 1.0) is
- *        undefined (it may be specified in the future).
- * @masking: Masking mode to use.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @nterms: The number of polynomial terms to take into account (half the number of items in @term_powers).
- * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each terms is described by a couple of powers
- *               (powerx, powery).
- * @coeffs: (nullable): Array of size @nterms to store the coefficients to, or %NULL to allocate a new array.
- *
- * Fit a given set of polynomial terms to a rectangular part of a data field.
- *
- * The polynomial coefficients correspond to normalized coordinates that are always from the interval [-1,1] where -1
- * corresponds to the left/topmost pixel and 1 corresponds to the bottom/rightmost pixel of the area (not the entire
- * field).
- *
- * Returns: Either @coeffs if it was not %NULL, or a newly allocated array with coefficients.
- **/
-gdouble*
-gwy_NIELD_area_fit_poly(GwyField *field,
                         GwyNield *mask,
                         GwyMaskingType masking,
                         gint col, gint row,
@@ -1421,7 +1225,7 @@ gwy_NIELD_area_fit_poly(GwyField *field,
                         gdouble *coeffs)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return NULL;
     g_return_val_if_fail(nterms >= 0, NULL);
 
@@ -1501,11 +1305,8 @@ gwy_NIELD_area_fit_poly(GwyField *field,
 /**
  * gwy_field_fit_poly:
  * @field: A data field.
- * @mask_field: (nullable):
- *              Mask of values to take values into account, or %NULL for full @field.  Values equal to 0.0 and
- *              below cause corresponding @field samples to be ignored, values equal to 1.0 and above cause
- *              inclusion of corresponding @field samples.  The behaviour for values inside (0.0, 1.0) is
- *              undefined (it may be specified in the future).
+ * @mask: (nullable):
+ *        Mask of values to take values into account, or %NULL for full @field.
  * @masking: Masking mode to use.
  * @nterms: The number of polynomial terms to take into account (half the number of items in @term_powers).
  * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each terms is described by a couple of powers
@@ -1518,14 +1319,14 @@ gwy_NIELD_area_fit_poly(GwyField *field,
  **/
 gdouble*
 gwy_field_fit_poly(GwyField *field,
-                   GwyField *mask_field,
+                   GwyNield *mask,
                    GwyMaskingType masking,
                    gint nterms,
                    const gint *term_powers,
                    gdouble *coeffs)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), NULL);
-    return gwy_field_area_fit_poly(field, mask_field, masking, 0, 0, field->xres, field->yres,
+    return gwy_field_area_fit_poly(field, mask, masking, 0, 0, field->xres, field->yres,
                                    nterms, term_powers, coeffs);
 }
 
@@ -1562,7 +1363,7 @@ gwy_field_area_subtract_poly(GwyField *field,
         return;
 
     gint xres = field->xres;
-    gdouble *data = field->priv->data + row*xres + col;;
+    gdouble *data = field->priv->data + row*xres + col;
 
     /* Precalculate x powers which are the same in all rows. */
     gdouble *px = g_new(gdouble, nterms*width);
@@ -1877,7 +1678,6 @@ gwy_field_local_plane_quantity(GwyField *field,
 void
 gwy_line_fit_line(GwyLine *line, gdouble *a, gdouble *b)
 {
-
     g_return_if_fail(GWY_IS_LINE(line));
 
     const gdouble *data = line->priv->data;
@@ -1978,7 +1778,7 @@ gwy_line_rotate(GwyLine *line,
             break;
         }
 
-        data[i] = gwy_interpolation_get_dval(x, dx[k-1], dy[k-1], dx[k], dy[k], interpolation);
+        data[i] = gwy_interpolation_interpolate(x, dx[k-1], dy[k-1], dx[k], dy[k], interpolation);
     }
     g_free(dx);
     g_free(dy);
@@ -2112,7 +1912,6 @@ gwy_line_part_subtract_poly(GwyLine *line,
 
         data[i] -= val;
     }
-
 }
 
 /**
