@@ -1,5 +1,5 @@
 /*
- *  $Id: line.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: line.c 29544 2026-02-25 10:28:00Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -370,8 +370,8 @@ gwy_line_part_extract(GwyLine *line,
 
 /**
  * gwy_line_copy_data:
- * @line: Source data line.
- * @target: Destination data line.
+ * @src: Source data line.
+ * @dest: Destination data line.
  *
  * Copies the contents of a data line to another already allocated data line of the same size.
  *
@@ -379,16 +379,61 @@ gwy_line_part_extract(GwyLine *line,
  * of dimensions, you can use gwy_line_assign().
  **/
 void
-gwy_line_copy_data(GwyLine *line, GwyLine *target)
+gwy_line_copy_data(GwyLine *src, GwyLine *dest)
 {
-    g_return_if_fail(GWY_IS_LINE(line));
-    g_return_if_fail(GWY_IS_LINE(target));
-    g_return_if_fail(line->res == target->res);
+    g_return_if_fail(GWY_IS_LINE(src));
+    g_return_if_fail(GWY_IS_LINE(dest));
+    g_return_if_fail(src->res == dest->res);
 
-    if (line == target)
+    if (src == dest)
         return;
 
-    gwy_assign(target->priv->data, line->priv->data, line->res);
+    gwy_assign(dest->priv->data, src->priv->data, src->res);
+    gwy_line_invalidate(dest);
+}
+
+/**
+ * gwy_line_part_copy:
+ * @src: Source data line.
+ * @dest: Destination data line.
+ * @pos: Index where to start in @src.
+ * @len: Length of copied segment. You can also pass -1 for full @src size.
+ * @destpos: Destination position in @dest.
+ *
+ * Copies a segment from one data line to another.
+ *
+ * The part starts at @pos in @src and its dimension is @len. It is copied to @dest starting from @destpos.
+ *
+ * The source part has to be completely contained in @src.  No assumptions are made about destination position,
+ * however. Parts of the source part sticking out the destination data field @dest are cut off.
+ *
+ * If @src is the same data line as @dest, the parts may not overlap.
+ **/
+void
+gwy_line_part_copy(GwyLine *src, GwyLine *dest,
+                   gint pos, gint len, gint destpos)
+{
+    g_return_if_fail(GWY_IS_LINE(src));
+    g_return_if_fail(GWY_IS_LINE(dest));
+    if (len == -1)
+        len = src->res;
+    g_return_if_fail(pos >= 0 && len >= 0 && pos + len <= src->res);
+
+    if (destpos + len > dest->res)
+        len = dest->res - destpos;
+    if (destpos < 0) {
+        pos -= destpos;
+        len += destpos;
+        destpos = 0;
+    }
+    if (len <= 0)
+        return;
+
+    gwy_line_invalidate(dest);
+
+    const gdouble *sdata = src->priv->data;
+    gdouble *ddata = dest->priv->data;
+    gwy_assign(ddata + destpos, sdata + pos, len);
 }
 
 /**
@@ -433,7 +478,7 @@ gwy_line_get_dval(GwyLine *line, gdouble x, GwyInterpolationType interpolation)
     if (l < 1 || l >= (line->res - 2))
         return (1.0 - rest)*data[l] + rest*data[l+1];
 
-    return gwy_interpolation_get_dval_of_equidists(rest, data + l-1, interpolation);
+    return gwy_interpolation_interpolate_equidists(rest, data + l-1, interpolation);
 }
 
 /**
@@ -855,7 +900,7 @@ gwy_line_invert_value(GwyLine *line)
     g_return_if_fail(GWY_IS_LINE(line));
     gdouble *data = line->priv->data;
     gint res = line->res;
-    gdouble avg = gwy_line_avg(line);
+    gdouble avg = gwy_line_mean(line);
     for (gint i = 0; i < res; i++)
         data[i] = 2*avg - data[i];
 }
@@ -872,11 +917,7 @@ gwy_line_fill(GwyLine *line,
               gdouble value)
 {
     g_return_if_fail(GWY_IS_LINE(line));
-
-    gdouble *data = line->priv->data;
-    gint res = line->res;
-    for (gint i = 0; i < res; i++)
-        data[i] = value;
+    gwy_math_fill(line->priv->data, line->res, value);
 }
 
 /**
@@ -1082,7 +1123,7 @@ gwy_line_part_threshold(GwyLine *line,
 }
 
 /**
- * gwy_line_get_der:
+ * gwy_line_der:
  * @line: A data line.
  * @i: Pixel coordinate.
  *
@@ -1091,7 +1132,7 @@ gwy_line_part_threshold(GwyLine *line,
  * Returns: Derivation at given position.
  **/
 gdouble
-gwy_line_get_der(GwyLine *line, gint i)
+gwy_line_der(GwyLine *line, gint i)
 {
     g_return_val_if_fail(GWY_IS_LINE(line), 0.0);
     gint res = line->res;
@@ -1144,7 +1185,7 @@ gwy_line_cumulate(GwyLine *line, gboolean transform_to_cdist)
 }
 
 /**
- * gwy_line_der:
+ * gwy_line_filter_slope:
  * @line: A data line.
  * @der: Data line where the derivative is to be stored. It will be resized to match @line.
  *
@@ -1165,8 +1206,7 @@ gwy_line_filter_slope(GwyLine *line,
     der->real = line->real;
     der->off = line->off;
     gwy_unit_assign(gwy_line_get_unit_x(der), gwy_line_get_unit_x(line));
-    gwy_unit_divide(gwy_line_get_unit_y(line), gwy_line_get_unit_x(line),
-                       gwy_line_get_unit_y(der));
+    gwy_unit_divide(gwy_line_get_unit_y(line), gwy_line_get_unit_x(line), gwy_line_get_unit_y(der));
     if (res == 1) {
         gwy_line_clear(der);
     }
