@@ -1,5 +1,5 @@
 /*
- *  $Id: linestats.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: linestats.c 29544 2026-02-25 10:28:00Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -157,7 +157,7 @@ gwy_line_max_pos_r(GwyLine *line)
 }
 
 /**
- * gwy_line_avg:
+ * gwy_line_mean:
  * @line: A data line.
  *
  * Computes average value of a data line.
@@ -165,7 +165,7 @@ gwy_line_max_pos_r(GwyLine *line)
  * Returns: Average value
  **/
 gdouble
-gwy_line_avg(GwyLine *line)
+gwy_line_mean(GwyLine *line)
 {
     g_return_val_if_fail(GWY_IS_LINE(line), 0.0);
     return gwy_line_sum(line)/line->res;
@@ -188,7 +188,7 @@ gwy_line_rms(GwyLine *line)
     if (res < 2)
         return 0.0;
 
-    gdouble avg = gwy_line_avg(line);
+    gdouble avg = gwy_line_mean(line);
     const gdouble *data = line->priv->data;
     gdouble sum2 = 0.0;
     for (gint i = 0; i < res; i++)
@@ -231,7 +231,7 @@ gwy_line_sum(GwyLine *line)
  **/
 gdouble
 gwy_line_part_max(GwyLine *line,
-                      gint pos, gint len)
+                  gint pos, gint len)
 {
     gdouble max = -G_MAXDOUBLE;
     if (!_gwy_line_check_part(line, pos, len, FALSE))
@@ -256,7 +256,7 @@ gwy_line_part_max(GwyLine *line,
  **/
 gdouble
 gwy_line_part_min(GwyLine *line,
-                      gint pos, gint len)
+                  gint pos, gint len)
 {
     gdouble min = G_MAXDOUBLE;
     if (!_gwy_line_check_part(line, pos, len, FALSE))
@@ -281,8 +281,8 @@ gwy_line_part_min(GwyLine *line,
  **/
 void
 gwy_line_part_min_max(GwyLine *line,
-                          gint pos, gint len,
-                          gdouble *min, gdouble *max)
+                      gint pos, gint len,
+                      gdouble *min, gdouble *max)
 {
     /* If both are not requested do not bother finding them. */
     if (!max && min)
@@ -316,14 +316,14 @@ gwy_line_part_min_max(GwyLine *line,
  **/
 void
 gwy_line_min_max(GwyLine *line,
-                     gdouble *min, gdouble *max)
+                 gdouble *min, gdouble *max)
 {
     g_return_if_fail(GWY_IS_LINE(line));
     gwy_line_part_min_max(line, 0, line->res, min, max);
 }
 
 /**
- * gwy_line_part_avg:
+ * gwy_line_part_mean:
  * @line: A data line.
  * @pos: Index where to start.
  * @len: Length of the segment.
@@ -333,7 +333,7 @@ gwy_line_min_max(GwyLine *line,
  * Returns: Average value within given interval.
  **/
 gdouble
-gwy_line_part_avg(GwyLine *a, gint pos, gint len)
+gwy_line_part_mean(GwyLine *a, gint pos, gint len)
 {
     return len ? gwy_line_part_sum(a, pos, len)/len : 0.0;
 }
@@ -356,7 +356,7 @@ gwy_line_part_rms(GwyLine *line, gint pos, gint len)
 
     if (len < 2)
         return 0.0;
-    gdouble avg = gwy_line_part_avg(line, pos, len);
+    gdouble avg = gwy_line_part_mean(line, pos, len);
     const gdouble *data = line->priv->data + pos;
     gdouble sum2 = 0.0;
     for (gint i = 0; i < len; i++)
@@ -433,7 +433,7 @@ gwy_line_part_ra(GwyLine *line, gint pos, gint len)
     if (len < 2)
         return 0.0;
 
-    gdouble avg = gwy_line_part_avg(line, pos, len);
+    gdouble avg = gwy_line_part_mean(line, pos, len);
     const gdouble *data = line->priv->data + pos;
     for (gint i = 0; i < len; i++)
         ra += fabs(data[i] - avg);
@@ -458,7 +458,7 @@ gwy_line_part_skew(GwyLine *line, gint pos, gint len)
     if (!_gwy_line_check_part(line, pos, len, FALSE))
         return skew;
 
-    gdouble avg = gwy_line_part_avg(line, pos, len);
+    gdouble avg = gwy_line_part_mean(line, pos, len);
     const gdouble *data = line->priv->data + pos;
     for (gint i = 0; i < len; i++) {
         gdouble d = data[i] - avg;
@@ -492,7 +492,7 @@ gwy_line_part_kurtosis(GwyLine *line, gint pos, gint len)
     if (!_gwy_line_check_part(line, pos, len, FALSE))
         return kurtosis;
 
-    gdouble avg = gwy_line_part_avg(line, pos, len);
+    gdouble avg = gwy_line_part_mean(line, pos, len);
     const gdouble *data = line->priv->data + pos;
     for (gint i = 0; i < len; i++) {
         gdouble d = data[i] - avg;
@@ -628,7 +628,7 @@ gwy_line_func_fft(GwyLine *line, GwyLine *target_line,
     g_return_if_fail(GWY_IS_LINE(line));
     g_return_if_fail(GWY_IS_LINE(target_line));
 
-    gdouble avg = gwy_line_avg(line);
+    gdouble avg = gwy_line_mean(line);
     gint res = line->res;
     gint size = gwy_fft_find_nice_size(2*res);
     gwy_line_resize(target_line, res);
@@ -912,7 +912,7 @@ gwy_line_angle_dist(GwyLine *line,
         ymin = G_MAXDOUBLE;
         ymax = -G_MAXDOUBLE;
         for (i = 0; i < n; i++) {
-            angle = gwy_line_get_der(line, i);
+            angle = gwy_line_der(line, i);
             if (ymin > angle)
                 ymin = angle;
             if (ymax < angle)
@@ -923,7 +923,7 @@ gwy_line_angle_dist(GwyLine *line,
     imin = ymin/step;
 
     for (i = 0; i < n; i++) {
-        val = (gint)(gwy_line_get_der(line, i)/step - imin);
+        val = (gint)(gwy_line_der(line, i)/step - imin);
         if (G_UNLIKELY(val < 0))
             val = 0; /* this should never happened */
         if (G_UNLIKELY(val >= nsteps))
