@@ -1,6 +1,6 @@
 /*
- *  $Id: math.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: math.c 29544 2026-02-25 10:28:00Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  The quicksort algorithm was copied from GNU C library, Copyright (C) 1991, 1992, 1996, 1997, 1999 Free Software
@@ -421,7 +421,7 @@ gwy_math_cut_line_by_rectangle(gdouble x,
     }
 
     if (vy != 0.0) {
-        for (gint s = 1; s <= 3; s+= 2) {
+        for (gint s = 1; s <= 3; s += 2) {
             gdouble tt = (rect[s] - y)/vy;
             if (tt >= 0.0 && tt < tbest && in_range(rect[0], rect[2], x + tt*vx)) {
                 tbest = tt;
@@ -897,7 +897,7 @@ gwy_math_tridiag_solve_rewrite(gint n,
  * Curvatures have signs, positive mean a concave (cup-like) surface, negative mean a convex (cap-like) surface.  They
  * are ordered including the sign.
  *
- * Directions are angles from the interval (-π/2, π/2].
+ * Directions are angles from the interval [-π/2, π/2].
  *
  * If the quadratic surface is degenerate, i.e. flat in at least one direction, the centre is undefined.  The centre
  * is then chosen as the closest point the origin of coordinates.  For flat surfaces this means the origin is simply
@@ -917,8 +917,6 @@ gwy_math_curvature_at_apex(const gdouble *coeffs,
                            gdouble *pzc)
 {
     gdouble a = coeffs[0], bx = coeffs[1], by = coeffs[2], cxx = coeffs[3], cxy = coeffs[4], cyy = coeffs[5];
-    gdouble cm, cp, bx1, by1, xc, yc, phi, cx, cy;
-    guint degree;
 
     /* Check if any sane quadratic term is present. */
     if (fabs(cxx) + fabs(cxy) + fabs(cyy) <= 1e-14*(fabs(bx) + fabs(by))) {
@@ -941,31 +939,31 @@ gwy_math_curvature_at_apex(const gdouble *coeffs,
     }
 
     /* At least one quadratic term.  Eliminate the mixed term, if any. */
-    cm = cxx - cyy;
-    cp = cxx + cyy;
-    phi = 0.5*atan2(cxy, cm);
-    cx = cp + hypot(cm, cxy);
-    cy = cp - hypot(cm, cxy);
-    bx1 = bx*cos(phi) + by*sin(phi);
-    by1 = -bx*sin(phi) + by*cos(phi);
+    gdouble cm = cxx - cyy, cp = cxx + cyy;
+    gdouble phi = 0.5*atan2(cxy, cm);
+    gdouble H = hypot(cm, cxy);
+    gdouble cx = 0.5*(cp + H), cy = 0.5*(cp - H);
+    gdouble bx1 = bx*cos(phi) + by*sin(phi), by1 = -bx*sin(phi) + by*cos(phi);
 
     /* Eliminate linear terms */
+    gdouble xc, yc;
+    guint degree;
     if (fabs(cx) < 1e-14*fabs(cy)) {
         /* Only y quadratic term */
-        xc = 0.0;
-        yc = -by1/cy;
+        xc = cx = 0.0;
+        yc = -by1/(2.0*cy);
         degree = 1;
     }
     else if (fabs(cy) < 1e-14*fabs(cx)) {
         /* Only x quadratic term */
-        xc = -bx1/cx;
-        yc = 0.0;
+        xc = -bx1/(2.0*cx);
+        yc = cy = 0.0;
         degree = 1;
     }
     else {
         /* Two quadratic terms */
-        xc = -bx1/cx;
-        yc = -by1/cy;
+        xc = -bx1/(2.0*cx);
+        yc = -by1/(2.0*cy);
         degree = 2;
     }
 
@@ -980,13 +978,11 @@ gwy_math_curvature_at_apex(const gdouble *coeffs,
         GWY_SWAP(gdouble, cx, cy);
         phi += G_PI_2;
     }
-    /* Compenstate the left-handed coordinate system */
-    phi = -phi;
 
     if (pkappa1)
-        *pkappa1 = cx;
+        *pkappa1 = 2.0*cx;
     if (pkappa2)
-        *pkappa2 = cy;
+        *pkappa2 = 2.0*cy;
 
     if (pphi1)
         *pphi1 = gwy_canonicalize_angle(phi, FALSE, FALSE);
@@ -996,37 +992,6 @@ gwy_math_curvature_at_apex(const gdouble *coeffs,
     return degree;
 }
 
-/**
- * gwy_math_curvature:
- * @coeffs: (array fixed-size=6):
- *          Array of the six polynomial coefficients of a quadratic surface in the following order: 1, x, y, x², xy, y².
- * @kappa1: (out): Location to store the smaller curvature to.
- * @kappa2: (out): Location to store the larger curvature to.
- * @phi1: (out): Location to store the direction of the smaller curvature to.
- * @phi2: (out): Location to store the direction of the larger curvature to.
- * @xc: (out): Location to store x-coordinate of the centre of the quadratic surface.
- * @yc: (out): Location to store y-coordinate of the centre of the quadratic surface.
- * @zc: (out): Location to store value at the centre of the quadratic surface.
- *
- * Calculates curvature parameters at the apex from two-dimensional quadratic polynomial coefficients.
- *
- * This is an old name for gwy_math_curvature_at_apex().  See the description there.
- *
- * Returns: The number of curved dimensions (0 to 2).
- **/
-guint
-gwy_math_curvature(const gdouble *coeffs,
-                   gdouble *pkappa1,
-                   gdouble *pkappa2,
-                   gdouble *pphi1,
-                   gdouble *pphi2,
-                   gdouble *pxc,
-                   gdouble *pyc,
-                   gdouble *pzc)
-{
-    return gwy_math_curvature_at_apex(coeffs, pkappa1, pkappa2, pphi1, pphi2, pxc, pyc, pzc);
-}
-
 /**
  * gwy_math_curvature_at_origin:
  * @coeffs: (array fixed-size=6):
@@ -1038,9 +1003,9 @@ gwy_math_curvature(const gdouble *coeffs,
  *
  * Calculates curvature parameters at origin from two-dimensional quadratic polynomial coefficients.
  *
- * See gwy_math_curvature() for discussion of scaling and sign convenrions.  This function function differs from it
- * by computing the local surface curvature at @x=0 and @y=0, whereas gwy_math_curvature() computes the curvature at
- * the apex of the parabolic surface.
+ * See gwy_math_curvature_at_apex() for discussion of scaling and sign convenrions.  This function function differs
+ * from it by computing the local surface curvature at @x=0 and @y=0, whereas gwy_math_curvature_at_apex() computes
+ * the curvature at the apex of the parabolic surface.
  *
  * The array @coeffs is consistent with gwy_math_curvature_at_apex(), even though here the constant term is not used.
  *
@@ -1074,6 +1039,103 @@ gwy_math_curvature_at_origin(const gdouble *coeffs,
     return gwy_math_curvature_at_apex(tpcoeffs, pkappa1, pkappa2, pphi1, pphi2, NULL, NULL, NULL);
 }
 
+static void
+Rmatrix_to_x(gdouble sxx, gdouble sxy, gdouble syy,
+             gdouble *R)
+{
+    gdouble cphi = sqrt(sxx/(sxx + syy));
+    gdouble sphi = sqrt(syy/(sxx + syy));
+    if (sxy < 0.0)
+        sphi = -sphi;
+    R[0] = R[3] = cphi;
+    R[1] = sphi;
+    R[2] = -sphi;
+}
+
+static void
+matrix_vector_2x2(const gdouble *A, const gdouble *v, gdouble *vrot)
+{
+    vrot[0] = A[0]*v[0] + A[1]*v[1];
+    vrot[1] = A[2]*v[0] + A[3]*v[1];
+}
+
+/**
+ * gwy_math_plane_coefficients:
+ * @sumx2: Sum of squared integer @x-coordinates.
+ * @sumxy: Sum of products of integer @x- and @y-coordinates.
+ * @sumy2: Sum of squared integer @y-coordinates.
+ * @sumxz: Sum of products of integer @x-coordinates and @z values.
+ * @sumyz: Sum of products of integer @y-coordinates and @z values.
+ * @n: Number of points.
+ * @bx: (out): Location where to store the plane @x-coeffictient.
+ * @by: (out): Location where to store the plane @y-coeffictient.
+ *
+ * Calculates minimum-norm plane coefficients.
+ *
+ * The @x and @y coordinates are assumed to form a grid with step 1 (or larger) in each direction, at least
+ * approximately. The sums entering the calculation must be calculated with respet to the centre of mass of the
+ * point set in the @xy plane.
+ *
+ * The function then calculates the plane coefficients (in the same integer coordinates), in the sense of minimum-norm
+ * solution in the degenerated cases. A typical degenerate case is that all points are collinear. In such case the
+ * coefficient along the line can be determined, but the coefficient in the orthogonal direction cannot – and is set
+ * to zero (and then they are projected into @x and @y). An even more degenerate case is a single point for which
+ * the minimum-norm coefficients are zero.
+ *
+ * Returns: The rank, which is 2 in non-degenerate cases, 1 for collinear points, 0 for a single point and -1 for no
+ *          points at all (which is the same here, but still useful to distinguish).
+ **/
+gint
+gwy_math_plane_coefficients(gdouble sumx2, gdouble sumxy, gdouble sumy2,
+                            gdouble sumxz, gdouble sumyz,
+                            gsize n,
+                            gdouble *bx, gdouble *by)
+{
+    /* Handle the trivial cases first. */
+    if (n == 0)
+        return -1;
+    if (n == 1)
+        return 0;
+
+    /* In the specfied centred coordinates, the matrix has the block form
+     * / n    0     0   \
+     * | 0  sumx2 sumxy |
+     * \ 0  sumxy sumy2 /
+     */
+    gdouble det = sumx2*sumy2 - sumxy*sumxy;
+
+    /* There seems to be a theoretical non-degenerate limit |det/n³| ≥ 1/64, reached with 3-pixel configurations.
+     * So we have quite a good margin for catching the degenerate cases. Handle the them first. */
+    if (fabs(det)/gwy_powi(n, 3) > 0.01) {
+        *bx = (sumxz*sumy2 - sumyz*sumxy)/det;
+        *by = (sumyz*sumx2 - sumxz*sumxy)/det;
+        return 2;
+    }
+
+    /* The single-degenerate case (collinear). */
+    gdouble R[4];
+    Rmatrix_to_x(sumx2, sumxy, sumy2, R);
+
+    /* Transform the system to make the degenerate component the last one. But we actually need only one element
+     * of the transformed matrix which is easy to calculate, so do it explicitly. Get the one element of rotated
+     * rhs by an explicit transformation. */
+    gdouble Arot00 = sumx2 + sumy2;
+
+    gdouble rhsrot[2], rhs[2] = { sumxz, sumyz };
+    matrix_vector_2x2(R, rhs, rhsrot);
+
+    rhsrot[0] = rhsrot[0]/Arot00;
+    /* Set the undetermined linear component to zero, getting the minimum-norm solution. */
+    rhsrot[1] = 0.0;
+
+    GWY_SWAP(gdouble, R[1], R[2]);
+    matrix_vector_2x2(R, rhsrot, rhs);
+    *bx = rhs[0];
+    *by = rhs[1];
+
+    return 1;
+}
+
 /**
  * gwy_math_refine_maximum_1d:
  * @y: (array fixed-size=3): Array of length 3, containing the neighbourhood values with the maximum in the centre.
@@ -1171,27 +1233,6 @@ gwy_math_refine_maximum_2d(const gdouble *z,
     return TRUE;
 }
 
-/**
- * gwy_math_refine_maximum:
- * @z: (array fixed-size=9):
- *     Array of length 9, containing the square 3x3 neighbourhood values in matrix order and with the maximum in the
- *     centre.
- * @x: (out): Location to store the refined @x-coordinate.
- * @y: (out): Location to store the refined @y-coordinate.
- *
- * Performs subpixel refinement of parabolic a two-dimensional maximum.
- *
- * An alias for gwy_math_refine_maximum_2d().
- *
- * Returns: %TRUE if the refinement succeeded, %FALSE if it failed.  The values of @x and @y are usable regardless of
- *          the return value.
- **/
-gboolean
-gwy_math_refine_maximum(const gdouble *z, gdouble *x, gdouble *y)
-{
-    return gwy_math_refine_maximum_2d(z, x, y);
-}
-
 static gboolean
 interpolate_parabolic(const GwyXY *xy, gdouble *x)
 {
@@ -1257,7 +1298,7 @@ gwy_accumulate_counts(guint *array,
 
 /**
  * gwy_math_linspace:
- * @array: (array length=n) (nullable): Array with @n elements to fill with values, or %NULL.
+ * @array: (array length=n) (nullable) (transfer full): Array with @n elements to fill with values, or %NULL.
  * @n: Number of items in @array.
  * @first: Value the first item should be set to.
  * @step: Difference between consecutive values.
@@ -1268,28 +1309,49 @@ gwy_accumulate_counts(guint *array,
  *
  * Note that the arguments differ from the similar numpy function.
  *
- * Returns: (array length=n):
+ * Returns: (array length=n) (transfer full):
  *          @array itself if it was not %NULL. If @array is %NULL a new array is allocated and returned.
  **/
 gdouble*
 gwy_math_linspace(gdouble *array,
-                  gint n,
+                  gsize n,
                   gdouble first,
                   gdouble step)
 {
-    gint i;
-
-    g_return_val_if_fail(n >= 0, array);
-
     if (!array)
         array = g_new(gdouble, n);
 
-    for (i = 0; i < n; i++)
+    for (gsize i = 0; i < n; i++)
         array[i] = first + i*step;
 
     return array;
 }
 
+/**
+ * gwy_math_fill:
+ * @array: (array length=n) (nullable) (transfer full): Array with @n elements to fill with values, or %NULL.
+ * @n: Number of items in @array.
+ * @value: Value to fill the array with.
+ *
+ * Fills an array with a constant.
+ *
+ * Returns: (array length=n) (transfer full):
+ *          @array itself if it was not %NULL. If @array is %NULL a new array is allocated and returned.
+ **/
+gdouble*
+gwy_math_fill(gdouble *array,
+              gsize n,
+              gdouble value)
+{
+    if (!array)
+        array = g_new(gdouble, n);
+
+    for (gsize i = 0; i < n; i++)
+        array[i] = value;
+
+    return array;
+}
+
 /**
  * gwy_compare_double:
  * @a: Pointer to a double.
