@@ -1,7 +1,7 @@
 #pragma once
 /*
- *  $Id: math.h 29099 2026-01-07 17:02:38Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: math.h 29532 2026-02-23 18:26:16Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -109,14 +109,6 @@ void     gwy_math_choleski_solve       (gint n,
                                         gdouble *rhs);
 gboolean gwy_math_choleski_invert      (gint n,
                                         gdouble *matrix);
-guint    gwy_math_curvature            (const gdouble *coeffs,
-                                        gdouble *kappa1,
-                                        gdouble *kappa2,
-                                        gdouble *phi1,
-                                        gdouble *phi2,
-                                        gdouble *xc,
-                                        gdouble *yc,
-                                        gdouble *zc);
 guint    gwy_math_curvature_at_apex    (const gdouble *coeffs,
                                         gdouble *kappa1,
                                         gdouble *kappa2,
@@ -130,14 +122,19 @@ guint    gwy_math_curvature_at_origin  (const gdouble *coeffs,
                                         gdouble *kappa2,
                                         gdouble *phi1,
                                         gdouble *phi2);
+gint     gwy_math_plane_coefficients   (gdouble sumx2,
+                                        gdouble sumxy,
+                                        gdouble sumy2,
+                                        gdouble sumxz,
+                                        gdouble sumyz,
+                                        gsize n,
+                                        gdouble *bx,
+                                        gdouble *by);
 gboolean gwy_math_refine_maximum_1d    (const gdouble *y,
                                         gdouble *x);
 gboolean gwy_math_refine_maximum_2d    (const gdouble *z,
                                         gdouble *x,
                                         gdouble *y);
-gboolean gwy_math_refine_maximum       (const gdouble *z,
-                                        gdouble *x,
-                                        gdouble *y);
 gdouble  gwy_math_find_minimum_1d      (GwyRealFunc function,
                                         gdouble a,
                                         gdouble b,
@@ -162,8 +159,11 @@ guint*   gwy_check_regular_2d_lattice  (const gdouble *coords,
 void     gwy_accumulate_counts         (guint *array,
                                         gint n,
                                         gboolean do_rewind);
+gdouble* gwy_math_fill                 (gdouble *array,
+                                        gsize n,
+                                        gdouble value);
 gdouble* gwy_math_linspace             (gdouble *array,
-                                        gint n,
+                                        gsize n,
                                         gdouble first,
                                         gdouble step);
 gdouble  gwy_math_median               (gdouble *array,
@@ -226,7 +226,7 @@ guint    gwy_math_histogram            (const gdouble *values,
  *   translation units.
  *
  * There are some compiler- and linker-specific features which can give us what we want. However, portability is an
- * issue then. So, are macros the only reasonable solution?
+ * issue then. Macros may be the least bad solution.
  *
  * Header:
  *
@@ -250,14 +250,16 @@ guint    gwy_math_histogram            (const gdouble *values,
  * }
  *
  * This achieves:
- * - All code and gi-scanner see the extern symbol gwy_foo() declared.
+ * - All code and gi-scanner see the extern symbol gwy_foo() declared since as it comes first.
  * - Any code is redirected to the the inline implementation, which is actually _gwy_foo_implementation().
  * - Since _gwy_foo_implementation() is static inline, nothing can link to it and it never polutes any symbol table.
  * - Any code which really wants to dlopen or link to the function (gi.repository) can do so.
  *
- * The remaning ugly bit is that C code which really wants to see the linkable version of the function must get rid of
- * the redirection macro. Allow disabling the machinery using preprocessor flag? Defining __GI_SCANNER__ does that but
- * it would be nicer to call it something else…
+ * The remaning ugly bit is that C code may really want to see the extern version of the function. It then must get
+ * rid of the redirection macro. The least contrived reason is being able to identify functions by address across
+ * different compilation units. However, since this is still niche and would require *all* relevant code compiled like
+ * this, we do not provide a dedicated flag to disable the indirection macros. Do a bunch of #undefs and send a bug
+ * report if it makes you sad?
  */
 
 int     gwy_isnan   (double x);
@@ -274,6 +276,7 @@ gdouble gwy_deg2rad (gdouble x);
 gdouble gwy_rad2deg (gdouble x);
 
 #ifndef __GI_SCANNER__
+#ifndef __GTK_DOC_IGNORE__
 #define gwy_isnan    _gwy_isnan_implementation
 #define gwy_isinf    _gwy_isinf_implementation
 #define gwy_isnormal _gwy_isnormal_implementation
@@ -289,35 +292,31 @@ gdouble gwy_rad2deg (gdouble x);
  *
  * An alternative may be gathering the detection code to some source compiled in IEEE standard-compliant mode. */
 
-/*
- * The empty comments fix gtk-doc.
- * See http://bugzilla.gnome.org/show_bug.cgi?id=481811
- */
 G_GNUC_UNUSED
 static inline int
 _gwy_isinf_implementation(double x)
 {
-    GDoubleIEEE754 /**/ dbl;
+    GDoubleIEEE754 dbl;
     dbl.v_double = x;
-    return /**/ (dbl.mpn.biased_exponent == 0x7ff && !dbl.mpn.mantissa_high && !dbl.mpn.mantissa_low);
+    return (dbl.mpn.biased_exponent == 0x7ff && !dbl.mpn.mantissa_high && !dbl.mpn.mantissa_low);
 }
 
 G_GNUC_UNUSED
 static inline int
 _gwy_isnan_implementation(double x)
 {
-    GDoubleIEEE754 /**/ dbl;
+    GDoubleIEEE754 dbl;
     dbl.v_double = x;
-    return /**/ (dbl.mpn.biased_exponent == 0x7ff && (dbl.mpn.mantissa_high || dbl.mpn.mantissa_low));
+    return (dbl.mpn.biased_exponent == 0x7ff && (dbl.mpn.mantissa_high || dbl.mpn.mantissa_low));
 }
 
 G_GNUC_UNUSED
 static inline int
 _gwy_isnormal_implementation(double x)
 {
-    GDoubleIEEE754 /**/ dbl;
+    GDoubleIEEE754 dbl;
     dbl.v_double = x;
-    return /**/ dbl.mpn.biased_exponent != 0x7ff;
+    return dbl.mpn.biased_exponent != 0x7ff;
 }
 
 G_GNUC_UNUSED
@@ -325,22 +324,22 @@ static inline gdouble
 _gwy_sinc_implementation(gdouble x)
 {
     if (G_LIKELY(fabs(x) > 3e-4))
-        return /**/ sin(x)/x;
-    return /**/ 1.0 - x*x/6.0;
+        return sin(x)/x;
+    return 1.0 - x*x/6.0;
 }
 
 G_GNUC_UNUSED
 static inline double
 _gwy_rad2deg_implementation(double x)
 {
-    return /**/ x/G_PI*180.0;
+    return x/G_PI*180.0;
 }
 
 G_GNUC_UNUSED
 static inline double
 _gwy_deg2rad_implementation(double x)
 {
-    return /**/ x/180.0*G_PI;
+    return x/180.0*G_PI;
 }
 
 #ifdef GWY_HAVE_EXP10
@@ -350,7 +349,7 @@ G_GNUC_UNUSED
 static inline double
 _gwy_exp10_implementation(double x)
 {
-    return /**/ exp(G_LN10 * x);
+    return exp(G_LN10 * x);
 }
 #endif
 
@@ -397,6 +396,7 @@ _gwy_powi_implementation(double x, int i)
 }
 #endif
 
+#endif
 #endif
 
 G_END_DECLS
