@@ -1,6 +1,6 @@
 /*
- *  $Id: mfm.c 28903 2025-11-24 15:49:51Z yeti-dn $
- *  Copyright (C) 2016-2023 David Necas (Yeti), Petr Klapetek.
+ *  $Id: mfm.c 29203 2026-01-14 13:37:36Z yeti-dn $
+ *  Copyright (C) 2016-202ž David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -271,48 +271,46 @@ mfm_perpendicular_create_field_mask(GwyField *fieldmask,
 
 /**
  * gwy_field_mfm_perpendicular_stray_field:
- * @mfield: Mask representing the magnetisation orientation.
+ * @mfield: Data field representing the magnetisation charge.
  * @out: Target data field to put the result to.  It will be resized to match @mfield.
  * @height: Height above the surface.
  * @thickness: Film thickness.
- * @sigma: Magnetic charge.
  * @walls: Include domain walls.
  * @wall_delta: Domain wall thickness
  *
  * Calculates stray field for perpendicular media, based on a mask showing the magnetisation orientation.
+ *
+ * The input field would often be filled with only two different values, -@sigma and +@sigma, depending on the domain
+ * orientation. However, it is not a requirement.
  **/
 void
 gwy_field_mfm_perpendicular_stray_field(GwyField *mfield,
                                         GwyField *out,
                                         gdouble height,
                                         gdouble thickness,
-                                        gdouble sigma,
                                         gboolean walls,
                                         gdouble wall_delta)
 {
-    GwyField *rea, *ima, *reb, *imb, *fieldmask, *wallmask = NULL;
-
     g_return_if_fail(GWY_IS_FIELD(mfield));
     g_return_if_fail(GWY_IS_FIELD(out));
 
-    rea = gwy_field_new_alike(mfield, TRUE);
-    reb = gwy_field_new_alike(mfield, TRUE);
-    ima = gwy_field_new_alike(mfield, TRUE);
-    imb = gwy_field_new_alike(mfield, TRUE);
-    fieldmask = gwy_field_new_alike(mfield, TRUE);
+    GwyField *rea = gwy_field_new_alike(mfield, TRUE);
+    GwyField *reb = gwy_field_new_alike(mfield, TRUE);
+    GwyField *ima = gwy_field_new_alike(mfield, TRUE);
+    GwyField *imb = gwy_field_new_alike(mfield, TRUE);
+    GwyField *fieldmask = gwy_field_new_alike(mfield, TRUE);
 
     gwy_field_copy_data(mfield, rea);
-    gwy_field_multiply(rea, 2*sigma);
-    gwy_field_add(rea, -sigma);
 
     if (walls) {
-        wallmask = gwy_field_new_alike(mfield, TRUE);
+        GwyField *wallmask = gwy_field_new_alike(mfield, TRUE);
         mfm_perpendicular_create_wall_mask(wallmask, wall_delta);
         gwy_field_area_ext_convolve(rea,
                                     0, 0,
                                     gwy_field_get_xres(rea), gwy_field_get_yres(rea),
                                     rea, wallmask,
                                     GWY_EXTERIOR_MIRROR, 0.0, FALSE);
+        g_object_unref(wallmask);
     }
 
     gwy_field_fft_2d_raw(rea, NULL, reb, imb, GWY_TRANSFORM_DIRECTION_FORWARD);
@@ -331,7 +329,6 @@ gwy_field_mfm_perpendicular_stray_field(GwyField *mfield,
     g_object_unref(ima);
     g_object_unref(imb);
     g_object_unref(fieldmask);
-    g_clear_object(&wallmask);
 }
 
 /**
