@@ -1,6 +1,6 @@
 /*
- *  $Id: nield.c 28968 2025-12-10 15:15:43Z yeti-dn $
- *  Copyright (C) 2025 David Necas (Yeti).
+ *  $Id: nield.c 29457 2026-02-11 10:35:29Z yeti-dn $
+ *  Copyright (C) 2025-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -184,7 +184,7 @@ gwy_nield_new(gint xres, gint yres)
 
 /**
  * gwy_nield_new_alike:
- * @model: A number field to take resolutions and units from.
+ * @model: A number field to take resolutions from.
  *
  * Creates a new number field similar to an existing one.
  *
@@ -202,6 +202,27 @@ gwy_nield_new_alike(GwyNield *model)
     return nield;
 }
 
+// We formally have it as a Field method, but it is more convenient to implement is as a Nield constructor.
+/**
+ * gwy_field_new_nield_alike:
+ * @field: A data field to take resolutions from.
+ *
+ * Creates a new number field with the same dimensions as a data field.
+ *
+ * The field is created as zero-filled.
+ *
+ * Returns: (transfer full):
+ *          A newly created number field.
+ **/
+GwyNield*
+gwy_field_new_nield_alike(GwyField *field)
+{
+    GwyNield *nield = g_object_new(GWY_TYPE_NIELD, NULL);
+    g_return_val_if_fail(GWY_IS_FIELD(field), nield);
+    alloc_data(nield, field->xres, field->yres, TRUE);
+    return nield;
+}
+
 /**
  * gwy_nield_data_changed:
  * @nield: A number field.
@@ -222,22 +243,19 @@ gwy_nield_data_changed(GwyNield *nield)
  *
  * Copies the contents of an already allocated number field to a number field of the same size.
  *
- * Only the data are copied.  To make a number field completely identical to another, including units and change of
- * dimensions, you can use gwy_nield_assign().
+ * Only the data are copied.  However, as #GwyNield currently does not have any additional properties, the function
+ * has the same effect as gwy_nield_assign().
  **/
 void
 gwy_nield_copy_data(GwyNield *nield, GwyNield *target)
 {
-    g_return_if_fail(GWY_IS_NIELD(nield));
-    g_return_if_fail(GWY_IS_NIELD(target));
-    g_return_if_fail(nield->xres == target->xres && nield->yres == target->yres);
-    if (nield == target)
+    if (!_gwy_nield_check_other(nield, target, FALSE) || target == nield)
         return;
 
     GwyNieldPrivate *priv = nield->priv, *tpriv = target->priv;
     gwy_assign(tpriv->data, priv->data, nield->xres*nield->yres);
     tpriv->cached = priv->cached;
-    gwy_assign(tpriv->cache, priv->cache, GWY_NIELD_CACHE_SIZE);
+    gwy_assign(tpriv->cache, priv->cache, GWY_NIELD_CACHE_size);
 }
 
 /**
@@ -551,6 +569,80 @@ gwy_nield_new_rotated_90(GwyNield *nield,
     return result;
 }
 
+/**
+ * gwy_nield_new_resampled:
+ * @nield: A number field.
+ * @xres: New number of columns.
+ * @yres: New number of rows.
+ *
+ * Resamples a number field.
+ *
+ * The result is always flattened (as in gwy_nield_flatten()). Pixels of the new number field which are covered by
+ * positive values by at least 1/2 are set to 1. Pixels covered from less than 1/2 are set to 0.
+ *
+ * Returns: (transfer full): A newly created number field.
+ **/
+GwyNield*
+gwy_nield_new_resampled(GwyNield *nield,
+                        gint xres,
+                        gint yres)
+{
+    g_return_val_if_fail(GWY_IS_NIELD(nield), NULL);
+    gint oldxres = nield->xres, oldyres = nield->yres;
+    if (xres == oldxres && yres == oldyres) {
+        nield = gwy_nield_copy(nield);
+        gwy_nield_flatten(nield);
+        return nield;
+    }
+
+    GwyNield *resampled = gwy_nield_new(xres, yres);
+    const gint *data = nield->priv->data;
+    gint *resdata = resampled->priv->data;
+
+    const gdouble qx = (gdouble)oldxres/xres, qy = (gdouble)oldyres/yres;
+    for (gint i = 0; i < yres; i++) {
+        gdouble yfrom = qy*i, yto = qy*(i + 1);
+        gint oldifrom = (gint)floor(yfrom), oldito = (gint)floor(yto) + 1;
+        oldito = MIN(oldito, oldyres);
+        for (gint j = 0; j < xres; j++) {
+            gdouble xfrom = qx*j, xto = qx*(j + 1);
+            gint oldjfrom = (gint)floor(xfrom), oldjto = (gint)floor(xto) + 1;
+            oldjto = MIN(oldjto, oldxres);
+            gdouble s = 0.0, w = 0.0;
+
+            for (gint oldi = oldifrom; oldi < oldito; oldi++) {
+                gdouble wy = 1.0;
+                /* Incomplete initial and terminal pixels (vertically). */
+                if (oldi == oldifrom && oldi < oldito-1)
+                    wy = oldifrom+1 - yfrom;
+                else if (oldi > oldifrom && oldi == oldito-1)
+                    wy = yto - (oldito-1);
+                /* Otherwise
+                 * (a) The entire contribution is from a single source pixel (vertically) which is larger than the
+                 *     target pixel. The weight is yto - yfrom but we do not need bother calculating it because there
+                 *     is no summation.
+                 * (b) The entire source pixel is contained in the target pixel (vertically), so the weight for this
+                 *     particular pixel is really 1. */
+
+                for (gint oldj = oldjfrom; oldj < oldjto; oldj++) {
+                    /* The same logic, horizontally. */
+                    gdouble wx = 1.0;
+                    if (oldj == oldjfrom && oldj < oldjto-1)
+                        wx = oldjfrom+1 - xfrom;
+                    else if (oldj > oldjfrom && oldj == oldjto-1)
+                        wx = xto - (oldjto-1);
+
+                    s += wx*wy*(data[oldi*oldxres + oldj] > 0);
+                    w += wx*wy;
+                }
+            }
+            resdata[i*xres + j] = (s/w >= 0.5);
+        }
+    }
+
+    return resampled;
+}
+
 static inline void
 invert_int_array_in_place(int *d, guint n)
 {
@@ -574,8 +666,8 @@ invert_int_array_in_place(int *d, guint n)
  **/
 void
 gwy_nield_flip(GwyNield *nield,
-                 gboolean xflipped,
-                 gboolean yflipped)
+               gboolean xflipped,
+               gboolean yflipped)
 {
     g_return_if_fail(GWY_IS_NIELD(nield));
     gint *data = nield->priv->data;
@@ -601,8 +693,9 @@ gwy_nield_flip(GwyNield *nield,
     else
         return;
 
-    /* No cached value changes */
-    nield->priv->cached &= NCBIT(MAX);
+    /* No cached value changes. However, renumbering would, in general, result in different numbers. So we cannot
+     * keep it cached. */
+    nield->priv->cached &= NCBIT(MAX) | NCBIT(COUNT);
 }
 
 /* Block sizes are measured in destination, in source, the dims are swapped. */
@@ -675,17 +768,21 @@ transpose_to(const GwyNield *source,
  **/
 void
 gwy_nield_transpose(GwyNield *src, GwyNield *dest,
-                  gboolean minor)
+                    gboolean minor)
 {
     g_return_if_fail(GWY_IS_NIELD(src));
     g_return_if_fail(GWY_IS_NIELD(dest));
 
-    gint xres = src->xres;
-    gint yres = src->yres;
+    gint xres = src->xres, yres = src->yres;
     alloc_data(dest, yres, xres, FALSE);
     transpose_to(src, 0, 0, xres, yres, dest, 0, 0);
     if (minor)
         invert_int_array_in_place(dest->priv->data, xres*yres);
+
+    /* No cached value changes. However, renumbering would, in general, result in different numbers. So we cannot
+     * keep it cached. */
+    gwy_assign(dest->priv->cache, src->priv->cache, GWY_NIELD_CACHE_size);
+    dest->priv->cached = src->priv->cached & (NCBIT(MAX) | NCBIT(COUNT));
 }
 
 /**
@@ -705,9 +802,9 @@ gwy_nield_transpose(GwyNield *src, GwyNield *dest,
  **/
 void
 gwy_nield_area_transpose(GwyNield *src,
-                       gint col, gint row, gint width, gint height,
-                       GwyNield *dest,
-                       gboolean minor)
+                         gint col, gint row, gint width, gint height,
+                         GwyNield *dest,
+                         gboolean minor)
 {
     if (!_gwy_nield_check_area(src, col, row, width, height, FALSE))
         return;
@@ -744,8 +841,9 @@ gwy_nield_fill(GwyNield *nield, gint value)
 static void
 set_cache_for_constant_nield(GwyNield *nield, gint value)
 {
-    nield->priv->cached = NCBIT(MAX);
+    nield->priv->cached = NCBIT(MAX) | NCBIT(COUNT);
     NCVAL(nield, MAX) = value;
+    NCVAL(nield, COUNT) = (value > 0 ? nield->xres*nield->yres : 0);
 }
 
 /**
@@ -772,11 +870,18 @@ gwy_nield_area_fill(GwyNield *nield,
         || !_gwy_nield_check_mask(nield, &mask, &mode))
         return;
 
+    gint xres = nield->xres, yres = nield->yres;
+    if (!mask && col == 0 && row == 0 && width == xres && height == yres) {
+        /* Prefills cache immediately. */
+        gwy_nield_fill(nield, value);
+        return;
+    }
+
     for (gint i = 0; i < height; i++) {
-        gint *drow = nield->priv->data + (row + i)*nield->xres + col;
+        gint *drow = nield->priv->data + (row + i)*xres + col;
 
         if (mask) {
-            const gint *mrow = mask->priv->data + (row + i)*mask->xres + col;
+            const gint *mrow = mask->priv->data + (row + i)*xres + col;
             for (gint j = 0; j < width; j++) {
                 if (nielded_included(mrow + j, mode))
                     drow[j] = value;
@@ -825,6 +930,13 @@ gwy_nield_area_clear(GwyNield *nield,
     if (!_gwy_nield_check_area(nield, col, row, width, height, TRUE))
         return;
 
+    gint xres = nield->xres, yres = nield->yres;
+    if (col == 0 && row == 0 && width == xres && height == yres) {
+        /* Prefills cache immediately. */
+        gwy_nield_clear(nield);
+        return;
+    }
+
     gwy_nield_invalidate(nield);
     if (height == 1 || (col == 0 && width == nield->xres)) {
         gwy_clear(nield->priv->data + nield->xres*row + col, width*height);
@@ -838,12 +950,12 @@ gwy_nield_area_clear(GwyNield *nield,
 }
 
 /**
- * gwy_field_get_max:
+ * gwy_field_max:
  * @nield: A number field.
  *
  * Finds the maximum value in a number field.
  *
- * This quantity is cached.
+ * This quantity is cached. Although it is not common, the return value can also be negative.
  *
  * Returns: The maximum value.
  **/
@@ -880,13 +992,19 @@ guint
 gwy_nield_count(GwyNield *nield)
 {
     g_return_val_if_fail(GWY_IS_NIELD(nield), 0);
-    const gint *d = nield->priv->data;
-    gint xres = nield->xres, yres = nield->yres;
-    gsize n = (gsize)xres * (gsize)yres;
-    guint count = 0;
-    for (gsize i = 0; i < n; i++)
-        count += (d[i] > 0);
-    return count;
+
+    if (!NCTEST(nield, COUNT)) {
+        const gint *d = nield->priv->data;
+        gint xres = nield->xres, yres = nield->yres;
+        gsize n = (gsize)xres * (gsize)yres;
+        guint count = 0;
+        for (gsize i = 0; i < n; i++)
+            count += (d[i] > 0);
+
+        NCVAL(nield, COUNT) = count;
+        nield->priv->cached |= NCBIT(COUNT);
+    }
+    return NCVAL(nield, COUNT);
 }
 
 /**
@@ -916,7 +1034,11 @@ gwy_nield_area_count(GwyNield *nield,
         || !_gwy_nield_check_mask(nield, &mask, &mode))
         return 0;
 
-    gint xres = nield->xres;
+    /* Use cache, if possible. */
+    gint xres = nield->xres, yres = nield->yres;
+    if (!mask && col == 0 && row == 0 && width == xres && height == yres)
+        return gwy_nield_count(nield);
+
     const gint *datapos = nield->priv->data + row*xres + col;
     guint count = 0;
     if (mask) {
@@ -1008,6 +1130,21 @@ _gwy_nield_check_field(GwyNield *nield,
     return TRUE;
 }
 
+gboolean
+_gwy_nield_check_other(GwyNield *nield,
+                       GwyNield *othernield,
+                       gboolean nullok)
+{
+    g_return_val_if_fail(GWY_IS_NIELD(nield), FALSE);
+    if (nullok && !othernield)
+        return TRUE;
+
+    g_return_val_if_fail(GWY_IS_NIELD(othernield), FALSE);
+    g_return_val_if_fail(othernield->xres == nield->xres, FALSE);
+    g_return_val_if_fail(othernield->yres == nield->yres, FALSE);
+    return TRUE;
+}
+
 static void
 serializable_itemize(GwySerializable *serializable, GwySerializableGroup *group)
 {
@@ -1062,7 +1199,7 @@ serializable_copy(GwySerializable *serializable)
     GwyNieldPrivate *priv = nield->priv, *cpriv = copy->priv;
     gwy_assign(cpriv->data, priv->data, nield->xres*nield->yres);
     cpriv->cached = priv->cached;
-    gwy_assign(cpriv->cache, priv->cache, GWY_NIELD_CACHE_SIZE);
+    gwy_assign(cpriv->cache, priv->cache, GWY_NIELD_CACHE_size);
     return GWY_SERIALIZABLE(copy);
 }
 
@@ -1075,7 +1212,7 @@ serializable_assign(GwySerializable *destination, GwySerializable *source)
     alloc_data(destnield, srcnield->xres, srcnield->yres, FALSE);
     gwy_nield_copy_data(srcnield, destnield);
     dpriv->cached = spriv->cached;
-    gwy_assign(dpriv->cache, spriv->cache, GWY_NIELD_CACHE_SIZE);
+    gwy_assign(dpriv->cache, spriv->cache, GWY_NIELD_CACHE_size);
 }
 
 /**
@@ -1138,6 +1275,17 @@ gwy_nield_invalidate(GwyNield *nield)
     nield->priv->cached = 0;
 }
 
+void
+_gwy_nield_fill_field_with_01(GwyNield *nield, GwyField *field)
+{
+    gint xres = nield->xres, yres = nield->yres;
+    gsize n = (gsize)xres * (gsize)yres;
+    const gint *m = nield->priv->data;
+    gdouble *f = field->priv->data;
+    for (gsize k = 0; k < n; k++)
+        f[k] = (m[k] > 0);
+}
+
 static GwyNield*
 create_uninitialized_nield(gint xres, gint yres)
 {
