@@ -1,5 +1,5 @@
 /*
- *  $Id: stats--acfpsdf.c 29062 2026-01-02 15:13:24Z yeti-dn $
+ *  $Id: stats--acfpsdf.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -75,7 +75,7 @@ gwy_field_area_func_fft(GwyField *field,
     if (orientation == GWY_ORIENTATION_VERTICAL) {
         for (i = 0; i < width; i++) {
             dcol = field->priv->data + row*xres + (i + col);
-            avg = gwy_field_area_get_avg(field, NULL, GWY_MASK_IGNORE, col+i, row, 1, height);
+            avg = gwy_field_area_mean(field, NULL, GWY_MASK_IGNORE, col+i, row, 1, height);
             for (j = 0; j < height; j++)
                 in[j] = dcol[j*xres] - avg;
             func(plan, din, dout, target_line);
@@ -86,7 +86,7 @@ gwy_field_area_func_fft(GwyField *field,
     else {
         for (i = 0; i < height; i++) {
             drow = field->priv->data + (i + row)*xres + col;
-            avg = gwy_field_area_get_avg(field, NULL, GWY_MASK_IGNORE, col, row+i, width, 1);
+            avg = gwy_field_area_mean(field, NULL, GWY_MASK_IGNORE, col, row+i, width, 1);
             for (j = 0; j < width; j++)
                 in[j] = drow[j] - avg;
             func(plan, din, dout, target_line);
@@ -294,8 +294,10 @@ gwy_field_area_ri_psdf_common(GwyField *field,
 
     gwy_field_fft_postprocess(re_field, TRUE);
     r = 0.5*MAX(re_field->xreal, re_field->yreal);
-    gwy_field_angular_average(re_field, NULL, GWY_MASK_IGNORE, target_line, 0.0, 0.0, r, *nstats ? *nstats+1 : -1);
+    GwyLine *rline = gwy_field_angular_average(re_field, NULL, GWY_MASK_IGNORE, 0.0, 0.0, r, *nstats ? *nstats+1 : -1);
     g_object_unref(re_field);
+    gwy_line_assign(target_line, rline);
+    g_object_unref(rline);
     /* Get rid of the zero first element which is bad for logscale. */
     *nstats = target_line->res-1;
     gwy_line_crop(target_line, 1, *nstats);
@@ -485,8 +487,10 @@ gwy_field_area_racf(GwyField *field,
     acf_field = gwy_field_new(2*size - 1, 2*size - 1, 1.0, 1.0, FALSE);
     gwy_field_area_acf_2d(field, NULL, GWY_MASK_IGNORE, acf_field, col, row, width, height, size, size, NULL);
     r = 0.5*MAX(acf_field->xreal, acf_field->yreal);
-    gwy_field_angular_average(acf_field, NULL, GWY_MASK_IGNORE, target_line, 0.0, 0.0, r, nstats);
+    GwyLine *rline = gwy_field_angular_average(acf_field, NULL, GWY_MASK_IGNORE, 0.0, 0.0, r, nstats);
     g_object_unref(acf_field);
+    gwy_line_assign(target_line, rline);
+    g_object_unref(rline);
 }
 
 /**
@@ -572,48 +576,6 @@ extract_2d_acf_real(GwyField *field,
  * @field: A data field.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @target_field: A data field to store the result to.  It will be resampled to (2@xrange-1)×(2@yrange-1).
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @xrange: Horizontal correlation range.  Non-positive value means the default range of half of @field width
- *          will be used.
- * @yrange: Vertical correlation range.  Non-positive value means the default range of half of @field height will
- *          be used.
- * @weights: (nullable):
- *           Field to store the denominators to (or %NULL).  It will be resized like @target_field.  The denominators
- *           are integers equal to the number of terms that contributed to each value.  They are suitable as fitting
- *           weights if the ACF is fitted.
- *
- * Calculates two-dimensional autocorrelation function of a data field area.
- *
- * The resulting data field has the correlation corresponding to (0,0) in the centre.
- *
- * The maximum possible values of @xrange and @yrange are @field width and height, respectively.  However, as the
- * values for longer distances are calculated from smaller number of data points they become increasingly bogus,
- * therefore the default range is half of the size.
- **/
-void
-gwy_field_area_acf_2d(GwyField *field,
-                      GwyField *mask,
-                      GwyMaskingType masking,
-                      GwyField *target,
-                      gint col, gint row,
-                      gint width, gint height,
-                      gint xrange, gint yrange,
-                      GwyField *weights)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gwy_NIELD_area_acf_2d(field, nield, masking, target, col, row, width, height, xrange, yrange, weights);
-    g_clear_object(&nield);
-}
-
-/**
- * gwy_NIELD_area_acf_2d:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
  * @target: A data field to store the result to.  It will be resampled to (2@xrange-1)×(2@yrange-1).
  * @col: Upper-left column coordinate.
  * @row: Upper-left row coordinate.
@@ -637,7 +599,7 @@ gwy_field_area_acf_2d(GwyField *field,
  * therefore the default range is half of the size.
  **/
 void
-gwy_NIELD_area_acf_2d(GwyField *field,
+gwy_field_area_acf_2d(GwyField *field,
                       GwyNield *mask,
                       GwyMaskingType masking,
                       GwyField *target,
@@ -647,7 +609,7 @@ gwy_NIELD_area_acf_2d(GwyField *field,
                       GwyField *weights)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return;
     g_return_if_fail(GWY_IS_FIELD(target));
     g_return_if_fail(!weights || GWY_IS_FIELD(weights));
@@ -742,7 +704,7 @@ gwy_NIELD_area_acf_2d(GwyField *field,
                 }
             }
         }
-        gwy_NIELD_laplace_solve(target, wmask, -1, 1.0);
+        gwy_field_laplace_solve(target, wmask, GWY_LAPLACE_MASKED, 1.0);
         g_object_unref(wmask);
     }
     else {
@@ -885,47 +847,6 @@ extract_2d_fft_cnorm(GwyField *target,
  * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
  * @windowing: Windowing type to use.
  * @level: The first polynomial degree to keep in the area; lower degrees than @level are subtracted.
- * @target_field: A data field to store the result to.  It will be resampled to @width×@height.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- *
- * Calculates two-dimensional power spectral density function of a data field area.
- *
- * The resulting data field has the spectral density corresponding zero frequency (0,0) in the centre.
- *
- * Only @level values 0 (no levelling) and 1 (subtract the mean value) and 2 (subtract the mean plane) are currently
- * available. For SPM data, you usually wish to pass 1.
- *
- * The reduction of the total energy by windowing is compensated by multiplying the PSDF to make its sum of squares
- * equal to the input data sum of squares.
- *
- * Do not assume the PSDF values are all positive, when masking is in effect. The PSDF should still have the correct
- * integral, but it will be contaminated with noise, both positive and negative.
- **/
-void
-gwy_field_area_psdf_2d(GwyField *field,
-                       GwyField *mask,
-                       GwyMaskingType masking,
-                       GwyField *target,
-                       gint col, gint row,
-                       gint width, gint height,
-                       GwyWindowingType windowing,
-                       gint level)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gwy_NIELD_area_psdf_2d(field, nield, masking, target, col, row, width, height, windowing, level);
-    g_clear_object(&nield);
-}
-
-/**
- * gwy_NIELD_area_psdf_2d:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @windowing: Windowing type to use.
- * @level: The first polynomial degree to keep in the area; lower degrees than @level are subtracted.
  * @target: A data field to store the result to.  It will be resampled to @width×@height.
  * @col: Upper-left column coordinate.
  * @row: Upper-left row coordinate.
@@ -946,7 +867,7 @@ gwy_field_area_psdf_2d(GwyField *field,
  * integral, but it will be contaminated with noise, both positive and negative.
  **/
 void
-gwy_NIELD_area_psdf_2d(GwyField *field,
+gwy_field_area_psdf_2d(GwyField *field,
                        GwyNield *mask,
                        GwyMaskingType masking,
                        GwyField *target,
@@ -956,7 +877,7 @@ gwy_NIELD_area_psdf_2d(GwyField *field,
                        gint level)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return;
     g_return_if_fail(GWY_IS_FIELD(target));
 
@@ -981,21 +902,21 @@ gwy_NIELD_area_psdf_2d(GwyField *field,
 
         if (level > 1) {
             gdouble avg, bx, by;
-            gwy_NIELD_area_fit_plane(target, target_mask, masking, 0, 0, width, height, &avg, &bx, &by);
+            gwy_field_area_fit_plane(target, target_mask, masking, 0, 0, width, height, &avg, &bx, &by);
             gwy_field_plane_level(target, avg, bx, by);
         }
         else if (level)
-            gwy_field_add(target, -gwy_NIELD_area_avg(target, target_mask, masking, 0, 0, width, height));
+            gwy_field_add(target, -gwy_field_area_mean(target, target_mask, masking, 0, 0, width, height));
 
-        gdouble rms = gwy_NIELD_area_rms(target, target_mask, masking, 0, 0, width, height);
+        gdouble rms = gwy_field_area_rms(target, target_mask, masking, 0, 0, width, height);
         gwy_field_fft_window(target, windowing);
 
-        gdouble newrms = gwy_NIELD_area_rms(target, target_mask, masking, 0, 0, width, height);
+        gdouble newrms = gwy_field_area_rms(target, target_mask, masking, 0, 0, width, height);
         if (newrms > 0.0)
             gwy_field_multiply(target, rms/newrms);
 
         /* Calculate unnormalised CACF of the mask, i.e. the denominators. */
-        gwy_field_area_fill_mask(buf, target_mask, 0, 0, width, height, 0.0, 1.0);
+        gwy_field_fill_mask(buf, target_mask, 0.0, 1.0);
         gwy_field_multiply_fields(target, buf, target);
 
         GwyField *weights = gwy_field_new_alike(target, FALSE);
@@ -1020,7 +941,7 @@ gwy_NIELD_area_psdf_2d(GwyField *field,
                 b[i] = 0.0;
             }
         }
-        gwy_NIELD_laplace_solve(buf, target_mask, -1, 1.0);
+        gwy_field_laplace_solve(buf, target_mask, GWY_LAPLACE_MASKED, 1.0);
         g_object_unref(target_mask);
 
         extract_2d_fft_real(target, plan, cbuf, cstride);
@@ -1041,11 +962,11 @@ gwy_NIELD_area_psdf_2d(GwyField *field,
             gwy_field_plane_level(target, avg, bx, by);
         }
         else if (level)
-            gwy_field_add(target, -gwy_field_get_avg(target));
+            gwy_field_add(target, -gwy_field_mean(target));
 
-        gdouble rms = gwy_field_get_rms(target);
+        gdouble rms = gwy_field_rms(target);
         gwy_field_fft_window(target, windowing);
-        gdouble newrms = gwy_field_get_rms(target);
+        gdouble newrms = gwy_field_rms(target);
         if (newrms > 0.0)
             gwy_field_multiply(target, rms/newrms);
 
@@ -1175,7 +1096,7 @@ gwy_field_psdf_to_angular_spectrum(GwyField *psdf,
 
     /* The result now has some weird normalisation depending on how we hit and missed the pixels.  Preserve the
      * integral which must be sigma^2 (but we only make half of the curve). */
-    wsum = gwy_field_get_sum(psdf) * xreal/xres * yreal/yres;
+    wsum = gwy_field_sum(psdf) * xreal/xres * yreal/yres;
     asum = gwy_line_sum(angspec) * 2.0*G_PI/nstats;
     if (asum > 0.0)
         gwy_line_multiply(angspec, wsum/asum);
@@ -1188,48 +1109,9 @@ gwy_field_psdf_to_angular_spectrum(GwyField *psdf,
 }
 
 /* Does not really belong here, but is is used only by functions from this source file, so... */
-
 /**
  * gwy_field_angular_average:
  * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to @nstats size.
- * @mask: (nullable): Mask of pixels to include from/exclude in the averaging, or %NULL for full @field.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @x: X-coordinate of the averaging disc origin, in real coordinates including offsets.
- * @y: Y-coordinate of the averaging disc origin, in real coordinates including offsets.
- * @r: Radius, in real coordinates.  It determines the real length of the resulting line.
- * @nstats: The number of samples the resulting line should have.  A non-positive value means the sampling will be
- *          determined automatically.
- *
- * Performs angular averaging of a part of a data field.
- *
- * The result of such averaging is an radial profile, starting from the disc centre.
- *
- * The function does not guarantee that @target_line will have exactly @nstats samples upon return.  A smaller number
- * of samples than requested may be calculated for instance if either central or outer part of the disc is excluded by
- * masking.
- **/
-void
-gwy_field_angular_average(GwyField *field,
-                          GwyField *mask,
-                          GwyMaskingType masking,
-                          GwyLine *target_line,
-                          gdouble x,
-                          gdouble y,
-                          gdouble r,
-                          gint nstats)
-{
-    g_return_if_fail(GWY_IS_LINE(target_line));
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *avgline = gwy_NIELD_angular_average(field, nield, masking, x, y, r, nstats);
-    g_clear_object(&nield);
-    gwy_line_assign(target_line, avgline);
-    g_object_unref(avgline);
-}
-
-/**
- * gwy_NIELD_angular_average:
- * @field: A data field.
  * @mask: (nullable): Mask of pixels to include from/exclude in the averaging, or %NULL for full @field.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
  * @x: X-coordinate of the averaging disc origin, in real coordinates including offsets.
@@ -1249,7 +1131,7 @@ gwy_field_angular_average(GwyField *field,
  * Returns: A new data line to with the distribution.
  **/
 GwyLine*
-gwy_NIELD_angular_average(GwyField *field,
+gwy_field_angular_average(GwyField *field,
                           GwyNield *mask,
                           GwyMaskingType masking,
                           gdouble x,
@@ -1259,7 +1141,7 @@ gwy_NIELD_angular_average(GwyField *field,
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), NULL);
     g_return_val_if_fail(r >= 0.0, NULL);
-    if (!_gwy_NIELD_check_mask(field, &mask, &masking))
+    if (!_gwy_field_check_mask(field, &mask, &masking))
         return NULL;
 
     gint xres = field->xres, yres = field->yres;
@@ -1475,7 +1357,7 @@ row_divide_nonzero_with_laplace(const gdouble *numerator,
     for (j = 0; j < size; j++)
         m[j] = (denominator[j] == 0);
 
-    gwy_line_correct_laplace(line, mask);
+    gwy_line_laplace_solve(line, mask);
     gwy_assign(out, line->priv->data, size);
 
     g_object_unref(line);
@@ -1725,7 +1607,6 @@ row_level_and_count(const gdouble *in,
                     guint maskrow,
                     guint level)
 {
-
     if (!mask || masking == GWY_MASK_IGNORE) {
         if (level > 1)
             row_level2(in, out, width);
@@ -1799,50 +1680,6 @@ set_cf_units(GwyField *field,
  **/
 GwyLine*
 gwy_field_area_row_acf(GwyField *field,
-                       GwyField *mask,
-                       GwyMaskingType masking,
-                       guint col, guint row,
-                       guint width, guint height,
-                       guint level,
-                       GwyLine *weights)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_area_row_acf(field, nield, masking, col, row, width, height, level, weights);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_row_acf:
- * @field: A two-dimensional data field.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @level: The first polynomial degree to keep in the rows, lower degrees than @level are subtracted.
- * @weights: (nullable):
- *           Line to store the denominators to (or %NULL).  It will be resized to match the returned line.  The
- *           denominators are integers equal to the number of terms that contributed to each value.  They are suitable
- *           as fitting weights if the ACF is fitted.
- *
- * Calculates the row-wise autocorrelation function (ACF) of a field.
- *
- * The calculated ACF has the natural number of points, i.e. @width.
- *
- * Masking is performed by omitting all terms that contain excluded pixels. Since different rows contain different
- * numbers of pixels, the resulting ACF values are calculated as a weighted sums where weight of each row's
- * contribution is proportional to the number of contributing terms.  In other words, the weighting is fair: each
- * contributing pixel has the same influence on the result.
- *
- * Only @level values 0 (no levelling) and 1 (subtract the mean value) and 2 (subtract the mean plane) are currently
- * available. For SPM data, you usually wish to pass 1.
- *
- * Returns: (transfer full): A new one-dimensional data line with the ACF.
- **/
-GwyLine*
-gwy_NIELD_area_row_acf(GwyField *field,
                        GwyNield *mask,
                        GwyMaskingType masking,
                        guint col, guint row,
@@ -1853,7 +1690,7 @@ gwy_NIELD_area_row_acf(GwyField *field,
     GwyLine *line = gwy_line_new(width, 1.0, TRUE);
 
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return line;
     g_return_val_if_fail(!weights || GWY_IS_LINE(weights), line);
 
@@ -1980,53 +1817,6 @@ normalise_window_square(gdouble *window, guint n)
  **/
 GwyLine*
 gwy_field_area_row_psdf(GwyField *field,
-                        GwyField *mask,
-                        GwyMaskingType masking,
-                        guint col, guint row,
-                        guint width, guint height,
-                        GwyWindowingType windowing,
-                        guint level)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_area_row_psdf(field, nield, masking, col, row, width, height, windowing, level);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_row_psdf:
- * @field: A two-dimensional data field.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @windowing: Windowing type to use.
- * @level: The first polynomial degree to keep in the rows; lower degrees than @level are subtracted.
- *
- * Calculates the row-wise power spectral density function (PSDF) of a rectangular part of a field.
- *
- * The calculated PSDF has the natural number of points that follows from DFT, i.e. @width/2+1.
- *
- * The reduction of the total energy by windowing is compensated by multiplying the PSDF to make its sum of squares
- * equal to the input data sum of squares.
- *
- * Masking is performed by omitting all terms that contain excluded pixels. Since different rows contain different
- * numbers of pixels, the resulting PSDF is calculated as a weighted sum where each row's weight is proportional to
- * the number of contributing pixels.  In other words, the weighting is fair: each contributing pixel has the same
- * influence on the result.
- *
- * Only @level values 0 (no levelling) and 1 (subtract the mean value) and 2 (subtract the mean plane) are currently
- * available. For SPM data, you usually wish to pass 1.
- *
- * Do not assume the PSDF values are all positive, when masking is in effect. The PSDF should still have the correct
- * integral, but it will be contaminated with noise, both positive and negative.
- *
- * Returns: (transfer full): A new one-dimensional data line with the PSDF.
- **/
-GwyLine*
-gwy_NIELD_area_row_psdf(GwyField *field,
                         GwyNield *mask,
                         GwyMaskingType masking,
                         guint col, guint row,
@@ -2037,7 +1827,7 @@ gwy_NIELD_area_row_psdf(GwyField *field,
     GwyLine *line = gwy_line_new(width, 1.0, TRUE);
 
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return line;
 
     fix_levelling_degree(&level);
@@ -2062,9 +1852,7 @@ gwy_NIELD_area_row_psdf(GwyField *field,
 
     gwy_clear(accum_data, size);
     gwy_clear(accum_mask, size);
-
-    for (guint j = 0; j < width; j++)
-        window[j] = 1.0;
+    gwy_math_fill(window, width, 1.0);
     gwy_fft_window(width, window, windowing);
     normalise_window_square(window, width);
     fftw_plan plan = gwy_fftw_plan_dft_r2c_1d(width, fftr, fftc, FFTW_DESTROY_INPUT | FFTW_ESTIMATE);
@@ -2158,50 +1946,6 @@ gwy_NIELD_area_row_psdf(GwyField *field,
  **/
 GwyLine*
 gwy_field_area_row_hhcf(GwyField *field,
-                        GwyField *mask,
-                        GwyMaskingType masking,
-                        guint col, guint row,
-                        guint width, guint height,
-                        guint level,
-                        GwyLine *weights)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_area_row_hhcf(field, nield, masking, col, row, width, height, level, weights);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_row_hhcf:
- * @field: A two-dimensional data field.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @level: The first polynomial degree to keep in the rows, lower degrees than @level are subtracted.
- * @weights: (nullable):
- *           Line to store the denominators to (or %NULL).  It will be resized to match the returned line.  The
- *           denominators are integers equal to the number of terms that contributed to each value.  They are suitable
- *           as fitting weights if the HHCF is fitted.
- *
- * Calculates the row-wise height-height correlation function (HHCF) of a rectangular part of a field.
- *
- * The calculated HHCF has the natural number of points, i.e. @width.
- *
- * Masking is performed by omitting all terms that contain excluded pixels. Since different rows contain different
- * numbers of pixels, the resulting HHCF values are calculated as a weighted sums where weight of each row's
- * contribution is proportional to the number of contributing terms.  In other words, the weighting is fair: each
- * contributing pixel has the same influence on the result.
- *
- * Only @level values 0 (no levelling) and 1 (subtract the mean value) and 2 (subtract the mean plane) are currently
- * available. For SPM data, you usually wish to pass 1.
- *
- * Returns: (transfer full): A new one-dimensional data line with the HHCF.
- **/
-GwyLine*
-gwy_NIELD_area_row_hhcf(GwyField *field,
                         GwyNield *mask,
                         GwyMaskingType masking,
                         guint col, guint row,
@@ -2212,7 +1956,7 @@ gwy_NIELD_area_row_hhcf(GwyField *field,
     GwyLine *line = gwy_line_new(width, 1.0, TRUE);
 
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return line;
     g_return_val_if_fail(!weights || GWY_IS_LINE(weights), line);
 
@@ -2361,51 +2105,13 @@ asg_correction(gdouble ex)
  **/
 GwyLine*
 gwy_field_area_row_asg(GwyField *field,
-                       GwyField *mask,
-                       GwyMaskingType masking,
-                       guint col, guint row,
-                       guint width, guint height,
-                       guint level)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    GwyLine *retval = gwy_NIELD_area_row_asg(field, nield, masking, col, row, width, height, level);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_row_asg:
- * @field: A two-dimensional data field.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @level: The first polynomial degree to keep in the rows, lower degrees than @level are subtracted.
- *
- * Calculates the row-wise area scale graph (ASG) of a rectangular part of a field.
- *
- * The calculated ASG has the natural number of points, i.e. @width-1.
- *
- * The ASG represents the apparent area excess (ratio of surface and projected area minus one) observed at given
- * length scale.  The quantity calculated by this function serves a similar purpose as ASME B46.1 area scale graph but
- * is defined differently, based on the HHCF.  See gwy_field_area_row_hhcf() for details of its calculation.
- *
- * Only @level values 0 (no levelling) and 1 (subtract the mean value) and 2 (subtract the mean plane) are currently
- * available. For SPM data, you usually wish to pass 1.
- *
- * Returns: (transfer full): A new one-dimensional data line with the ASG.
- **/
-GwyLine*
-gwy_NIELD_area_row_asg(GwyField *field,
                        GwyNield *mask,
                        GwyMaskingType masking,
                        guint col, guint row,
                        guint width, guint height,
                        guint level)
 {
-    GwyLine *hhcf = gwy_NIELD_area_row_hhcf(field, mask, masking, col, row, width, height, level, NULL);
+    GwyLine *hhcf = gwy_field_area_row_hhcf(field, mask, masking, col, row, width, height, level, NULL);
     g_return_val_if_fail(hhcf, NULL);
 
     guint res = hhcf->res;
