@@ -1,5 +1,5 @@
 /*
- *  $Id: stats--entropy.c 28935 2025-12-02 14:04:43Z yeti-dn $
+ *  $Id: stats--entropy.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -373,124 +373,12 @@ bin_tree_entropies_at_scales(BinTree *btree, guint maxdepth)
 
 static gdouble*
 calculate_entropy_at_scales(GwyField *dfield,
-                            GwyField *mask,
+                            GwyNield *mask,
                             GwyMaskingType mode,
                             gint col, gint row,
                             gint width, gint height,
                             guint *maxdiv,
                             gdouble *S)
-{
-    gint xres;
-    guint i, j, n;
-    gdouble *xdata;
-    const gdouble *base;
-    gboolean must_free_xdata = TRUE;
-    gdouble *ecurve;
-    BinTree *btree;
-
-    if (mask) {
-        gwy_field_area_count_in_range(mask, NULL, GWY_MASK_IGNORE,
-                                      col, row, width, height, G_MAXDOUBLE, 1.0, NULL, &n);
-        if (mode == GWY_MASK_EXCLUDE)
-            n = width*height - n;
-    }
-    else
-        n = width*height;
-
-    if (!*maxdiv) {
-        if (n >= 2)
-            *maxdiv = (guint)floor(3.0*log(n)/G_LN2 + 1e-12);
-        else
-            *maxdiv = 2;
-
-        /* We will run out of significant digits in coordinates after that. */
-        *maxdiv = MIN(*maxdiv, 50);
-    }
-
-    if (n < 2) {
-        ecurve = g_new(gdouble, *maxdiv+1);
-        for (i = 0; i <= *maxdiv; i++)
-            ecurve[i] = -G_MAXDOUBLE;
-        if (S)
-            *S = -G_MAXDOUBLE;
-        return ecurve;
-    }
-
-    xres = dfield->xres;
-    base = dfield->priv->data + row*xres + col;
-    if (n == xres*dfield->yres) {
-        /* Handle the full-field case without allocating anything. */
-        xdata = dfield->priv->data;
-        must_free_xdata = FALSE;
-    }
-    else {
-        xdata = g_new(gdouble, n);
-        if (mask) {
-            const gdouble *mbase = mask->priv->data + row*xres + col;
-            const gboolean invert = (mode == GWY_MASK_EXCLUDE);
-            guint k = 0;
-
-            for (i = 0; i < height; i++) {
-                const gdouble *d = base + i*xres;
-                const gdouble *m = mbase + i*xres;
-                for (j = width; j; j--, d++, m++) {
-                    if ((*m < 1.0) == invert)
-                        xdata[k++] = *d;
-                }
-            }
-            g_assert(k == n);
-        }
-        else {
-            for (i = 0; i < height; i++)
-                gwy_assign(xdata + i*width, base + i*xres, width);
-        }
-    }
-
-    /* FIXME: How can we parallelise this mess?
-     * Trees covering overlapping (or the same) intervals are lots of work to merge.  Processing them separately is
-     * possible, but then we hit different number of add_estimated_unsplit_node_entropy() depending on the number of
-     * threads.
-     *
-     * So one option is add a gwy_math_kth_ranks() preprocessing.  It finds the values that split the data to equal
-     * chunks.  And not only that, it also physically splits them, so each chunk becomes a continuous block in the
-     * array.  Neat!
-     *
-     * So each thread can construct its own, independent tree.  However, the result still depends on the number of
-     * threads because the bin boundaries are not the same as for serial processing.
-     *
-     * For deterministic results each thread must essentially construct exactly one branch of the tree.  We must
-     * assign an interval of the input of length (max-min)/2^n for some n and also at position corresponding to
-     * a branch.  Then we just merge the branches to form a common root.
-     *
-     * Splitting the work reasonably requires a fair amount of initial analysis.   The result could be for instance
-     * that if we have 6 threads they should process 1/4, 1/4, 1/16, 1/16, 1/8 and 1/4 of the entire interval of
-     * values.
-     *
-     * For a key commonly used function it may be woth implementing this. Here, it is hardly a priority. */
-    btree = bin_tree_new(xdata, n, *maxdiv);
-    if (must_free_xdata)
-        g_free(xdata);
-
-    ecurve = bin_tree_entropies_at_scales(btree, *maxdiv);
-    if (S) {
-        if (btree->degenerate)
-            *S = btree->degenerateS;
-        else
-            *S = calculate_entropy_from_scaling(ecurve, *maxdiv);
-    }
-    bin_tree_free(btree);
-
-    return ecurve;
-}
-
-static gdouble*
-calculate_entropy_at_scales_NIELD(GwyField *dfield,
-                                  GwyNield *mask,
-                                  GwyMaskingType mode,
-                                  gint col, gint row,
-                                  gint width, gint height,
-                                  guint *maxdiv,
-                                  gdouble *S)
 {
     guint n;
     gdouble *xdata;
@@ -592,7 +480,7 @@ calculate_entropy_at_scales_NIELD(GwyField *dfield,
 }
 
 /**
- * gwy_field_area_get_entropy_at_scales:
+ * gwy_field_area_entropy_at_scales:
  * @field: A data field.
  * @target_line: A data line to store the result to.  It will be resampled to @maxdiv+1 items.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
@@ -608,60 +496,7 @@ calculate_entropy_at_scales_NIELD(GwyField *dfield,
  * Returns: The best estimate, as gwy_field_area_get_entropy().
  **/
 gdouble
-gwy_field_area_get_entropy_at_scales(GwyField *field,
-                                     GwyField *mask,
-                                     GwyMaskingType masking,
-                                     GwyLine *target_line,
-                                     gint col, gint row,
-                                     gint width, gint height,
-                                     gint maxdiv)
-{
-    guint umaxdiv = (maxdiv > 0 ? maxdiv : 0);
-    gdouble *ecurve;
-    gdouble min, max, S = -G_MAXDOUBLE;
-    gint i;
-
-    if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_field_check_mask(field, &mask, &masking))
-        return S;
-    g_return_val_if_fail(GWY_IS_LINE(target_line), S);
-
-    ecurve = calculate_entropy_at_scales(field, mask, masking, col, row, width, height, &umaxdiv, &S);
-    maxdiv = maxdiv ? maxdiv : umaxdiv + 1;
-    gwy_line_resize(target_line, maxdiv);
-    target_line->real = maxdiv*G_LN2;
-    for (i = 0; i < maxdiv; i++)
-        target_line->priv->data[maxdiv-1 - i] = ecurve[i];
-    g_free(ecurve);
-
-    gwy_field_area_get_min_max(field, mask, masking, col, row, width, height, &min, &max);
-    if (max > min)
-        target_line->off = log(max - min) - (maxdiv - 0.5)*G_LN2;
-
-    gwy_unit_clear(gwy_line_get_unit_x(target_line));
-    gwy_unit_clear(gwy_line_get_unit_y(target_line));
-
-    return S;
-}
-
-/**
- * gwy_NIELD_area_entropy_at_scales:
- * @field: A data field.
- * @target_line: A data line to store the result to.  It will be resampled to @maxdiv+1 items.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @maxdiv: Maximum number of divisions of the value range.  Pass zero to choose it automatically.
- *
- * Calculates estimates of value distribution entropy at various scales.
- *
- * Returns: The best estimate, as gwy_field_area_get_entropy().
- **/
-gdouble
-gwy_NIELD_area_entropy_at_scales(GwyField *field,
+gwy_field_area_entropy_at_scales(GwyField *field,
                                  GwyNield *mask,
                                  GwyMaskingType masking,
                                  GwyLine *target_line,
@@ -672,12 +507,12 @@ gwy_NIELD_area_entropy_at_scales(GwyField *field,
     gdouble S = -G_MAXDOUBLE;
 
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return S;
     g_return_val_if_fail(GWY_IS_LINE(target_line), S);
 
     guint umaxdiv = (maxdiv > 0 ? maxdiv : 0);
-    gdouble *ecurve = calculate_entropy_at_scales_NIELD(field, mask, masking, col, row, width, height, &umaxdiv, &S);
+    gdouble *ecurve = calculate_entropy_at_scales(field, mask, masking, col, row, width, height, &umaxdiv, &S);
     maxdiv = maxdiv ? maxdiv : umaxdiv + 1;
     gwy_line_resize(target_line, maxdiv);
     target_line->real = maxdiv*G_LN2;
@@ -686,7 +521,7 @@ gwy_NIELD_area_entropy_at_scales(GwyField *field,
     g_free(ecurve);
 
     gdouble min, max;
-    gwy_NIELD_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
+    gwy_field_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
     if (max > min)
         target_line->off = log(max - min) - (maxdiv - 0.5)*G_LN2;
 
@@ -696,7 +531,7 @@ gwy_NIELD_area_entropy_at_scales(GwyField *field,
     return S;
 }
 /**
- * gwy_field_get_entropy:
+ * gwy_field_entropy:
  * @field: A data field.
  *
  * Computes the entropy of a data field.
@@ -708,7 +543,7 @@ gwy_NIELD_area_entropy_at_scales(GwyField *field,
  * Returns: The value distribution entropy.
  **/
 gdouble
-gwy_field_get_entropy(GwyField *field)
+gwy_field_entropy(GwyField *field)
 {
     gdouble S = -G_MAXDOUBLE;
     gdouble *ecurve;
@@ -720,8 +555,7 @@ gwy_field_get_entropy(GwyField *field)
     if (FCTEST(field, ENT))
         return FCVAL(field, ENT);
 
-    ecurve = calculate_entropy_at_scales_NIELD(field, NULL, GWY_MASK_IGNORE, 0, 0, field->xres, field->yres,
-                                               &maxdiv, &S);
+    ecurve = calculate_entropy_at_scales(field, NULL, GWY_MASK_IGNORE, 0, 0, field->xres, field->yres, &maxdiv, &S);
     g_free(ecurve);
 
     FCVAL(field, ENT) = S;
@@ -731,7 +565,7 @@ gwy_field_get_entropy(GwyField *field)
 }
 
 /**
- * gwy_field_area_get_entropy:
+ * gwy_field_area_entropy:
  * @field: A data field.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
@@ -753,53 +587,7 @@ gwy_field_get_entropy(GwyField *field)
  *          -%G_MAXDOUBLE.
  **/
 gdouble
-gwy_field_area_get_entropy(GwyField *field,
-                           GwyField *mask,
-                           GwyMaskingType masking,
-                           gint col, gint row,
-                           gint width, gint height)
-{
-    gdouble S = -G_MAXDOUBLE;
-    gdouble *ecurve;
-    guint maxdiv = 0;
-
-    if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_field_check_mask(field, &mask, &masking))
-        return S;
-
-    /* The result is the same, but it can be cached. */
-    if (!mask && row == 0 && col == 0 && width == field->xres && height == field->yres)
-        return gwy_field_get_entropy(field);
-
-    ecurve = calculate_entropy_at_scales(field, mask, masking, col, row, width, height, &maxdiv, &S);
-    g_free(ecurve);
-    return S;
-}
-
-/**
- * gwy_NIELD_area_entropy:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- *
- * Estimates the entropy of field data distribution.
- *
- * The estimate is calculated as @S = ln(@n Δ) − 1/@n ∑ @n_i ln(@n_i), where @n is the number of pixels considered,
- * Δ the bin size and @n_i the count in the @i-th bin.  If @S is plotted as a function of the bin size Δ, it is,
- * generally, a growing function with a plateau for ‘reasonable’ bin sizes. The estimate is taken at the plateau.  If
- * no plateau is found, which means the distribution is effectively a sum of δ-functions, -%G_MAXDOUBLE is returned.
- *
- * It should be noted that this estimate may be biased.
- *
- * Returns: The estimated entropy of the data values.  The entropy of no data or a single single is returned as
- *          -%G_MAXDOUBLE.
- **/
-gdouble
-gwy_NIELD_area_entropy(GwyField *field,
+gwy_field_area_entropy(GwyField *field,
                        GwyNield *mask,
                        GwyMaskingType masking,
                        gint col, gint row,
@@ -807,15 +595,15 @@ gwy_NIELD_area_entropy(GwyField *field,
 {
     gdouble S = -G_MAXDOUBLE;
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return S;
 
     /* The result is the same, but it can be cached. */
     if (!mask && row == 0 && col == 0 && width == field->xres && height == field->yres)
-        return gwy_field_get_entropy(field);
+        return gwy_field_entropy(field);
 
     guint maxdiv = 0;
-    gdouble *ecurve = calculate_entropy_at_scales_NIELD(field, mask, masking, col, row, width, height, &maxdiv, &S);
+    gdouble *ecurve = calculate_entropy_at_scales(field, mask, masking, col, row, width, height, &maxdiv, &S);
     g_free(ecurve);
     return S;
 }
@@ -1132,7 +920,7 @@ calculate_entropy_2d_at_scales(GwyField *xfield,
 }
 
 /**
- * gwy_field_get_entropy_2d_at_scales:
+ * gwy_field_entropy_2d_at_scales:
  * @xfield: A data field containing the @x-coordinates.
  * @yfield: A data field containing the @y-coordinates.
  * @target_line: A data line to store the result to.  It will be resampled to @maxdiv+1 items.
@@ -1140,25 +928,23 @@ calculate_entropy_2d_at_scales(GwyField *xfield,
  *
  * Calculates estimates of entropy of two-dimensional point cloud at various scales.
  *
- * Returns: The best estimate, as gwy_field_get_entropy_2d().
+ * Returns: The best estimate, as gwy_field_entropy_2d().
  **/
 gdouble
-gwy_field_get_entropy_2d_at_scales(GwyField *xfield,
-                                   GwyField *yfield,
-                                   GwyLine *target_line,
-                                   gint maxdiv)
+gwy_field_entropy_2d_at_scales(GwyField *xfield,
+                               GwyField *yfield,
+                               GwyLine *target_line,
+                               gint maxdiv)
 {
+    if (!_gwy_field_check_other(xfield, yfield, FALSE))
+        return -G_MAXDOUBLE;
+    g_return_val_if_fail(GWY_IS_LINE(target_line), -G_MAXDOUBLE);
+
     guint umaxdiv = (maxdiv > 0 ? maxdiv/2 : 0);
     gdouble *ecurve;
     gdouble xmin, xmax, ymin, ymax, S = -G_MAXDOUBLE;
     gint i;
 
-    g_return_val_if_fail(GWY_IS_FIELD(xfield), S);
-    g_return_val_if_fail(GWY_IS_FIELD(yfield), S);
-    g_return_val_if_fail(GWY_IS_LINE(target_line), S);
-    g_return_val_if_fail(xfield->xres == yfield->xres, S);
-    g_return_val_if_fail(xfield->yres == yfield->yres, S);
-
     ecurve = calculate_entropy_2d_at_scales(xfield, yfield, &umaxdiv, &S);
     maxdiv = maxdiv ? maxdiv : 2*umaxdiv + 1;
     gwy_line_resize(target_line, maxdiv);
@@ -1167,8 +953,8 @@ gwy_field_get_entropy_2d_at_scales(GwyField *xfield,
         target_line->priv->data[maxdiv-1 - i] = ecurve[i];
     g_free(ecurve);
 
-    gwy_field_get_min_max(xfield, &xmin, &xmax);
-    gwy_field_get_min_max(xfield, &ymin, &ymax);
+    gwy_field_min_max(xfield, &xmin, &xmax);
+    gwy_field_min_max(xfield, &ymin, &ymax);
     if ((xmax > xmin) && (ymax > ymin))
         target_line->off = (log((xmax - xmin)*(ymax - ymin)) - (maxdiv - 0.5)*G_LN2);
 
@@ -1179,7 +965,7 @@ gwy_field_get_entropy_2d_at_scales(GwyField *xfield,
 }
 
 /**
- * gwy_field_get_entropy_2d:
+ * gwy_field_entropy_2d:
  * @xfield: A data field containing the @x-coordinates.
  * @yfield: A data field containing the @y-coordinates.
  *
@@ -1191,18 +977,15 @@ gwy_field_get_entropy_2d_at_scales(GwyField *xfield,
  * Returns: The two-dimensional distribution entropy.
  **/
 gdouble
-gwy_field_get_entropy_2d(GwyField *xfield,
-                         GwyField *yfield)
+gwy_field_entropy_2d(GwyField *xfield, GwyField *yfield)
 {
+    if (!_gwy_field_check_other(xfield, yfield, FALSE))
+        return -G_MAXDOUBLE;
+
     gdouble *ecurve;
     guint maxdiv = 0;
     gdouble S = -G_MAXDOUBLE;
 
-    g_return_val_if_fail(GWY_IS_FIELD(xfield), S);
-    g_return_val_if_fail(GWY_IS_FIELD(yfield), S);
-    g_return_val_if_fail(xfield->xres == yfield->xres, S);
-    g_return_val_if_fail(xfield->yres == yfield->yres, S);
-
     ecurve = calculate_entropy_2d_at_scales(xfield, yfield, &maxdiv, &S);
     g_free(ecurve);
 
