@@ -1,6 +1,6 @@
 /*
- *  $Id: stats--minkowski.c 28986 2025-12-12 17:15:25Z yeti-dn $
- *  Copyright (C) 2009-2025 David Nečas (Yeti).
+ *  $Id: stats--minkowski.c 29550 2026-02-27 09:08:17Z yeti-dn $
+ *  Copyright (C) 2009-2026 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -34,7 +34,9 @@ sanitise_range(gdouble *min,
         return;
     if (*max) {
         gdouble d = fabs(*max);
-        *max += 0.1*d;
+        // Break the symmetry in whatever way, but consistently. Otherwise we would be comparing the same numbers
+        // to themselves, just obtained differently, and be completely at mercy of rounding errors.
+        *max += 0.11*d;
         *min -= 0.1*d;
         return;
     }
@@ -72,7 +74,7 @@ minkowski_volume(GwyField *field,
         return NULL;
 
     if (!(min < max))
-        gwy_NIELD_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
+        gwy_field_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
     sanitise_range(&min, &max);
 
     if (!npoints)
@@ -142,7 +144,7 @@ count_edges(GwyField *field,
             gdouble *pmin, gdouble *pmax)
 {
     if (masking == GWY_MASK_IGNORE) {
-        gwy_NIELD_area_min_max(field, NULL, GWY_MASK_IGNORE, col, row, width, height, pmin, pmax);
+        gwy_field_area_min_max(field, NULL, GWY_MASK_IGNORE, col, row, width, height, pmin, pmax);
         return 2*width*height - width - height;
     }
 
@@ -537,11 +539,10 @@ grain_number_dist(GwyField *field,
                 grains[k] = ngrains++;
                 continue;
             }
-
         }
 
-        // Resolve remaining grain number links in the map.  This nicely works
-        // because we resolve downwards and go from the lowest number.
+        // Resolve remaining grain number links in the map.  This nicely works because we resolve downwards and go
+        // from the lowest number.
         guint count = 0;
         for (guint i = 1; i < ngrains; i++) {
             m[i] = m[m[i]];
@@ -600,7 +601,7 @@ minkowski_ngrains(GwyField *field,
                   gdouble min, gdouble max)
 {
     if (!(min < max))
-        gwy_NIELD_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
+        gwy_field_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
     sanitise_range(&min, &max);
 
     return grain_number_dist(field, mask, masking, col, row, width, height, white, npoints, min, max);
@@ -616,7 +617,7 @@ minkowski_connectivity(GwyField *field,
                        gdouble min, gdouble max)
 {
     if (!(min < max))
-        gwy_NIELD_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
+        gwy_field_area_min_max(field, mask, masking, col, row, width, height, &min, &max);
     sanitise_range(&min, &max);
 
     GwyLine *whitedist = grain_number_dist(field, mask, masking, col, row, width, height, TRUE, npoints, min, max);
@@ -631,6 +632,28 @@ minkowski_connectivity(GwyField *field,
     return whitedist;
 }
 
+/**
+ * gwy_field_minkowski:
+ * @field: A two-dimensional data field.
+ * @type: Type of functional to calculate.
+ * @nstats: Resolution, i.e. the number of returned line points. Pass zero to choose a suitable resolution
+ *          automatically.
+ *
+ * Calculates a Minkowski functional of a data field.
+ *
+ * Returns: (transfer full):
+ *          A new one-dimensional data line with the requested functional.
+ **/
+GwyLine*
+gwy_field_minkowski(GwyField *field,
+                    GwyMinkowskiFunctional type,
+                    gint nstats)
+{
+    g_return_val_if_fail(GWY_IS_FIELD(field), NULL);
+    return gwy_field_area_minkowski(field, NULL, GWY_MASK_IGNORE, 0, 0, field->xres, field->yres,
+                                    type, nstats, G_MAXDOUBLE, -G_MAXDOUBLE);
+}
+
 /**
  * gwy_field_area_minkowski:
  * @field: A two-dimensional data field.
@@ -642,14 +665,17 @@ minkowski_connectivity(GwyField *field,
  * @height: Area height (number of rows).
  * @type: Type of functional to calculate.
  * @nstats: Resolution, i.e. the number of returned line points. Pass zero to choose a suitable resolution
- *           automatically.
+ *          automatically.
  * @min: Minimum value of the range to calculate the distribution in.
  * @max: Maximum value of the range to calculate the distribution in.
  *
- * Calculates given Minkowski functional of values in a field.
+ * Calculates a Minkowski functional of a part of a data field.
  *
  * Pass @max <= @min to calculate the functional in the full data range (with masking still considered).
  *
+ * If the area contains no pixels to consider due to masking, a valid but useless #GwyLine is returned. It is best to
+ * check the number of pixels with gwy_nield_area_count().
+ *
  * Returns: (transfer full):
  *          A new one-dimensional data line with the requested functional.
  **/
@@ -664,7 +690,7 @@ gwy_field_area_minkowski(GwyField *field,
                          gdouble min, gdouble max)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, TRUE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return NULL;
 
     // Cannot determine nstats here, it depends on the functional. But pass 0 in place of negative values since the
@@ -687,165 +713,17 @@ gwy_field_area_minkowski(GwyField *field,
         return NULL;
     }
 
+    if (!line) {
+        sanitise_range(&min, &max);
+        line = gwy_line_new(1, max-min, TRUE);
+        line->off = min;
+    }
+
     gwy_unit_assign(gwy_line_get_unit_x(line), gwy_field_get_unit_z(field));
 
     return line;
 }
 
-/**
- * gwy_field_area_minkowski_volume:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski volume functional of a rectangular part of a data field.
- *
- * Volume functional is calculated as the number of values above each threshold value (,white pixels`) divided by the
- * total number of samples in the area.  Is it's equivalent to 1-CDH.
- **/
-void
-gwy_field_area_minkowski_volume(GwyField *field,
-                                GwyLine *target_line,
-                                gint col, gint row,
-                                gint width, gint height,
-                                gint nstats)
-{
-    gwy_NIELD_area_height_dist(field, NULL, GWY_MASK_IGNORE, target_line, col, row, width, height, nstats);
-    gwy_line_cumulate(target_line, TRUE);
-    gwy_line_multiply(target_line, -1.0);
-    gwy_line_add(target_line, 1.0);
-}
-
-/**
- * gwy_field_minkowski_volume:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski volume functional of a data field.
- *
- * See gwy_field_area_minkowski_volume() for details.
- **/
-void
-gwy_field_minkowski_volume(GwyField *field,
-                           GwyLine *target_line,
-                           gint nstats)
-{
-    gwy_field_dh(field, target_line, nstats);
-    gwy_line_cumulate(target_line, TRUE);
-    gwy_line_multiply(target_line, -1.0);
-    gwy_line_add(target_line, 1.0);
-}
-
-/**
- * gwy_field_area_minkowski_boundary:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski boundary functional of a rectangular part of a data field.
- *
- * Boundary functional is calculated as the number of boundaries for each threshold value (the number of pixel sides
- * where of neighouring pixels is ,white` and the other ,black`) divided by the total number of samples in the area.
- **/
-void
-gwy_field_area_minkowski_boundary(GwyField *field,
-                                  GwyLine *target_line,
-                                  gint col, gint row,
-                                  gint width, gint height,
-                                  gint nstats)
-{
-    GwyLine *line = gwy_field_area_minkowski(field, NULL, GWY_MASK_IGNORE, col, row, width, height,
-                                             GWY_MINKOWSKI_BOUNDARY, nstats, G_MAXDOUBLE, G_MINDOUBLE);
-    if (line) {
-        gwy_line_assign(target_line, line);
-        g_object_unref(line);
-    }
-}
-
-/**
- * gwy_field_minkowski_boundary:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski boundary functional of a data field.
- *
- * See gwy_field_area_minkowski_boundary() for details.
- **/
-void
-gwy_field_minkowski_boundary(GwyField *field,
-                             GwyLine *target_line,
-                             gint nstats)
-{
-    g_return_if_fail(GWY_IS_FIELD(field));
-    gwy_field_area_minkowski_boundary(field, target_line, 0, 0, field->xres, field->yres, nstats);
-}
-
-/**
- * gwy_field_area_minkowski_euler:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski connectivity functional (Euler characteristics) of a rectangular part of a data field.
- *
- * Connectivity functional is calculated as the number connected areas of pixels above threhsold (,white`) minus the
- * number of connected areas of pixels below threhsold (,black`) for each threshold value, divided by the total number
- * of samples in the area.
- **/
-void
-gwy_field_area_minkowski_euler(GwyField *field,
-                               GwyLine *target_line,
-                               gint col, gint row,
-                               gint width, gint height,
-                               gint nstats)
-{
-    GwyLine *line = gwy_field_area_minkowski(field, NULL, GWY_MASK_IGNORE, col, row, width, height,
-                                             GWY_MINKOWSKI_CONNECTIVITY, nstats, G_MAXDOUBLE, G_MINDOUBLE);
-    if (line) {
-        gwy_line_assign(target_line, line);
-        g_object_unref(line);
-    }
-}
-
-/**
- * gwy_field_minkowski_euler:
- * @field: A data field.
- * @target_line: A data line to store the distribution to.  It will be resampled to requested width.
- * @nstats: The number of samples to take on the distribution function.  If nonpositive, a suitable resolution is
- *          determined automatically.
- *
- * Calculates Minkowski connectivity functional (Euler characteristics) of a data field.
- *
- * See gwy_field_area_minkowski_euler() for details.
- **/
-void
-gwy_field_minkowski_euler(GwyField *field,
-                          GwyLine *target_line,
-                          gint nstats)
-{
-    g_return_if_fail(GWY_IS_FIELD(field));
-    gwy_field_area_minkowski_euler(field, target_line, 0, 0, field->xres, field->yres, nstats);
-}
-
 /**
  * GwyMinkowskiFunctional:
  * @GWY_MINKOWSKI_VOLUME: Fraction of ‘white’ pixels from the total number of pixels.
