@@ -1,5 +1,5 @@
 /*
- *  $Id: stats--sum.c 28955 2025-12-05 19:17:51Z yeti-dn $
+ *  $Id: stats--sum.c 29439 2026-02-05 08:28:47Z yeti-dn $
  *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -21,7 +21,7 @@
 #include "libgwyddion/macros.h"
 #include "libgwyddion/field.h"
 #include "libgwyddion/stats.h"
-#include "libgwyddion/grains-nield.h"
+#include "libgwyddion/grains.h"
 #include "libgwyddion/linestats.h"
 
 #include "libgwyddion/omp.h"
@@ -306,7 +306,7 @@ calculate_surface_area_NIELD(GwyField *field,
 }
 
 /**
- * gwy_field_get_surface_area:
+ * gwy_field_surface_area:
  * @field: A data field.
  *
  * Computes surface area of a data field.
@@ -316,7 +316,7 @@ calculate_surface_area_NIELD(GwyField *field,
  * Returns: The surface area.
  **/
 gdouble
-gwy_field_get_surface_area(GwyField *field)
+gwy_field_surface_area(GwyField *field)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0.0);
 
@@ -330,7 +330,7 @@ gwy_field_get_surface_area(GwyField *field)
 }
 
 /**
- * gwy_field_area_get_surface_area_mask:
+ * gwy_field_area_surface_area:
  * @field: A data field.
  * @mask: Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
@@ -347,37 +347,7 @@ gwy_field_get_surface_area(GwyField *field)
  * Returns: The surface area.
  **/
 gdouble
-gwy_field_area_get_surface_area(GwyField *field,
-                                GwyField *mask,
-                                GwyMaskingType masking,
-                                gint col, gint row,
-                                gint width, gint height)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gdouble retval = gwy_NIELD_area_surface_area(field, nield, masking, col, row, width, height);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_surface_area_mask:
- * @field: A data field.
- * @mask: Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- *
- * Computes surface area of a rectangular part of a data field.
- *
- * This quantity makes sense only if the lateral dimensions and values of @field are the same physical
- * quantities.
- *
- * Returns: The surface area.
- **/
-gdouble
-gwy_NIELD_area_surface_area(GwyField *field,
+gwy_field_area_surface_area(GwyField *field,
                             GwyNield *mask,
                             GwyMaskingType masking,
                             gint col, gint row,
@@ -386,12 +356,12 @@ gwy_NIELD_area_surface_area(GwyField *field,
     gdouble area = 0.0;
 
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return area;
 
     /* The result is the same, but it can be cached. */
     if (!mask && row == 0 && col == 0 && width == field->xres && height == field->yres)
-        return gwy_field_get_surface_area(field);
+        return gwy_field_surface_area(field);
 
     return calculate_surface_area_NIELD(field, mask, masking, col, row, width, height);
 }
@@ -497,7 +467,7 @@ calculate_rms_slope(GwyField *field,
 }
 
 /**
- * gwy_field_area_get_rms_slope:
+ * gwy_field_area_rms_slope:
  * @field: A data field.
  * @mask: Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
@@ -511,36 +481,21 @@ calculate_rms_slope(GwyField *field,
  * Returns: The root mean square surface slope.
  **/
 gdouble
-gwy_NIELD_area_rms_slope(GwyField *field,
+gwy_field_area_rms_slope(GwyField *field,
                          GwyNield *mask,
                          GwyMaskingType masking,
                          gint col, gint row,
                          gint width, gint height)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return 0.0;
 
     return calculate_rms_slope(field, mask, masking, col, row, width, height);
 }
 
-gdouble
-gwy_field_area_get_surface_slope(GwyField *field,
-                                 GwyField *mask,
-                                 GwyMaskingType masking,
-                                 gint col,
-                                 gint row,
-                                 gint width,
-                                 gint height)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gdouble retval = gwy_NIELD_area_rms_slope(field, nield, masking, col, row, width, height);
-    g_clear_object(&nield);
-    return retval;
-}
-
 /**
- * gwy_field_get_rms_slope:
+ * gwy_field_rms_slope:
  * @field: A data field.
  *
  * Computes root mean square surface slope (Sdq) of a data field.
@@ -548,7 +503,7 @@ gwy_field_area_get_surface_slope(GwyField *field,
  * Returns: The root mean square surface slope.
  **/
 gdouble
-gwy_field_get_rms_slope(GwyField *field)
+gwy_field_rms_slope(GwyField *field)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0.0);
 
@@ -639,7 +594,7 @@ calculate_variation_NIELD(GwyField *field,
 }
 
 /**
- * gwy_field_get_variation:
+ * gwy_field_variation:
  * @field: A data field.
  *
  * Computes the total variation of a data field.
@@ -651,7 +606,7 @@ calculate_variation_NIELD(GwyField *field,
  * Returns: The variation.
  **/
 gdouble
-gwy_field_get_variation(GwyField *field)
+gwy_field_variation(GwyField *field)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0.0);
 
@@ -665,7 +620,7 @@ gwy_field_get_variation(GwyField *field)
 }
 
 /**
- * gwy_field_area_get_variation:
+ * gwy_field_area_variation:
  * @field: A data field.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
@@ -687,54 +642,19 @@ gwy_field_get_variation(GwyField *field)
  * Returns: The variation.
  **/
 gdouble
-gwy_field_area_get_variation(GwyField *field,
-                             GwyField *mask,
-                             GwyMaskingType masking,
-                             gint col, gint row,
-                             gint width, gint height)
-{
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    gdouble retval = gwy_NIELD_area_variation(field, nield, masking, col, row, width, height);
-    g_clear_object(&nield);
-    return retval;
-}
-
-/**
- * gwy_NIELD_area_variation:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- *
- * Computes the total variation of a rectangular part of a data field.
- *
- * The total variation is estimated as the integral of the absolute value of local gradient.
- *
- * This quantity has the somewhat odd units of value unit times lateral unit. It can be envisioned as follows.  If the
- * surface has just two height levels (upper and lower planes) then the quantity is the length of the boundary between
- * the upper and lower part, multiplied by the step height.  If the surface is piece-wise constant, then the variation
- * is the step height integrated along the boundaries between the constant parts.  Therefore, for non-fractal surfaces
- * it scales with the linear dimension of the image, not with its area, despite being an area integral.
- *
- * Returns: The variation.
- **/
-gdouble
-gwy_NIELD_area_variation(GwyField *field,
+gwy_field_area_variation(GwyField *field,
                          GwyNield *mask,
                          GwyMaskingType masking,
                          gint col, gint row,
                          gint width, gint height)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return 0.0;
 
     /* The result is the same, but it can be cached. */
     if (!mask && row == 0 && col == 0 && width == field->xres && height == field->yres)
-        return gwy_field_get_variation(field);
+        return gwy_field_variation(field);
 
     return calculate_variation_NIELD(field, mask, masking, col, row, width, height);
 }
@@ -787,363 +707,6 @@ square_volumew(gdouble z1, gdouble z2, gdouble z3, gdouble z4,
             + w3*(3.0*z3 + z2 + z4 + c) + w4*(3.0*z4 + z3 + z1 + c))/24.0;
 }
 
-/**
- * stripe_volume:
- * @n: The number of values in @r, @rr, @m.
- * @stride: Stride in @r, @rr, @m.
- * @r: Array of @n z-values of vertices, this row of vertices is considered inside.
- * @rr: Array of @n z-values of vertices, this row of vertices is considered outside.
- * @m: Mask for @r (@rr does not need mask since it has zero weight by definition), or %NULL to sum over all @r
- *     vertices.
- * @masking: Masking mode to use.
- *
- * Calculates approximate volume of a half-pixel stripe.
- *
- * Returns: The volume.
- **/
-static gdouble
-stripe_volume(gint n,
-              gint stride,
-              const gdouble *r,
-              const gdouble *rr,
-              const gdouble *m,
-              GwyMaskingType masking)
-{
-    gdouble sum = 0.0;
-    gint j;
-
-    if (m) {
-        for (j = 0; j < n-1; j++) {
-            sum += square_volumew(r[j*stride], r[(j + 1)*stride], rr[(j + 1)*stride], rr[j*stride],
-                                  masked_included(m + j*stride, masking), masked_included(m + (j + 1)*stride, masking),
-                                  0, 0);
-        }
-    }
-    else {
-        for (j = 0; j < n-1; j++) {
-            sum += square_volumew(r[j*stride], r[(j + 1)*stride], rr[(j + 1)*stride], rr[j*stride],
-                                  1, 1, 0, 0);
-        }
-    }
-
-    return sum;
-}
-
-/**
- * stripe_volumeb:
- * @n: The number of values in @r, @rr, @m.
- * @stride: Stride in @r, @rr, @m.
- * @r: Array of @n z-values of vertices, this row of vertices is considered inside.
- * @rr: Array of @n z-values of vertices, this row of vertices is considered outside.
- * @b: Array of @n z-values of basis, this row of vertices is considered inside.
- * @br: Array of @n z-values of basis, this row of vertices is considered outside.
- * @m: Mask for @r (@rr does not need mask since it has zero weight by definition), or %NULL to sum over all @r
- *     vertices.
- * @masking: Masking mode to use.
- *
- * Calculates approximate volume of a half-pixel stripe, taken from basis.
- *
- * Returns: The volume.
- **/
-static gdouble
-stripe_volumeb(gint n,
-               gint stride,
-               const gdouble *r,
-               const gdouble *rr,
-               const gdouble *b,
-               const gdouble *br,
-               const gdouble *m,
-               GwyMaskingType masking)
-{
-    gdouble sum = 0.0;
-    gint j;
-
-    if (m) {
-        for (j = 0; j < n-1; j++) {
-            sum += square_volumew(r[j*stride] - b[j*stride],
-                                  r[(j + 1)*stride] - b[(j + 1)*stride],
-                                  rr[(j + 1)*stride] - br[(j + 1)*stride],
-                                  rr[j*stride] - br[j*stride],
-                                  masked_included(m + j*stride, masking), masked_included(m + (j + 1)*stride, masking),
-                                  0, 0);
-        }
-    }
-    else {
-        for (j = 0; j < n-1; j++) {
-            sum += square_volumew(r[j*stride] - b[j*stride],
-                                  r[(j + 1)*stride] - b[(j + 1)*stride],
-                                  rr[(j + 1)*stride] - br[(j + 1)*stride],
-                                  rr[j*stride] - br[j*stride],
-                                  1, 1, 0, 0);
-        }
-    }
-
-    return sum;
-}
-
-static gdouble
-calculate_volume(GwyField *dfield,
-                 GwyField *basis,
-                 GwyField *mask,
-                 GwyMaskingType masking,
-                 gint col, gint row,
-                 gint width, gint height)
-{
-    const gdouble *dataul, *maskul, *basisul, *r, *m, *b;
-    gint i, j, xres, yres, s;
-    gdouble sum = 0.0;
-
-    /* special cases */
-    if (!width || !height)
-        return sum;
-
-    xres = dfield->xres;
-    yres = dfield->yres;
-    dataul = dfield->priv->data + xres*row + col;
-
-    if (mask) {
-        maskul = mask->priv->data + xres*row + col;
-        if (!basis) {
-            /* Inside */
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:sum) \
-            private(r,m,i,j) \
-            shared(dataul,maskul,masking,xres,height,width)
-#endif
-            for (i = 0; i < height-1; i++) {
-                r = dataul + xres*i;
-                m = maskul + xres*i;
-                for (j = 0; j < width-1; j++) {
-                    sum += square_volumew(r[j], r[j+1], r[j+xres+1], r[j+xres],
-                                          masked_included(m + j, masking), masked_included(m + j+1, masking),
-                                          masked_included(m + j+xres+1, masking), masked_included(m + j+xres, masking));
-                }
-            }
-
-            /* Top row */
-            s = !(row == 0);
-            sum += stripe_volume(width, 1, dataul, dataul - s*xres, maskul, masking);
-
-            /* Bottom row */
-            s = !(row + height == yres);
-            sum += stripe_volume(width, 1, dataul + xres*(height-1),
-                                 dataul + xres*(height-1 + s),
-                                 maskul + xres*(height-1), masking);
-
-            /* Left column */
-            s = !(col == 0);
-            sum += stripe_volume(height, xres, dataul, dataul - s, maskul, masking);
-
-            /* Right column */
-            s = !(col + width == xres);
-            sum += stripe_volume(height, xres, dataul + width-1, dataul + width-1 + s, maskul + width-1, masking);
-
-            /* Just take the four corner quater-pixels as flat.  */
-            if (masked_included(maskul, masking))
-                sum += dataul[0]/4.0;
-            if (masked_included(maskul + width-1, masking))
-                sum += dataul[width-1]/4.0;
-            if (masked_included(maskul + xres*(height-1), masking))
-                sum += dataul[xres*(height-1)]/4.0;
-            if (masked_included(maskul + xres*(height-1) + width-1, masking))
-                sum += dataul[xres*(height-1) + width-1]/4.0;
-        }
-        else {
-            basisul = basis->priv->data + xres*row + col;
-
-            /* Inside */
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:sum) \
-            private(r,m,b,i,j) \
-            shared(dataul,maskul,masking,basisul,xres,height,width)
-#endif
-            for (i = 0; i < height-1; i++) {
-                r = dataul + xres*i;
-                m = maskul + xres*i;
-                b = basisul + xres*i;
-                for (j = 0; j < width-1; j++) {
-                    sum += square_volumew(r[j] - b[j],
-                                          r[j+1] - b[j+1],
-                                          r[j+xres+1] - b[j+xres+1],
-                                          r[j+xres] - b[j+xres],
-                                          masked_included(m + j, masking), masked_included(m + j+1, masking),
-                                          masked_included(m + j+xres+1, masking), masked_included(m + j+xres, masking));
-                }
-            }
-
-            /* Top row */
-            s = !(row == 0);
-            sum += stripe_volumeb(width, 1, dataul, dataul - s*xres, basisul, basisul - s*xres, maskul, masking);
-
-            /* Bottom row */
-            s = !(row + height == yres);
-            sum += stripe_volumeb(width, 1,
-                                  dataul + xres*(height-1),
-                                  dataul + xres*(height-1 + s),
-                                  basisul + xres*(height-1),
-                                  basisul + xres*(height-1 + s),
-                                  maskul + xres*(height-1),
-                                  masking);
-
-            /* Left column */
-            s = !(col == 0);
-            sum += stripe_volumeb(height, xres, dataul, dataul - s, basisul, basisul - s, maskul, masking);
-
-            /* Right column */
-            s = !(col + width == xres);
-            sum += stripe_volumeb(height, xres,
-                                  dataul + width-1, dataul + width-1 + s,
-                                  basisul + width-1, basisul + width-1 + s,
-                                  maskul + width-1, masking);
-
-            /* Just take the four corner quater-pixels as flat.  */
-            if (masked_included(maskul, masking))
-                sum += (dataul[0] - basisul[0])/4.0;
-            if (masked_included(maskul + width-1, masking))
-                sum += (dataul[width-1] - basisul[width-1])/4.0;
-            if (masked_included(maskul + xres*(height-1), masking))
-                sum += (dataul[xres*(height-1)] - basisul[xres*(height-1)])/4.0;
-            if (masked_included(maskul + xres*(height-1) + width-1, masking))
-                sum += (dataul[xres*(height-1) + width-1] - basisul[xres*(height-1) + width-1])/4.0;
-        }
-    }
-    else {
-        if (!basis) {
-            /* Inside */
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:sum) \
-            private(r,i,j) \
-            shared(dataul,xres,height,width)
-#endif
-            for (i = 0; i < height-1; i++) {
-                r = dataul + xres*i;
-                for (j = 0; j < width-1; j++)
-                    sum += square_volume(r[j], r[j+1], r[j+xres+1], r[j+xres]);
-            }
-
-            /* Top row */
-            s = !(row == 0);
-            sum += stripe_volume(width, 1, dataul, dataul - s*xres, NULL, GWY_MASK_IGNORE);
-
-            /* Bottom row */
-            s = !(row + height == yres);
-            sum += stripe_volume(width, 1, dataul + xres*(height-1), dataul + xres*(height-1 + s),
-                                 NULL, GWY_MASK_IGNORE);
-
-            /* Left column */
-            s = !(col == 0);
-            sum += stripe_volume(height, xres, dataul, dataul - s, NULL, GWY_MASK_IGNORE);
-
-            /* Right column */
-            s = !(col + width == xres);
-            sum += stripe_volume(height, xres, dataul + width-1, dataul + width-1 + s, NULL, GWY_MASK_IGNORE);
-
-            /* Just take the four corner quater-pixels as flat.  */
-            sum += dataul[0]/4.0;
-            sum += dataul[width-1]/4.0;
-            sum += dataul[xres*(height-1)]/4.0;
-            sum += dataul[xres*(height-1) + width-1]/4.0;
-        }
-        else {
-            basisul = basis->priv->data + xres*row + col;
-
-            /* Inside */
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:sum) \
-            private(r,b,i,j) \
-            shared(dataul,basisul,xres,height,width)
-#endif
-            for (i = 0; i < height-1; i++) {
-                r = dataul + xres*i;
-                b = basisul + xres*i;
-                for (j = 0; j < width-1; j++) {
-                    sum += square_volume(r[j] - b[j],
-                                         r[j+1] - b[j+1],
-                                         r[j+xres+1] - b[j+xres+1],
-                                         r[j+xres] - b[j+xres]);
-                }
-            }
-
-            /* Top row */
-            s = !(row == 0);
-            sum += stripe_volumeb(width, 1, dataul, dataul - s*xres, basisul, basisul - s*xres, NULL, GWY_MASK_IGNORE);
-
-            /* Bottom row */
-            s = !(row + height == yres);
-            sum += stripe_volumeb(width, 1,
-                                  dataul + xres*(height-1),
-                                  dataul + xres*(height-1 + s),
-                                  basisul + xres*(height-1),
-                                  basisul + xres*(height-1 + s),
-                                  NULL, GWY_MASK_IGNORE);
-
-            /* Left column */
-            s = !(col == 0);
-            sum += stripe_volumeb(height, xres, dataul, dataul - s, basisul, basisul - s, NULL, GWY_MASK_IGNORE);
-
-            /* Right column */
-            s = !(col + width == xres);
-            sum += stripe_volumeb(height, xres,
-                                  dataul + width-1, dataul + width-1 + s,
-                                  basisul + width-1, basisul + width-1 + s,
-                                  NULL, GWY_MASK_IGNORE);
-
-            /* Just take the four corner quater-pixels as flat.  */
-            sum += (dataul[0] - basisul[0])/4.0;
-            sum += (dataul[width-1] - basisul[width-1])/4.0;
-            sum += (dataul[xres*(height-1)] - basisul[xres*(height-1)])/4.0;
-            sum += (dataul[xres*(height-1) + width-1] - basisul[xres*(height-1) + width-1])/4.0;
-        }
-    }
-
-    return sum* dfield->xreal/dfield->xres * dfield->yreal/dfield->yres;
-}
-
-/* Don't define gwy_field_get_volume() without mask and basis, it would
- * just be a complicate way to calculate gwy_field_get_sum() */
-
-/**
- * gwy_field_area_get_volume:
- * @field: A data field.
- * @basis: (nullable):
- *         The basis or background for volume calculation if not %NULL. The height of each vertex is then the
- *         difference between @field value and @basis value.  Value %NULL is the same as passing all zeroes for
- *         the basis.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use.  See the introduction for description of masking modes.
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- *
- * Computes volume of a rectangular part of a data field.
- *
- * Returns: The volume.
- **/
-gdouble
-gwy_field_area_get_volume(GwyField *field,
-                          GwyField *basis,
-                          GwyField *mask,
-                          GwyMaskingType masking,
-                          gint col, gint row,
-                          gint width, gint height)
-{
-    gdouble vol = 0.0;
-
-    if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_field_check_mask(field, &mask, &masking))
-        return vol;
-    g_return_val_if_fail(!basis || (GWY_IS_FIELD(basis)
-                                    && basis->xres == field->xres
-                                    && basis->yres == field->yres), vol);
-
-    return calculate_volume(field, basis, mask, masking, col, row, width, height);
-}
-
 static gdouble
 volume_corner(gdouble z1, gdouble z2, gdouble z3, gdouble z4,
               guint w1, guint w2, guint w3, guint w4,
@@ -1163,12 +726,12 @@ volume_corner_all(gdouble z1, gdouble z2, gdouble z3, gdouble z4,
 }
 
 static gdouble
-calculate_volume_NIELD(GwyField *field,
-                       GwyNield *mask,
-                       GwyMaskingType masking,
-                       GwyFieldVolumeMethod method,
-                       gint col, gint row,
-                       gint width, gint height)
+calculate_volume(GwyField *field,
+                 GwyNield *mask,
+                 GwyMaskingType masking,
+                 GwyFieldVolumeMethod method,
+                 gint col, gint row,
+                 gint width, gint height)
 {
     // The centre and cardinal direction weights; the diagonal weight is always 1.
     static const gdouble volume_weights[GWY_FIELD_VOLUME_NMETHODS][2] = {
@@ -1188,7 +751,7 @@ calculate_volume_NIELD(GwyField *field,
 }
 
 /**
- * gwy_NIELD_area_volume:
+ * gwy_field_area_volume:
  * @field: A data field.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use.  See the introduction for description of masking modes.
@@ -1203,7 +766,7 @@ calculate_volume_NIELD(GwyField *field,
  * Returns: The volume.
  **/
 gdouble
-gwy_NIELD_area_volume(GwyField *field,
+gwy_field_area_volume(GwyField *field,
                       GwyNield *mask,
                       GwyMaskingType masking,
                       GwyFieldVolumeMethod method,
@@ -1211,11 +774,11 @@ gwy_NIELD_area_volume(GwyField *field,
                       gint width, gint height)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return 0.0;
     g_return_val_if_fail(method <= GWY_FIELD_VOLUME_BIQUADRATIC, 0.0);
 
-    return calculate_volume_NIELD(field, mask, masking, method, col, row, width, height);
+    return calculate_volume(field, mask, masking, method, col, row, width, height);
 }
 
 static gdouble
@@ -1363,149 +926,7 @@ gwy_field_area_material_volume(GwyField *field,
 }
 
 /**
- * gwy_field_area_get_dispersion:
- * @field: A data field.
- * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
- * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
- * @col: Upper-left column coordinate.
- * @row: Upper-left row coordinate.
- * @width: Area width (number of columns).
- * @height: Area height (number of rows).
- * @xcenter: (out) (optional):
- *           Location where to store the horizontal position of centre of mass (in pixel coordinates), or %NULL.
- * @ycenter: (out) (optional):
- *           Location where to store the vertical position of centre of mass (in pixel coordinates), or %NULL.
- *
- * Calculates the dispersion of a data field area, taking it as a distribution.
- *
- * The function takes @field as a distribution, finds the centre of mass in the area and then calculates the mean
- * squared distance from this centre, weighted by @field values.  Normally @field should contain only
- * non-negative data.
- *
- * The dispersion is measured in real coordinates, so horizontal and vertical pixel sizes play a role and the units
- * are squared lateral units of @field.  Note, however, that @xcenter and @ycenter is returned in pixel
- * coordinates since it is usually more convenient.
- *
- * Returns: Dispersion, i.e. estimated average squared distance from centre of mass.
- **/
-gdouble
-gwy_field_area_get_dispersion(GwyField *field,
-                              GwyField *mask,
-                              GwyMaskingType masking,
-                              gint col,
-                              gint row,
-                              gint width,
-                              gint height,
-                              gdouble *xcenter,
-                              gdouble *ycenter)
-{
-    gint xres, yres, i, j;
-    gdouble dx, dy;
-    gdouble sx, sy, s2, sw;
-
-    if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_field_check_mask(field, &mask, &masking))
-        return 0.0;
-
-    xres = field->xres;
-    yres = field->yres;
-    dx = field->xreal/xres;
-    dy = field->yreal/yres;
-
-    sx = sy = sw = 0.0;
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:sx,sy,sw) \
-            private(i,j) \
-            shared(field,mask,xres,width,height,row,col,masking)
-#endif
-    for (i = 0; i < height; i++) {
-        const gdouble *d = field->priv->data + (row + i)*xres + col;
-
-        if (masking == GWY_MASK_INCLUDE) {
-            const gdouble *m = mask->priv->data + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                gdouble w = d[j]*(m[j] > 0.0);
-                sw += w;
-                sx += j*w;
-                sy += i*w;
-            }
-        }
-        else if (masking == GWY_MASK_EXCLUDE) {
-            const gdouble *m = mask->priv->data + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                gdouble w = d[j]*(m[j] <= 0.0);
-                sw += w;
-                sx += j*w;
-                sy += i*w;
-            }
-        }
-        else {
-            for (j = 0; j < width; j++) {
-                gdouble w = d[j];
-                sw += w;
-                sx += j*w;
-                sy += i*w;
-            }
-        }
-    }
-
-    /* Negative values are silly but do not prevent us from continuing. */
-    if (sw == 0.0) {
-        if (xcenter)
-            *xcenter = col + 0.5*width;
-        if (ycenter)
-            *ycenter = row + 0.5*height;
-        return 0.0;
-    }
-
-    sx /= sw;
-    sy /= sw;
-    if (xcenter)
-        *xcenter = sx;
-    if (ycenter)
-        *ycenter = sy;
-    sx *= dx;
-    sy *= dy;
-
-    s2 = 0.0;
-#ifdef _OPENMP
-#pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            reduction(+:s2) \
-            private(i,j) \
-            shared(field,mask,xres,width,height,row,col,dx,dy,sx,sy,masking)
-#endif
-    for (i = 0; i < height; i++) {
-        const gdouble *d = field->priv->data + (row + i)*xres + col;
-        gdouble y = i*dy - sy;
-
-        if (masking == GWY_MASK_INCLUDE) {
-            const gdouble *m = mask->priv->data + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                gdouble x = j*dx - sx;
-                s2 += (m[j] > 0.0)*(x*x + y*y)*d[j];
-            }
-        }
-        else if (masking == GWY_MASK_EXCLUDE) {
-            const gdouble *m = mask->priv->data + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                gdouble x = j*dx - sx;
-                s2 += (m[j] <= 0.0)*(x*x + y*y)*d[j];
-            }
-        }
-        else {
-            for (j = 0; j < width; j++) {
-                gdouble x = j*dx - sx;
-                s2 += (x*x + y*y)*d[j];
-            }
-        }
-    }
-
-    return s2/sw;
-}
-
-/**
- * gwy_NIELD_area_dispersion:
+ * gwy_field_area_dispersion:
  * @field: A data field.
  * @mask: (nullable): Mask specifying which values to take into account/exclude, or %NULL.
  * @masking: Masking mode to use (has any effect only with non-%NULL @mask).
@@ -1542,7 +963,7 @@ gwy_field_area_dispersion(GwyField *field,
                           gdouble *ycenter)
 {
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return 0.0;
 
     gint xres = field->xres, yres = field->yres;
@@ -1626,7 +1047,7 @@ gwy_field_area_dispersion(GwyField *field,
 }
 
 /**
- * gwy_field_get_dispersion:
+ * gwy_field_dispersion:
  * @field: A data field.
  * @xcenter: (out) (optional):
  *           Location where to store the horizontal position of centre of mass (in pixel coordinates), or %NULL.
@@ -1640,9 +1061,8 @@ gwy_field_area_dispersion(GwyField *field,
  * Returns: Dispersion, i.e. estimated average squared distance from centre of mass.
  **/
 gdouble
-gwy_field_get_dispersion(GwyField *field,
-                         gdouble *xcenter,
-                         gdouble *ycenter)
+gwy_field_dispersion(GwyField *field,
+                     gdouble *xcenter, gdouble *ycenter)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0.0);
     return gwy_field_area_dispersion(field, NULL, GWY_MASK_IGNORE, 0, 0,
