@@ -1,6 +1,6 @@
 /*
- *  $Id: surface.c 28965 2025-12-10 10:34:12Z yeti-dn $
- *  Copyright (C) 2011-2025 David Nečas (Yeti).
+ *  $Id: surface.c 29431 2026-02-03 00:36:52Z yeti-dn $
+ *  Copyright (C) 2011-2026 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -332,7 +332,7 @@ copy_field_to_surface(GwyField *field,
         priv->min.y = yoff;
         priv->max.x = dx*(xres - 1) + xoff;
         priv->max.y = dy*(yres - 1) + yoff;
-        gwy_field_get_min_max(field, &priv->min.z, &priv->max.z);
+        gwy_field_min_max(field, &priv->min.z, &priv->max.z);
     }
 }
 
@@ -444,8 +444,8 @@ gwy_surface_copy_data(GwySurface *surface, GwySurface *target)
  *
  * Invalidates cached surface statistics.
  *
- * Cached statistics include ranges returned by gwy_surface_get_xrange(), gwy_surface_get_yrange() and
- * gwy_surface_get_min_max(), the fingerprint for gwy_surface_xy_is_compatible() and and possibly other
+ * Cached statistics include ranges returned by gwy_surface_xrange(), gwy_surface_yrange() and
+ * gwy_surface_min_max(), the fingerprint for gwy_surface_xy_is_compatible() and and possibly other
  * characteristics in the future.
  *
  * See gwy_field_invalidate() for discussion of invalidation and examples.
@@ -482,28 +482,7 @@ gwy_surface_set_from_field(GwySurface *surface,
 }
 
 /**
- * gwy_surface_set_from_field_mask:
- * @surface: A surface.
- * @field: A two-dimensional data field.
- * @mask: (nullable): Mask of pixels to include from/exclude, or %NULL
- * @masking: Masking mode to use.
- *
- * Fills the data of a surface from a data field, possibly using masking.
- **/
-void
-gwy_surface_set_from_field_mask(GwySurface *surface,
-                                GwyField *field,
-                                GwyField *mask,
-                                GwyMaskingType masking)
-{
-    g_return_if_fail(GWY_IS_SURFACE(surface));
-    GwyNield *nield = oldstyle_mask_to_nield(mask, masking);
-    copy_field_to_surface(field, surface, nield, masking, 0, 0, field->xres, field->yres);
-    g_clear_object(&nield);
-}
-
-/**
- * gwy_surface_set_from_NIELD:
+ * gwy_surface_set_from_field_area:
  * @surface: A surface.
  * @field: A two-dimensional data field.
  * @mask: (nullable): Mask of pixels to include from/exclude, or %NULL
@@ -516,18 +495,18 @@ gwy_surface_set_from_field_mask(GwySurface *surface,
  * Fills the data of a surface from a data field, possibly using masking.
  **/
 void
-gwy_surface_set_from_NIELD(GwySurface *surface,
-                           GwyField *field,
-                           GwyNield *mask,
-                           GwyMaskingType masking,
-                           gint col,
-                           gint row,
-                           gint width,
-                           gint height)
+gwy_surface_set_from_field_area(GwySurface *surface,
+                                GwyField *field,
+                                GwyNield *mask,
+                                GwyMaskingType masking,
+                                gint col,
+                                gint row,
+                                gint width,
+                                gint height)
 {
     g_return_if_fail(GWY_IS_SURFACE(surface));
     if (!_gwy_field_check_area(field, col, row, width, height, FALSE)
-        || !_gwy_NIELD_check_mask(field, &mask, &masking))
+        || !_gwy_field_check_mask(field, &mask, &masking))
         return;
     copy_field_to_surface(field, surface, mask, masking, col, row, width, height);
 }
@@ -611,8 +590,8 @@ gwy_surface_get_value_format_xy(GwySurface *surface,
         return gwy_unit_get_format_with_resolution(siunit, style, max, max/10.0, format);
     }
 
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
+    gwy_surface_yrange(surface, &ymin, &ymax);
     max = MAX(MAX(fabs(xmax), fabs(xmin)), MAX(fabs(ymax), fabs(ymin)));
     if (!max)
         max = 1.0;
@@ -645,7 +624,7 @@ gwy_surface_get_value_format_z(GwySurface *surface,
     g_return_val_if_fail(GWY_IS_SURFACE(surface), NULL);
 
     siunit = gwy_surface_get_unit_z(surface);
-    gwy_surface_get_min_max(surface, &min, &max);
+    gwy_surface_min_max(surface, &min, &max);
     if (max == min) {
         max = ABS(max);
         min = 0.0;
@@ -804,7 +783,7 @@ gwy_surface_set_data_full(GwySurface *surface,
 }
 
 /**
- * gwy_surface_get_xrange:
+ * gwy_surface_xrange:
  * @surface: A surface.
  * @min: (out): Location where to store the minimum value.
  * @max: (out): Location where to store the maximum value.
@@ -814,9 +793,9 @@ gwy_surface_set_data_full(GwySurface *surface,
  * This information is cached.
  **/
 void
-gwy_surface_get_xrange(GwySurface *surface,
-                       gdouble *min,
-                       gdouble *max)
+gwy_surface_xrange(GwySurface *surface,
+                   gdouble *min,
+                   gdouble *max)
 {
     g_return_if_fail(GWY_IS_SURFACE(surface));
     ensure_ranges(surface);
@@ -827,7 +806,7 @@ gwy_surface_get_xrange(GwySurface *surface,
 }
 
 /**
- * gwy_surface_get_yrange:
+ * gwy_surface_yrange:
  * @surface: A surface.
  * @min: (out): Location where to store the minimum value.
  * @max: (out): Location where to store the maximum value.
@@ -837,9 +816,9 @@ gwy_surface_get_xrange(GwySurface *surface,
  * This information is cached.
  **/
 void
-gwy_surface_get_yrange(GwySurface *surface,
-                       gdouble *min,
-                       gdouble *max)
+gwy_surface_yrange(GwySurface *surface,
+                   gdouble *min,
+                   gdouble *max)
 {
     g_return_if_fail(GWY_IS_SURFACE(surface));
     ensure_ranges(surface);
@@ -850,7 +829,7 @@ gwy_surface_get_yrange(GwySurface *surface,
 }
 
 /**
- * gwy_surface_get_min_max:
+ * gwy_surface_min_max:
  * @surface: A surface.
  * @min: (out): Location where to store the minimum value.
  * @max: (out): Location where to store the maximum value.
@@ -860,9 +839,9 @@ gwy_surface_get_yrange(GwySurface *surface,
  * This information is cached.
  **/
 void
-gwy_surface_get_min_max(GwySurface *surface,
-                        gdouble *min,
-                        gdouble *max)
+gwy_surface_min_max(GwySurface *surface,
+                    gdouble *min,
+                    gdouble *max)
 {
     g_return_if_fail(GWY_IS_SURFACE(surface));
     ensure_ranges(surface);
@@ -1098,7 +1077,9 @@ gwy_surface_reduce_points(GwySurface *surface, gsize npoints)
     GwySurface *retval;
     GwyRandGenSet *rngset;
     GRand *rng;
-    gdouble xmin, xmax, ymin, ymax, xlen, ylen, d;
+    // If xlen and ylen are uninitialised, then xres=1 and yres=1 are also kept unchanged, and the function returns
+    // early. Can't you see it?
+    gdouble xmin, xmax, ymin, ymax, xlen = sizeof("GCC is dumb."), ylen = sizeof("GCC is dumb"), d;
     gboolean x_is_degenerate, y_is_degenerate;
     gint k, n, xres = 1, yres = 1, i, j;
     guint *redindex, *pts = NULL;
@@ -1123,8 +1104,8 @@ gwy_surface_reduce_points(GwySurface *surface, gsize npoints)
 
     /* If a reasonable number of points is requested try to spread them. */
     if (npoints > 3) {
-        gwy_surface_get_xrange(surface, &xmin, &xmax);
-        gwy_surface_get_yrange(surface, &ymin, &ymax);
+        gwy_surface_xrange(surface, &xmin, &xmax);
+        gwy_surface_yrange(surface, &ymin, &ymax);
         xlen = xmax - xmin;
         ylen = ymax - ymin;
         x_is_degenerate = (xmin >= xmax);
