@@ -1,5 +1,5 @@
 /*
- *  $Id: tip-model.c 28903 2025-11-24 15:49:51Z yeti-dn $
+ *  $Id: tip-model.c 29503 2026-02-18 19:43:32Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -302,7 +302,7 @@ round_pyramid(GwyField *tip, gdouble angle, gint n, gdouble ballradius)
 {
     gint xres = tip->xres, yres = tip->yres;
     //gdouble pxsize = sqrt(xres*xres + yres*yres)/2.0;
-    gdouble height = gwy_field_get_max(tip);
+    gdouble height = gwy_field_max(tip);
     gdouble dx = gwy_field_get_dx(tip), dy = gwy_field_get_dy(tip);
     //gdouble beta = atan(dy*pxsize/height);
     gdouble center_x = gwy_field_get_xreal(tip)/2;
@@ -393,7 +393,7 @@ ell_parabola_model(GwyField *tip, const gdouble *params)
             d[xres*row + col] = -(a1*xx*xx + a2*yy*yy);
         }
     }
-    gwy_field_add(tip, -gwy_field_get_min(tip));
+    gwy_field_add(tip, -gwy_field_min(tip));
 }
 
 static void
@@ -416,7 +416,7 @@ cone_model(GwyField *tip, const gdouble *params)
             d[xres*row + col] = (r2 < br2 ? sqrt(radius*radius - r2) : z0 - ta*sqrt(r2));
         }
     }
-    gwy_field_add(tip, -gwy_field_get_min(tip));
+    gwy_field_add(tip, -gwy_field_min(tip));
 }
 
 static void
@@ -495,6 +495,44 @@ gwy_tip_model_get_params(GwyTipModel *model)
     return model->priv->builtin->params;
 }
 
+/**
+ * gwy_tip_model_fill_param:
+ * @model: Tip model.
+ * @params: Array of parameters of @model where to fill one specific value. The number of elements must be at least
+ *          the number returned by gwy_tip_model_get_nparams().
+ * @type: The parameter to fill.
+ * @value: Value to set the parameter to.
+ *
+ * Fills one value in an array of tip model parameters.
+ *
+ * This helper function simplifies the lookup when setting the values of specific parameters. Instead of getting the
+ * list of parameters using gwy_tip_model_get_params() and searching for the position of each parameter, you can do
+ * |[
+ * gdouble *params = g_new(gdouble, gwy_tip_model_get_nparams(model));
+ * gwy_tip_model_fill_param(model, params, GWY_TIP_PARAM_RADIUS, 6e-9);
+ * gwy_tip_model_fill_param(model, params, GWY_TIP_PARAM_ROTATION, gwy_deg2rad(60));
+ * ]|
+ * provided you know that the model has parameters %GWY_TIP_PARAM_RADIUS and %GWY_TIP_PARAM_ROTATION. It is an error
+ * to try to set a non-existent parameter.
+ **/
+void
+gwy_tip_model_fill_param(GwyTipModel* model,
+                         gdouble *params,
+                         GwyTipParamType type,
+                         gdouble value)
+{
+    g_return_if_fail(GWY_IS_TIP_MODEL(model));
+    g_return_if_fail(params);
+    const TipModelBuiltin *builtin = model->priv->builtin;
+    for (guint i = 0; i < builtin->nparams; i++) {
+        if (type == builtin->params[i]) {
+            params[i] = value;
+            return;
+        }
+    }
+    g_assert_not_reached();
+}
+
 /**
  * gwy_tip_model_create:
  * @model: Tip model.
@@ -634,25 +672,25 @@ check_tip_zrange(GwyField *tip, gdouble zrange,
                  gdouble *zrange_leftright, gdouble *zrange_topbottom,
                  guint *can_shrink_width, guint *can_shrink_height)
 {
-    gdouble max = gwy_field_get_max(tip);
+    gdouble max = gwy_field_max(tip);
     guint xres = tip->xres, yres = tip->yres;
     gdouble hmax, vmax;
 
-    vmax = fmax(gwy_field_area_get_max(tip, NULL, GWY_MASK_IGNORE, 0, 0, xres, 1),
-                gwy_field_area_get_max(tip, NULL, GWY_MASK_IGNORE, 0, yres-1, xres, 1));
+    vmax = fmax(gwy_field_area_max(tip, NULL, GWY_MASK_IGNORE, 0, 0, xres, 1),
+                gwy_field_area_max(tip, NULL, GWY_MASK_IGNORE, 0, yres-1, xres, 1));
     *zrange_topbottom = max - vmax;
-    hmax = fmax(gwy_field_area_get_max(tip, NULL, GWY_MASK_IGNORE, 0, 0, 1, yres),
-                gwy_field_area_get_max(tip, NULL, GWY_MASK_IGNORE, xres-1, 0, 1, yres));
+    hmax = fmax(gwy_field_area_max(tip, NULL, GWY_MASK_IGNORE, 0, 0, 1, yres),
+                gwy_field_area_max(tip, NULL, GWY_MASK_IGNORE, xres-1, 0, 1, yres));
     *zrange_leftright = max - hmax;
     *can_shrink_height = *can_shrink_width = 0;
 
     if (!(fmax(*zrange_topbottom, *zrange_leftright) >= zrange))
         return FALSE;
 
-    GwyField *mask = gwy_field_copy(tip);
-    gwy_field_threshold(mask, max - zrange, 0.0, 1.0);
+    GwyNield *mask = gwy_field_new_nield_alike(tip);
+    gwy_nield_mark_by_threshold(mask, tip, max - zrange, TRUE);
     guint left, right, up, down;
-    if (gwy_field_grains_autocrop(mask, TRUE, &left, &right, &up, &down)) {
+    if (gwy_nield_autocrop(mask, TRUE, &left, &right, &up, &down)) {
         /* There were some empty rows, i.e. rows with too small values. */
         *can_shrink_width = left;
         *can_shrink_height = up;
@@ -702,10 +740,11 @@ gwy_tip_models(void)
  * @GWY_TIP_PARAM_HEIGHT: Total tip height.  This is used only in the delta function tip; for all others it is
  *                        implied.
  * @GWY_TIP_PARAM_RADIUS: Radius of curvature of the tip apex.
- * @GWY_TIP_PARAM_ROTATION: Rotation angle.
- * @GWY_TIP_PARAM_NSIDES: Number of sides for pyramidal tips.
- * @GWY_TIP_PARAM_SLOPE: Half-angle of the apex (complement of the side slope for straight sides). A small angle means
- *                       a sharp tip.
+ * @GWY_TIP_PARAM_ROTATION: Rotation angle (in radians).
+ * @GWY_TIP_PARAM_NSIDES: The number of sides for pyramidal tips (an integer ≥ 3, even though it is passed as
+ *                        a double).
+ * @GWY_TIP_PARAM_SLOPE: Half-angle of the apex (complement of the side slope for straight sides), in radians. A
+ *                       small slope angle means a sharp tip.
  * @GWY_TIP_PARAM_ANISOTROPY: Ratio between larger and smaller tip width in two orthotonal directions.
  *
  * Type of tip model parameter.
