@@ -1,5 +1,5 @@
 /*
- *  $Id: utils.c 28909 2025-11-24 18:04:22Z yeti-dn $
+ *  $Id: utils.c 29431 2026-02-03 00:36:52Z yeti-dn $
  *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1150,8 +1150,8 @@ gwy_parse_doubles_error_quark(void)
  * Returns: A FILE* if the file was successfully opened, or %NULL if an error occurred.
  **/
 #ifdef G_OS_WIN32
-FILE *
-gwy_fopen(const gchar *filename, const gchar *mode)
+FILE*
+gwy_fopen(const char *filename, const char *mode)
 {
     wchar_t *wfilename = g_utf8_to_utf16(filename, -1, NULL, NULL, NULL);
     wchar_t *wmode;
@@ -1197,9 +1197,9 @@ gwy_fopen(const gchar *filename, const gchar *mode)
  *
  * Returns: the number of bytes printed.
  **/
-gint
+int
 gwy_fprintf(FILE        *file,
-            gchar const *format,
+            char const *format,
             ...)
 {
     gchar *string = NULL;
@@ -1219,19 +1219,19 @@ gwy_fprintf(FILE        *file,
 #undef gwy_fprintf
 
 FILE*
-gwy_fopen(const gchar *filename,
-          const gchar *mode)
+gwy_fopen(const char *filename,
+          const char *mode)
 {
     return fopen(filename, mode);
 }
 
-gint
+int
 gwy_fprintf(FILE        *file,
-            gchar const *format,
+            char const *format,
             ...)
 {
     va_list args;
-    gint retval;
+    int retval;
 
     va_start(args, format);
     retval = vfprintf(file, format, args);
