@@ -1,5 +1,5 @@
 /*
- *  $Id: watershed.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: watershed.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -17,11 +17,12 @@
 
 #include "config.h"
 #include <string.h>
-#include <libgwyddion/macros.h>
-#include <libgwyddion/filters.h>
-#include <libgwyddion/stats.h>
-#include <libgwyddion/grains-nield.h>
-#include <libgwyddion/watershed.h>
+
+#include "libgwyddion/macros.h"
+#include "libgwyddion/filters.h"
+#include "libgwyddion/stats.h"
+#include "libgwyddion/grains.h"
+#include "libgwyddion/watershed.h"
 
 #include "libgwyddion/int-list.h"
 #include "libgwyddion/omp.h"
@@ -88,7 +89,7 @@ static void     ensure_separation    (GwyNield *nield);
  * Performs watershed algorithm.
  **/
 void
-gwy_NIELD_mark_watershed(GwyField *field,
+gwy_field_mark_watershed(GwyField *field,
                          GwyNield *grains,
                          gint locate_steps,
                          gint locate_thresh,
@@ -136,7 +137,7 @@ gwy_NIELD_mark_watershed(GwyField *field,
 }
 
 /**
- * gwy_NIELD_watershed_init:
+ * gwy_field_watershed_init:
  * @field: Data to be used for marking.
  * @grains: Result of marking (mask).
  * @locate_steps: Locating algorithm steps.
@@ -154,7 +155,7 @@ gwy_NIELD_mark_watershed(GwyField *field,
  * Returns: A new watershed iterator.
  **/
 GwyComputationState*
-gwy_NIELD_watershed_init(GwyField *field,
+gwy_field_watershed_init(GwyField *field,
                          GwyNield *grains,
                          gint locate_steps,
                          gint locate_thresh,
@@ -188,7 +189,7 @@ gwy_NIELD_watershed_init(GwyField *field,
 }
 
 /**
- * gwy_NIELD_watershed_iteration:
+ * gwy_field_watershed_iteration:
  * @state: Watershed iterator.
  *
  * Performs one iteration of the watershed algorithm.
@@ -201,7 +202,7 @@ gwy_NIELD_watershed_init(GwyField *field,
  * resources.
  **/
 void
-gwy_NIELD_watershed_iteration(GwyComputationState *cstate)
+gwy_field_watershed_iteration(GwyComputationState *cstate)
 {
     GwyWatershedState *state = (GwyWatershedState*)cstate;
 
@@ -268,13 +269,13 @@ gwy_NIELD_watershed_iteration(GwyComputationState *cstate)
 }
 
 /**
- * gwy_NIELD_watershed_finalize:
+ * gwy_field_watershed_finalize:
  * @state: Watershed iterator.
  *
  * Destroys a watershed iterator, freeing all resources.
  **/
 void
-gwy_NIELD_watershed_finalize(GwyComputationState *cstate)
+gwy_field_watershed_finalize(GwyComputationState *cstate)
 {
     GwyWatershedState *state = (GwyWatershedState*)cstate;
 
@@ -287,7 +288,7 @@ gwy_NIELD_watershed_finalize(GwyComputationState *cstate)
 }
 
 /**
- * gwy_NIELD_splash_water:
+ * gwy_field_splash_water:
  * @field: Data field used for marking.
  * @water: Number field where to mark minima.
  * @markbuf: (nullable): Scratch space data field to avoid frequent allocations if used repeatedly.
@@ -299,14 +300,15 @@ gwy_NIELD_watershed_finalize(GwyComputationState *cstate)
  * If a non-%NULL @markbuf is passed, it must have the same dimensions as @field and @water.
  **/
 void
-gwy_NIELD_splash_water(GwyField *field,
+gwy_field_splash_water(GwyField *field,
                        GwyNield *water,
                        GwyField *markbuf,
                        gint locate_steps,
                        gdouble locate_dropsize)
 {
-    g_return_if_fail(GWY_IS_FIELD(field));
-    g_return_if_fail(GWY_IS_FIELD(water));
+    if (!_gwy_nield_check_field(water, field, FALSE)
+        || !_gwy_field_check_other(field, markbuf, TRUE))
+        return;
 
     if (!markbuf)
         markbuf = gwy_field_copy(field);
@@ -606,7 +608,7 @@ fix_grain_numbers(gint *grains, gint *buf, gint n)
 }
 
 /**
- * gwy_NIELD_waterpour:
+ * gwy_field_waterpour:
  * @field: A data field to segmentate.
  * @grains: Number field that will be filled with the resulting mask grain numbers. It will be resized to the
  *          dimensions of @field.
@@ -629,7 +631,7 @@ fix_grain_numbers(gint *grains, gint *buf, gint n)
  * Returns: The number of segments (grains) in the result, excluding the separators.
  **/
 gint
-gwy_NIELD_waterpour(GwyField *field,
+gwy_field_waterpour(GwyField *field,
                     GwyNield *grains)
 {
     g_return_val_if_fail(GWY_IS_FIELD(field), 0);
@@ -732,7 +734,7 @@ gwy_NIELD_waterpour(GwyField *field,
         assigned[k] = gnok;
     }
 
-    /* The grain numbering differs from gwy_field_number_grains() which performs the numbering from top left to
+    /* The grain numbering differs from gwy_nield_number_contiguous() which performs the numbering from top left to
      * bottom right. Since we guarantee stable grain numbers, renumber the grains to match that. Recycle @queue as
      * a scratch buffer. */
     gwy_clear(queue, gno+1);
@@ -900,7 +902,7 @@ propagate_non_extrema_marking(GwyField *field, GwyNield *types)
  * a single value is considered to have neither minimum nor maximum.
  **/
 void
-gwy_NIELD_mark_extrema(GwyField *field,
+gwy_field_mark_extrema(GwyField *field,
                        GwyNield *extrema,
                        gboolean maxima)
 {
@@ -911,7 +913,7 @@ gwy_NIELD_mark_extrema(GwyField *field,
     gwy_nield_clear(extrema);
 
     gdouble min, max;
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     /* This takes care of 1×1 fields too. */
     if (min == max)
         return;
