@@ -1,5 +1,5 @@
 /*
- *  $Id: color-axis.c 28669 2025-10-20 13:33:51Z yeti-dn $
+ *  $Id: color-axis.c 29522 2026-02-23 12:44:07Z yeti-dn $
  *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -454,17 +454,17 @@ draw_labels_ticks(GwyColorAxis *axis, cairo_t *cr)
     if (priv->orientation == GTK_ORIENTATION_VERTICAL) {
         cairo_rectangle(cr, 0.5, 0.5, swidth, height-1);
         cairo_move_to(cr, 0.5, 0.5);
-        cairo_rel_line_to(cr, width-1, 0.0);
+        cairo_rel_line_to(cr, swidth + tlength, 0.0);
         cairo_move_to(cr, 0.5, height - 0.5);
-        cairo_rel_line_to(cr, width-1, 0.0);
+        cairo_rel_line_to(cr, swidth + tlength, 0.0);
         size = height;
     }
     else {
         cairo_rectangle(cr, 0.5, 0.5, width-1, swidth);
         cairo_move_to(cr, 0.5, 0.5);
-        cairo_rel_line_to(cr, 0.5, height-1);
+        cairo_rel_line_to(cr, 0.5, swidth + tlength);
         cairo_move_to(cr, width - 0.5, 0.5);
-        cairo_rel_line_to(cr, 0.5, height-1);
+        cairo_rel_line_to(cr, 0.5, swidth + tlength);
         size = width;
     }
     cairo_stroke(cr);
