@@ -1,5 +1,5 @@
 /*
- *  $Id: gwydataview.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: gwydataview.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -58,7 +58,7 @@ struct _GwyDataViewPrivate {
     gchar *cursor_name;
 
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGradient *gradient;
     GwyVectorLayer *interactive_layer;
     GwyColorMappingType color_mapping;
@@ -794,7 +794,7 @@ gwy_data_view_set_field(GwyDataView *view,
  * Returns: (nullable) (transfer none):
  *          The currently displayed mask field, possibly %NULL.
  **/
-GwyField*
+GwyNield*
 gwy_data_view_get_mask(GwyDataView *view)
 {
     g_return_val_if_fail(GWY_IS_DATA_VIEW(view), NULL);
@@ -804,17 +804,17 @@ gwy_data_view_get_mask(GwyDataView *view)
 /**
  * gwy_data_view_set_mask:
  * @view: A data view.
- * @mask: (transfer none) (nullable):
+ * @mask: (transfer none) (nullable): Number field to draw as the mask.
  *
  * Sets the mask field currently shown by the data view.
  **/
 void
 gwy_data_view_set_mask(GwyDataView *view,
-                       GwyField *mask)
+                       GwyNield *mask)
 {
     g_return_if_fail(GWY_IS_DATA_VIEW(view));
     GwyDataViewPrivate *priv = view->priv;
-    if (!gwy_set_member_object(view, mask, GWY_TYPE_FIELD, &priv->mask,
+    if (!gwy_set_member_object(view, mask, GWY_TYPE_NIELD, &priv->mask,
                                "data-changed", &mask_changed, &priv->mask_changed_id, G_CONNECT_SWAPPED,
                                NULL))
         return;
@@ -1726,9 +1726,21 @@ default_gradient_changed(GwyDataView *view)
 }
 
 static GdkPixbuf*
-ensure_pixbuf(GwyField *field, GdkPixbuf *pixbuf, gboolean has_alpha)
+ensure_pixbuf(gpointer field, GdkPixbuf *pixbuf, gboolean has_alpha)
 {
-    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint xres, yres;
+    if (GWY_IS_FIELD(field)) {
+        xres = gwy_field_get_xres(field);
+        yres = gwy_field_get_yres(field);
+    }
+    else if (GWY_IS_NIELD(field)) {
+        xres = gwy_nield_get_xres(field);
+        yres = gwy_nield_get_yres(field);
+    }
+    else {
+        g_return_val_if_reached(NULL);
+    }
+
     if (pixbuf && gdk_pixbuf_get_width(pixbuf) == xres && gdk_pixbuf_get_height(pixbuf) == yres)
         return pixbuf;
 
@@ -1754,7 +1766,7 @@ paint_field(GwyDataView *view)
      * outliers. */
     if (color_mapping == GWY_COLOR_MAPPING_FULL || color_mapping == GWY_COLOR_MAPPING_ADAPT
         || (color_mapping == GWY_COLOR_MAPPING_FIXED && !priv->fixed_range_set)) {
-        gwy_field_get_min_max(field, &priv->range_min, &priv->range_max);
+        gwy_field_min_max(field, &priv->range_min, &priv->range_max);
         if (color_mapping == GWY_COLOR_MAPPING_ADAPT)
             gwy_draw_field_pixbuf_adaptive(pixbuf, field, gradient);
         else
@@ -1766,7 +1778,7 @@ paint_field(GwyDataView *view)
         priv->range_min = priv->fixed_min;
         priv->range_max = priv->fixed_max;
         if (color_mapping == GWY_COLOR_MAPPING_AUTO)
-            gwy_field_get_autorange(field, &priv->range_min, &priv->range_max);
+            gwy_field_autorange(field, &priv->range_min, &priv->range_max);
         gwy_draw_field_pixbuf_with_range(pixbuf, field, gradient, priv->range_min, priv->range_max);
     }
 }
@@ -1778,12 +1790,12 @@ paint_mask(GwyDataView *view)
     if (!priv->field_needs_repaint)
         return;
 
-    GwyField *mask = priv->mask;
+    GwyNield *mask = priv->mask;
 
     g_return_if_fail(mask);
 
     GdkPixbuf *pixbuf = priv->mask_pixbuf = ensure_pixbuf(mask, priv->mask_pixbuf, TRUE);
-    gwy_draw_field_pixbuf_mask(pixbuf, mask, &priv->mask_color);
+    gwy_draw_nield_pixbuf_mask(pixbuf, mask, &priv->mask_color);
 }
 
 /**
