@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyglwindow.c 28812 2025-11-05 18:59:42Z yeti-dn $
+ *  $Id: gwyglwindow.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -423,18 +423,18 @@ pack_buttons(GwyGLWindow *window, guint offset, GtkBox *box)
 
 /**
  * gwy_gl_window_new:
- * @data: A #GwyContainer containing the data to display.
+ * @data: A #GwyDict containing the data to display.
  *
  * Creates a new OpenGL 3D data displaying window.
  *
  * Returns: A newly created widget, as #GtkWidget.
  **/
 GtkWidget*
-gwy_gl_window_new(GwyContainer *data)
+gwy_gl_window_new(GwyDict *data)
 {
     GwyGLWindow *window = g_object_new(GWY_TYPE_GL_WINDOW, NULL);
 
-    g_return_val_if_fail(GWY_IS_CONTAINER(data), (GtkWidget*)window);
+    g_return_val_if_fail(GWY_IS_DICT(data), (GtkWidget*)window);
 
     GwyGLWindowPrivate *priv = window->priv;
     GtkWidget *hbox = gtk_bin_get_child(GTK_BIN(window));
@@ -610,7 +610,7 @@ build_visual_tab(GwyGLWindow *window)
     GwyGLWindowPrivate *priv = window->priv;
     GwyGLView *view = GWY_GL_VIEW(priv->view);
     GwyGLSetup *setup = gwy_gl_view_get_setup(view);
-    GwyContainer *data = gwy_gl_view_get_data(view);
+    GwyDict *data = gwy_gl_view_get_data(view);
     GwyGLVisualization visualization;
     g_object_get(setup, "visualization", &visualization, NULL);
 
@@ -662,7 +662,7 @@ build_visual_tab(GwyGLWindow *window)
     row++;
 
     const gchar *name = NULL;
-    gwy_container_gis_string_by_name(data, gwy_gl_view_get_material_key(view), &name);
+    gwy_dict_gis_string_by_name(data, gwy_gl_view_get_material_key(view), &name);
     menu = gwy_gl_material_selection_new(G_CALLBACK(set_material), window, name);
     priv->material_menu = menu;
     gtk_widget_set_sensitive(menu, is_material);
@@ -684,7 +684,7 @@ build_visual_tab(GwyGLWindow *window)
     row++;
 
     name = NULL;
-    gwy_container_gis_string_by_name(data, gwy_gl_view_get_gradient_key(view), &name);
+    gwy_dict_gis_string_by_name(data, gwy_gl_view_get_gradient_key(view), &name);
     menu = gwy_gradient_selection_new(G_CALLBACK(set_gradient), window, name);
     gtk_widget_set_sensitive(menu, is_gradient || is_overlay);
     priv->gradient_menu = menu;
@@ -1037,7 +1037,7 @@ set_gradient(GtkTreeSelection *selection, GwyGLWindow *window)
     gtk_tree_model_get(model, &iter, 0, &resource, -1);
     const gchar *name = gwy_resource_get_name(resource);
 
-    gwy_container_set_const_string_by_name(gwy_gl_view_get_data(view),
+    gwy_dict_set_const_string_by_name(gwy_gl_view_get_data(view),
                                            gwy_gl_view_get_gradient_key(view),
                                            name);
 }
@@ -1058,7 +1058,7 @@ set_material(GtkTreeSelection *selection, GwyGLWindow *window)
     gtk_tree_model_get(model, &iter, 0, &resource, -1);
     const gchar *name = gwy_resource_get_name(resource);
 
-    gwy_container_set_const_string_by_name(gwy_gl_view_get_data(view),
+    gwy_dict_set_const_string_by_name(gwy_gl_view_get_data(view),
                                            gwy_gl_view_get_material_key(view),
                                            name);
 }
@@ -1305,19 +1305,19 @@ reset_visualisation(GwyGLWindow *window)
 {
     GwyGLWindowPrivate *priv = window->priv;
     GwyGLView *view = GWY_GL_VIEW(priv->view);
-    GwyContainer *data = gwy_gl_view_get_data(view);
+    GwyDict *data = gwy_gl_view_get_data(view);
     const gchar *name, *key;
 
     /* This sequence ensures gradient changes to the *current* default, even if it unset presently. */
     key = gwy_gl_view_get_gradient_key(view);
     name = gwy_inventory_get_default_item_name(gwy_gradients());
-    gwy_container_set_const_string_by_name(data, key, name);
-    gwy_container_remove_by_name(data, key);
+    gwy_dict_set_const_string_by_name(data, key, name);
+    gwy_dict_remove_by_name(data, key);
 
     key = gwy_gl_view_get_material_key(view);
     name = gwy_inventory_get_default_item_name(gwy_gl_materials());
-    gwy_container_set_const_string_by_name(data, key, name);
-    gwy_container_remove_by_name(data, key);
+    gwy_dict_set_const_string_by_name(data, key, name);
+    gwy_dict_remove_by_name(data, key);
 }
 
 static gboolean
@@ -1405,7 +1405,7 @@ gradient_selected(GtkWidget *item, GwyGLWindow *window)
     const gchar *name = g_object_get_data(G_OBJECT(item), "gradient-name");
     gwy_gradient_selection_set_active(priv->gradient_menu, name);
     /* FIXME: Double update if tree view is visible. Remove once selection buttons can emit signals. */
-    gwy_container_set_const_string_by_name(gwy_gl_view_get_data(view),
+    gwy_dict_set_const_string_by_name(gwy_gl_view_get_data(view),
                                            gwy_gl_view_get_gradient_key(view),
                                            name);
 }
@@ -1419,7 +1419,7 @@ material_selected(GtkWidget *item, GwyGLWindow *window)
 
     gwy_gl_material_selection_set_active(priv->material_menu, name);
     /* FIXME: Double update if tree view is visible. Remove once selection buttons can emit signals. */
-    gwy_container_set_const_string_by_name(gwy_gl_view_get_data(view),
+    gwy_dict_set_const_string_by_name(gwy_gl_view_get_data(view),
                                            gwy_gl_view_get_material_key(view),
                                            name);
 }
@@ -1430,18 +1430,18 @@ set_zscale(GwyGLWindow *window)
     GwyGLWindowPrivate *priv = window->priv;
     GwyGLView *view = GWY_GL_VIEW(priv->view);
     GwyGLSetup *setup = gwy_gl_view_get_setup(view);
-    GwyContainer *container = gwy_gl_view_get_data(view);
+    GwyDict *container = gwy_gl_view_get_data(view);
     const gchar *data_key = gwy_gl_view_get_data_key(view);
     GwyField *dfield = NULL;
 
-    if (!container || !setup || !data_key || !gwy_container_gis_object_by_name(container, data_key, &dfield))
+    if (!container || !setup || !data_key || !gwy_dict_gis_object_by_name(container, data_key, &dfield))
         return;
 
     gdouble entryval = g_strtod(gtk_entry_get_text(GTK_ENTRY(priv->physcale_entry)), NULL);
 
     /* XXX: We need to carefully emulate the code from GL view here. */
     gdouble min, max, xreal, yreal, scale, zscale;
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
     xreal = gwy_field_get_xreal(dfield);
     yreal = gwy_field_get_yreal(dfield);
     scale = 2.0/MAX(xreal, yreal);
@@ -1456,7 +1456,7 @@ update_physcale_entry(GwyGLWindow *window, GtkAdjustment *adj)
     GwyGLWindowPrivate *priv = window->priv;
     GwyGLView *view = GWY_GL_VIEW(priv->view);
     GwyGLSetup *setup = gwy_gl_view_get_setup(view);
-    GwyContainer *container = gwy_gl_view_get_data(view);
+    GwyDict *container = gwy_gl_view_get_data(view);
     const gchar *data_key = gwy_gl_view_get_data_key(view);
     GwyField *dfield = NULL;
 
@@ -1464,12 +1464,12 @@ update_physcale_entry(GwyGLWindow *window, GtkAdjustment *adj)
     container = gwy_gl_view_get_data(view);
     setup = gwy_gl_view_get_setup(view);
     data_key = gwy_gl_view_get_data_key(view);
-    if (!container || !setup || !data_key || !gwy_container_gis_object_by_name(container, data_key, &dfield))
+    if (!container || !setup || !data_key || !gwy_dict_gis_object_by_name(container, data_key, &dfield))
         return;
 
     /* XXX: We need to carefully emulate the code from GL view here. */
     gdouble min, max, xreal, yreal, scale, physcale;
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
     xreal = gwy_field_get_xreal(dfield);
     yreal = gwy_field_get_yreal(dfield);
     scale = 2.0/MAX(xreal, yreal);
