@@ -1,6 +1,6 @@
 #pragma once
 /*
- *  $Id: icons.h 28233 2025-07-16 10:46:57Z yeti-dn $
+ *  $Id: icons.h 29226 2026-01-15 09:58:34Z yeti-dn $
  *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -83,8 +83,8 @@ G_BEGIN_DECLS
 #define GWY_ICON_GRADIENT_HORIZONTAL            "gwy_gradient_horizontal"
 #define GWY_ICON_GRADIENT_VERTICAL              "gwy_gradient_vertical"
 #define GWY_ICON_GRAIN_BOUNDING_BOX             "gwy_grain_bounding_box"
+#define GWY_ICON_GRAIN_CIRCUMCIRCLE             "gwy_grain_circumcircle"
 #define GWY_ICON_GRAIN_CORRELATION              "gwy_grain_correlation"
-#define GWY_ICON_GRAIN_EXSCRIBED_CIRCLE         "gwy_grain_exscribed_circle"
 #define GWY_ICON_GRAIN_INSCRIBED_BOX            "gwy_grain_inscribed_box"
 #define GWY_ICON_GRAIN_INSCRIBED_CIRCLE         "gwy_grain_inscribed_circle"
 #define GWY_ICON_GRAINS                         "gwy_grains"
