@@ -1,5 +1,5 @@
 /*
- *  $Id: utils.c 28674 2025-10-20 15:36:44Z yeti-dn $
+ *  $Id: utils.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -422,7 +422,7 @@ gwy_gtkgrid_hscale_get_middle_widget(GObject *pivot)
 
 typedef struct {
     GwyColorButton *color_button;
-    GwyContainer *container;
+    GwyDict *container;
     GQuark quark;
 } MaskColorSelectorData;
 
@@ -433,7 +433,7 @@ mask_color_updated(GwyColorEditor *editor, MaskColorSelectorData *mcsdata)
 
     GwyRGBA color;
     gwy_color_editor_get_color(editor, &color);
-    gwy_container_set_boxed(mcsdata->container, GWY_TYPE_RGBA, mcsdata->quark, &color);
+    gwy_dict_set_boxed(mcsdata->container, GWY_TYPE_RGBA, mcsdata->quark, &color);
 
     if (mcsdata->color_button)
         gwy_color_button_set_color(mcsdata->color_button, &color);
@@ -457,7 +457,7 @@ void
 gwy_mask_color_selector_run(const gchar *dialog_title,
                             GtkWindow *parent,
                             GwyColorButton *color_button,
-                            GwyContainer *container,
+                            GwyDict *container,
                             GQuark quark)
 {
     g_return_if_fail(quark);
@@ -469,7 +469,7 @@ gwy_mask_color_selector_run(const gchar *dialog_title,
     };
 
     GwyRGBA color = { 1.0, 0.0, 0.0, 0.5 };
-    if (!gwy_container_gis_boxed(container, GWY_TYPE_RGBA, quark, &color))
+    if (!gwy_dict_gis_boxed(container, GWY_TYPE_RGBA, quark, &color))
         g_warning("No current color to modify.");
 
     GtkWidget *dialog = gwy_color_dialog_new(parent, TRUE);
