@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_align.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti).
+ *  $Id: cmap_align.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -57,7 +57,7 @@ typedef struct {
     GwyLawn *lawn;
     GwyLawn *result;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     /* Cached input data properties. */
     gint nsegments;
 } ModuleArgs;
@@ -110,7 +110,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Aligns curves in a curve map by shifting the values."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2021",
 };
@@ -188,9 +188,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     sanitise_params(&args);
 
     args.field = gwy_lawn_new_field_alike(lawn, -1, TRUE);
-    args.mask = gwy_field_new_alike(args.field, TRUE);
+    args.mask = gwy_field_new_nield_alike(args.field);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -201,7 +201,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     output = gwy_params_get_flags(args.params, PARAM_OUTPUT);
     if (output & (1 << OUTPUT_PREVIEW)) {
-        field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+        field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
         gwy_field_assign(field, args.field);
         gwy_field_data_changed(field);
     }
@@ -209,10 +209,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         newid = gwy_file_add_image(data, args.field);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Topography"), TRUE);
-        if (gwy_field_get_max(args.mask) > 0.0)
-            gwy_file_pass_image_mask(data, gwy_file_key_image_mask(newid), args.mask);
-        else
-            g_clear_object(&args.mask);
+        gint ngrains = gwy_nield_number_contiguous(args.mask);
+        gwy_file_set_image_mask(data, newid, ngrains ? args.mask : NULL);
 
         gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                             data, GWY_FILE_IMAGE, newid,
@@ -250,7 +248,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     dialog = GWY_DIALOG(gui.dialog);
     gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
@@ -386,15 +384,15 @@ execute(ModuleArgs *args)
     AlignMethod method = gwy_params_get_enum(params, PARAM_METHOD);
     AlignOutput output = gwy_params_get_flags(params, PARAM_OUTPUT);
     GwyLawn *lawn = args->lawn;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     gint xres = gwy_lawn_get_xres(lawn), yres = gwy_lawn_get_yres(lawn);
-    gdouble *data, *mdata;
 
     /* First locate the point in all data.  This allows interpolating the failed ones. */
     gwy_unit_assign(gwy_field_get_unit_z(field), gwy_lawn_get_unit_curve(lawn, abscissa));
-    gwy_field_clear(mask);
-    data = gwy_field_get_data(field);
-    mdata = gwy_field_get_data(mask);
+    gwy_nield_clear(mask);
+    gdouble *data = gwy_field_get_data(field);
+    gint *mdata = gwy_nield_get_data(mask);
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -412,12 +410,12 @@ execute(ModuleArgs *args)
             if (locate_in_one_curve(lawn, col, row, abscissa, ordinate, segment, method, &x))
                 data[k] = x;
             else
-                mdata[k] = 1.0;
+                mdata[k] = 1;
         }
     }
 
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_field_laplace_solve(field, mask, -1, 1.0);
+    if (gwy_nield_count(mask))
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 1.0);
 
     if (output & (1 << OUTPUT_ALIGN)) {
         gint ndata, k, m, col, row;
