@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_fdfit.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti).
+ *  $Id: cmap_fdfit.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -59,7 +59,7 @@ typedef struct {
     gdouble *fit_param;
     gboolean *fixed;
     GPtrArray *result_fields;
-    GwyField *mask;
+    GwyNield *mask;
     gint adhesion_index;
     gdouble xmin;
     gdouble xmax;
@@ -159,7 +159,7 @@ static void             fit_param_table_update_units(ModuleGUI *gui);
 static void             update_graph_model_props    (GwyGraphModel *gmodel,
                                                      ModuleArgs *args);
 static void             add_mask_and_copy_gradient  (GwyFile *data,
-                                                     GwyField *mask,
+                                                     GwyNield *mask,
                                                      gint id,
                                                      gint newid);
 static void             param_value_activate        (ModuleGUI *gui,
@@ -171,7 +171,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fit FD curves."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2021",
 };
@@ -247,7 +247,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result_fields = g_ptr_array_new_full(0, g_object_unref);
     args.field = gwy_lawn_new_field_alike(lawn, -1, TRUE);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -275,10 +275,12 @@ end:
 }
 
 static void
-add_mask_and_copy_gradient(GwyFile *data, GwyField *mask, gint id, gint newid)
+add_mask_and_copy_gradient(GwyFile *data, GwyNield *mask, gint id, gint newid)
 {
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+    if (gwy_nield_max(mask) > 0) {
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
+    }
 
     gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -305,7 +307,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gtk_dialog_add_button(GTK_DIALOG(dialog), C_("verb", "_Fit single"), RESPONSE_FIT);
     gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
@@ -715,8 +717,8 @@ execute(ModuleArgs *args, GtkWindow *window)
         g_object_unref(unit);
         rdata[i] = gwy_field_get_data(result_field);
     }
-    args->mask = gwy_field_new(xres, yres, xreal, yreal, TRUE);
-    gdouble *mdata = gwy_field_get_data(args->mask);
+    args->mask = gwy_nield_new(xres, yres);
+    gint *mdata = gwy_nield_get_data(args->mask);
 
     gwy_app_wait_start(window, _("Fitting..."));
 
@@ -730,7 +732,7 @@ execute(ModuleArgs *args, GtkWindow *window)
         row = k/xres;
         cd = gwy_lawn_get_curves_data_const(lawn, col, row, &ndata);
         if (!ndata) {
-            mdata[k] = 1.0;
+            mdata[k] = 1;
             continue;
         }
 
@@ -757,13 +759,13 @@ execute(ModuleArgs *args, GtkWindow *window)
              rdata[j][k] = fit_param[j];
 
         if (!fitok)
-            mdata[k] = 1.0;
+            mdata[k] = 1;
     }
 
-    if (!cancelled && gwy_field_get_max(args->mask) > 0.0) {
+    if (!cancelled && gwy_nield_max(args->mask) > 0) {
         for (guint i = 0; i < nparams; i++) {
             GwyField *result_field = g_ptr_array_index(args->result_fields, i);
-            gwy_field_laplace_solve(result_field, args->mask, -1, 1.0);
+            gwy_field_laplace_solve(result_field, args->mask, GWY_LAPLACE_MASKED, 1.0);
         }
     }
 
@@ -947,7 +949,7 @@ do_fdfit(const gdouble *xdata, const gdouble *ydata,
        }
        adhesion -= baseline;
 
-       if (adhesion_index >=0 ) {
+       if (adhesion_index >= 0) {
            fitparams[adhesion_index] = adhesion;
            fix[adhesion_index] = 1;
        }
