@@ -1,6 +1,6 @@
 /*
  *  $Id: cmap_fit.c 25639 2023-09-07 12:23:42Z yeti-dn $
- *  Copyright (C) 2021-2025 David Necas (Yeti), Petr Klapetek.
+ *  Copyright (C) 2021-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -57,7 +57,7 @@ typedef struct {
     GwyField *field;
     gint nsegments;
     GPtrArray *result_fields;
-    GwyField *mask;
+    GwyNield *mask;
     gdouble *fit_param;
     gboolean *fixed;
     gdouble xmin;
@@ -141,7 +141,7 @@ static void             fit_param_table_update_units(ModuleGUI *gui);
 static void             update_graph_model_props    (GwyGraphModel *gmodel,
                                                      ModuleArgs *args);
 static void             add_mask_and_copy_gradient  (GwyFile *data,
-                                                     GwyField *mask,
+                                                     GwyNield *mask,
                                                      gint id,
                                                      gint newid);
 static void             param_value_activate        (ModuleGUI *gui,
@@ -153,7 +153,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fit curves in volume data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2024",
 };
@@ -231,7 +231,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_field_set_yoffset(args.field, gwy_lawn_get_yoffset(lawn));
     gwy_unit_assign(gwy_field_get_unit_xy(args.field), gwy_lawn_get_unit_xy(lawn));
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -290,10 +290,12 @@ end:
 }
 
 static void
-add_mask_and_copy_gradient(GwyFile *data, GwyField *mask, gint id, gint newid)
+add_mask_and_copy_gradient(GwyFile *data, GwyNield *mask, gint id, gint newid)
 {
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+    if (gwy_nield_max(mask) > 0) {
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
+    }
 
     gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -321,7 +323,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
@@ -686,7 +688,7 @@ execute(ModuleArgs *args, GtkWindow *window)
     gdouble fit_param[nparams], errors[nparams];
     gboolean fixed[nparams];
     GwyLawn *lawn = args->lawn;
-    gdouble **rdata, *mdata;
+    gdouble **rdata;
     gdouble chisq;
     gint xres = gwy_lawn_get_xres(lawn), yres = gwy_lawn_get_yres(lawn);
     gboolean fitok, cancelled = FALSE;
@@ -734,8 +736,8 @@ execute(ModuleArgs *args, GtkWindow *window)
     g_assert(n == args->result_fields->len);
     g_object_unref(unitx);
 
-    args->mask = gwy_lawn_new_field_alike(lawn, -1, TRUE);
-    mdata = gwy_field_get_data(args->mask);
+    args->mask = gwy_nield_new(gwy_lawn_get_xres(lawn), gwy_lawn_get_yres(lawn));
+    gint *mdata = gwy_nield_get_data(args->mask);
 
     gwy_app_wait_start(window, _("Fitting..."));
 
@@ -751,7 +753,7 @@ execute(ModuleArgs *args, GtkWindow *window)
         extract_one_curve(lawn, gc, col, row, segment, params);
         guint ndata = gwy_graph_curve_model_get_ndata(gc);
         if (!ndata) {
-            mdata[k] = 1.0;
+            mdata[k] = 1;
             continue;
         }
 
@@ -774,13 +776,13 @@ execute(ModuleArgs *args, GtkWindow *window)
             rdata[nparams + nparams*report_err][k] = chisq;
 
         if (!fitok)
-            mdata[k] = 1.0;
+            mdata[k] = 1;
     }
 
-    if (!cancelled && gwy_field_get_max(args->mask) > 0.0) {
+    if (!cancelled && gwy_nield_max(args->mask) > 0) {
         for (guint i = 0; i < nparams; i++) {
             GwyField *result_field = g_ptr_array_index(args->result_fields, i);
-            gwy_field_laplace_solve(result_field, args->mask, -1, 1.0);
+            gwy_field_laplace_solve(result_field, args->mask, GWY_LAPLACE_MASKED, 1.0);
         }
     }
 
