@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_linestat.c 29023 2025-12-19 13:06:16Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti).
+ *  $Id: cmap_linestat.c 29543 2026-02-24 14:07:07Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -62,7 +62,7 @@ typedef struct {
     GwyParams *params;
     GwyLawn *lawn;
     GwyField *result;
-    GwyField *mask;
+    GwyNield *mask;
     /* Cached input data properties. */
     gint nsegments;
 } ModuleArgs;
@@ -108,7 +108,7 @@ static void                        sanitise_params        (ModuleArgs *args);
 
 /* XXX: This is more or less identical to tools/linestat.c. */
 static const LineStatQuantityInfo quantities[] =  {
-    { N_("Mean"),            GWY_LINE_STAT_MEAN,     gwy_line_avg,      },
+    { N_("Mean"),            GWY_LINE_STAT_MEAN,     gwy_line_mean,      },
     { N_("Median"),          GWY_LINE_STAT_MEDIAN,   gwy_line_median,   },
     { N_("Minimum"),         GWY_LINE_STAT_MINIMUM,  gwy_line_min,      },
     { N_("Maximum"),         GWY_LINE_STAT_MAXIMUM,  gwy_line_max,      },
@@ -209,10 +209,10 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.nsegments = gwy_lawn_get_n_segments(lawn);
     args.params = gwy_params_new_from_settings(define_module_params());
     args.result = gwy_lawn_new_field_alike(lawn, -1, TRUE);
-    args.mask = gwy_field_new_alike(args.result, TRUE);
+    args.mask = gwy_field_new_nield_alike(args.result);
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -228,14 +228,12 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         title = gwy_C(find_quantity(quantity)->name);
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, title, TRUE);
-        if (gwy_field_get_max(args.mask) > 0.0)
-            gwy_file_pass_image_mask(data, newid, args.mask);
-        else
-            g_clear_object(&args.mask);
+        gint ngrains = gwy_nield_number_contiguous(args.mask);
+        gwy_file_set_image_mask(data, newid, ngrains ? args.mask : NULL);
         gwy_log_add_full(data, GWY_FILE_IMAGE, -1, newid, "cmap::cmap_linestat", NULL);
     }
     else if (output_type == OUTPUT_PREVIEW)
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(oldid), args.result);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_cmap_picture(oldid), args.result);
     else {
         g_assert_not_reached();
     }
@@ -403,17 +401,16 @@ update_current_value(ModuleGUI *gui)
     gint row = gwy_params_get_int(args->params, PARAM_YPOS);
     GwyValueFormat *vf;
     GwyUnit *unit;
-    gdouble v, m;
     gchar *s;
 
-    v = gwy_field_get_val(args->result, col, row);
-    m = gwy_field_get_val(args->mask, col, row);
+    gdouble v = gwy_field_get_val(args->result, col, row);
+    gint m = gwy_nield_get_val(args->mask, col, row);
     unit = gwy_field_get_unit_z(args->result);
     vf = gui->vf = gwy_unit_get_format_with_digits(unit, GWY_UNIT_FORMAT_VFMARKUP, v, 3, gui->vf);
     s = g_strdup_printf("%.*f%s%s", vf->precision, v/vf->magnitude, *vf->units ? " " : "", vf->units);
     gwy_param_table_info_set_valuestr(gui->table_quantity, LABEL_VALUE, s);
     g_free(s);
-    gwy_param_table_info_set_valuestr(gui->table_quantity, LABEL_INTERPOLATED, m > 0.0 ? _("(interpolated)") : NULL);
+    gwy_param_table_info_set_valuestr(gui->table_quantity, LABEL_INTERPOLATED, m > 0 ? _("(interpolated)") : NULL);
 }
 
 static void
@@ -424,7 +421,7 @@ preview(gpointer user_data)
 
     execute(args);
     gwy_field_data_changed(args->result);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
     update_graph_curve(gui);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
@@ -441,14 +438,14 @@ get_line_range(GwyLine *line)
 static gdouble
 get_line_Rt(GwyLine *line)
 {
-    gwy_line_add(line, -gwy_line_avg(line));
+    gwy_line_add(line, -gwy_line_mean(line));
     return gwy_line_xtm(line, 1, 1);
 }
 
 static gdouble
 get_line_Rz(GwyLine *line)
 {
-    gwy_line_add(line, -gwy_line_avg(line));
+    gwy_line_add(line, -gwy_line_mean(line));
     return gwy_line_xtm(line, 5, 1);
 }
 
@@ -461,18 +458,16 @@ execute(ModuleArgs *args)
     gboolean segment_enabled = args->nsegments ? gwy_params_get_boolean(params, PARAM_ENABLE_SEGMENT) : FALSE;
     gint segment = segment_enabled ? gwy_params_get_int(params, PARAM_SEGMENT) : -1;
     GwyLawn *lawn = args->lawn;
-    GwyField *field = args->result, *mask = args->mask;
+    GwyField *field = args->result;
+    GwyNield *mask = args->mask;
     GwyUnit *imgunit, *valunit;
     gint xres = gwy_lawn_get_xres(lawn), yres = gwy_lawn_get_yres(lawn);
-    LineStatFunc lsfunc = NULL;
-    gdouble *data, *mdata;
-
     /* Quantities we handle (somewhat inefficiently) by using Line statistics. */
-    lsfunc = find_quantity(quantity)->func;
+    LineStatFunc lsfunc = find_quantity(quantity)->func;
 
-    gwy_field_clear(mask);
-    data = gwy_field_get_data(field);
-    mdata = gwy_field_get_data(mask);
+    gwy_nield_clear(mask);
+    gdouble *data = gwy_field_get_data(field);
+    gint *mdata = gwy_nield_get_data(mask);
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -488,7 +483,7 @@ execute(ModuleArgs *args)
             if (extract_line(lawn, dline, k % xres, k/xres, curveno, segment))
                 data[k] = lsfunc(dline);
             else
-                mdata[k] = 1.0;
+                mdata[k] = 1;
         }
 
         g_object_unref(dline);
@@ -502,8 +497,8 @@ execute(ModuleArgs *args)
     else
         gwy_unit_assign(imgunit, valunit);
 
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_field_laplace_solve(field, mask, -1, 1.0);
+    if (gwy_nield_max(mask) > 0)
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 1.0);
 }
 
 static gint
