@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_lockin.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti).
+ *  $Id: cmap_lockin.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -63,7 +63,7 @@ typedef struct {
     GwyLawn *lawn;
     GwyField *amplitude;
     GwyField *phase;
-    GwyField *mask;
+    GwyNield *mask;
     gdouble xmin;
     gdouble xmax;
     gint nsegments;
@@ -84,7 +84,7 @@ static GwyParamDef*     define_module_params      (void);
 static void             module_main               (GwyFile *data,
                                                    GwyRunModeFlags mode);
 static void             add_mask_and_copy_gradient(GwyFile *data,
-                                                   GwyField *mask,
+                                                   GwyNield *mask,
                                                    gint id,
                                                    gint newid);
 static void             execute                   (ModuleArgs *args,
@@ -140,7 +140,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Detect oscillations in a curve."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2022",
 };
@@ -236,9 +236,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.phase = gwy_lawn_new_field_alike(lawn, -1, TRUE);
     gwy_unit_assign(gwy_field_get_unit_z(args.phase), gwy_unit_new("rad"));
 
-    args.mask = gwy_lawn_new_field_alike(lawn, -1, TRUE);
+    args.mask = gwy_nield_new(gwy_lawn_get_xres(lawn), gwy_lawn_get_yres(lawn));
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -250,7 +250,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     output = gwy_params_get_flags(args.params, PARAM_OUTPUT);
     if (output & (1 << OUTPUT_PREVIEW)) {
-        field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+        field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
         gwy_field_assign(field, args.amplitude);
         gwy_field_data_changed(field);
     }
@@ -276,10 +276,12 @@ end:
 }
 
 static void
-add_mask_and_copy_gradient(GwyFile *data, GwyField *mask, gint id, gint newid)
+add_mask_and_copy_gradient(GwyFile *data, GwyNield *mask, gint id, gint newid)
 {
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+    if (gwy_nield_max(mask) > 0) {
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
+    }
 
     gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -304,7 +306,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     dialog = GWY_DIALOG(gui.dialog);
     gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
@@ -523,17 +525,16 @@ execute(ModuleArgs *args, GtkWindow *window)
 {
     GwyParams *params = args->params;
     gdouble amplitude, phase, frequency, carrier_phase;
-    gdouble *adata, *pdata, *mdata;
     gint xres = gwy_lawn_get_xres(args->lawn), yres = gwy_lawn_get_yres(args->lawn);
     gint quantity = gwy_params_get_int(params, PARAM_QUANTITY);
     gint k, col, row;
     gboolean fitok;
 
-    gwy_field_fill(args->mask, 0);
+    gwy_nield_clear(args->mask);
 
-    adata = gwy_field_get_data(args->amplitude);
-    pdata = gwy_field_get_data(args->phase);
-    mdata = gwy_field_get_data(args->mask);
+    gdouble *adata = gwy_field_get_data(args->amplitude);
+    gdouble *pdata = gwy_field_get_data(args->phase);
+    gint *mdata = gwy_nield_get_data(args->mask);
 
     gwy_app_wait_start(window, _("Fitting..."));
 
@@ -553,15 +554,15 @@ execute(ModuleArgs *args, GtkWindow *window)
     }
     gwy_field_data_changed(args->amplitude);
     gwy_field_data_changed(args->phase);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
 
     gwy_unit_assign(gwy_field_get_unit_z(args->amplitude), gwy_lawn_get_unit_curve(args->lawn, quantity));
 
     gwy_app_wait_finish();
 
-    if (gwy_field_get_max(args->mask) > 0.0) {
-        gwy_field_laplace_solve(args->amplitude, args->mask, -1, 1.0);
-        gwy_field_laplace_solve(args->phase, args->mask, -1, 1.0);
+    if (gwy_nield_max(args->mask) > 0) {
+        gwy_field_laplace_solve(args->amplitude, args->mask, GWY_LAPLACE_MASKED, 1.0);
+        gwy_field_laplace_solve(args->phase, args->mask, GWY_LAPLACE_MASKED, 1.0);
     }
 }
 
@@ -735,7 +736,8 @@ guess(gdouble *y, gint n, gdouble *amplitude, gdouble *phase, gdouble *offset)
 
 static gboolean
 process_point(GwyLawn *lawn, gint nsegments, const gint *segments, gint col, gint row,
-              GwyParams *params, gdouble *amplitude, gdouble *phase, gdouble *frequency, gdouble *carrier_phase)
+              GwyParams *params,
+              gdouble *amplitude, gdouble *phase, gdouble *frequency, gdouble *carrier_phase)
 {
     gint ndata, nndata;
     gdouble from = gwy_params_get_double(params, PARAM_RANGE_FROM);
