@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_possearch.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti).
+ *  $Id: cmap_possearch.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -60,7 +60,7 @@ typedef struct {
     GwyParams *params;
     GwyLawn *lawn;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyValueFormat *vf;
     /* Cached input data properties. */
     gint nsegments;
@@ -110,7 +110,7 @@ static void             extract_one_curve         (GwyLawn *lawn,
 static void             update_graph_model_props  (GwyGraphModel *gmodel,
                                                    ModuleArgs *args);
 static void             add_mask_and_copy_gradient(GwyFile *data,
-                                                   GwyField *mask,
+                                                   GwyNield *mask,
                                                    gint id,
                                                    gint newid);
 static void             sanitise_params           (ModuleArgs *args);
@@ -120,7 +120,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Picks a quantity at some threshold position."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2022",
 };
@@ -204,9 +204,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.vf = gwy_lawn_get_value_format_curve(lawn, 0, GWY_UNIT_FORMAT_VFMARKUP, NULL);
 
     args.field = gwy_lawn_new_field_alike(lawn, -1, TRUE);
-    args.mask = gwy_field_new_alike(args.field, TRUE);
+    args.mask = gwy_field_new_nield_alike(args.field);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -217,7 +217,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     output = gwy_params_get_flags(args.params, PARAM_OUTPUT);
     if (output & (1 << OUTPUT_PREVIEW)) {
-        field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+        field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
         gwy_field_assign(field, args.field);
         gwy_field_data_changed(field);
     }
@@ -236,10 +236,12 @@ end:
 }
 
 static void
-add_mask_and_copy_gradient(GwyFile *data, GwyField *mask, gint id, gint newid)
+add_mask_and_copy_gradient(GwyFile *data, GwyNield *mask, gint id, gint newid)
 {
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+    if (gwy_nield_max(mask) > 0) {
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
+    }
 
     gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -439,15 +441,15 @@ execute(ModuleArgs *args)
     PosSearchDir dir = gwy_params_get_enum(params, PARAM_DIR);
     gdouble threshold = gwy_params_get_double(params, PARAM_THRESHOLD)*args->vf->magnitude;
     GwyLawn *lawn = args->lawn;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     gint xres = gwy_lawn_get_xres(lawn), yres = gwy_lawn_get_yres(lawn);
-    gdouble *data, *mdata;
 
     /* First locate the point in all data.  This allows interpolating the failed ones. */
     gwy_unit_assign(gwy_field_get_unit_z(field), gwy_lawn_get_unit_curve(lawn, pick_curve));
-    gwy_field_clear(mask);
-    data = gwy_field_get_data(field);
-    mdata = gwy_field_get_data(mask);
+    gwy_nield_clear(mask);
+    gdouble *data = gwy_field_get_data(field);
+    gint *mdata = gwy_nield_get_data(mask);
 
     /*
 #ifdef _OPENMP
@@ -466,12 +468,12 @@ execute(ModuleArgs *args)
             if (locate_in_one_curve(lawn, col, row, pick_curve, search_curve, segment, method, dir, threshold, &x))
                 data[k] = x;
             else
-                mdata[k] = 1.0;
+                mdata[k] = 1;
         }
     }
 
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_field_laplace_solve(field, mask, -1, 1.0);
+    if (gwy_nield_max(mask) > 0)
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 1.0);
 }
 
 static gboolean
