@@ -1,6 +1,6 @@
 /*
- *  $Id: cmap_simplemech.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: cmap_simplemech.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2021-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -71,7 +71,7 @@ typedef struct {
     GwyLawn *lawn;
     GwyField *result[NOUTPUTS];
     GwyField *preview;
-    GwyField *mask;
+    GwyNield *mask;
     /* Cached input data properties. */
     gint nsegments;
 } ModuleArgs;
@@ -137,7 +137,7 @@ static void             extract_one_curve         (GwyLawn *lawn,
                                                    gint ordinate);
 static void             update_graph_model_props  (ModuleGUI *gui);
 static void             add_mask_and_copy_gradient(GwyFile *data,
-                                                   GwyField *mask,
+                                                   GwyNield *mask,
                                                    gint id,
                                                    gint newid);
 static void             sanitise_params           (ModuleArgs *args);
@@ -253,14 +253,14 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    args.preview = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(oldid));
+    args.preview = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(oldid));
     sanitise_params(&args);
 
     for (i = 0; i < NOUTPUTS; i++)
         args.result[i] = gwy_lawn_new_field_alike(lawn, -1, TRUE);
-    args.mask = gwy_field_new_alike(args.result[0], TRUE);
+    args.mask = gwy_field_new_nield_alike(args.result[0]);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -285,13 +285,16 @@ end:
     for (i = 0; i < NOUTPUTS; i++)
         g_object_unref(args.result[i]);
     g_object_unref(args.params);
+    g_object_unref(args.mask);
 }
 
 static void
-add_mask_and_copy_gradient(GwyFile *data, GwyField *mask, gint id, gint newid)
+add_mask_and_copy_gradient(GwyFile *data, GwyNield *mask, gint id, gint newid)
 {
-    if (gwy_field_get_max(mask) > 0.0)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+    if (gwy_nield_max(mask) > 0) {
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
+    }
 
     gwy_file_sync_items(data, GWY_FILE_CMAP, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -325,7 +328,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gwy_dialog_add_content(GWY_DIALOG(gui.dialog), hbox, TRUE, TRUE, 0);
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gui.view = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
@@ -864,18 +867,17 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     gdouble radius = gwy_params_get_double(params, PARAM_RADIUS);
     gdouble nu = gwy_params_get_double(params, PARAM_NU);
 
-    GwyUnit *unit, *xunit, *yunit;
     gboolean cancelled = FALSE;
-    gdouble *rdata[NOUTPUTS], *mdata;
+    gdouble *rdata[NOUTPUTS];
     guint i;
 
     /* Find segment cut points. */
     gwy_app_wait_start(wait_window, _("Fitting in progress..."));
 
-    xunit = gwy_lawn_get_unit_curve(lawn, abscissa);
-    yunit = gwy_lawn_get_unit_curve(lawn, ordinate);
+    GwyUnit *xunit = gwy_lawn_get_unit_curve(lawn, abscissa);
+    GwyUnit *yunit = gwy_lawn_get_unit_curve(lawn, ordinate);
     for (i = 0; i < NOUTPUTS; i++) {
-        unit = gwy_field_get_unit_z(args->result[i]);
+        GwyUnit *unit = gwy_field_get_unit_z(args->result[i]);
         if (output_info[i].power_u)
             gwy_unit_set_from_string(unit, "Pa");
         else if (output_info[i].power_v)
@@ -885,8 +887,8 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         gwy_field_clear(args->result[i]);
         rdata[i] = gwy_field_get_data(args->result[i]);
     }
-    gwy_field_clear(args->mask);
-    mdata = gwy_field_get_data(args->mask);
+    gwy_nield_clear(args->mask);
+    gint *mdata = gwy_nield_get_data(args->mask);
 
 /*#ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -907,7 +909,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
                     rdata[j][k] = values[j];
             }
             else
-                mdata[k] = 1.0;
+                mdata[k] = 1;
 
             if (k % 1000)
                 continue;
@@ -925,8 +927,8 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     }
 
     for (i = 0; i < NOUTPUTS; i++) {
-        if (gwy_field_get_max(args->mask) > 0.0)
-            gwy_field_laplace_solve(args->result[i], args->mask, -1, 1.0);
+        if (gwy_nield_max(args->mask) > 0)
+            gwy_field_laplace_solve(args->result[i], args->mask, GWY_LAPLACE_MASKED, 1.0);
     }
     return TRUE;
 }
