@@ -1,5 +1,5 @@
 /*
- *  $Id: cmap_sinebg.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: cmap_sinebg.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -174,7 +174,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     args.field = gwy_lawn_new_field_alike(lawn, -1, TRUE);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -210,7 +210,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     dialog = GWY_DIALOG(gui.dialog);
     gwy_dialog_add_buttons(dialog, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(id));
+    field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(id));
     dataview = gwy_create_preview(field, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(dataview), data, GWY_FILE_CMAP, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
