@@ -1,5 +1,5 @@
 /*
- *  $Id: accurell.c 28808 2025-11-05 18:26:20Z yeti-dn $
+ *  $Id: accurell.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -134,7 +134,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     AccurionFile acfile;
     GwySurface *surface;
     gint power10;
@@ -196,7 +196,7 @@ load_file(const gchar *filename,
             continue;
 
         if (!meta)
-            meta = gwy_container_new();
+            meta = gwy_dict_new();
 
         u = (acfile.unitstrs[j] && *acfile.unitstrs[j]
              ? gwy_convert_to_utf8(acfile.unitstrs[j], -1, "ISO-8859-1")
@@ -206,7 +206,7 @@ load_file(const gchar *filename,
                             u ? " " : "",
                             u ? u : "");
         g_free(u);
-        gwy_container_set_string_by_name(meta, acfile.headers[j], s);
+        gwy_dict_set_string_by_name(meta, acfile.headers[j], s);
     }
 
     file = gwy_file_new_in_construction();
@@ -236,7 +236,7 @@ load_file(const gchar *filename,
         gwy_file_pass_xyz(file, j, surface);
         gwy_file_set_title(file, GWY_FILE_XYZ, j, acfile.headers[j], FALSE);
         if (meta)
-            gwy_file_pass_meta(file, GWY_FILE_XYZ, j, gwy_container_copy(meta));
+            gwy_file_pass_meta(file, GWY_FILE_XYZ, j, gwy_dict_copy(meta));
         gwy_log_add_import(file, GWY_FILE_XYZ, j, NULL, filename);
     }
 
