@@ -1,5 +1,5 @@
 /*
- *  $Id: accurexii-txt.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: accurexii-txt.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -102,7 +102,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield = NULL;
     GwyUnit *xunit, *yunit, *zunit;
     gchar *end, *p, *value, *header = NULL, *buffer = NULL;
@@ -208,7 +208,7 @@ load_file(const gchar *filename,
     gwy_file_pass_image(file, 0, dfield);
     if ((value = g_hash_table_lookup(hash, "Data Type")))
         gwy_file_set_title(file, GWY_FILE_IMAGE, 0, value, FALSE);
-    meta = gwy_container_new();
+    meta = gwy_dict_new();
     g_hash_table_foreach(hash, add_meta, meta);
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
@@ -225,7 +225,7 @@ fail:
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    gwy_container_set_const_string_by_name(GWY_CONTAINER(user_data), (gchar*)hkey, hvalue);
+    gwy_dict_set_const_string_by_name(GWY_DICT(user_data), (gchar*)hkey, hvalue);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
