@@ -1,5 +1,5 @@
 /*
- *  $Id: aistfile.c 28805 2025-11-05 12:28:20Z yeti-dn $
+ *  $Id: aistfile.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -111,7 +111,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports AIST-NT data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.6",
+    "0.7",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -231,45 +231,40 @@ extract_units(const gchar *label,
     return unit;
 }
 
-static GwyField*
-make_mask_field(GwyField *dfield,
+static GwyNield*
+make_mask_field(GwyField *field,
                 const guchar *data)
 {
-    GwyField *mfield;
-    guint xres, yres, i, j, rowstride;
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    guint n, rowstride = xres;
     const guchar *datarow;
-    gdouble *d;
-
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    rowstride = xres;
 
     /* Do not create the mask if it is all zero. */
-    for (i = 0; i < rowstride*yres; i++) {
-        if (!data[i])
+    for (n = 0; n < rowstride*yres; n++) {
+        if (!data[n])
             break;
     }
-    if (i == rowstride*yres)
+    if (n == rowstride*yres)
         return NULL;
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
-    d = gwy_field_get_data(mfield);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
+    gint *d = gwy_nield_get_data(mask);
 
-    for (i = 0; i < yres; i++) {
+    for (guint i = 0; i < yres; i++) {
         datarow = data + (yres-1 - i)*rowstride;
-        for (j = 0; j < xres; j++) {
-            *(d++) = datarow[j];
+        for (guint j = 0; j < xres; j++) {
+            *(d++) = !datarow[j];
         }
     }
 
-    return mfield;
+    return gwy_remove_bad_image_data(field, mask);
 }
 
 static gboolean
 read_aist_raster(const guchar **p, gsize *size, AistContext *context)
 {
     AistRaster raster;
-    GwyField *dfield, *mfield;
+    GwyField *field;
     GwyUnit *xyunit, *zunit;
     gboolean ok = FALSE;
     guint i, n, len;
@@ -305,27 +300,27 @@ read_aist_raster(const guchar **p, gsize *size, AistContext *context)
 
     xyunit = extract_units(raster.xunits, &qxy);
     zunit = extract_units(raster.zunits, &qz);
-    dfield = gwy_field_new(raster.xres, raster.yres,
-                           qxy*fabs(raster.right - raster.left), qxy*fabs(raster.bottom - raster.top),
-                           FALSE);
-    gwy_unit_assign(gwy_field_get_unit_xy(dfield), xyunit);
-    gwy_unit_assign(gwy_field_get_unit_z(dfield), zunit);
+    field = gwy_field_new(raster.xres, raster.yres,
+                          qxy*fabs(raster.right - raster.left), qxy*fabs(raster.bottom - raster.top),
+                          FALSE);
+    gwy_unit_assign(gwy_field_get_unit_xy(field), xyunit);
+    gwy_unit_assign(gwy_field_get_unit_z(field), zunit);
     /* Apparently this is not generally wanted.
-    gwy_field_set_xoffset(dfield, qxy*MIN(raster.left, raster.right));
-    gwy_field_set_yoffset(dfield, qxy*MIN(raster.top, raster.bottom));
+    gwy_field_set_xoffset(field, qxy*MIN(raster.left, raster.right));
+    gwy_field_set_yoffset(field, qxy*MIN(raster.top, raster.bottom));
     */
 
     g_object_unref(xyunit);
     g_object_unref(zunit);
 
-    d = gwy_field_get_data(dfield);
+    d = gwy_field_get_data(field);
     for (i = 0; i < raster.yres; i++) {
         gwy_convert_raw_data(data + i*raster.xres*sizeof(gdouble), raster.xres, 1,
                              GWY_RAW_DATA_DOUBLE, GWY_BYTE_ORDER_LITTLE_ENDIAN,
                              d + (raster.yres-1 - i)*raster.xres, qz, 0.0);
     }
 
-    gwy_file_pass_image(context->file, context->channel_id, dfield);
+    gwy_file_pass_image(context->file, context->channel_id, field);
     gwy_log_add_import(context->file, GWY_FILE_IMAGE, context->channel_id, NULL, context->filename);
 
     cn = raster.common.name;
@@ -344,11 +339,9 @@ read_aist_raster(const guchar **p, gsize *size, AistContext *context)
      * normally create masks upon import). */
     if (read_qt_byte_array(p, size, &len, &data)) {
         if (len == raster.xres*raster.yres) {
-            mfield = make_mask_field(dfield, data);
-            if (mfield) {
-                gwy_app_channel_remove_bad_data(dfield, mfield);
-                gwy_file_pass_image_mask(context->file, context->channel_id, mfield);
-            }
+            GwyNield *mask = make_mask_field(field, data);
+            if (mask)
+                gwy_file_pass_image_mask(context->file, context->channel_id, mask);
         }
 
         /* Here's something called view data.  It means the data was processed (by whatever means) hence we are not
