@@ -1,5 +1,5 @@
 /*
- *  $Id: alicona.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: alicona.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -108,7 +108,7 @@ static gchar*         texture_lo_ptr    (const Al3DTag *tag);
 static gchar*         texture_ptr       (const Al3DTag *tag);
 static GwyField*      read_depth_image  (const Al3DFile *afile,
                                          const guchar *buffer,
-                                         GwyField **badmask);
+                                         GwyNield **badmask);
 static GwyField*      read_hi_lo_texture(const Al3DFile *afile,
                                          const Al3DTag *hitag,
                                          const Al3DTag *lotag,
@@ -140,7 +140,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Alicona Imaging AL3D files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti)",
     "2011",
 };
@@ -252,14 +252,12 @@ load_file(const gchar *filename,
     file = gwy_file_new_in_construction();
 
     if (afile.depthoffset) {
-        GwyField *badmask = NULL;
+        GwyNield *badmask = NULL;
 
         field = read_depth_image(&afile, buffer, &badmask);
         gwy_file_set_image(file, id, field);
-        if (badmask) {
-            gwy_app_channel_remove_bad_data(field, badmask);
+        if ((badmask = gwy_remove_bad_image_data(field, badmask)))
             gwy_file_pass_image_mask(file, id, badmask);
-        }
         g_object_unref(field);
         set_title(file, id, "Depth", -1);
         add_meta(file, id, &afile);
@@ -318,7 +316,7 @@ load_file(const gchar *filename,
 
 fail:
     gwy_file_abandon_contents(buffer, size, NULL);
-    if (file && !gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (file && !gwy_dict_get_n_items(GWY_DICT(file))) {
         g_object_unref(file);
         file = NULL;
     }
@@ -362,10 +360,10 @@ add_meta(GwyFile *file,
          guint id,
          const Al3DFile *afile)
 {
-    GwyContainer *meta = gwy_container_new();
+    GwyDict *meta = gwy_dict_new();
     guint i;
 
-    gwy_container_set_const_string_by_name(meta, afile->version->key, afile->version->value);
+    gwy_dict_set_const_string_by_name(meta, afile->version->key, afile->version->value);
     for (i = 0; i < afile->ntags; i++) {
         const Al3DTag *tag = afile->tags + i;
 
@@ -377,13 +375,13 @@ add_meta(GwyFile *file,
             || g_str_has_suffix(tag->key, "Offset"))
             continue;
 
-        gwy_container_set_const_string_by_name(meta, tag->key, tag->value);
+        gwy_dict_set_const_string_by_name(meta, tag->key, tag->value);
     }
 
     if (*(afile->comment)) {
         gchar *p = gwy_convert_to_utf8(afile->comment, -1, "ISO-8859-1");
         if (p)
-            gwy_container_set_string_by_name(meta, "Comment", p);
+            gwy_dict_set_string_by_name(meta, "Comment", p);
     }
 
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
@@ -417,11 +415,13 @@ texture_ptr(const Al3DTag *tag)
 static GwyField*
 read_depth_image(const Al3DFile *afile,
                  const guchar *buffer,
-                 GwyField **badmask)
+                 GwyNield **badmask)
 {
-    GwyField *field, *mask = NULL;
+    GwyField *field;
+    GwyNield *mask = NULL;
     guint rowstride = (afile->xres*sizeof(gfloat) + 7)/8*8;
-    gdouble *d, *m = NULL;
+    gdouble *d;
+    gint *m = NULL;
     guint i;
     gdouble invalid_value = NAN, invalid_eps;
     gboolean invalid_is_nan;
@@ -446,12 +446,11 @@ read_depth_image(const Al3DFile *afile,
     for (i = 0; i < xres*yres; i++) {
         if (gwy_isnan(d[i]) || (!invalid_is_nan && fabs(d[i] - invalid_value) < invalid_eps)) {
             if (!mask) {
-                mask = gwy_field_new_alike(field, FALSE);
-                gwy_field_fill(mask, 1.0);
-                m = gwy_field_get_data(mask);
+                mask = gwy_field_new_nield_alike(field);
+                m = gwy_nield_get_data(mask);
             }
             d[i] = 0.0;
-            m[i] = 0.0;
+            m[i] = 1;
         }
     }
 
