@@ -1,5 +1,5 @@
 /*
- *  $Id: anasys_xml.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: anasys_xml.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2018 Jeffrey J. Schwartz.
  *  E-mail: schwartz@physics.ucla.edu
  *
@@ -211,7 +211,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
     GwyField *dfield;
     GwyField *dfield_rotate;
     GwyField *dfield_temp;
-    GwyContainer *meta;
+    GwyDict *meta;
     xmlChar *key, *xmlPropValue1, *xmlPropValue2;
     xmlNode *childNode, *posNode, *sizeNode, *resNode, *subNode, *tempNode, *tagNode;
 
@@ -244,8 +244,8 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
         xmlPropValue2 = NULL;
 
         xmlPropValue1 = getprop(childNode, "DataChannel");
-        meta = gwy_container_new_in_construction();
-        gwy_container_set_const_string_by_name(meta, "DataChannel", (const guchar*)xmlPropValue1);
+        meta = gwy_dict_new_in_construction();
+        gwy_dict_set_const_string_by_name(meta, "DataChannel", (const guchar*)xmlPropValue1);
         xmlFree(xmlPropValue1);
 
         for (tempNode = childNode->children;
@@ -265,7 +265,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                     else if (strequal(posNode->name, "Y"))
                         pos_y = g_ascii_strtod((const gchar*)key, endptr);
                     tempStr = g_strdup_printf("Position_%s", posNode->name);
-                    gwy_container_set_const_string_by_name(meta, tempStr, (guchar *)key);
+                    gwy_dict_set_const_string_by_name(meta, tempStr, (guchar *)key);
                     xmlFree(key);
                     g_free(tempStr);
                 }
@@ -282,7 +282,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                     else if (strequal(sizeNode->name, "Y"))
                         range_y = g_ascii_strtod((const gchar*)key, endptr);
                     tempStr = g_strdup_printf("Size_%s", sizeNode->name);
-                    gwy_container_set_const_string_by_name(meta, tempStr, (guchar *)key);
+                    gwy_dict_set_const_string_by_name(meta, tempStr, (guchar *)key);
                     xmlFree(key);
                     g_free(tempStr);
                 }
@@ -299,7 +299,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                     else if (strequal(resNode->name, "Y"))
                         resolution_y = (gint32)atoi((char *)key);
                     tempStr = g_strdup_printf("Resolution_%s", resNode->name);
-                    gwy_container_set_const_string_by_name(meta, tempStr, (guchar *)key);
+                    gwy_dict_set_const_string_by_name(meta, tempStr, (guchar *)key);
                     xmlFree(key);
                     g_free(tempStr);
                 }
@@ -308,7 +308,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                 key = xmlNodeListGetString(doc,
                                            tempNode->children, 1);
                 zUnit = g_strdup((gchar*)key);
-                gwy_container_set_const_string_by_name(meta, "Units", (guchar *)zUnit);
+                gwy_dict_set_const_string_by_name(meta, "Units", (guchar *)zUnit);
                 xmlFree(key);
             }
             else if (strequal(tempNode->name, "UnitPrefix")) {
@@ -351,7 +351,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                     xmlFree(xmlPropValue1);
                     xmlPropValue1 = getprop(tagNode, "Name");
                     xmlPropValue2 = getprop(tagNode, "Value");
-                    gwy_container_set_const_string_by_name(meta, (const gchar*)xmlPropValue1, (guchar*)xmlPropValue2);
+                    gwy_dict_set_const_string_by_name(meta, (const gchar*)xmlPropValue1, (guchar*)xmlPropValue2);
                     xmlFree(xmlPropValue1);
                     xmlFree(xmlPropValue2);
                 }
@@ -364,7 +364,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
             else {
                 if (xmlChildElementCount(tempNode) == 0) {
                     key = xmlNodeListGetString(doc, tempNode->children, 1);
-                    gwy_container_set_const_string_by_name(meta, (const gchar*)tempNode->name, (guchar*)key);
+                    gwy_dict_set_const_string_by_name(meta, (const gchar*)tempNode->name, (guchar*)key);
                     xmlFree(key);
                 }
                 else {
@@ -375,7 +375,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
                             continue;
                         key = xmlNodeListGetString(doc, subNode->children, 1);
                         tempStr = g_strdup_printf("%s_%s", tempNode->name, subNode->name);
-                        gwy_container_set_const_string_by_name(meta, tempStr, (guchar*)key);
+                        gwy_dict_set_const_string_by_name(meta, tempStr, (guchar*)key);
                         g_free(tempStr);
                         xmlFree(key);
                     }
@@ -491,7 +491,7 @@ readHeightMaps(GwyFile *file, xmlDoc *doc, const xmlNode *curNode,
 
         if (oblique_angle) {
             gwy_file_pass_image(file, 100000 + imageNum, dfield_rotate);
-            gwy_file_pass_meta(file, GWY_FILE_IMAGE, 100000 + imageNum, gwy_container_copy(meta));
+            gwy_file_pass_meta(file, GWY_FILE_IMAGE, 100000 + imageNum, gwy_dict_copy(meta));
             xmlPropValue1 = getprop(childNode, "Label");
             gwy_file_pass_title(file, GWY_FILE_IMAGE, 100000 + imageNum,
                                 g_strdup_printf("%s (Rotated)", xmlPropValue1));
