@@ -1,5 +1,5 @@
 /*
- *  $Id: anfatec.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: anfatec.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2025 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -91,7 +91,7 @@ static gdouble          lawn_reduce_avg    (gint ncurves,
                                             gint curvelength,
                                             const gdouble *curvedata,
                                             gpointer user_data);
-static GwyContainer*    get_meta           (GHashTable *hash);
+static GwyDict*    get_meta           (GHashTable *hash);
 static void             add_meta           (gpointer hkey,
                                             gpointer hvalue,
                                             gpointer user_data);
@@ -212,7 +212,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GHashTable *hash = NULL, *hash2 = NULL;
     gchar *line, *value, *key, *dirname = NULL, *text = NULL, *p;
     GError *err = NULL;
@@ -314,7 +314,7 @@ load_file(const gchar *filename,
     for (id = 0; id <= maxid; id++) {
         GwyField *dfield;
         GwyLawn *lawn;
-        GwyContainer *metacopy;
+        GwyDict *metacopy;
         const gchar *dataname, *title;
         gint ncurves;
 
@@ -333,7 +333,7 @@ load_file(const gchar *filename,
             gwy_file_pass_cmap(file, id, lawn);
 
             if (meta) {
-                metacopy = gwy_container_copy(meta);
+                metacopy = gwy_dict_copy(meta);
                 g_hash_table_foreach(hash2, add_meta, metacopy);
                 gwy_file_pass_meta(file, GWY_FILE_CMAP, id, metacopy);
             }
@@ -347,14 +347,14 @@ load_file(const gchar *filename,
                                    FALSE);
             gwy_lawn_reduce_to_plane(lawn, dfield, lawn_reduce_avg, NULL);
             gwy_unit_assign(gwy_field_get_unit_z(dfield), gwy_lawn_get_unit_curve(lawn, ncurves-1));
-            gwy_container_pass_object(GWY_CONTAINER(file), gwy_file_key_cmap_picture(id), dfield);
+            gwy_dict_pass_object(GWY_DICT(file), gwy_file_key_cmap_picture(id), dfield);
 
             gwy_log_add_import(file, GWY_FILE_CMAP, id, NULL, dataname);
         }
         else if ((dfield = load_image(hash, id, dirname))) {
             gwy_file_pass_image(file, id, dfield);
             if (meta)
-                gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_container_copy(meta));
+                gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_dict_copy(meta));
 
             if (title)
                 gwy_file_set_title(file, GWY_FILE_IMAGE, id, title, FALSE);
@@ -365,7 +365,7 @@ load_file(const gchar *filename,
         }
     }
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
     }
@@ -903,12 +903,12 @@ lawn_reduce_avg(gint ncurves, gint curvelength, const gdouble *curvedata,
     return s/curvelength;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new();
+    GwyDict *meta = gwy_dict_new();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
@@ -918,13 +918,13 @@ get_meta(GHashTable *hash)
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *value = hvalue, *skey = hkey;
 
     if (!*value || !*skey || g_ascii_isdigit(skey[0]))
         return;
 
-    gwy_container_set_const_string_by_name(meta, skey, value);
+    gwy_dict_set_const_string_by_name(meta, skey, value);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
