@@ -1,5 +1,5 @@
 /*
- *  $Id: apedaxfile.c 28805 2025-11-05 12:28:20Z yeti-dn $
+ *  $Id: apedaxfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -205,42 +205,42 @@ static const APEXmlField dax_stm[] = {
 
 /* Prototypes */
 
-static gboolean      module_register       (void);
-static gint          detect_file           (const GwyFileDetectInfo *fileinfo,
-                                            gboolean only_name);
-static gboolean      is_plausible_file     (const guchar *filehead,
-                                            gsize len);
-static GwyFile*      load_file             (const gchar *filename,
-                                            GwyRunModeFlags mode,
-                                            GError **error);
-static GwyContainer* get_meta              (guchar *scan_xml_content,
-                                            gsize content_size,
-                                            gboolean apdt_file);
-static gchar*        get_xml_node_as_string(xmlDocPtr doc,
-                                            const gchar *node_xpath);
-static GwyField*     get_field             (GwyZipFile uFile,
-                                            const gchar *chFileName,
-                                            const APEScanSize *scan_size,
-                                            const gchar *zUnit,
-                                            gdouble scale,
-                                            GError **error);
-static gboolean      get_channels_data     (GwyZipFile uFile,
-                                            guchar *scan_xml_content,
-                                            gsize content_size,
-                                            const gchar *filename,
-                                            GwyFile *file,
-                                            GwyContainer *meta,
-                                            const APEScanSize *scan_size,
-                                            GError **error);
-static gboolean      is_xml_valid          (guchar *scan_xml_content,
-                                            gsize content_size);
-static gboolean      is_xml_node_present   (xmlDocPtr doc,
-                                            const gchar *node_xbase_path,
-                                            const gchar *node_xpath,
-                                            gboolean unique);
-static gboolean      get_scan_size         (xmlDocPtr doc,
-                                            APEScanSize *scan_size,
-                                            GError **error);
+static gboolean  module_register       (void);
+static gint      detect_file           (const GwyFileDetectInfo *fileinfo,
+                                        gboolean only_name);
+static gboolean  is_plausible_file     (const guchar *filehead,
+                                        gsize len);
+static GwyFile*  load_file             (const gchar *filename,
+                                        GwyRunModeFlags mode,
+                                        GError **error);
+static GwyDict*  get_meta              (guchar *scan_xml_content,
+                                        gsize content_size,
+                                        gboolean apdt_file);
+static gchar*    get_xml_node_as_string(xmlDocPtr doc,
+                                        const gchar *node_xpath);
+static GwyField* get_field             (GwyZipFile uFile,
+                                        const gchar *chFileName,
+                                        const APEScanSize *scan_size,
+                                        const gchar *zUnit,
+                                        gdouble scale,
+                                        GError **error);
+static gboolean  get_channels_data     (GwyZipFile uFile,
+                                        guchar *scan_xml_content,
+                                        gsize content_size,
+                                        const gchar *filename,
+                                        GwyFile *file,
+                                        GwyDict *meta,
+                                        const APEScanSize *scan_size,
+                                        GError **error);
+static gboolean  is_xml_valid          (guchar *scan_xml_content,
+                                        gsize content_size);
+static gboolean  is_xml_node_present   (xmlDocPtr doc,
+                                        const gchar *node_xbase_path,
+                                        const gchar *node_xpath,
+                                        gboolean unique);
+static gboolean  get_scan_size         (xmlDocPtr doc,
+                                        APEScanSize *scan_size,
+                                        GError **error);
 
 /* Informations about the module */
 
@@ -347,7 +347,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyZipFile uFile;
     guchar *buffer = NULL;
     gsize content_size = 0;
@@ -434,12 +434,12 @@ cleanup:
 }
 
 /* Gets the metadata from the XML file */
-static GwyContainer*
+static GwyDict*
 get_meta(guchar *scan_xml_content,
          gsize content_size,
          gboolean apdt_file)
 {
-    GwyContainer* meta = NULL;
+    GwyDict* meta = NULL;
     xmlDocPtr doc = NULL;
     xmlNodePtr cur = NULL;
     xmlNodePtr cur_child = NULL;
@@ -463,7 +463,7 @@ get_meta(guchar *scan_xml_content,
     if (!scan_xml_content || content_size == 0)
         return NULL;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     gwy_debug("Parsing the scan XML file");
     doc = xmlReadMemory(scan_xml_content, content_size, XML_FILE_NAME, NULL, 0);
@@ -498,7 +498,7 @@ get_meta(guchar *scan_xml_content,
                     value = xmlNodeGetContent(cur_child);
                     if (value) {
                         concat_key = g_strconcat(key, " - ", key_child, NULL);
-                        gwy_container_set_const_string_by_name(meta, concat_key, (gchar*)value);
+                        gwy_dict_set_const_string_by_name(meta, concat_key, (gchar*)value);
                         g_free(concat_key);
                         xmlFree(value);
                         have_child = TRUE;
@@ -509,7 +509,7 @@ get_meta(guchar *scan_xml_content,
             if (!have_child) {
                 value = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
                 if (value) {
-                    gwy_container_set_const_string_by_name(meta, key, (gchar*)value);
+                    gwy_dict_set_const_string_by_name(meta, key, (gchar*)value);
                     xmlFree(value);
                 }
             }
@@ -523,12 +523,12 @@ get_meta(guchar *scan_xml_content,
     else {
         gwy_debug("Selected DAX file fields");
         /* Fetch the SPM Mode */
-        if (gwy_container_contains_by_name(meta, SPM_MODE_NAME)) {
-            buffer = gwy_container_get_string_by_name(meta, SPM_MODE_NAME);
+        if (gwy_dict_contains_by_name(meta, SPM_MODE_NAME)) {
+            buffer = gwy_dict_get_string_by_name(meta, SPM_MODE_NAME);
             current_SPM_mode = gwy_string_to_enum(buffer, spm_modes_names, G_N_ELEMENTS(spm_modes_names));
             spm_mode_disp = gwy_enum_to_string(current_SPM_mode, spm_modes_display_names,
                                                G_N_ELEMENTS(spm_modes_display_names));
-            gwy_container_set_const_string_by_name(meta, SPM_MODE_NAME, spm_mode_disp);
+            gwy_dict_set_const_string_by_name(meta, SPM_MODE_NAME, spm_mode_disp);
             /* Change the meta names */
             switch (current_SPM_mode) {
                 case SPM_MODE_AFM_CONTACT:
@@ -553,8 +553,8 @@ get_meta(guchar *scan_xml_content,
             }
 
             for (i = 0; i < fields_size; i++) {
-                if (gwy_container_contains_by_name(meta, fields[i].name)) {
-                    gwy_container_rename_by_name(meta, fields[i].name, fields[i].display_name, FALSE);
+                if (gwy_dict_contains_by_name(meta, fields[i].name)) {
+                    gwy_dict_rename_by_name(meta, fields[i].name, fields[i].display_name, FALSE);
                 }
                 else {
                     gwy_debug("Some metadata not present!");
@@ -676,7 +676,7 @@ get_channels_data(GwyZipFile uFile,
                   gsize content_size,
                   const gchar *filename,
                   GwyFile *file,
-                  GwyContainer *meta,
+                  GwyDict *meta,
                   const APEScanSize *scan_size,
                   GError **error)
 {
@@ -695,7 +695,7 @@ get_channels_data(GwyZipFile uFile,
     gchar *zUnit_string = NULL;
     gchar *bin_filename = NULL;
     GwyField *dfield;
-    GwyContainer *channel_meta;
+    GwyDict *channel_meta;
 
     if (!scan_xml_content || content_size == 0)
         return FALSE;
@@ -732,7 +732,7 @@ get_channels_data(GwyZipFile uFile,
 
         cur = node_set->nodeTab[i]->xmlChildrenNode;
         /* Create a meta file for this channel */
-        channel_meta = gwy_container_copy(meta);
+        channel_meta = gwy_dict_copy(meta);
         while (cur) {
             buffer = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
             if (buffer) {
@@ -758,7 +758,7 @@ get_channels_data(GwyZipFile uFile,
                 }
                 else {
                     /* Add the info to the metadata of the channel */
-                    gwy_container_set_const_string_by_name(channel_meta, curname, (gchar*)buffer);
+                    gwy_dict_set_const_string_by_name(channel_meta, curname, (gchar*)buffer);
                 }
                 xmlFree(buffer);
             }
