@@ -1,5 +1,5 @@
 /*
- *  $Id: apefile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: apefile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -162,7 +162,7 @@ static GwyFile*      load_file      (const gchar *filename,
                                      GError **error);
 static void          fill_fields    (APEFile *apefile,
                                      const guchar *buffer);
-static GwyContainer* get_metadata   (APEFile *apefile);
+static GwyDict* get_metadata   (APEFile *apefile);
 static gchar*        format_vt_date (gdouble vt_date);
 
 static const GwyEnum spm_modes[] = {
@@ -238,7 +238,7 @@ load_file(const gchar *filename,
 {
     APEFile apefile;
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     const guchar *p;
     gsize size = 0;
@@ -431,7 +431,7 @@ load_file(const gchar *filename,
         }
         if (title && *title)
             gwy_file_set_title(file, GWY_FILE_IMAGE, n, title, FALSE);
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, n, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, n, gwy_dict_copy(meta));
         gwy_log_add_import(file, GWY_FILE_IMAGE, n, NULL, filename);
         n++;
     }
@@ -504,14 +504,14 @@ fill_fields(APEFile *apefile,
 }
 
 #define HASH_STORE(key, fmt, field) \
-    gwy_container_set_string_by_name(meta, key, g_strdup_printf(fmt, apefile->field))
+    gwy_dict_set_string_by_name(meta, key, g_strdup_printf(fmt, apefile->field))
 
-static GwyContainer*
+static GwyDict*
 get_metadata(APEFile *apefile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_string_by_name(meta, "Version", g_strdup_printf("%u.%u", apefile->version, apefile->subversion));
+    gwy_dict_set_string_by_name(meta, "Version", g_strdup_printf("%u.%u", apefile->version, apefile->subversion));
 
     /*
      * In SPM_MODE_SNOM or SPM_MODE_AFM_NONCONTACT freq_osc_tip holds the tip oscillation frequency.
@@ -530,12 +530,12 @@ get_metadata(APEFile *apefile)
 
     /* We will fetch the HV Amplifier status only if file version>= 2.4*/
     if (apefile->version > 1 && apefile->subversion >= 4) {
-        gwy_container_set_const_string_by_name(meta, "XY HV Status",
-                                               gwy_enum_to_string(apefile->xy_hv_status, hva_statuses,
-                                                                  G_N_ELEMENTS(hva_statuses)));
-        gwy_container_set_const_string_by_name(meta, "Z HV Status",
-                                               gwy_enum_to_string(apefile->z_hv_status, hva_statuses,
-                                                                  G_N_ELEMENTS(hva_statuses)));
+        gwy_dict_set_const_string_by_name(meta, "XY HV Status",
+                                          gwy_enum_to_string(apefile->xy_hv_status, hva_statuses,
+                                                             G_N_ELEMENTS(hva_statuses)));
+        gwy_dict_set_const_string_by_name(meta, "Z HV Status",
+                                          gwy_enum_to_string(apefile->z_hv_status, hva_statuses,
+                                                             G_N_ELEMENTS(hva_statuses)));
     }
 
     HASH_STORE("Acquire delay", "%.6f s", acquire_delay);
@@ -544,12 +544,12 @@ get_metadata(APEFile *apefile)
 
     gchar *p;
     if (apefile->remark && *apefile->remark && (p = gwy_convert_to_utf8(apefile->remark, -1, "ISO-8859-1")))
-        gwy_container_set_string_by_name(meta, "Comment", p);
-    gwy_container_set_const_string_by_name(meta, "SPM mode",
+        gwy_dict_set_string_by_name(meta, "Comment", p);
+    gwy_dict_set_const_string_by_name(meta, "SPM mode",
                                            gwy_enum_to_string(apefile->spm_mode, spm_modes, G_N_ELEMENTS(spm_modes)));
     p = format_vt_date(apefile->scan_date);
     if (p)
-        gwy_container_set_string_by_name(meta, "Date", p);
+        gwy_dict_set_string_by_name(meta, "Date", p);
 
     return meta;
 }
