@@ -1,5 +1,5 @@
 /*
- *  $Id: ardf.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: ardf.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2023 Vojtech Klapetek, Matt Poss
  *  E-mail: vojvojta@gmail.com
  *
@@ -208,7 +208,7 @@ static gboolean      read_XDAT          (guchar **pp,
                                          gsize size,
                                          gint32 address,
                                          GError **error);
-static GwyContainer* parse_metadata     (ARDF_TEXT *raw);
+static GwyDict* parse_metadata     (ARDF_TEXT *raw);
 static void          free_ARDF_TOC      (ARDF_TOC *toc);
 static void          free_ARDF_TEXT     (ARDF_TEXT *txt);
 static void          free_ARDF_VNAM     (ARDF_VNAM *vnam);
@@ -267,8 +267,8 @@ load_file(const gchar *filename,
     ARDF_DEF *imdef = NULL;
     ARDF_DEF *vdef = NULL;
     GwyFile *file = NULL;
-    GwyContainer *instrument_data = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *instrument_data = NULL;
+    GwyDict *meta = NULL;
     GwyField *dfield = NULL;
     GwyBrick **volm_channels = NULL;
     guchar *buffer, *b, *p;
@@ -367,8 +367,8 @@ load_file(const gchar *filename,
     instrument_data = parse_metadata(txt);
 
     lat_size = 10e-6;
-    if (gwy_container_contains_by_name(instrument_data, "FastScanSize"))
-        sscanf(gwy_container_get_string_by_name(instrument_data, "FastScanSize"), "%lf", &lat_size);
+    if (gwy_dict_contains_by_name(instrument_data, "FastScanSize"))
+        sscanf(gwy_dict_get_string_by_name(instrument_data, "FastScanSize"), "%lf", &lat_size);
     else {
         gwy_debug("scan size not set, guessing 10e-6\n");
     }
@@ -431,7 +431,7 @@ load_file(const gchar *filename,
         }
         if (numb_imag_text == 0) {
             // if no note is present, adds instrument data instead
-            gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(instrument_data));
+            gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(instrument_data));
         }
 
         gwy_debug("size %i %i\n", idat->x_size, idat->y_size);
@@ -1520,10 +1520,10 @@ read_XDAT(guchar **pp, guchar *start, gsize size, gint32 address, GError **error
     return TRUE;
 }
 
-static GwyContainer*
+static GwyDict*
 parse_metadata(ARDF_TEXT *raw)
 {
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     guchar keyword_stack[raw->len];
     guchar value_stack[raw->len];
     guchar* key;
@@ -1531,7 +1531,7 @@ parse_metadata(ARDF_TEXT *raw)
     gboolean value_wanted = FALSE;
     guint32 i, key_i, val_i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     key_i = 0;
     val_i = 0;
@@ -1562,7 +1562,7 @@ parse_metadata(ARDF_TEXT *raw)
             if (value_wanted) {
                 //put value-key pair
                 key = g_strndup(keyword_stack, key_i);
-                gwy_container_set_string_by_name(meta, key, g_strndup(value_stack, val_i));
+                gwy_dict_set_string_by_name(meta, key, g_strndup(value_stack, val_i));
                 key_i = 0;
                 val_i = 0;
                 value_wanted = FALSE;
