@@ -1,5 +1,5 @@
 /*
- *  $Id: asdfile.c 28772 2025-11-03 18:02:12Z yeti-dn $
+ *  $Id: asdfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2024-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -147,7 +147,7 @@ static gint          detect_file         (const GwyFileDetectInfo *fileinfo,
 static GwyFile*      load_file           (const gchar *filename,
                                           GwyRunModeFlags mode,
                                           GError **error);
-static GwyContainer* get_meta            (ASDHeader *header);
+static GwyDict* get_meta            (ASDHeader *header);
 static void          create_graphs       (GwyFile *file,
                                           GArray *frames,
                                           gint id,
@@ -339,7 +339,7 @@ load_file(const gchar *filename,
         }
 
         /* It seems not acquired channels as simply zero-filled. Skip those. */
-        if (gwy_brick_get_max(brick) == 0.0 && gwy_brick_get_min(brick) == 0.0) {
+        if (gwy_brick_max(brick) == 0.0 && gwy_brick_min(brick) == 0.0) {
             g_object_unref(brick);
             g_array_free(frames, TRUE);
             continue;
@@ -369,34 +369,34 @@ fail:
     return file;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(ASDHeader *header)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_string_by_name(meta, "Date and time",
-                                     g_strdup_printf("%04u-%02u-%02u %02u:%02u:%02u",
-                                                     header->year, header->month, header->day,
-                                                     header->hour, header->minute, header->second));
-    gwy_container_set_const_string_by_name(meta, "Averaging", header->averaging ? "Yes" : "No");
-    gwy_container_set_string_by_name(meta, "Averaging num", g_strdup_printf("%u", header->avg_window));
-    gwy_container_set_string_by_name(meta, "Frame acquisition time", g_strdup_printf("%g ms", header->frame_acq_time));
-    gwy_container_set_string_by_name(meta, "Z sensor sensitivity", g_strdup_printf("%g nm/V", header->zsensor_sens));
-    gwy_container_set_string_by_name(meta, "Phase sensitivity", g_strdup_printf("%g deg/V", header->phase_sens));
-    gwy_container_set_string_by_name(meta, "X maximum scanning range", g_strdup_printf("%g nm", header->x_maxreal));
-    gwy_container_set_string_by_name(meta, "Y maximum scanning range", g_strdup_printf("%g nm", header->y_maxreal));
-    gwy_container_set_string_by_name(meta, "X piezo extension coefficient",
-                                     g_strdup_printf("%g nm/V", header->x_piezo_ext));
-    gwy_container_set_string_by_name(meta, "Y piezo extension coefficient",
-                                     g_strdup_printf("%g nm/V", header->y_piezo_ext));
-    gwy_container_set_string_by_name(meta, "Z piezo extension coefficient",
-                                     g_strdup_printf("%g nm/V", header->z_piezo_ext));
-    gwy_container_set_string_by_name(meta, "Z drive gain", g_strdup_printf("%g", header->z_piezo_gain));
+    gwy_dict_set_string_by_name(meta, "Date and time",
+                                g_strdup_printf("%04u-%02u-%02u %02u:%02u:%02u",
+                                                header->year, header->month, header->day,
+                                                header->hour, header->minute, header->second));
+    gwy_dict_set_const_string_by_name(meta, "Averaging", header->averaging ? "Yes" : "No");
+    gwy_dict_set_string_by_name(meta, "Averaging num", g_strdup_printf("%u", header->avg_window));
+    gwy_dict_set_string_by_name(meta, "Frame acquisition time", g_strdup_printf("%g ms", header->frame_acq_time));
+    gwy_dict_set_string_by_name(meta, "Z sensor sensitivity", g_strdup_printf("%g nm/V", header->zsensor_sens));
+    gwy_dict_set_string_by_name(meta, "Phase sensitivity", g_strdup_printf("%g deg/V", header->phase_sens));
+    gwy_dict_set_string_by_name(meta, "X maximum scanning range", g_strdup_printf("%g nm", header->x_maxreal));
+    gwy_dict_set_string_by_name(meta, "Y maximum scanning range", g_strdup_printf("%g nm", header->y_maxreal));
+    gwy_dict_set_string_by_name(meta, "X piezo extension coefficient",
+                                g_strdup_printf("%g nm/V", header->x_piezo_ext));
+    gwy_dict_set_string_by_name(meta, "Y piezo extension coefficient",
+                                g_strdup_printf("%g nm/V", header->y_piezo_ext));
+    gwy_dict_set_string_by_name(meta, "Z piezo extension coefficient",
+                                g_strdup_printf("%g nm/V", header->z_piezo_ext));
+    gwy_dict_set_string_by_name(meta, "Z drive gain", g_strdup_printf("%g", header->z_piezo_gain));
     /* FIXME: UTF-8? It should be, but who knows. */
     if (*header->operator_name)
-        gwy_container_set_const_string_by_name(meta, "Operator name", header->operator_name);
+        gwy_dict_set_const_string_by_name(meta, "Operator name", header->operator_name);
     if (*header->comment)
-        gwy_container_set_const_string_by_name(meta, "Comment", header->comment);
+        gwy_dict_set_const_string_by_name(meta, "Comment", header->comment);
 
     return meta;
 }
