@@ -1,5 +1,5 @@
 /*
- *  $Id: assing-afm.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: assing-afm.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -137,7 +137,7 @@ load_file(const gchar *filename,
     p += 2*afmfile.res*afmfile.res;
 
     afmfile.range = gwy_get_gfloat_le(&p);
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
     if (min == max)
         gwy_field_clear(dfield);
     else
@@ -193,7 +193,7 @@ export_file(G_GNUC_UNUSED GwyFile *data,
     r = GUINT16_TO_LE(res);
     fwrite(&res, 1, sizeof(r), fh);
 
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
     if (min == max) {
         q = 0.0;
         z0 = 0.0;
