@@ -1,5 +1,5 @@
 /*
- *  $Id: attocube.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: attocube.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -110,7 +110,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield = NULL;
     gchar *line, *p, *value, *header, *buffer = NULL;
     GwyTextHeaderParser parser;
@@ -210,20 +210,20 @@ load_file(const gchar *filename,
     if ((value = g_hash_table_lookup(hash, "display")))
         gwy_file_set_title(file, GWY_FILE_IMAGE, 0, value, FALSE);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     value = g_strdup_printf("%04u-%02u-%02u %02u:%02u:%02u",
                             year, month, day, hour, minute, second);
-    gwy_container_set_string_by_name(meta, "Date", value);
+    gwy_dict_set_string_by_name(meta, "Date", value);
 
     if ((value = g_hash_table_lookup(hash, "scanspeed")))
-        gwy_container_set_const_string_by_name(meta, "Scan Speed", value);
+        gwy_dict_set_const_string_by_name(meta, "Scan Speed", value);
 
     if ((value = g_hash_table_lookup(hash, "x-offset")))
-        gwy_container_set_const_string_by_name(meta, "X Offset", value);
+        gwy_dict_set_const_string_by_name(meta, "X Offset", value);
 
     if ((value = g_hash_table_lookup(hash, "y-offset")))
-        gwy_container_set_const_string_by_name(meta, "Y Offset", value);
+        gwy_dict_set_const_string_by_name(meta, "Y Offset", value);
 
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
