@@ -1,5 +1,5 @@
 /*
- *  $Id: bcrfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: bcrfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -106,22 +106,22 @@ static GwyField*     file_load_real  (const guchar *buffer,
                                       gsize size,
                                       gsize header_size,
                                       GHashTable *meta,
-                                      GwyField **voidmask,
+                                      GwyNield **voidmask,
                                       GError **error);
 static GwyField*     read_field      (const guchar *buffer,
                                       gint xres,
                                       gint yres,
                                       GwyRawDataType rawtype,
                                       GwyByteOrder byteorder,
-                                      GwyField **voidmask);
-static GwyContainer* get_metadata    (GHashTable *bcrmeta);
+                                      GwyNield **voidmask);
+static GwyDict* get_metadata    (GHashTable *bcrmeta);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Imports Image Metrology BCR data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.19",
+    "0.20",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
@@ -166,12 +166,13 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     gchar *header;
     gsize header_size, size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL, *voidmask = NULL;
+    GwyField *field = NULL;
+    GwyNield *voidmask = NULL;
     GwyTextHeaderParser parser;
     GHashTable *bcrmeta = NULL;
     gboolean utf16 = FALSE;
@@ -212,11 +213,11 @@ load_file(const gchar *filename,
     parser.key_value_separator = "=";
     bcrmeta = gwy_text_header_parse(header, &parser, NULL, NULL);
 
-    dfield = file_load_real(buffer + header_size, size, header_size, bcrmeta, &voidmask, error);
+    field = file_load_real(buffer + header_size, size, header_size, bcrmeta, &voidmask, error);
     gwy_file_abandon_contents(buffer, size, NULL);
-    if (dfield) {
+    if (field) {
         file = gwy_file_new_in_construction();
-        gwy_file_pass_image(file, 0, dfield);
+        gwy_file_pass_image(file, 0, field);
 
         //gwy_app_set_field_title(file, 0, g_strdup(g_strrstr(filename, "/") + 1));
         gwy_image_title_fall_back(file, 0);
@@ -273,12 +274,11 @@ file_load_real(const guchar *buffer,
                gsize size,
                gsize header_size,
                GHashTable *meta,
-               GwyField **voidmask,
+               GwyNield **voidmask,
                GError **error)
 {
-    GwyField *dfield;
+    GwyField *field;
     GwyUnit *siunit2 = NULL;
-    gboolean voidpixels = FALSE;
     GwyByteOrder byteorder = GWY_BYTE_ORDER_LITTLE_ENDIAN;
     GwyRawDataType rawtype;
     gdouble q, qq;
@@ -322,17 +322,15 @@ file_load_real(const guchar *buffer,
     if (err_SIZE_MISMATCH(error, xres*yres*gwy_raw_data_size(rawtype), (guint)(size - header_size), FALSE))
         return NULL;
 
-    /* Do not trust `voidpixels' and always read data assuming the rules for
-     * bad pixels. */
-    dfield = read_field(buffer, xres, yres, rawtype, byteorder, voidmask);
+    field = read_field(buffer, xres, yres, rawtype, byteorder, voidmask);
 
     if ((s = g_hash_table_lookup(meta, "xlength")) && (q = g_ascii_strtod(s, NULL)) > 0) {
         if (!(s = g_hash_table_lookup(meta, "xunit")))
             s = "nm";
 
-        power10 = gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), s);
+        power10 = gwy_unit_set_from_string(gwy_field_get_unit_xy(field), s);
         q *= gwy_exp10(power10);
-        gwy_field_set_xreal(dfield, q);
+        gwy_field_set_xreal(field, q);
     }
 
     if ((s = g_hash_table_lookup(meta, "ylength")) && (q = g_ascii_strtod(s, NULL)) > 0) {
@@ -341,38 +339,31 @@ file_load_real(const guchar *buffer,
 
         siunit2 = gwy_unit_new_parse(s, &power10);
         q *= gwy_exp10(power10);
-        if (!gwy_unit_equal(gwy_field_get_unit_xy(dfield), siunit2))
+        if (!gwy_unit_equal(gwy_field_get_unit_xy(field), siunit2))
             g_warning("Incompatible x and y units");
         g_object_unref(siunit2);
-        gwy_field_set_yreal(dfield, q);
+        gwy_field_set_yreal(field, q);
     }
 
     if (!(s = g_hash_table_lookup(meta, "zunit")))
         s = "nm";
-    power10 = gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), s);
+    power10 = gwy_unit_set_from_string(gwy_field_get_unit_z(field), s);
     q = gwy_exp10(power10);
 
     if (rawtype == GWY_RAW_DATA_SINT16) {
         if ((s = g_hash_table_lookup(meta, "bit2nm")) && (qq = g_ascii_strtod(s, NULL)) > 0)
-            gwy_field_multiply(dfield, q*qq);
+            gwy_field_multiply(field, q*qq);
     }
     else if (rawtype == GWY_RAW_DATA_FLOAT)
-        gwy_field_multiply(dfield, q);
+        gwy_field_multiply(field, q);
 
     if ((s = g_hash_table_lookup(meta, "zmin")) && (qq = g_ascii_strtod(s, NULL)) > 0)
-        gwy_field_add(dfield, q*qq - gwy_field_get_min(dfield));
+        gwy_field_add(field, q*qq - gwy_field_min(field));
 
-    if (voidpixels) {
-        gwy_field_set_xreal(*voidmask, gwy_field_get_xreal(dfield));
-        gwy_field_set_yreal(*voidmask, gwy_field_get_yreal(dfield));
-        gwy_unit_assign(gwy_field_get_unit_xy(*voidmask), gwy_field_get_unit_xy(dfield));
-        gwy_unit_clear(gwy_field_get_unit_z(*voidmask));
-    }
-
-    return dfield;
+    return field;
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(GHashTable *bcrmeta)
 {
     const struct {
@@ -390,7 +381,7 @@ get_metadata(GHashTable *bcrmeta)
         /* FIXME: I've seen other stuff, but don't know interpretation */
     };
 
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     for (guint i = 0; i < G_N_ELEMENTS(metakeys); i++) {
         gchar *value;
@@ -398,12 +389,12 @@ get_metadata(GHashTable *bcrmeta)
             continue;
 
         if (metakeys[i].unit)
-            gwy_container_set_string_by_name(meta, metakeys[i].key, g_strdup_printf("%s %s", value, metakeys[i].unit));
+            gwy_dict_set_string_by_name(meta, metakeys[i].key, g_strdup_printf("%s %s", value, metakeys[i].unit));
         else
-            gwy_container_set_const_string_by_name(meta, metakeys[i].key, value);
+            gwy_dict_set_const_string_by_name(meta, metakeys[i].key, value);
     }
 
-    if (!gwy_container_get_n_items(meta))
+    if (!gwy_dict_get_n_items(meta))
         g_clear_object(&meta);
 
     return meta;
@@ -415,36 +406,32 @@ read_field(const guchar *buffer,
            gint yres,
            GwyRawDataType rawtype,
            GwyByteOrder byteorder,
-           GwyField **voidmask)
+           GwyNield **voidmask)
 {
-    GwyField *dfield;
-    gdouble *data, *voids;
     guint i, n = xres*yres;
 
-    dfield = gwy_field_new(xres, yres, 1e-6, 1e-6, FALSE);
-    *voidmask = gwy_field_new(xres, yres, 1e-6, 1e-6, FALSE);
-    gwy_field_fill(*voidmask, 1.0);
+    GwyField *field = gwy_field_new(xres, yres, 1e-6, 1e-6, FALSE);
+    *voidmask = gwy_field_new_nield_alike(field);
 
-    data = gwy_field_get_data(dfield);
-    voids = gwy_field_get_data(*voidmask);
+    gdouble *data = gwy_field_get_data(field);
+    gint *voids = gwy_nield_get_data(*voidmask);
     gwy_convert_raw_data(buffer, n, 1, rawtype, byteorder, data, 1.0, 0.0);
     if (rawtype == GWY_RAW_DATA_SINT16) {
         for (i = 0; i < n; i++) {
             if (data[i] == 32767.0)
-                voids[i] = 0.0;
+                voids[i] = 1;
         }
     }
     else if (rawtype == GWY_RAW_DATA_FLOAT) {
         for (i = 0; i < n; i++) {
             if (data[i] > 1.7e38)
-                voids[i] = 0.0;
+                voids[i] = 1;
         }
     }
 
-    if (!gwy_app_channel_remove_bad_data(dfield, *voidmask))
-        g_clear_object(voidmask);
+    *voidmask = gwy_remove_bad_image_data(field, *voidmask);
 
-    return dfield;
+    return field;
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
