@@ -1,5 +1,5 @@
 /*
- *  $Id: codevfile.c 28805 2025-11-05 12:28:20Z yeti-dn $
+ *  $Id: codevfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -61,7 +61,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Code V interferogram files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.4",
+    "0.5",
     "David Nečas (Yeti)",
     "2011",
 };
@@ -136,8 +136,8 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
-    GwyField *dfield = NULL, *mfield = NULL;
+    GwyDict *meta;
+    GwyField *field = NULL;
     CodeVGridDataType type;
     gchar *line, *p, *comment, *end, *buffer = NULL;
     const gchar *unit, *title;
@@ -149,7 +149,6 @@ load_file(const gchar *filename,
     guint fi;
     gdouble scale_size, wavelength, q = 1.0, x_scale = 1.0;
     gboolean nearest_neighbour = FALSE;
-    gdouble *data, *mdata;
 
     if (!g_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -243,7 +242,7 @@ load_file(const gchar *filename,
 
     yreal = 1.0;
     xreal = x_scale*yreal;
-    dfield = gwy_field_new(xres, yres, xreal, yreal, TRUE);
+    field = gwy_field_new(xres, yres, xreal, yreal, TRUE);
 
     if (type == CODEV_INT_SURFACE_DEFORMATION) {
         q = 1e-6*wavelength/scale_size;
@@ -260,36 +259,34 @@ load_file(const gchar *filename,
         title = fields[3];
     }
 
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), unit);
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), unit);
 
-    mfield = gwy_field_new_alike(dfield, TRUE);
-    data = gwy_field_get_data(dfield);
-    mdata = gwy_field_get_data(mfield);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
+    gdouble *data = gwy_field_get_data(field);
+    gint *mdata = gwy_nield_get_data(mask);
 
     for (i = 0; i < xres*yres; i++, p = end) {
         gint value = strtol(p, &end, 10);
 
-        if (value != no_data_value && (type != CODEV_INT_INTENSITY_FILTER || value >= 0)) {
-            mdata[i] = 1.0;
+        if (value != no_data_value && (type != CODEV_INT_INTENSITY_FILTER || value >= 0))
             data[i] = q*value;
-        }
+        else
+            mdata[i] = 1;
     }
-
-    if (!gwy_app_channel_remove_bad_data(dfield, mfield))
-        g_clear_object(&mfield);
+    mask = gwy_remove_bad_image_data(field, mask);
 
     file = gwy_file_new_in_construction();
 
-    gwy_file_pass_image(file, 0, dfield);
+    gwy_file_pass_image(file, 0, field);
     gwy_file_set_title(file, GWY_FILE_IMAGE, 0, title, FALSE);
     gwy_check_nonsquare_image(file, 0);
-    if (mfield)
-        gwy_file_pass_image_mask(file, 0, mfield);
+    if (mask)
+        gwy_file_pass_image_mask(file, 0, mask);
 
-    meta = gwy_container_new_in_construction();
-    gwy_container_set_const_string_by_name(meta, "Comment", comment);
-    gwy_container_set_const_string_by_name(meta, "Interpolation", nearest_neighbour ? "NNB" : "Linear");
-    gwy_container_set_string_by_name(meta, "Wavelength", g_strdup_printf("%g μm", wavelength));
+    meta = gwy_dict_new_in_construction();
+    gwy_dict_set_const_string_by_name(meta, "Comment", comment);
+    gwy_dict_set_const_string_by_name(meta, "Interpolation", nearest_neighbour ? "NNB" : "Linear");
+    gwy_dict_set_string_by_name(meta, "Wavelength", g_strdup_printf("%g μm", wavelength));
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
 
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
