@@ -1,5 +1,5 @@
 /*
- *  $Id: createc.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: createc.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004 Rok Zitko.
  *  E-mail: rok.zitko@ijs.si.
  *  Copyright (C) 2009-2025 David Necas (Yeti).
@@ -109,7 +109,7 @@ static void           read_binary_data    (gint n,
                                            gdouble *data,
                                            const gchar *buffer,
                                            gint bpp);
-static GwyContainer*  get_metadata        (GHashTable *hash);
+static GwyDict*  get_metadata        (GHashTable *hash);
 
 static const GwyEnum versions[] = {
     { "[Parameter]", CREATEC_1,  },
@@ -204,7 +204,7 @@ load_file(const gchar *filename,
         { "Voltage",    0,                  },
     };
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL, *zbuffer = NULL, *imagedata;
     gchar *p, *head;
     gsize size = 0, datasize = 0, offset;
@@ -447,10 +447,10 @@ fail:
 #define HASH_STORE(key) \
     if ((val = g_hash_table_lookup(hash, key))) { \
         gwy_debug("key = %s, val = %s", key, val); \
-        gwy_container_set_const_string_by_name(meta, key, val); \
+        gwy_dict_set_const_string_by_name(meta, key, val); \
     }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(GHashTable *hash)
 {
     /* Relocation-less storage */
@@ -710,16 +710,16 @@ get_metadata(GHashTable *hash)
         "memo:1\0"
         "memo:2\0"
         "\0";
-    GwyContainer *meta;
+    GwyDict *meta;
     const gchar *ctr;
     gchar *val;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     for (ctr = tobestored; *ctr; ctr += strlen(ctr) + 1)
         HASH_STORE(ctr);
 
-    if (!gwy_container_get_n_items(meta)) {
+    if (!gwy_dict_get_n_items(meta)) {
         g_object_unref(meta);
         meta = NULL;
     }
