@@ -1,5 +1,5 @@
 /*
- *  $Id: csmfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: csmfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -121,7 +121,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GHashTable *hash = NULL;
     guchar *d24, *buffer = NULL;
     gsize size = 0;
@@ -209,7 +209,7 @@ load_file(const gchar *filename,
     file = gwy_file_new_in_construction();
     gwy_file_pass_image(file, 0, dfield);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, store_meta, meta);
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
 
@@ -275,16 +275,16 @@ read_bmp_header(const guchar *p,
 static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
     if (g_utf8_validate(value, -1, NULL)) {
-        gwy_container_set_const_string_by_name(meta, key, value);
+        gwy_dict_set_const_string_by_name(meta, key, value);
     }
     else {
         // FIXME: Is this Windows-locale dependent?
         gchar *s = gwy_convert_to_utf8(value, -1, "GB2312");
         if (s)
-            gwy_container_set_string_by_name(meta, key, s);
+            gwy_dict_set_string_by_name(meta, key, s);
     }
 }
 
