@@ -1,5 +1,5 @@
 /*
- *  $Id: dektakvca.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: dektakvca.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2017-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -164,7 +164,7 @@ static gboolean          find_2d_data    (GHashTable *hash,
                                           GString *str,
                                           const gchar *filename,
                                           GError **error);
-static GwyContainer*     create_meta     (GHashTable *hash);
+static GwyDict*     create_meta     (GHashTable *hash);
 static GwyUnit*          find_quantity   (GHashTable *hash,
                                           const gchar *key,
                                           GString *str,
@@ -266,7 +266,7 @@ load_file(const gchar *filename,
         goto fail;
     }
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         err_NO_DATA(error);
         g_clear_object(&file);
     }
@@ -398,9 +398,10 @@ find_2d_data(GHashTable *hash, GwyFile *file, GString *str, const gchar *filenam
              GError **error)
 {
     GwyUnit *xunit = NULL, *yunit = NULL, *zunit = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GPtrArray *channels;
-    GwyField *dfield, *mask;
+    GwyField *dfield;
+    GwyNield *mask;
     const DektakItem *item;
     gboolean ok = FALSE;
     const guchar *rawdata;
@@ -462,7 +463,7 @@ find_2d_data(GHashTable *hash, GwyFile *file, GString *str, const gchar *filenam
 
         gwy_file_set_image(file, i, dfield);
         gwy_log_add_import(file, GWY_FILE_IMAGE, i, NULL, filename);
-        if ((mask = gwy_app_channel_mask_of_nans(dfield, TRUE)))
+        if ((mask = gwy_mask_nans_in_field(dfield, TRUE)))
             gwy_file_pass_image_mask(file, i, mask);
         g_object_unref(dfield);
 
@@ -494,7 +495,7 @@ create_meta_item(gpointer key, gpointer value, gpointer user_data)
 {
     const gchar *name = (const gchar*)key;
     const DektakItem *item = (const DektakItem*)value;
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *metakey, *metavalue;
 
     if (!g_str_has_prefix(name, "/MetaData/"))
@@ -549,17 +550,17 @@ create_meta_item(gpointer key, gpointer value, gpointer user_data)
     }
 
     metakey = gwy_strreplace(name + 10, "/", "::", (gsize)-1);
-    gwy_container_set_string_by_name(meta, metakey, metavalue);
+    gwy_dict_set_string_by_name(meta, metakey, metavalue);
     g_free(metakey);
 }
 
-static GwyContainer*
+static GwyDict*
 create_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(hash, create_meta_item, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
