@@ -1,5 +1,5 @@
 /*
- *  $Id: dm3file.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: dm3file.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2012-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -180,7 +180,7 @@ struct _DM3File {
 };
 
 typedef struct {
-    GwyContainer *meta;
+    GwyDict *meta;
     GString *value;
     DM3File *dm3file;
 } DM3MetaData;
@@ -198,11 +198,11 @@ static GwyFile*      dm4file_load          (const gchar *filename,
                                             GError **error);
 static DM3ImgResult  dm3_read_image        (DM3File *dm3file,
                                             GwyFile *file,
-                                            GwyContainer *meta,
+                                            GwyDict *meta,
                                             guint i,
                                             guint *id,
                                             GError **error);
-static GwyContainer* dm3_create_meta       (DM3File *dm3file);
+static GwyDict* dm3_create_meta       (DM3File *dm3file);
 static gboolean      dm3_get_uint          (DM3File *dm3file,
                                             guint *value,
                                             const gchar *keyfmt,
@@ -369,7 +369,7 @@ dm3file_load(const gchar *filename,
              GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     DM3File dm3file;
     DM3ImgResult status;
     guchar *buffer = NULL;
@@ -431,7 +431,7 @@ dm4file_load(const gchar *filename,
              GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     DM3File dm4file;
     DM3ImgResult status;
     guchar *buffer = NULL;
@@ -490,7 +490,7 @@ fail:
 static DM3ImgResult
 dm3_read_image(DM3File *dm3file,
                GwyFile *file,
-               GwyContainer *meta,
+               GwyDict *meta,
                guint i,
                guint *id,
                GError **error)
@@ -618,7 +618,7 @@ dm3_read_image(DM3File *dm3file,
         }
 
         if (meta) {
-            GwyContainer *mymeta = gwy_container_copy(meta);
+            GwyDict *mymeta = gwy_dict_copy(meta);
             gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, mymeta);
         }
 
@@ -726,22 +726,22 @@ create_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
     ukey = gwy_convert_to_utf8(strkey+1, -1, "ISO-8859-1");
     fkey = gwy_strreplace(ukey, "/", "::", (gsize)-1);
     g_free(ukey);
-    gwy_container_set_const_string_by_name(md->meta, fkey, value->str);
+    gwy_dict_set_const_string_by_name(md->meta, fkey, value->str);
     g_free(fkey);
 }
 
-static GwyContainer*
+static GwyDict*
 dm3_create_meta(DM3File *dm3file)
 {
     DM3MetaData md = { NULL, NULL, NULL };
 
-    md.meta = gwy_container_new_in_construction();
+    md.meta = gwy_dict_new_in_construction();
     md.value = g_string_new(NULL);
     md.dm3file = dm3file;
     g_hash_table_foreach(dm3file->hash, create_meta, &md);
     g_string_free(md.value, TRUE);
 
-    if (gwy_container_get_n_items(md.meta))
+    if (gwy_dict_get_n_items(md.meta))
         return md.meta;
 
     g_object_unref(md.meta);
