@@ -1,5 +1,5 @@
 /*
- *  $Id: ecsfile.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: ecsfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -123,7 +123,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     gsize size = 0;
     GError *err = NULL;
@@ -205,7 +205,7 @@ load_file(const gchar *filename,
     gwy_file_pass_title(file, GWY_FILE_IMAGE, 0, s);
     s = NULL;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     /* Date & time */
     p = buffer + ECS_DATE;
@@ -214,7 +214,7 @@ load_file(const gchar *filename,
         p = buffer + ECS_TIME;
         s2 = get_PASCAL_STRING(&p, HEADER_SIZE - ECS_TIME);
         if (s2) {
-            gwy_container_set_string_by_name(meta, "Date", g_strconcat(s, " ", s2, NULL));
+            gwy_dict_set_string_by_name(meta, "Date", g_strconcat(s, " ", s2, NULL));
             g_free(s2);
             s2 = NULL;
         }
@@ -226,11 +226,11 @@ load_file(const gchar *filename,
     p = buffer + ECS_CHANNEL;
     s = get_PASCAL_STRING(&p, HEADER_SIZE - ECS_CHANNEL);
     if (s && *s) {
-        gwy_container_set_string_by_name(meta, "Comment", s);
+        gwy_dict_set_string_by_name(meta, "Comment", s);
         s = NULL;
     }
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     else
         g_object_unref(meta);
