@@ -1,5 +1,5 @@
 /*
- *  $Id: ezdfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: ezdfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -94,32 +94,32 @@ typedef struct {
     GError *firsterror;
 } EZDSection;
 
-static gboolean      module_register     (void);
-static gint          detect_file         (const GwyFileDetectInfo *fileinfo,
-                                          gboolean only_name);
-static GwyFile*      load_file           (const gchar *filename,
-                                          GwyRunModeFlags mode,
-                                          GError **error);
-static guint         find_data_start     (const guchar *buffer,
-                                          gsize size);
-static void          ezdfile_free        (GPtrArray *ezdfile);
-static void          ezdsection_free     (EZDSection *section);
-static GwyField*     read_field          (EZDSection *section,
-                                          GError **error);
-static gboolean      file_read_header    (GPtrArray *ezdfile,
-                                          gchar *buffer,
-                                          GError **error);
-static guint         find_data_offsets   (const gchar *buffer,
-                                          gsize size,
-                                          GPtrArray *ezdfile,
-                                          GError **error);
-static GwyContainer* ezdfile_get_metadata(GPtrArray *ezdfile,
-                                          gint idx);
-static void          fix_scales          (EZDSection *section,
-                                          gint idx,
-                                          GwyFile *file);
-static void          check_section_ranges(gpointer data,
-                                          gpointer user_data);
+static gboolean  module_register     (void);
+static gint      detect_file         (const GwyFileDetectInfo *fileinfo,
+                                      gboolean only_name);
+static GwyFile*  load_file           (const gchar *filename,
+                                      GwyRunModeFlags mode,
+                                      GError **error);
+static guint     find_data_start     (const guchar *buffer,
+                                      gsize size);
+static void      ezdfile_free        (GPtrArray *ezdfile);
+static void      ezdsection_free     (EZDSection *section);
+static GwyField* read_field          (EZDSection *section,
+                                      GError **error);
+static gboolean  file_read_header    (GPtrArray *ezdfile,
+                                      gchar *buffer,
+                                      GError **error);
+static guint     find_data_offsets   (const gchar *buffer,
+                                      gsize size,
+                                      GPtrArray *ezdfile,
+                                      GError **error);
+static GwyDict*  get_metadata        (GPtrArray *ezdfile,
+                                      gint idx);
+static void      fix_scales          (EZDSection *section,
+                                      gint idx,
+                                      GwyFile *file);
+static void      check_section_ranges(gpointer data,
+                                      gpointer user_data);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -165,7 +165,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     gsize size = 0;
     GError *err = NULL;
@@ -217,7 +217,7 @@ load_file(const gchar *filename,
         gwy_file_pass_image(file, i, dfield);
         fix_scales(section, i, file);
 
-        meta = ezdfile_get_metadata(ezdfile, n);
+        meta = get_metadata(ezdfile, n);
         if (meta)
             gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, meta);
 
@@ -525,23 +525,23 @@ fix_scales(EZDSection *section,
 static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *cval;
 
     if (!(cval = gwy_convert_to_utf8(value, -1, "ISO-8859-1")))
         return;
-    gwy_container_set_string_by_name(meta, key, cval);
+    gwy_dict_set_string_by_name(meta, key, cval);
 }
 
-static GwyContainer*
-ezdfile_get_metadata(GPtrArray *ezdfile,
-                     G_GNUC_UNUSED gint idx)
+static GwyDict*
+get_metadata(GPtrArray *ezdfile,
+             G_GNUC_UNUSED gint idx)
 {
     EZDSection *section;
-    GwyContainer *meta;
+    GwyDict *meta;
     guint i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     for (i = 0; i < ezdfile->len; i++) {
         section = (EZDSection*)g_ptr_array_index(ezdfile, i);
@@ -549,7 +549,7 @@ ezdfile_get_metadata(GPtrArray *ezdfile,
             g_hash_table_foreach(section->meta, store_meta, meta);
     }
 
-    if (!gwy_container_get_n_items(meta)) {
+    if (!gwy_dict_get_n_items(meta)) {
         g_object_unref(meta);
         meta = NULL;
     }
