@@ -49,6 +49,7 @@ GwyModuleInfo* _gwy_module_query__femtoscan_txt(void);
 GwyModuleInfo* _gwy_module_query__formats3d(void);
 GwyModuleInfo* _gwy_module_query__gdeffile(void);
 GwyModuleInfo* _gwy_module_query__gsffile(void);
+GwyModuleInfo* _gwy_module_query__gwyfile(void);
 GwyModuleInfo* _gwy_module_query__gxyzffile(void);
 GwyModuleInfo* _gwy_module_query__hdf4file(void);
 GwyModuleInfo* _gwy_module_query__hitachi_afm(void);
@@ -99,6 +100,7 @@ GwyModuleInfo* _gwy_module_query__pltfile(void);
 GwyModuleInfo* _gwy_module_query__princetonspe(void);
 GwyModuleInfo* _gwy_module_query__psia(void);
 GwyModuleInfo* _gwy_module_query__pt3file(void);
+GwyModuleInfo* _gwy_module_query__qnami(void);
 GwyModuleInfo* _gwy_module_query__quazarnpic(void);
 GwyModuleInfo* _gwy_module_query__quesant(void);
 GwyModuleInfo* _gwy_module_query__rawfile(void);
@@ -182,6 +184,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__formats3d, "formats3d", },
   { _gwy_module_query__gdeffile, "gdeffile", },
   { _gwy_module_query__gsffile, "gsffile", },
+  { _gwy_module_query__gwyfile, "gwyfile", },
   { _gwy_module_query__gxyzffile, "gxyzffile", },
   { _gwy_module_query__hdf4file, "hdf4file", },
   { _gwy_module_query__hitachi_afm, "hitachi-afm", },
@@ -232,6 +235,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__princetonspe, "princetonspe", },
   { _gwy_module_query__psia, "psia", },
   { _gwy_module_query__pt3file, "pt3file", },
+  { _gwy_module_query__qnami, "qnami", },
   { _gwy_module_query__quazarnpic, "quazarnpic", },
   { _gwy_module_query__quesant, "quesant", },
   { _gwy_module_query__rawfile, "rawfile", },
