@@ -1,5 +1,5 @@
 /*
- *  $Id: fitsfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: fitsfile.c 29329 2026-01-23 16:22:18Z yeti-dn $
  *  Copyright (C) 2014-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -128,7 +128,8 @@ load_file(const gchar *filename,
 {
     GwyFile *file = NULL;
     fitsfile *fptr = NULL;
-    GwyField *field = NULL, *mask;
+    GwyField *field = NULL;
+    GwyNield *mask;
     gint status = 0;   /* Must be initialised to zero! */
     gint hdutype, naxis, anynull, nkeys, k;
     glong res[3];    /* First index is the fast looping one. */
@@ -235,7 +236,7 @@ load_file(const gchar *filename,
         if (invalid[k])
             d[k] = NAN;
     }
-    if ((mask = gwy_app_channel_mask_of_nans(field, TRUE)))
+    if ((mask = gwy_mask_nans_in_field(field, TRUE)))
         gwy_file_pass_image_mask(file, 0, mask);
 
 fail:
