@@ -1,5 +1,5 @@
 /*
- *  $Id: formats3d.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: formats3d.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -636,7 +636,7 @@ make_scaling_info(GwyField *dfield, ScalingInfo *scinfo)
     yres = gwy_field_get_yres(dfield);
     dx = gwy_field_get_dx(dfield);
     dy = gwy_field_get_dy(dfield);
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
 
     scinfo->zscale_1_1 = 1.0/sqrt(dx*dy);
     scinfo->dx = dx*scinfo->zscale_1_1;
@@ -686,7 +686,7 @@ make_triangulation(ExportArgs *args,
 
     xres = gwy_field_get_xres(field);
     yres = gwy_field_get_yres(field);
-    min = gwy_field_get_min(field);
+    min = gwy_field_min(field);
 
     if (zscale_type == ZSCALE_USER)
         qz *= gwy_params_get_double(args->params, PARAM_ZSCALE);
@@ -874,7 +874,7 @@ formats3d_export(G_GNUC_UNUSED GwyFile *data,
     args.params = params = gwy_params_new_from_settings(define_export_params());
     export_sanitise_params(&args, fmt);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = export_run_gui(fmt, &args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL) {
@@ -1239,7 +1239,7 @@ formats3d_import(const gchar *filename,
 
     args.image = image = check_regular_grid(surface);
     args.params = gwy_params_new_from_settings(define_import_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = import_run_gui(fmt, &args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL) {
@@ -1584,13 +1584,13 @@ import_param_changed(ImportGUI *gui, gint id)
     gdouble min, max;
 
     if (id < 0 || id == PARAM_XY_UNITS) {
-        gwy_surface_get_xrange(args->surface, &min, &max);
+        gwy_surface_xrange(args->surface, &min, &max);
         update_range_lables(table, LABEL_XRANGE, min, max, gwy_params_get_string(params, PARAM_XY_UNITS));
-        gwy_surface_get_yrange(args->surface, &min, &max);
+        gwy_surface_yrange(args->surface, &min, &max);
         update_range_lables(table, LABEL_YRANGE, min, max, gwy_params_get_string(params, PARAM_XY_UNITS));
     }
     if (id < 0 || id == PARAM_Z_UNITS) {
-        gwy_surface_get_min_max(args->surface, &min, &max);
+        gwy_surface_min_max(args->surface, &min, &max);
         update_range_lables(table, LABEL_ZRANGE, min, max, gwy_params_get_string(params, PARAM_Z_UNITS));
     }
 }
