@@ -1,5 +1,5 @@
 /*
- *  $Id: gdeffile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: gdeffile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -544,38 +544,38 @@ gdef_read_channel_comment(GDEFControlBlock *block)
     return gdef_get_string_var(comment_var);
 }
 
-static GwyContainer*
+static GwyDict*
 gdef_read_channel_meta(GDEFControlBlock *block)
 {
-    GwyContainer *meta;
+    GwyDict *meta;
     gchar *s;
     guint i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     for (i = 0; i < block->n_variables; i++) {
         GDEFVariable *var = block->variables + i;
 
         if (var->type == VAR_INTEGER || var->type == VAR_WORD || var->type == VAR_DWORD) {
             s = g_strdup_printf("%ld", (glong)gdef_get_int_var(var));
-            gwy_container_set_string_by_name(meta, var->name, s);
+            gwy_dict_set_string_by_name(meta, var->name, s);
         }
         else if (var->type == VAR_BOOL) {
             const gchar *cs = gdef_get_int_var(var) ? "true" : "false";
-            gwy_container_set_const_string_by_name(meta, var->name, cs);
+            gwy_dict_set_const_string_by_name(meta, var->name, cs);
         }
         else if (var->type == VAR_DOUBLE || var->type == VAR_FLOAT) {
             s = g_strdup_printf("%g", gdef_get_real_var(var));
-            gwy_container_set_string_by_name(meta, var->name, s);
+            gwy_dict_set_string_by_name(meta, var->name, s);
         }
     }
 
     s = gdef_read_channel_comment(block);
     if (s)
-        gwy_container_set_string_by_name(meta, "Comment", s);
+        gwy_dict_set_string_by_name(meta, "Comment", s);
     else
         g_free(s);
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
@@ -588,7 +588,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     const guchar *p;
     gsize size = 0;
