@@ -1,5 +1,5 @@
 /*
- *  $Id: gsffile.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: gsffile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -117,8 +117,9 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
-    GwyField *dfield = NULL, *mask;
+    GwyDict *meta = NULL;
+    GwyField *dfield = NULL;
+    GwyNield *mask;
     GwyTextHeaderParser parser;
     guchar *p, *value, *buffer = NULL, *header = NULL;
     const guchar *datap;
@@ -180,7 +181,7 @@ load_file(const gchar *filename,
 
     file = gwy_file_new_in_construction();
     gwy_file_pass_image(file, 0, dfield);
-    if ((mask = gwy_app_channel_mask_of_nans(dfield, TRUE)))
+    if ((mask = gwy_mask_nans_in_field(dfield, TRUE)))
         gwy_file_pass_image_mask(file, 0, mask);
 
     if ((value = g_hash_table_lookup(hash, "Title")) && g_utf8_validate(value, -1, NULL))
@@ -188,9 +189,9 @@ load_file(const gchar *filename,
     else
         gwy_image_title_fall_back(file, 0);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     else
         g_object_unref(meta);
@@ -215,7 +216,7 @@ add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
                      NULL))
         return;
 
-    gwy_container_set_const_string_by_name(GWY_CONTAINER(user_data), (gchar *)hkey, (gchar *)hvalue);
+    gwy_dict_set_const_string_by_name(GWY_DICT(user_data), (gchar *)hkey, (gchar *)hvalue);
 }
 
 static guint
