@@ -1,6 +1,6 @@
 /*
- *  $Id: gwyfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
- *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
+ *  $Id: gwyfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -15,6 +15,8 @@
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+// TODO: We may want to define individual file types at least for 2 and 3 to be able to do ‘save as GWY v2’.
+
 /**
  * [FILE-MAGIC-FREEDESKTOP]
  * <mime-type type="application/x-gwyddion-spm">
@@ -22,6 +24,7 @@
  *   <magic priority="100">
  *     <match type="string" offset="0" value="GWYOGwyContainer"/>
  *     <match type="string" offset="0" value="GWYPGwyContainer"/>
+ *     <match type="string" offset="0" value="GWYQGwyFile"/>
  *   </magic>
  *   <glob pattern="*.gwy"/>
  *   <glob pattern="*.GWY"/>
@@ -58,9 +61,15 @@
 #include "err.h"
 
 #define EXTENSION ".gwy"
-#define MAGIC "GWYO"
-#define MAGIC2 "GWYP"
-#define MAGIC_SIZE (sizeof(MAGIC)-1)
+#define MAGIC_COMMON "GWY"
+#define MAGIC_COMMON_SIZE (sizeof(MAGIC_COMMON)-1)
+#define MAGIC_SIZE (MAGIC_COMMON_SIZE+1)
+#define MAGIC1 "OGwyContainer\0"
+#define MAGIC1_SIZE (sizeof(MAGIC1)-1)
+#define MAGIC2 "PGwyContainer\0"
+#define MAGIC2_SIZE (sizeof(MAGIC2)-2)
+#define MAGIC3 "QGwyFile\0"
+#define MAGIC3_SIZE (sizeof(MAGIC3)-3)
 
 /* The container prefix all graph reside in.  This is a bit silly but it does not worth to break file compatibility
  * with 1.x. */
@@ -70,25 +79,25 @@ typedef struct {
     GArray *map;   /* data numbers in container, map plain position -> id */
     gint len;   /* length of reverse map @rmap */
     gint *rmap;   /* inversion of @map, defined only for the image of @map */
-    GwyContainer *target;   /* container to remap keys to */
+    GwyDict *target;   /* container to remap keys to */
     GString *str;   /* scratch space */
 } CompressIdData;
 
-static gboolean      module_register              (void);
-static gint          gwyfile_detect               (const GwyFileDetectInfo *fileinfo,
-                                                   gboolean only_name);
-static GwyContainer* gwyfile_load                 (const gchar *filename,
-                                                   GwyRunModeFlags mode,
-                                                   GError **error);
-static gboolean      gwyfile_save                 (GwyContainer *data,
-                                                   const gchar *filename,
-                                                   GwyRunModeFlags mode,
-                                                   GError **error);
-static void          gwyfile_pack_metadata        (GwyContainer *data);
-static void          gwyfile_remove_old_data      (GObject *object);
-static GObject*      gwy_container_deserialize_old(const guchar *buffer,
-                                                   gsize size,
-                                                   gsize *position);
+static gboolean module_register(void);
+static gint     detect_file    (const GwyFileDetectInfo *fileinfo,
+                                gboolean only_name);
+static GwyFile* load_file      (const gchar *filename,
+                                GwyRunModeFlags mode,
+                                GError **error);
+static gboolean save_file      (GwyFile *data,
+                                const gchar *filename,
+                                GwyRunModeFlags mode,
+                                GError **error);
+static void     pack_metadata  (GwyDict *data);
+static void     remove_old_data(GObject *object);
+static GObject* deserialize_old(const guchar *buffer,
+                                gsize size,
+                                gsize *position);
 
 
 static GwyModuleInfo module_info = {
@@ -96,7 +105,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Loads and saves Gwyddion native data files (serialized objects)."),
     "Yeti <yeti@gwyddion.net>",
-    "0.18",
+    "0.19",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -108,55 +117,74 @@ module_register(void)
 {
     gwy_file_func_register("gwyfile",
                            N_("Gwyddion native format (.gwy)"),
-                           &gwyfile_detect,
-                           &gwyfile_load,
-                           &gwyfile_save,
+                           &detect_file,
+                           &load_file,
+                           &save_file,
                            NULL);
 
     return TRUE;
 }
 
 static gint
-gwyfile_detect(const GwyFileDetectInfo *fileinfo,
-               gboolean only_name)
+detect_version(const gchar *buf, gsize size)
+{
+    if (size <= MAGIC_COMMON_SIZE || memcmp(buf, MAGIC_COMMON, MAGIC_COMMON_SIZE))
+        return -1;
+    // Go from the highest version, assuming it will eventually become the most common one.
+    if (size >= MAGIC_COMMON_SIZE + MAGIC3_SIZE && !memcmp(buf + MAGIC_COMMON_SIZE, MAGIC3, MAGIC3_SIZE))
+        return 3;
+    if (size >= MAGIC_COMMON_SIZE + MAGIC2_SIZE && !memcmp(buf + MAGIC_COMMON_SIZE, MAGIC2, MAGIC2_SIZE))
+        return 2;
+    if (size >= MAGIC_COMMON_SIZE + MAGIC1_SIZE && !memcmp(buf + MAGIC_COMMON_SIZE, MAGIC1, MAGIC1_SIZE))
+        return 1;
+    return -1;
+}
+
+static gint
+detect_file(const GwyFileDetectInfo *fileinfo, gboolean only_name)
 {
     gint score = 0;
 
     if (only_name)
         return g_str_has_suffix(fileinfo->name_lowercase, EXTENSION) ? 20 : 0;
 
-    if (fileinfo->buffer_len > MAGIC_SIZE
-        && (memcmp(fileinfo->head, MAGIC, MAGIC_SIZE) == 0 || memcmp(fileinfo->head, MAGIC2, MAGIC_SIZE) == 0))
+    if (detect_version(fileinfo->head, fileinfo->buffer_len) > 0)
         score = 100;
 
     return score;
 }
 
-static GwyContainer*
-gwyfile_load(const gchar *filename,
-             G_GNUC_UNUSED GwyRunModeFlags mode,
-             GError **error)
+static GwyFile*
+load_file(const gchar *filename,
+          G_GNUC_UNUSED GwyRunModeFlags mode,
+          GError **error)
 {
-    GwyContainer *container;
     GObject *object;
     GError *err = NULL;
     guchar *buffer = NULL;
     gsize size = 0;
     gsize pos = 0;
+    gint format_version = -1;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
         return NULL;
     }
-    if (size < MAGIC_SIZE || (memcmp(buffer, MAGIC, MAGIC_SIZE) && memcmp(buffer, MAGIC2, MAGIC_SIZE))) {
+    if ((format_version = detect_version(buffer, size)) <= 0) {
         err_FILE_TYPE(error, "Gwyddion");
         gwy_file_abandon_contents(buffer, size, &err);
         return NULL;
     }
 
-    if (!memcmp(buffer, MAGIC, MAGIC_SIZE)) {
-        object = gwy_container_deserialize_old(buffer + MAGIC_SIZE, size - MAGIC_SIZE, &pos);
-        gwyfile_remove_old_data(object);
+    if (format_version == 1) {
+        object = deserialize_old(buffer + MAGIC_SIZE, size - MAGIC_SIZE, &pos);
+        remove_old_data(object);
+    }
+    else if (format_version == 2) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_SPECIFIC,
+                    _("Loading GWY files version 2 is not implemented yet."));
+        gwy_file_abandon_contents(buffer, size, NULL);
+        return NULL;
     }
     else {
         /* TODO: Do something with the error list. */
@@ -169,44 +197,47 @@ gwyfile_load(const gchar *filename,
                     _("Data deserialization failed."));
         return NULL;
     }
-    if (!GWY_IS_CONTAINER(object)) {
+    if (!GWY_IS_FILE(object)) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                     _("Data deserialization succeeded, but resulted in an unexpected object %s."),
                     g_type_name(G_TYPE_FROM_INSTANCE(object)));
         g_object_unref(object);
         return NULL;
     }
-    container = GWY_CONTAINER(object);
-    gwyfile_pack_metadata(container);
 
-    /* Make sure that if there is "/filename" it is set by the app. */
-    gwy_container_remove_by_name(container, "/filename");
+    GwyDict *dict = GWY_DICT(object);
+    if (format_version < 3)
+        pack_metadata(dict);
 
-    return container;
+    /* Make sure that if there is filename, it is set by the app. */
+    gwy_dict_remove(dict, gwy_file_key_filename());
+
+    return GWY_FILE(dict);
 }
 
 static gboolean
-gwyfile_save(GwyContainer *data,
-             const gchar *filename,
-             G_GNUC_UNUSED GwyRunModeFlags mode,
-             GError **error)
+save_file(GwyFile *data,
+          const gchar *filename,
+          G_GNUC_UNUSED GwyRunModeFlags mode,
+          GError **error)
 {
     gboolean ok = TRUE;
 
-    /* Ensure the saved file contains its own name under "/filename" */
+    /* Ensure the saved file contains its own name under "/filename". Meaning we need to set it before saving it. */
     gboolean restore_filename = TRUE;
     const gchar *s = NULL;
-    gwy_container_gis_string_by_name(data, "/filename", &s);
+    GQuark key = gwy_file_key_filename();
+    gwy_dict_gis_string(GWY_DICT(data), key, &s);
     gchar *filename_orig_utf8 = g_strdup(s);
 
     gchar *filename_utf8 = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
     if (!filename_utf8)
-        gwy_container_remove_by_name(data, "/filename");
+        gwy_dict_remove(GWY_DICT(data), key);
     else if (filename_orig_utf8 && gwy_strequal(filename_orig_utf8, filename_utf8)) {
         restore_filename = FALSE;
     }
     else {
-        gwy_container_set_string_by_name(data, "/filename", filename_utf8);
+        gwy_dict_set_string(GWY_DICT(data), key, filename_utf8);
         filename_utf8 = NULL;
     }
 
@@ -218,7 +249,8 @@ gwyfile_save(GwyContainer *data,
         ok = FALSE;
     }
     if (ok) {
-        g_output_stream_write(G_OUTPUT_STREAM(stream), MAGIC2, MAGIC_SIZE, NULL, NULL);
+        g_output_stream_write(G_OUTPUT_STREAM(stream), MAGIC_COMMON, MAGIC_COMMON_SIZE, NULL, NULL);
+        g_output_stream_write(G_OUTPUT_STREAM(stream), "Q", 1, NULL, NULL);
         if (!gwy_serialize_gio(GWY_SERIALIZABLE(data), G_OUTPUT_STREAM(stream), &err)) {
             g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_IO,
                         _("Cannot write to file: %s."), err->message);
@@ -232,9 +264,9 @@ gwyfile_save(GwyContainer *data,
     /* Restore filename if save failed */
     if (!ok && restore_filename) {
         if (filename_orig_utf8)
-            gwy_container_set_string_by_name(data, "/filename", filename_orig_utf8);
+            gwy_dict_set_string(GWY_DICT(data), key, filename_orig_utf8);
         else
-            gwy_container_remove_by_name(data, "/filename");
+            gwy_dict_remove(GWY_DICT(data), key);
         filename_orig_utf8 = NULL;
     }
     g_free(filename_orig_utf8);
@@ -247,7 +279,7 @@ gwyfile_save(GwyContainer *data,
 static void
 gwyfile_gather_one_meta(GQuark quark,
                         GValue *value,
-                        GwyContainer *meta,
+                        GwyDict *meta,
                         const gchar *prefix,
                         guint prefix_len)
 {
@@ -260,63 +292,62 @@ gwyfile_gather_one_meta(GQuark quark,
     if (strkey[0] != '/' || !strkey[1] || !G_VALUE_HOLDS_STRING(value))
         return;
 
-    gwy_container_set_string_by_name(meta, strkey+1, g_value_dup_string(value));
+    gwy_dict_set_string_by_name(meta, strkey+1, g_value_dup_string(value));
 }
 
 static void
 gwyfile_gather_meta(GQuark quark, GValue *gvalue, gpointer user_data)
 {
-    gwyfile_gather_one_meta(quark, gvalue, (GwyContainer*)user_data, "/meta", sizeof("/meta")-1);
+    gwyfile_gather_one_meta(quark, gvalue, (GwyDict*)user_data, "/meta", sizeof("/meta")-1);
 }
 
 static void
 gwyfile_gather_0_data_meta(GQuark quark, GValue *gvalue, gpointer user_data)
 {
-    gwyfile_gather_one_meta(quark, gvalue, (GwyContainer*)user_data, "/0/data/meta", sizeof("/0/data/meta")-1);
+    gwyfile_gather_one_meta(quark, gvalue, (GwyDict*)user_data, "/0/data/meta", sizeof("/0/data/meta")-1);
 }
 
 /**
- * gwyfile_pack_metadata:
+ * pack_metadata:
  * @data: A data container.
  *
  * Pack scattered metadata under "/meta" to a container at "/0/meta" and metadata scattered under "/0/data/meta" to
  * a container at "/0/meta".
  **/
 static void
-gwyfile_pack_metadata(GwyContainer *data)
+pack_metadata(GwyDict *data)
 {
-    GwyContainer *meta;
-
-    meta = gwy_container_new();
+    GwyDict *meta = gwy_dict_new();
 
     /* Mindlessly run one packing after another.  Losing some metadata is not a tragedy and the file has to be borken
      * in the first place to have metadata conflicts. */
-    gwy_container_foreach(data, "/meta", &gwyfile_gather_meta, meta);
-    gwy_container_foreach(data, "/0/data/meta", &gwyfile_gather_0_data_meta, meta);
-    if (gwy_container_get_n_items(meta)) {
-        gwy_container_remove_by_prefix(data, "/meta");
-        gwy_container_remove_by_prefix(data, "/0/data/meta");
-        gwy_container_set_object_by_name(data, "/0/meta", meta);
+    gwy_dict_foreach(data, "/meta", &gwyfile_gather_meta, meta);
+    gwy_dict_foreach(data, "/0/data/meta", &gwyfile_gather_0_data_meta, meta);
+    if (!gwy_dict_get_n_items(meta)) {
+        g_object_unref(meta);
+        return;
     }
 
-    g_object_unref(meta);
+    gwy_dict_remove_by_prefix(data, "/meta");
+    gwy_dict_remove_by_prefix(data, "/0/data/meta");
+    gwy_file_pass_meta(GWY_FILE(data), GWY_FILE_IMAGE, 0, meta);
 }
 
 static GwySelection*
-gwyfile_gather_old_rect_selection(GwyContainer *data)
+gwyfile_gather_old_rect_selection(GwyDict *data)
 {
     GwySelection *sel;
     gboolean selected;
     gdouble xy[4];
 
-    if (!gwy_container_gis_boolean_by_name(data, "/0/select/rect/selected", &selected)
+    if (!gwy_dict_gis_boolean_by_name(data, "/0/select/rect/selected", &selected)
         || !selected)
         return NULL;
 
-    if (!gwy_container_gis_double_by_name(data, "/0/select/rect/x0", &xy[0])
-        || !gwy_container_gis_double_by_name(data, "/0/select/rect/y0", &xy[1])
-        || !gwy_container_gis_double_by_name(data, "/0/select/rect/x1", &xy[2])
-        || !gwy_container_gis_double_by_name(data, "/0/select/rect/y1", &xy[3]))
+    if (!gwy_dict_gis_double_by_name(data, "/0/select/rect/x0", &xy[0])
+        || !gwy_dict_gis_double_by_name(data, "/0/select/rect/y0", &xy[1])
+        || !gwy_dict_gis_double_by_name(data, "/0/select/rect/x1", &xy[2])
+        || !gwy_dict_gis_double_by_name(data, "/0/select/rect/y1", &xy[3]))
         return NULL;
 
     sel = GWY_SELECTION(g_object_new(GWY_TYPE_SELECTION_RECTANGLE, "max-objects", 1, NULL));
@@ -326,14 +357,14 @@ gwyfile_gather_old_rect_selection(GwyContainer *data)
 }
 
 static GwySelection*
-gwyfile_gather_old_point_selection(GwyContainer *data)
+gwyfile_gather_old_point_selection(GwyDict *data)
 {
     GwySelection *sel;
     gint i, nselected;
     gdouble xy[2];
     gchar key[40];
 
-    if (!gwy_container_gis_int32_by_name(data, "/0/select/points/nselected", &nselected))
+    if (!gwy_dict_gis_int32_by_name(data, "/0/select/points/nselected", &nselected))
         return NULL;
 
     nselected = CLAMP(nselected, 0, 16);
@@ -343,10 +374,10 @@ gwyfile_gather_old_point_selection(GwyContainer *data)
     sel = GWY_SELECTION(g_object_new(GWY_TYPE_SELECTION_POINT, "max-objects", nselected, NULL));
     for (i = 0; i < nselected; i++) {
         g_snprintf(key, sizeof(key), "/0/select/points/%d/x", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[0]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[0]))
             break;
         g_snprintf(key, sizeof(key), "/0/select/points/%d/y", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[1]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[1]))
             break;
 
         gwy_selection_set_object(sel, i, xy);
@@ -359,14 +390,14 @@ gwyfile_gather_old_point_selection(GwyContainer *data)
 }
 
 static GwySelection*
-gwyfile_gather_old_line_selection(GwyContainer *data)
+gwyfile_gather_old_line_selection(GwyDict *data)
 {
     GwySelection *sel;
     gint i, nselected;
     gdouble xy[4];
     gchar key[40];
 
-    if (!gwy_container_gis_int32_by_name(data, "/0/select/lines/nselected", &nselected))
+    if (!gwy_dict_gis_int32_by_name(data, "/0/select/lines/nselected", &nselected))
         return NULL;
 
     nselected = CLAMP(nselected, 0, 16);
@@ -376,16 +407,16 @@ gwyfile_gather_old_line_selection(GwyContainer *data)
     sel = GWY_SELECTION(g_object_new(GWY_TYPE_SELECTION_LINE, "max-objects", nselected, NULL));
     for (i = 0; i < nselected; i++) {
         g_snprintf(key, sizeof(key), "/0/select/lines/%d/x0", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[0]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[0]))
             break;
         g_snprintf(key, sizeof(key), "/0/select/lines/%d/y0", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[1]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[1]))
             break;
         g_snprintf(key, sizeof(key), "/0/select/lines/%d/x1", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[2]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[2]))
             break;
         g_snprintf(key, sizeof(key), "/0/select/lines/%d/y1", i);
-        if (!gwy_container_gis_double_by_name(data, key, &xy[3]))
+        if (!gwy_dict_gis_double_by_name(data, key, &xy[3]))
             break;
 
         gwy_selection_set_object(sel, i, xy);
@@ -398,39 +429,39 @@ gwyfile_gather_old_line_selection(GwyContainer *data)
 }
 
 static void
-gwyfile_remove_old_data(GObject *object)
+remove_old_data(GObject *object)
 {
-    GwyContainer *data;
+    GwyDict *data;
     GwySelection *rect, *point, *line;
 
-    if (!object || !GWY_IS_CONTAINER(object))
+    if (!object || !GWY_IS_DICT(object))
         return;
 
-    data = GWY_CONTAINER(object);
+    data = GWY_DICT(object);
 
     /* Selections */
     rect = gwyfile_gather_old_rect_selection(data);
     point = gwyfile_gather_old_point_selection(data);
     line = gwyfile_gather_old_line_selection(data);
-    gwy_container_remove_by_prefix(data, "/0/select");
+    gwy_dict_remove_by_prefix(data, "/0/select");
     if (rect) {
-        gwy_container_pass_object_by_name(data, "/0/select/rectangle", rect);
+        gwy_dict_pass_object_by_name(data, "/0/select/rectangle", rect);
     }
     if (point) {
-        gwy_container_pass_object_by_name(data, "/0/select/point", point);
+        gwy_dict_pass_object_by_name(data, "/0/select/point", point);
     }
     if (line) {
-        gwy_container_pass_object_by_name(data, "/0/select/line", line);
+        gwy_dict_pass_object_by_name(data, "/0/select/line", line);
     }
 
     /* 3D */
-    gwy_container_remove_by_prefix(data, "/0/3d/labels");
-    gwy_container_remove_by_name(data, "/0/3d/rot_x");
-    gwy_container_remove_by_name(data, "/0/3d/rot_y");
-    gwy_container_remove_by_name(data, "/0/3d/view_scale");
-    gwy_container_remove_by_name(data, "/0/3d/deformation_z");
-    gwy_container_remove_by_name(data, "/0/3d/light_z");
-    gwy_container_remove_by_name(data, "/0/3d/light_y");
+    gwy_dict_remove_by_prefix(data, "/0/3d/labels");
+    gwy_dict_remove_by_name(data, "/0/3d/rot_x");
+    gwy_dict_remove_by_name(data, "/0/3d/rot_y");
+    gwy_dict_remove_by_name(data, "/0/3d/view_scale");
+    gwy_dict_remove_by_name(data, "/0/3d/deformation_z");
+    gwy_dict_remove_by_name(data, "/0/3d/light_z");
+    gwy_dict_remove_by_name(data, "/0/3d/light_y");
 }
 /* }}} */
 
@@ -575,9 +606,9 @@ check_string(const guchar *buffer,
 }
 
 static GObject*
-gwy_container_deserialize_old(const guchar *buffer,
-                              gsize size,
-                              gsize *position)
+deserialize_old(const guchar *buffer,
+                gsize size,
+                gsize *position)
 {
     gsize mysize, pos;
     const guchar *buf;
@@ -585,15 +616,15 @@ gwy_container_deserialize_old(const guchar *buffer,
     gwy_debug("");
     g_return_val_if_fail(buffer, NULL);
 
-    pos = check_string(buffer, size, *position, g_type_name(GWY_TYPE_CONTAINER));
+    pos = check_string(buffer, size, *position, g_type_name(GWY_TYPE_DICT));
     g_return_val_if_fail(pos, NULL);
     *position += pos;
     mysize = unpack_int32(buffer, size, position);
     buf = buffer + *position;
     pos = 0;
 
-    GwyContainer *container = gwy_container_new();
-    gwy_container_start_construction(container);
+    GwyDict *container = gwy_dict_new();
+    gwy_dict_start_construction(container);
     while (pos < mysize) {
         GType type;
         guchar *name;
@@ -609,31 +640,31 @@ gwy_container_deserialize_old(const guchar *buffer,
         switch (type) {
             case G_TYPE_OBJECT:
             if ((object = gwy_deserialize_memory(buf, mysize, &pos, NULL)))
-                gwy_container_pass_object(container, key, object);
+                gwy_dict_pass_object(container, key, object);
             break;
 
             case G_TYPE_BOOLEAN:
-            gwy_container_set_boolean(container, key, unpack_boolean(buf, mysize, &pos));
+            gwy_dict_set_boolean(container, key, unpack_boolean(buf, mysize, &pos));
             break;
 
             case G_TYPE_UCHAR:
-            gwy_container_set_uchar(container, key, unpack_char(buf, mysize, &pos));
+            gwy_dict_set_uchar(container, key, unpack_char(buf, mysize, &pos));
             break;
 
             case G_TYPE_INT:
-            gwy_container_set_int32(container, key, unpack_int32(buf, mysize, &pos));
+            gwy_dict_set_int32(container, key, unpack_int32(buf, mysize, &pos));
             break;
 
             case G_TYPE_INT64:
-            gwy_container_set_int64(container, key, unpack_int64(buf, mysize, &pos));
+            gwy_dict_set_int64(container, key, unpack_int64(buf, mysize, &pos));
             break;
 
             case G_TYPE_DOUBLE:
-            gwy_container_set_double(container, key, unpack_double(buf, mysize, &pos));
+            gwy_dict_set_double(container, key, unpack_double(buf, mysize, &pos));
             break;
 
             case G_TYPE_STRING:
-            gwy_container_set_string(container, key, unpack_string(buf, mysize, &pos));
+            gwy_dict_set_string(container, key, unpack_string(buf, mysize, &pos));
             break;
 
             default:
@@ -642,7 +673,7 @@ gwy_container_deserialize_old(const guchar *buffer,
         }
     }
     *position += mysize;
-    gwy_container_finish_construction(container);
+    gwy_dict_finish_construction(container);
 
     return (GObject*)container;
 }
