@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyzip.h 26741 2024-10-18 14:09:45Z yeti-dn $
+ *  $Id: gwyzip.h 29403 2026-01-29 17:37:40Z yeti-dn $
  *  Copyright (C) 2015-2024 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -32,9 +32,13 @@ struct _GwyZipFile;
 
 typedef struct _GwyZipFile *GwyZipFile;
 
-#if defined(HAVE_MINIZIP1) || defined(HAVE_MINIZIP2) || defined(HAVE_LIBZIP) || defined(HAVE_ZZIP)
+#if defined(HAVE_MINIZIP1) || defined(HAVE_MINIZIP2) || defined(HAVE_MINIZIPNG) || defined(HAVE_LIBZIP) || defined(HAVE_ZZIP)
 #define HAVE_GWYZIP 1
-/* This is the interface we implement. */
+/* This is the interface we implement.
+ *
+ * There is also an optional gwyzip_open_memory(), which some backens implement.
+ *
+ * There can be other symbols starting with gwyzip_ defined, they are reserved. */
 static GwyZipFile gwyzip_open                (const gchar *path,
                                               GError **error);
 static void       gwyzip_close               (GwyZipFile zipfile);
@@ -62,6 +66,10 @@ static guchar*    gwyzip_get_file_content    (GwyZipFile zipfile,
 #include "gwyzip-minizip2.h"
 #endif
 
+#ifdef HAVE_MINIZIPNG
+#include "gwyzip-minizip-ng.h"
+#endif
+
 #ifdef HAVE_LIBZIP
 #include "gwyzip-libzip.h"
 #endif
@@ -70,25 +78,33 @@ static guchar*    gwyzip_get_file_content    (GwyZipFile zipfile,
 #include "gwyzip-zzlib.h"
 #endif
 
-/* Backend-independent utilities. */
+/* Backend-independent utilities.
+ *
+ * NB: The function may fill NULL to actualname if the library supports memory streams (or we create an anonymous
+ * file). */
 #ifdef HAVE_GWYZIP
 G_GNUC_UNUSED
 static GwyZipFile
 gwyzip_make_temporary_archive(const guchar *buffer, gsize size,
-                              const gchar *nametemplate, gchar **actualname, GError **error)
+                              G_GNUC_UNUSED const gchar *nametemplate,
+                              GError **error)
 {
+#ifdef GWYZIP_HAS_MEMORY_FILES
+    return gwyzip_open_memory(buffer, size, error);
+#else
     GwyZipFile zipfile;
     GError *err = NULL;
     gssize bytes_written;
     gint fd;
     guint failcount = 0;
+    gchar *actualname = NULL;
 
-    fd = g_file_open_tmp(nametemplate, actualname, &err);
+    fd = g_file_open_tmp(nametemplate, &actualname, &err);
     if (fd == -1) {
         err_OPEN_WRITE_GERROR(error, &err);
         return NULL;
     }
-    gwy_debug("temporary ZIP file <%s>", *actualname);
+    gwy_debug("temporary ZIP file <%s>", actualname);
 
     while (size) {
         bytes_written = write(fd, buffer, size);
@@ -108,14 +124,18 @@ gwyzip_make_temporary_archive(const guchar *buffer, gsize size,
     }
 
     close(fd);
-    if ((zipfile = gwyzip_open(*actualname, error)))
+    if ((zipfile = gwyzip_open(actualname, error))) {
+        /* Backends which do not have memory files must have this field. They must also clean up the file in their
+         * gwyzip_close() function! */
+        zipfile->tmpfilename = actualname;
         return zipfile;
+    }
 
 fail:
-    g_unlink(*actualname);
-    g_free(*actualname);
-    *actualname = NULL;
+    g_unlink(actualname);
+    g_free(actualname);
     return NULL;
+#endif
 }
 
 G_GNUC_UNUSED
