@@ -1,5 +1,5 @@
 /*
- *  $Id: hdf4file.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: hdf4file.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -301,7 +301,7 @@ static gboolean      psi_read_header   (const guchar *buffer,
 static GArray*       hdf4_read_tags    (const guchar *buffer,
                                         gsize size,
                                         GError **error);
-static GwyContainer* psi_get_metadadata(const PsiHeader *header);
+static GwyDict* psi_get_metadadata(const PsiHeader *header);
 #ifdef DEBUG
 static guint        get_data_type_size     (HDF4TypeInfo id,
                                             GError **error);
@@ -579,18 +579,18 @@ psi_read_header(const guchar *buffer,
     return TRUE;
 }
 
-static GwyContainer*
+static GwyDict*
 psi_get_metadadata(const PsiHeader *header)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_string_by_name(meta, "Set point",
-                                     g_strdup_printf("%g %s", header->set_point, header->set_point_unit));
-    gwy_container_set_string_by_name(meta, "Sample bias", g_strdup_printf("%g V", header->sample_bias));
-    gwy_container_set_string_by_name(meta, "Tip bias", g_strdup_printf("%g V", header->tip_bias));
-    gwy_container_set_string_by_name(meta, "Instrument", g_strdup_printf("%s", header->instrument));
-    gwy_container_set_string_by_name(meta, "Rotation", g_strdup_printf("%g deg", header->rotation));
-    gwy_container_set_string_by_name(meta, "Scan speed", g_strdup_printf("%g lines/s", header->lines_per_sec));
+    gwy_dict_set_string_by_name(meta, "Set point",
+                                g_strdup_printf("%g %s", header->set_point, header->set_point_unit));
+    gwy_dict_set_string_by_name(meta, "Sample bias", g_strdup_printf("%g V", header->sample_bias));
+    gwy_dict_set_string_by_name(meta, "Tip bias", g_strdup_printf("%g V", header->tip_bias));
+    gwy_dict_set_string_by_name(meta, "Instrument", g_strdup_printf("%s", header->instrument));
+    gwy_dict_set_string_by_name(meta, "Rotation", g_strdup_printf("%g deg", header->rotation));
+    gwy_dict_set_string_by_name(meta, "Scan speed", g_strdup_printf("%g lines/s", header->lines_per_sec));
 
     return meta;
 }
