@@ -1,5 +1,5 @@
 /*
- *  $Id: datxfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: datxfile.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2020-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -75,7 +75,7 @@ static gboolean       read_images            (const DatxFile *dfile,
                                               gboolean surfaces,
                                               gint *id,
                                               GError **error);
-static GwyField*      channel_mask_of_invalid(GwyField *dfield,
+static GwyNield*      channel_mask_of_invalid(GwyField *field,
                                               gboolean removebad);
 static gboolean       read_metadata          (DatxFile *dfile,
                                               hid_t file_id,
@@ -156,7 +156,7 @@ load_file(const gchar *filename,
     if (!read_images(&dfile, file_id, file, TRUE, &id, error)
         || !read_images(&dfile, file_id, file, FALSE, &id, error))
         g_clear_object(&file);
-    else if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    else if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
     }
@@ -176,7 +176,7 @@ read_images(const DatxFile *dfile, hid_t file_id, GwyFile *file,
             gint *id, GError **error)
 {
     gint dims[2] = { -1, -1 };
-    GwyField *field, *mask;
+    GwyField *field;
     const DatxMetadata *m;
     DatxConverter *converter;
     GString *title;
@@ -268,7 +268,7 @@ read_images(const DatxFile *dfile, hid_t file_id, GwyFile *file,
         }
 
         /* Create the mask first. Applying units can mess up the invalid value detection. */
-        mask = channel_mask_of_invalid(field, TRUE);
+        GwyNield *mask = channel_mask_of_invalid(field, TRUE);
         gwy_field_multiply(field, zscale);
         free_datx_converter(converter);
 
@@ -289,32 +289,32 @@ fail:
     return ok;
 }
 
-/* Like gwy_app_channel_mask_of_nans(), but the invalid data are not NaNs, they are large finite values.
- * FIXME: We should probably have ‘also mark suspiciously huge values’ as an option for gwy_app_channel_mask_of_nans()
+/* Like gwy_mask_nans_in_field(), but the invalid data are not NaNs, they are large finite values.
+ * FIXME: We should probably have ‘also mark suspiciously huge values’ as an option for gwy_mask_nans_in_field()
  * but it is an API change, so do it in 3.x. */
-static GwyField*
-channel_mask_of_invalid(GwyField *dfield, gboolean removebad)
+static GwyNield*
+channel_mask_of_invalid(GwyField *field, gboolean removebad)
 {
-    GwyField *mask = NULL;
-    guint k, n = dfield->xres*dfield->yres;
-    gdouble *d = gwy_field_get_data(dfield), *m = NULL;
+    GwyNield *mask = NULL;
+    guint k, n = field->xres*field->yres;
+    gdouble *d = gwy_field_get_data(field);
+    gint *m = NULL;
 
     for (k = 0; k < n; k++) {
         /* Probably anything larger than √G_MAXDOUBLE is suspicious, but this should be a sufficient margin. */
         if (gwy_isnan(d[k]) || gwy_isinf(d[k]) || fabs(d[k]) > 1e-9*G_MAXDOUBLE) {
             if (G_UNLIKELY(!mask)) {
-                mask = gwy_field_new_alike(dfield, TRUE);
-                m = gwy_field_get_data(mask);
-                gwy_unit_clear(gwy_field_get_unit_z(mask));
+                mask = gwy_field_new_nield_alike(field);
+                m = gwy_nield_get_data(mask);
             }
-            m[k] = 1.0;
+            m[k] = 1;
         }
     }
 
     if (!mask || !removebad)
         return mask;
 
-    gwy_field_laplace_solve(dfield, mask, -1, 0.25);
+    gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 0.25);
 
     return mask;
 }
