@@ -1,5 +1,5 @@
 /*
- *  $Id: epflfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: epflfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2020-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -68,7 +68,7 @@ typedef struct {
 } USIDDimensionInfo;
 
 typedef struct {
-    GwyContainer *meta;
+    GwyDict *meta;
     gchar *path;
     hid_t file_id;
 } GroupMetaData;
@@ -77,23 +77,23 @@ typedef struct {
     const gchar *filename;
 } EPFLFile;
 
-static gint          detect_file             (const GwyFileDetectInfo *fileinfo,
-                                              gboolean only_name);
-static GwyFile*      load_file               (const gchar *filename,
-                                              GwyRunModeFlags mode,
-                                              GError **error);
-static void          create_image            (hid_t file_id,
-                                              const gchar *dataset_path,
-                                              GwyHDF5File *ghfile,
-                                              GwyFile *file,
-                                              gint *id);
-static GwyContainer* gather_meta             (hid_t file_id,
-                                              GwyHDF5File *ghfile,
-                                              const gchar *basekey);
-static gboolean      read_usid_dimension_info(hid_t file_id,
-                                              const gchar *dataset_path,
-                                              GwyHDF5File *ghfile,
-                                              USIDDimensionInfo *info);
+static gint     detect_file             (const GwyFileDetectInfo *fileinfo,
+                                         gboolean only_name);
+static GwyFile* load_file               (const gchar *filename,
+                                         GwyRunModeFlags mode,
+                                         GError **error);
+static void     create_image            (hid_t file_id,
+                                         const gchar *dataset_path,
+                                         GwyHDF5File *ghfile,
+                                         GwyFile *file,
+                                         gint *id);
+static GwyDict* gather_meta             (hid_t file_id,
+                                         GwyHDF5File *ghfile,
+                                         const gchar *basekey);
+static gboolean read_usid_dimension_info(hid_t file_id,
+                                         const gchar *dataset_path,
+                                         GwyHDF5File *ghfile,
+                                         USIDDimensionInfo *info);
 
 void
 gwyhdf5_register_epflfile(void)
@@ -182,7 +182,7 @@ load_file(const gchar *filename,
 
     gwyhdf5_free(&ghfile);
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
     }
@@ -197,7 +197,7 @@ create_image(hid_t file_id,
              GwyFile *file,
              gint *id)
 {
-    GwyContainer *meta, *hash = ghfile->meta;
+    GwyDict *meta, *hash = ghfile->meta;
     EPFLFile *efile = (EPFLFile*)ghfile->impl;
     gint dims[2] = { -1, -1 };
     const gchar *name;
@@ -262,13 +262,13 @@ create_image(hid_t file_id,
     s = name;
     g_string_truncate(key, klen);
     g_string_append(key, "quantity");
-    gwy_container_gis_string_by_name(hash, key->str, &s);
+    gwy_dict_gis_string_by_name(hash, key->str, &s);
     gwy_file_set_title(file, GWY_FILE_IMAGE, *id, s, FALSE);
 
     /* Value units. */
     g_string_truncate(key, klen);
     g_string_append(key, "units");
-    if (gwy_container_gis_string_by_name(hash, key->str, &s)) {
+    if (gwy_dict_gis_string_by_name(hash, key->str, &s)) {
         gwy_debug("found units <%s>", s);
         power10 = gwy_unit_set_from_string(gwy_field_get_unit_z(field), s);
         if (power10)
@@ -279,7 +279,7 @@ create_image(hid_t file_id,
     }
 
     /* Lateral dimensions – take from metadata. */
-    if (gwy_container_gis_string_by_name(meta, "Width", &s)) {
+    if (gwy_dict_gis_string_by_name(meta, "Width", &s)) {
         gwy_debug("found Width <%s>", s);
         u = g_ascii_strtod(s, &end);
         sanitise_real_size(&u, "x size");
@@ -291,7 +291,7 @@ create_image(hid_t file_id,
         gwy_debug("did NOT find Width");
     }
 
-    if (gwy_container_gis_string_by_name(meta, "Height", &s)) {
+    if (gwy_dict_gis_string_by_name(meta, "Height", &s)) {
         gwy_debug("found Height <%s>", s);
         u = g_ascii_strtod(s, &end);
         sanitise_real_size(&u, "y size");
@@ -303,7 +303,7 @@ create_image(hid_t file_id,
         gwy_debug("did NOT find Height");
     }
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, meta);
     else
         g_object_unref(meta);
@@ -325,7 +325,7 @@ scan_meta_group(G_GNUC_UNUSED hid_t loc_id,
     /* Do not overwrite existing metadata. This should generally not happen, but we go from the innermost group
      * to the outermost. So if it does happen keep the information closest to the data. */
     gwy_debug("attr %s", name);
-    if (gwy_container_contains_by_name(gmd->meta, name)) {
+    if (gwy_dict_contains_by_name(gmd->meta, name)) {
         gwy_debug("already exists");
         return 0;
     }
@@ -345,12 +345,12 @@ scan_meta_group(G_GNUC_UNUSED hid_t loc_id,
     g_strdelimit(s_utf8, "\n\r\t\v", ' ');
 
     gwy_debug("value %s", s_utf8);
-    gwy_container_set_string_by_name(gmd->meta, name, s_utf8);
+    gwy_dict_set_string_by_name(gmd->meta, name, s_utf8);
 
     return 0;
 }
 
-static GwyContainer*
+static GwyDict*
 gather_meta(hid_t file_id, GwyHDF5File *ghfile, const gchar *basekey)
 {
     /* There is a lot of rubbish. So use a whitelist. */
@@ -362,7 +362,7 @@ gather_meta(hid_t file_id, GwyHDF5File *ghfile, const gchar *basekey)
     static const gchar *group_attributes[] = {
         "Width", "Height", "Date", "Mode", "Lines", "Scan Rate", "X Offset", "Y Offset",
     };
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     const gchar *s;
     GroupMetaData gmd;
     GString *key;
@@ -377,8 +377,8 @@ gather_meta(hid_t file_id, GwyHDF5File *ghfile, const gchar *basekey)
     for (i = 0; i < G_N_ELEMENTS(dataset_attributes); i++) {
         g_string_truncate(key, klen);
         g_string_append(key, dataset_attributes[i]);
-        if (gwy_container_gis_string_by_name(ghfile->meta, key->str, &s))
-            gwy_container_set_const_string_by_name(meta, key->str + klen, s);
+        if (gwy_dict_gis_string_by_name(ghfile->meta, key->str, &s))
+            gwy_dict_set_const_string_by_name(meta, key->str + klen, s);
     }
 
     /* Metadata (from a parent group). We cannot be sure how deep we are with respect to the parent group, so just
@@ -390,7 +390,7 @@ gather_meta(hid_t file_id, GwyHDF5File *ghfile, const gchar *basekey)
         for (i = 0; i < G_N_ELEMENTS(group_attributes); i++) {
             g_string_truncate(key, klen+1);
             g_string_append(key, group_attributes[i]);
-            if (gwy_container_gis_string_by_name(ghfile->meta, key->str, &s)) {
+            if (gwy_dict_gis_string_by_name(ghfile->meta, key->str, &s)) {
                 g_string_truncate(key, klen);
                 gwy_debug("found canary attribute <%s> in parent group <%s>", group_attributes[i], key->str);
                 gmd.meta = meta;
@@ -426,7 +426,7 @@ read_usid_dimension_info(hid_t file_id,
                          GwyHDF5File *ghfile,
                          USIDDimensionInfo *info)
 {
-    GwyContainer *hash = ghfile->meta;
+    GwyDict *hash = ghfile->meta;
     GString *key = g_string_new(NULL);
     gboolean ok = FALSE;
     const gchar *s;
@@ -445,7 +445,7 @@ read_usid_dimension_info(hid_t file_id,
     g_string_assign(key, dataset_path+1);
     g_string_append(key, "/Position_Indices");
     gwy_debug("looking for %s", key->str);
-    if (!gwy_container_gis_string_by_name(hash, key->str, &s))
+    if (!gwy_dict_gis_string_by_name(hash, key->str, &s))
         goto end;
 
     gwy_debug("found %s, checking dimensions", s);
@@ -462,7 +462,7 @@ read_usid_dimension_info(hid_t file_id,
     g_string_assign(key, dataset_path+1);
     g_string_append(key, "/Position_Values");
     gwy_debug("looking for %s", key->str);
-    if (!gwy_container_gis_string_by_name(hash, key->str, &s))
+    if (!gwy_dict_gis_string_by_name(hash, key->str, &s))
         goto end;
 
     gwy_debug("found %s, checking dimensions", s);
@@ -475,7 +475,7 @@ read_usid_dimension_info(hid_t file_id,
     g_string_assign(key, dataset_path+1);
     g_string_append(key, "/Spectroscopic_Indices");
     gwy_debug("looking for %s", key->str);
-    if (!gwy_container_gis_string_by_name(hash, key->str, &s))
+    if (!gwy_dict_gis_string_by_name(hash, key->str, &s))
         goto end;
 
     gwy_debug("found %s, checking dimensions", s);
@@ -492,7 +492,7 @@ read_usid_dimension_info(hid_t file_id,
     g_string_assign(key, dataset_path+1);
     g_string_append(key, "/Spectroscopic_Values");
     gwy_debug("looking for %s", key->str);
-    if (!gwy_container_gis_string_by_name(hash, key->str, &s))
+    if (!gwy_dict_gis_string_by_name(hash, key->str, &s))
         goto end;
 
     gwy_debug("found %s, checking dimensions", s);
