@@ -1,5 +1,5 @@
 /*
- *  $Id: fusionscope.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: fusionscope.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -66,8 +66,8 @@
 
 typedef struct {
     GwyField *field;
-    GwyField *mask;
-    GwyContainer *meta;
+    GwyNield *mask;
+    GwyDict *meta;
     gchar *title;
     gchar *id_prefix;
     gchar *metadata_prefix;
@@ -446,7 +446,7 @@ create_image(FScopeFile *fsfile, hid_t dataset, const gint *dims)
     set_real_dimensions(field, fsfile);
 
     image.field = field;
-    image.mask = gwy_app_channel_mask_of_nans(field, TRUE);
+    image.mask = gwy_mask_nans_in_field(field, TRUE);
     if (gwyhdf5_get_str_attr(dataset, ".", "SUBCHANNEL_NAME", &channel_name, NULL))
         chname = channel_name;
     image.title = g_strconcat(fsfile->region_clean, ", ",
@@ -530,7 +530,7 @@ add_simple_meta(gpointer hkey, gpointer hdata, gpointer user_data)
     if (!len || len > 250)
         return;
 
-    gwy_container_set_const_string(image->meta, g_quark_from_string(key), value);
+    gwy_dict_set_const_string(image->meta, g_quark_from_string(key), value);
 }
 
 static void
@@ -560,13 +560,13 @@ add_meta_with_data_id(gpointer hkey, gpointer hdata, gpointer user_data)
         key += strlen(image->metadata_prefix);
     }
 
-    gwy_container_set_const_string(image->meta, g_quark_from_string(key), value);
+    gwy_dict_set_const_string(image->meta, g_quark_from_string(key), value);
 }
 
 static void
 create_image_meta(FScopeFile *fsfile, FScopeImage *image)
 {
-    image->meta = gwy_container_new_in_construction();
+    image->meta = gwy_dict_new_in_construction();
 
     /* TODO: There are also a couple top level attributes and attributes scattered in the HDF5 groups. Most do not
      * seem very useful, but some may be. */
