@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyhdf5.c 29026 2025-12-19 14:03:38Z yeti-dn $
+ *  $Id: gwyhdf5.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2020-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -57,7 +57,7 @@ gwyhdf5_init(GwyHDF5File *ghfile, hid_t file_id, H5O_token_t token)
 {
     gwy_clear(ghfile, 1);
     ghfile->file_id = file_id;
-    ghfile->meta = gwy_container_new();
+    ghfile->meta = gwy_dict_new();
     ghfile->path = g_string_new(NULL);
     ghfile->buf = g_string_new(NULL);
     ghfile->tokens = g_array_new(FALSE, FALSE, sizeof(H5O_token_t));
@@ -569,7 +569,7 @@ gwyhdf5_process_attribute(hid_t loc_id,
                 gwy_debug("compound %s reading status %d (value %s)", member_name, status, buf->str);
                 if (status >= 0) {
                     gwy_debug("[%s] = <%s>", path->str, buf->str);
-                    gwy_container_set_const_string_by_name(ghfile->meta, path->str+1, buf->str);
+                    gwy_dict_set_const_string_by_name(ghfile->meta, path->str+1, buf->str);
                 }
             }
 
@@ -585,7 +585,7 @@ gwyhdf5_process_attribute(hid_t loc_id,
 
     if (status >= 0) {
         gwy_debug("[%s] = <%s>", path->str, buf->str);
-        gwy_container_set_const_string_by_name(ghfile->meta, path->str+1, buf->str);
+        gwy_dict_set_const_string_by_name(ghfile->meta, path->str+1, buf->str);
     }
     else if (type_class == H5T_COMPOUND) {
         /* Dealt with, one way or another. */
@@ -990,19 +990,19 @@ transform_key(GQuark quark, GValue *gvalue, gpointer user_data)
 {
     const gchar *oldkey = g_quark_to_string(quark);
     const gchar *value = g_value_get_string(gvalue);
-    GwyContainer *newmeta = (GwyContainer*)user_data;
+    GwyDict *newmeta = (GwyDict*)user_data;
     gchar *newkey = gwy_strreplace(oldkey, "/", "::", (gsize)-1);
 
-    gwy_container_set_const_string_by_name(newmeta, newkey, value);
+    gwy_dict_set_const_string_by_name(newmeta, newkey, value);
     g_free(newkey);
 }
 
-GwyContainer*
-gwyhdf5_meta_slash_to_4dots(GwyContainer *meta)
+GwyDict*
+gwyhdf5_meta_slash_to_4dots(GwyDict *meta)
 {
-    GwyContainer *newmeta = gwy_container_new();
+    GwyDict *newmeta = gwy_dict_new();
 
-    gwy_container_foreach(meta, NULL, transform_key, newmeta);
+    gwy_dict_foreach(meta, NULL, transform_key, newmeta);
     return newmeta;
 }
 
