@@ -1,6 +1,6 @@
 #pragma once
 /*
- *  $Id: gwyhdf5.h 29026 2025-12-19 14:03:38Z yeti-dn $
+ *  $Id: gwyhdf5.h 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2020-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -48,7 +48,7 @@ struct _GwyHDF5File {
     GArray *tokens;
     GString *path;
     GString *buf;
-    GwyContainer *meta;
+    GwyDict *meta;
 
     /* Generic gathering of some numeric values. */
     guint nlists;
@@ -145,7 +145,7 @@ G_GNUC_INTERNAL gboolean      gwyhdf5_check_status             (herr_t status,
                                                                 GwyHDF5File *ghfile,
                                                                 const gchar *func_name,
                                                                 GError **error);
-G_GNUC_INTERNAL GwyContainer* gwyhdf5_meta_slash_to_4dots      (GwyContainer *meta);
+G_GNUC_INTERNAL GwyDict* gwyhdf5_meta_slash_to_4dots      (GwyDict *meta);
 
 static inline void
 err_HDF5(GError **error, const gchar *where, glong code)
