@@ -1,5 +1,5 @@
 /*
- *  $Id: gxsm4.c 29026 2025-12-19 14:03:38Z yeti-dn $
+ *  $Id: gxsm4.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net
  *
@@ -45,7 +45,7 @@ typedef enum {
 typedef struct {
     const gchar *filename;
     GwyFile *file;
-    GwyContainer *meta;
+    GwyDict *meta;
     const gchar *dataset_name;
     GXSM4DataKind datakind;
 } GXSM4File;
@@ -68,7 +68,7 @@ static void     set_brick_zcalibration(GwyBrick *brick,
                                        hid_t dscale,
                                        gint zlen);
 static void     add_more_meta         (hid_t file_id,
-                                       GwyContainer *meta);
+                                       GwyDict *meta);
 
 void
 gwyhdf5_register_gxsm4(void)
@@ -146,7 +146,7 @@ load_file(const gchar *filename,
         return NULL;
 
     g4file.meta = gwyhdf5_meta_slash_to_4dots(ghfile.meta);
-    gwy_container_remove_by_name(g4file.meta, "_NCProperties");
+    gwy_dict_remove_by_name(g4file.meta, "_NCProperties");
     add_more_meta(file_id, g4file.meta);
 
     if (!find_main_dataset(&g4file, file_id, error))
@@ -289,7 +289,7 @@ read_image(GXSM4File *g4file, hid_t file_id, GError **error)
     else
         gwy_image_title_fall_back(g4file->file, 0);
 
-    gwy_file_pass_meta(g4file->file, GWY_FILE_IMAGE, 0, gwy_container_copy(g4file->meta));
+    gwy_file_pass_meta(g4file->file, GWY_FILE_IMAGE, 0, gwy_dict_copy(g4file->meta));
     gwy_log_add_import(g4file->file, GWY_FILE_IMAGE, 0, NULL, g4file->filename);
 
     ok = TRUE;
@@ -357,10 +357,10 @@ read_timeseries(GXSM4File *g4file, hid_t file_id, GError **error)
         gwy_debug("found label %s", s);
         gwy_file_pass_title(g4file->file, GWY_FILE_VOLUME, 0, s);
     }
-    else 
+    else
         gwy_file_set_title(g4file->file, GWY_FILE_VOLUME, 0, "Timeseries", FALSE);
 
-    gwy_file_pass_meta(g4file->file, GWY_FILE_VOLUME, 0, gwy_container_copy(g4file->meta));
+    gwy_file_pass_meta(g4file->file, GWY_FILE_VOLUME, 0, gwy_dict_copy(g4file->meta));
     gwy_log_add_import(g4file->file, GWY_FILE_VOLUME, 0, NULL, g4file->filename);
 
     ok = TRUE;
@@ -434,7 +434,7 @@ scan_aux_datasets(hid_t loc_id,
         "basename", "bright", "contrast", "comment", "dateofscan", "reftime", "extra_scan_info", "spm_scancontrol",
         "spm_scancontrol_dim", "title", "username",
     };
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *unit = NULL;
     H5T_class_t type_class;
     H5O_info_t infobuf;
@@ -472,7 +472,7 @@ scan_aux_datasets(hid_t loc_id,
         if (s) {
             g_strstrip(s);
             gwy_debug("read as string dataset %s as <%s>", name, s);
-            gwy_container_set_string_by_name(meta, metaname, s);
+            gwy_dict_set_string_by_name(meta, metaname, s);
         }
         return 0;
     }
@@ -483,15 +483,15 @@ scan_aux_datasets(hid_t loc_id,
         gdouble v;
         if (H5Dread(dataset, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, &v) >= 0) {
             if (unit)
-                gwy_container_set_string_by_name(meta, metaname, g_strdup_printf("%g %s", v, unit));
+                gwy_dict_set_string_by_name(meta, metaname, g_strdup_printf("%g %s", v, unit));
             else
-                gwy_container_set_string_by_name(meta, metaname, g_strdup_printf("%g", v));
+                gwy_dict_set_string_by_name(meta, metaname, g_strdup_printf("%g", v));
         }
     }
     else if (type_class == H5T_INTEGER) {
         glong v;
         if (H5Dread(dataset, H5T_NATIVE_LONG, H5S_ALL, H5S_ALL, H5P_DEFAULT, &v) >= 0)
-            gwy_container_set_string_by_name(meta, metaname, g_strdup_printf("%ld", v));
+            gwy_dict_set_string_by_name(meta, metaname, g_strdup_printf("%ld", v));
     }
     else {
         gwy_debug("don't know what to do with type class %d", type_class);
@@ -505,7 +505,7 @@ scan_aux_datasets(hid_t loc_id,
 }
 
 static void
-add_more_meta(hid_t file_id, GwyContainer *meta)
+add_more_meta(hid_t file_id, GwyDict *meta)
 {
     H5Literate(file_id, H5_INDEX_NAME, H5_ITER_NATIVE, NULL, scan_aux_datasets, meta);
 }
