@@ -1,5 +1,5 @@
 /*
- *  $Id: nhffile.c 29006 2025-12-15 16:08:13Z yeti-dn $
+ *  $Id: nhffile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2024-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -190,7 +190,7 @@ static gboolean  dataset_is_placeholder   (hid_t parent_id,
 static void      set_gerror_hdf_internal  (NHFFile *nhfile,
                                            const gchar *funcname,
                                            herr_t status);
-static void      clean_up_json_meta       (GwyContainer *meta);
+static void      clean_up_json_meta       (GwyDict *meta);
 
 static const GwyEnum group_names[] = {
     { "calibration",      NHF_GROUP_CALIBRATION,      },
@@ -786,9 +786,9 @@ handle_cmap_subgroup(hid_t loc_id,
     }
 
     if (gwyhdf5_get_str_attr_g(subgrp_id, ".", "segment_configuration", &segment_config, NULL))
-        gwy_container_set_string_by_name(nhfile->ghfile->meta, "segment_configuration", segment_config);
+        gwy_dict_set_string_by_name(nhfile->ghfile->meta, "segment_configuration", segment_config);
     else
-        gwy_container_remove_by_name(nhfile->ghfile->meta, "segment_configuration");
+        gwy_dict_remove_by_name(nhfile->ghfile->meta, "segment_configuration");
 
     if (npts > 1)
         create_curve_map(nhfile);
@@ -820,14 +820,14 @@ end:
 static herr_t
 handle_image_group(hid_t grp_id, NHFFile *nhfile)
 {
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     herr_t status;
 
     nhfile->extracting = NHF_EXTRACTING_IMAGES;
     if (!get_image_real_range(grp_id, nhfile))
         return NHF_FAIL;
 
-    gwy_container_remove_by_prefix(meta, NULL);
+    gwy_dict_remove_by_prefix(meta, NULL);
     H5Aiterate2(grp_id, H5_INDEX_NAME, H5_ITER_NATIVE, NULL, gwyhdf5_process_attribute, nhfile->ghfile);
 
     /* There should be two subgroups (segments) called subgroup_0000 and subgroup_0001. But assuming this does not
@@ -847,14 +847,14 @@ end:
 static herr_t
 handle_wnma_group(hid_t grp_id, NHFFile *nhfile)
 {
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     herr_t status;
 
     nhfile->extracting = NHF_EXTRACTING_VOLUMES;
     if (!get_image_real_range(grp_id, nhfile))
         return NHF_FAIL;
 
-    gwy_container_remove_by_prefix(meta, NULL);
+    gwy_dict_remove_by_prefix(meta, NULL);
     H5Aiterate2(grp_id, H5_INDEX_NAME, H5_ITER_NATIVE, NULL, gwyhdf5_process_attribute, nhfile->ghfile);
 
     /* First iterate over datasets and find free wave. We are not guaranteed to get it in any particular order with
@@ -886,7 +886,7 @@ static herr_t
 handle_cmap_group(hid_t grp_id, NHFFile *nhfile)
 {
     herr_t status = NHF_NEUTRAL;
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     guint npts = nhfile->xres * nhfile->yres;
     guint xres, yres;
     GwyXY xymin, xymax;
@@ -910,7 +910,7 @@ handle_cmap_group(hid_t grp_id, NHFFile *nhfile)
         gwy_debug("got usable grid point index");
     }
 
-    gwy_container_remove_by_prefix(meta, NULL);
+    gwy_dict_remove_by_prefix(meta, NULL);
     H5Aiterate2(grp_id, H5_INDEX_NAME, H5_ITER_NATIVE, NULL, gwyhdf5_process_attribute, nhfile->ghfile);
 
     /* There are some number of subgroups (segments) called subgroup_0000 and subgroup_0001. Usually four. The way
@@ -1144,7 +1144,7 @@ static gboolean
 create_image_data(NHFFile *nhfile, hid_t dataset_id)
 {
     GwyFile *file = nhfile->file;
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     GwyField *field = NULL;
     gchar *signal_name = NULL;
     gint id, xres = nhfile->xres, yres = nhfile->yres;
@@ -1180,8 +1180,8 @@ create_image_data(NHFFile *nhfile, hid_t dataset_id)
         gwy_image_title_fall_back(file, id);
     add_segment_name_to_title(nhfile, gwy_file_key_image_title(id));
 
-    if (gwy_container_get_n_items(meta)) {
-        meta = gwy_container_copy(meta);
+    if (gwy_dict_get_n_items(meta)) {
+        meta = gwy_dict_copy(meta);
         clean_up_json_meta(meta);
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     }
@@ -1201,7 +1201,7 @@ static gboolean
 create_volume_data(NHFFile *nhfile, hid_t dataset_id)
 {
     GwyFile *file = nhfile->file;
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     GwyBrick *brick = NULL, *tmpbrick = NULL;
     gchar *signal_name = NULL;
     gint id, xres = nhfile->xres, yres = nhfile->yres, zres = gwy_line_get_res(nhfile->freewave);
@@ -1243,8 +1243,8 @@ create_volume_data(NHFFile *nhfile, hid_t dataset_id)
         gwy_file_set_title(file, GWY_FILE_VOLUME, id, signal_name, FALSE);
     add_segment_name_to_title(nhfile, gwy_file_key_volume_title(id));
 
-    if (gwy_container_get_n_items(meta)) {
-        meta = gwy_container_copy(meta);
+    if (gwy_dict_get_n_items(meta)) {
+        meta = gwy_dict_copy(meta);
         clean_up_json_meta(meta);
         gwy_file_pass_meta(file, GWY_FILE_VOLUME, id, meta);
     }
@@ -1300,7 +1300,7 @@ static void
 create_curve_map(NHFFile *nhfile)
 {
     GwyFile *file = nhfile->file;
-    GwyContainer *meta = nhfile->ghfile->meta;
+    GwyDict *meta = nhfile->ghfile->meta;
     GwyLawn *lawn;
     gdouble *buf;
     guint m, start, len, ncurves, maxlen = nhfile->maxlen;
@@ -1343,8 +1343,8 @@ create_curve_map(NHFFile *nhfile)
         H5free_memory(name);
     }
 
-    if (gwy_container_get_n_items(meta)) {
-        meta = gwy_container_copy(meta);
+    if (gwy_dict_get_n_items(meta)) {
+        meta = gwy_dict_copy(meta);
         clean_up_json_meta(meta);
         gwy_file_pass_meta(file, GWY_FILE_CMAP, id, meta);
     }
@@ -1511,9 +1511,9 @@ add_segment_name_to_title(NHFFile *nhfile, GQuark quark)
     if (!nhfile->segment_name)
         return;
 
-    s = gwy_container_get_string(GWY_CONTAINER(nhfile->file), quark);
+    s = gwy_dict_get_string(GWY_DICT(nhfile->file), quark);
     t = g_strconcat(s, " [", nhfile->segment_name, "]", NULL);
-    gwy_container_set_string(GWY_CONTAINER(nhfile->file), quark, t);
+    gwy_dict_set_string(GWY_DICT(nhfile->file), quark, t);
 }
 
 static gboolean
@@ -1557,7 +1557,7 @@ format_atomic_json_meta(JsonNode *node, GString *str)
 }
 
 static void
-expand_json_meta(GwyContainer *meta, JsonParser *parser, const gchar *str, GString *path, GString *buf)
+expand_json_meta(GwyDict *meta, JsonParser *parser, const gchar *str, GString *path, GString *buf)
 {
     if (!json_parser_load_from_data(parser, str, -1, NULL))
         return;
@@ -1579,7 +1579,7 @@ expand_json_meta(GwyContainer *meta, JsonParser *parser, const gchar *str, GStri
         g_string_append(path, name);
         g_string_truncate(buf, 0);
         if (format_atomic_json_meta(node, buf)) {
-            gwy_container_set_const_string_by_name(meta, path->str, buf->str);
+            gwy_dict_set_const_string_by_name(meta, path->str, buf->str);
         }
         else if (JSON_NODE_HOLDS_ARRAY(node)) {
             JsonArray *array = json_node_get_array(node);
@@ -1591,7 +1591,7 @@ expand_json_meta(GwyContainer *meta, JsonParser *parser, const gchar *str, GStri
             }
             if (buf->len >= 2)
                 g_string_truncate(buf, buf->len-2);
-            gwy_container_set_const_string_by_name(meta, path->str, buf->str);
+            gwy_dict_set_const_string_by_name(meta, path->str, buf->str);
         }
         else if (JSON_NODE_HOLDS_OBJECT(node) && gwy_strequal(name, "property")) {
             /* "property" is a nested dictionary with further nested members name:{value:x} or name{value:x,unit:y}.
@@ -1617,7 +1617,7 @@ expand_json_meta(GwyContainer *meta, JsonParser *parser, const gchar *str, GStri
                         g_string_append(buf, " ");
                         format_atomic_json_meta(unit, buf);
                     }
-                    gwy_container_set_const_string_by_name(meta, path->str, buf->str);
+                    gwy_dict_set_const_string_by_name(meta, path->str, buf->str);
                 }
             }
         }
@@ -1630,17 +1630,17 @@ expand_json_meta(GwyContainer *meta, JsonParser *parser, const gchar *str, GStri
 #endif
 
 static void
-clean_up_json_meta(GwyContainer *meta)
+clean_up_json_meta(GwyDict *meta)
 {
-    GQuark *keys = gwy_container_keys(meta);
-    guint i, n = gwy_container_get_n_items(meta);
+    GQuark *keys = gwy_dict_keys(meta);
+    guint i, n = gwy_dict_get_n_items(meta);
 #ifdef HAVE_JSON_GLIB
     GString *path = NULL, *buf = NULL;
     JsonParser *parser = NULL;
 #endif
 
     for (i = 0; i < n; i++) {
-        const gchar *value = gwy_container_get_string(meta, keys[i]);
+        const gchar *value = gwy_dict_get_string(meta, keys[i]);
         guint len, x = 0, jschars = 0;
         gchar c;
 
@@ -1672,7 +1672,7 @@ clean_up_json_meta(GwyContainer *meta)
          * We could to it in the opposite order if we duplicated the string… */
         expand_json_meta(meta, parser, value, path, buf);
 #endif
-        gwy_container_remove(meta, keys[i]);
+        gwy_dict_remove(meta, keys[i]);
     }
 
     g_free(keys);
