@@ -1,5 +1,5 @@
 /*
- *  $Id: shilpsfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: shilpsfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2020-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -160,7 +160,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyHDF5File ghfile;
     hid_t file_id;
     G_GNUC_UNUSED herr_t status;
@@ -216,7 +216,7 @@ load_file(const gchar *filename,
     set_spectra_coordinates(file, nspec, nxyz);
 
     /* All data types are optional so we might not have failed but also have not read anything. */
-    if (file && !gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (file && !gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
     }
@@ -257,13 +257,13 @@ gather_to_remove(GQuark quark, G_GNUC_UNUSED GValue *gvalue, gpointer user_data)
 static void
 filter_meta(GwyHDF5File *ghfile)
 {
-    GwyContainer *meta = ghfile->meta;
+    GwyDict *meta = ghfile->meta;
     GArray *quarks = g_array_new(FALSE, FALSE, sizeof(GQuark));
     guint i;
 
-    gwy_container_foreach(meta, NULL, gather_to_remove, quarks);
+    gwy_dict_foreach(meta, NULL, gather_to_remove, quarks);
     for (i = 0; i < quarks->len; i++)
-        gwy_container_remove(meta, g_array_index(quarks, GQuark, i));
+        gwy_dict_remove(meta, g_array_index(quarks, GQuark, i));
     g_array_free(quarks, TRUE);
 }
 
@@ -331,7 +331,7 @@ read_images(GwyFile *file,
         else
             gwy_image_title_fall_back(file, i);
 
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(ghfile->meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(ghfile->meta));
     }
     g_free(xyunitstr);
 
@@ -578,7 +578,7 @@ regularise_curve_sampling(const gdouble *xdata, const gdouble *ydata, gint n, gi
             w[i] = 1.0;
     }
 
-    gwy_line_correct_laplace(line, weight);
+    gwy_line_laplace_solve(line, weight);
 
     g_object_unref(weight);
 }
@@ -978,7 +978,7 @@ read_volumes(GwyFile *file,
             H5free_memory(channel);
         }
 
-        gwy_file_pass_meta(file, GWY_FILE_VOLUME, i, gwy_container_copy(ghfile->meta));
+        gwy_file_pass_meta(file, GWY_FILE_VOLUME, i, gwy_dict_copy(ghfile->meta));
     }
     g_free(xyunitstr);
 
@@ -1038,7 +1038,7 @@ read_xyzs(GwyFile *file,
     GString *str = ghfile->buf;
     GwySurface *surface;
     gchar *channel, *xyunitstr;
-    GwyContainer *meta;
+    GwyDict *meta;
     guint i, id;
 
     gwy_debug("nxyzs %u", xyzs->len);
@@ -1068,7 +1068,7 @@ read_xyzs(GwyFile *file,
         else
             gwy_xyz_title_fall_back(file, i);
 
-        meta = gwy_container_copy(ghfile->meta);
+        meta = gwy_dict_copy(ghfile->meta);
         gwy_file_pass_meta(file, GWY_FILE_XYZ, i, meta);
     }
     g_free(xyunitstr);
