@@ -1,5 +1,5 @@
 /*
- *  $Id: hdrimage.cc 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: hdrimage.cc 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -344,7 +344,7 @@ exr_export(GwyFile *file,
 
     gwy_clear(&args, 1);
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &file,
+    gwy_data_browser_get_current(GWY_APP_FILE, &file,
                                  GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
@@ -511,7 +511,7 @@ exr_write_image(GwyField *field,
     header.insert(GWY_IMGKEY_YREAL, Imf::DoubleAttribute(v));
     if (bit_depth == GWY_BIT_DEPTH_INT32) {
         gdouble zmin, zmax;
-        gwy_field_get_min_max(field, &zmin, &zmax);
+        gwy_field_min_max(field, &zmin, &zmax);
         header.insert(GWY_IMGKEY_ZMIN, Imf::DoubleAttribute(zmin));
         header.insert(GWY_IMGKEY_ZMAX, Imf::DoubleAttribute(zmax));
     }
@@ -815,7 +815,7 @@ exr_load_image(const gchar *filename,
         gdouble *d = gwy_field_get_data(dfield);
         *objects = g_slist_prepend(*objects, (gpointer)dfield);
         gwy_convert_raw_data(l->data, xres*yres, 1, rawdatatype, GWY_BYTE_ORDER_NATIVE, d, q, z0);
-        GwyField *mask = gwy_app_channel_mask_of_nans(dfield, TRUE);
+        GwyNield *mask = gwy_mask_nans_in_field(dfield, TRUE);
 
         if (unitxy)
             gwy_unit_assign(gwy_field_get_unit_xy(dfield), unitxy);
@@ -971,7 +971,7 @@ find_range(GwyField *field,
     *pmin = min;
     *pcentre = exp(logcentre/nc);
 
-    gwy_field_get_min_max(field, fmin, fmax);
+    gwy_field_min_max(field, fmin, fmax);
 }
 #endif
 
@@ -1310,7 +1310,7 @@ png16_load(const gchar *filename,
 
         if (basetitle && gwy_stramong(basetitle, "Red", "Green", "Blue", NULL)) {
             gchar *palette = g_strconcat("RGB-", basetitle, NULL);
-            gwy_container_set_string(file, gwy_app_get_data_palette_key_for_id(id), (const guchar*)palette);
+            gwy_dict_set_string(file, gwy_app_get_data_palette_key_for_id(id), (const guchar*)palette);
         }
 
         gwy_log_add_import(file, GWY_FILE_IMAGE, id, "png16", filename);
@@ -1679,7 +1679,6 @@ load_tiff_channels(GwyFile *file,
 
     for (guint cid = 0; cid < nchannels; cid++) {
         GwyField *dfield = gwy_field_new(xres, yres, xreal, yreal, FALSE);
-        GwyField *mask = NULL;
         gdouble *d = gwy_field_get_data(dfield);
         const gchar *title;
 
@@ -1692,8 +1691,9 @@ load_tiff_channels(GwyFile *file,
             }
         }
 
+        GwyNield *mask = NULL;
         if (reader->sample_format == GWY_TIFF_SAMPLE_FORMAT_FLOAT)
-            mask = gwy_app_channel_mask_of_nans(dfield, TRUE);
+            mask = gwy_mask_nans_in_field(dfield, TRUE);
 
         gwy_unit_assign(gwy_field_get_unit_xy(dfield), unitxy);
         gwy_unit_assign(gwy_field_get_unit_z(dfield), unitz);
