@@ -1,5 +1,5 @@
 /*
- *  $Id: hitachi-sem.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: hitachi-sem.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -129,7 +129,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GdkPixbuf *pixbuf = NULL;
     GwyField *dfield = NULL;
     gchar *value, *imagename = NULL, *header = NULL;
@@ -205,7 +205,7 @@ load_file(const gchar *filename,
     else
         gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "SEM", FALSE);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, store_meta, meta);
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
 
@@ -300,14 +300,14 @@ hitachi_find_data_name(const gchar *header_name,
 static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
     if (g_utf8_validate(value, -1, NULL))
-        gwy_container_set_const_string_by_name(meta, key, value);
+        gwy_dict_set_const_string_by_name(meta, key, value);
     else {
         gchar *s = gwy_convert_to_utf8(value, -1, "CP1252");
         if (s)
-            gwy_container_set_string_by_name(meta, key, s);
+            gwy_dict_set_string_by_name(meta, key, s);
     }
 }
 
