@@ -1,5 +1,5 @@
 /*
- *  $Id: igorfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: igorfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -205,7 +205,7 @@ typedef struct {
     IgorDataShape asylum_shape;
     /* Processing data */
     const gchar **ignore_prefixes;
-    GwyContainer *channelmeta;
+    GwyDict *channelmeta;
 } IgorFile;
 
 typedef struct {
@@ -214,91 +214,91 @@ typedef struct {
     guint size;
 } PXPRecordHeader;
 
-static gboolean      module_register         (void);
-static gint          ibwfile_detect          (const GwyFileDetectInfo *fileinfo,
-                                              gboolean only_name);
-static GwyFile*      ibwfile_load            (const gchar *filename,
-                                              GwyRunModeFlags mode,
-                                              GError **error);
-static gboolean      ibwfile_export          (GwyFile *data,
-                                              const gchar *filename,
-                                              GwyRunModeFlags mode,
-                                              GError **error);
-static gboolean      igor_load_single        (const guchar *buffer,
-                                              gsize size,
-                                              const gchar *filename,
-                                              GwyFile *file,
-                                              gint idgraph,
-                                              gint idfield,
-                                              gint idbrick,
-                                              gint *ngraphs,
-                                              gint *nfields,
-                                              gint *nbricks,
-                                              GError **error);
-static void          igor_read_images        (IgorFile *igorfile,
-                                              const gchar *buffer,
-                                              const gchar *filename,
-                                              GwyFile *file,
-                                              gint idfrom,
-                                              gint *nfields);
-static void          igor_read_volumes       (IgorFile *igorfile,
-                                              const gchar *buffer,
-                                              const gchar *filename,
-                                              GwyFile *file,
-                                              gint idfrom,
-                                              gint *nbricks);
-static void          igor_read_curves        (IgorFile *igorfile,
-                                              const gchar *buffer,
-                                              const gchar *filename,
-                                              GwyFile *file,
-                                              gint idfrom,
-                                              gint *nfields);
-static guint         igor_read_headers       (IgorFile *igorfile,
-                                              const guchar *buffer,
-                                              gsize size,
-                                              gboolean check_only,
-                                              GError **error);
-static void          read_asylum_footer      (IgorFile *igorfile,
-                                              const guchar *buffer,
-                                              gsize size);
-static guint         igor_checksum           (gconstpointer buffer,
-                                              gsize size,
-                                              gboolean lsb);
-static guint         igor_data_type_size     (IgorDataType type);
-static GwyField*     igor_read_field         (const IgorFile *igorfile,
-                                              const guchar *buffer,
-                                              guint i,
-                                              const gchar *zunits,
-                                              gboolean is_imaginary);
-static GwyBrick*     igor_read_brick         (const IgorFile *igorfile,
-                                              const guchar *buffer,
-                                              guint i,
-                                              const gchar *wunits,
-                                              gboolean is_imaginary);
-static GwyLine*      igor_read_line          (const IgorFile *igorfile,
-                                              const guchar *buffer,
-                                              guint i,
-                                              const gchar *yunits,
-                                              gboolean is_imaginary);
-static GwyContainer* igor_get_metadata       (IgorFile *igorfile,
-                                              guint id);
-static GPtrArray*    read_channel_labels     (const gchar *p,
-                                              guint n,
-                                              guint l);
-static gchar*        canonicalize_title      (const gchar *title);
-static const gchar*  channel_title_to_units  (const gchar *title);
-static gint*         find_compatible_channels(GwyFile *file,
-                                              GwyField *dfield,
-                                              guint *n);
-static gint          pxpfile_detect          (const GwyFileDetectInfo *fileinfo,
-                                              gboolean only_name);
-static GwyFile*      pxpfile_load            (const gchar *filename,
-                                              GwyRunModeFlags mode,
-                                              GError **error);
-static gboolean      pxp_read_record_header  (PXPRecordHeader *header,
-                                              GwyByteOrder byteorder,
-                                              const guchar **p,
-                                              gsize size);
+static gboolean     module_register         (void);
+static gint         ibwfile_detect          (const GwyFileDetectInfo *fileinfo,
+                                             gboolean only_name);
+static GwyFile*     ibwfile_load            (const gchar *filename,
+                                             GwyRunModeFlags mode,
+                                             GError **error);
+static gboolean     ibwfile_export          (GwyFile *data,
+                                             const gchar *filename,
+                                             GwyRunModeFlags mode,
+                                             GError **error);
+static gboolean     igor_load_single        (const guchar *buffer,
+                                             gsize size,
+                                             const gchar *filename,
+                                             GwyFile *file,
+                                             gint idgraph,
+                                             gint idfield,
+                                             gint idbrick,
+                                             gint *ngraphs,
+                                             gint *nfields,
+                                             gint *nbricks,
+                                             GError **error);
+static void         igor_read_images        (IgorFile *igorfile,
+                                             const gchar *buffer,
+                                             const gchar *filename,
+                                             GwyFile *file,
+                                             gint idfrom,
+                                             gint *nfields);
+static void         igor_read_volumes       (IgorFile *igorfile,
+                                             const gchar *buffer,
+                                             const gchar *filename,
+                                             GwyFile *file,
+                                             gint idfrom,
+                                             gint *nbricks);
+static void         igor_read_curves        (IgorFile *igorfile,
+                                             const gchar *buffer,
+                                             const gchar *filename,
+                                             GwyFile *file,
+                                             gint idfrom,
+                                             gint *nfields);
+static guint        igor_read_headers       (IgorFile *igorfile,
+                                             const guchar *buffer,
+                                             gsize size,
+                                             gboolean check_only,
+                                             GError **error);
+static void         read_asylum_footer      (IgorFile *igorfile,
+                                             const guchar *buffer,
+                                             gsize size);
+static guint        igor_checksum           (gconstpointer buffer,
+                                             gsize size,
+                                             gboolean lsb);
+static guint        igor_data_type_size     (IgorDataType type);
+static GwyField*    igor_read_field         (const IgorFile *igorfile,
+                                             const guchar *buffer,
+                                             guint i,
+                                             const gchar *zunits,
+                                             gboolean is_imaginary);
+static GwyBrick*    igor_read_brick         (const IgorFile *igorfile,
+                                             const guchar *buffer,
+                                             guint i,
+                                             const gchar *wunits,
+                                             gboolean is_imaginary);
+static GwyLine*     igor_read_line          (const IgorFile *igorfile,
+                                             const guchar *buffer,
+                                             guint i,
+                                             const gchar *yunits,
+                                             gboolean is_imaginary);
+static GwyDict*     get_metadata            (IgorFile *igorfile,
+                                             guint id);
+static GPtrArray*   read_channel_labels     (const gchar *p,
+                                             guint n,
+                                             guint l);
+static gchar*       canonicalize_title      (const gchar *title);
+static const gchar* channel_title_to_units  (const gchar *title);
+static gint*        find_compatible_channels(GwyFile *file,
+                                             GwyField *field,
+                                             guint *n);
+static gint         pxpfile_detect          (const GwyFileDetectInfo *fileinfo,
+                                             gboolean only_name);
+static GwyFile*     pxpfile_load            (const gchar *filename,
+                                             GwyRunModeFlags mode,
+                                             GError **error);
+static gboolean     pxp_read_record_header  (PXPRecordHeader *header,
+                                             GwyByteOrder byteorder,
+                                             const guchar **p,
+                                             gsize size);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -617,8 +617,9 @@ igor_read_images(IgorFile *igorfile, const gchar *buffer, const gchar *filename,
                  GwyFile *file, gint idfrom, gint *nfields)
 {
     IgorWaveHeader5 *wave5 = &igorfile->wave5;
-    GwyField *dfield = NULL, *maskfield = NULL;
-    GwyContainer *meta = NULL;
+    GwyField *field = NULL;
+    GwyNield *mask = NULL;
+    GwyDict *meta = NULL;
     gint i, chid;
 
     for (i = 0, chid = idfrom; i < igorfile->nchannels; i++, chid++) {
@@ -628,13 +629,13 @@ igor_read_images(IgorFile *igorfile, const gchar *buffer, const gchar *filename,
         if (igorfile->channel_info) {
             AsylumChannelInfo *chinfo = igorfile->channel_info + i;
             zunits = chinfo->units;
-            meta = igor_get_metadata(igorfile, i + 1);
+            meta = get_metadata(igorfile, i + 1);
         }
-        dfield = igor_read_field(igorfile, buffer, i, zunits, FALSE);
-        maskfield = gwy_app_channel_mask_of_nans(dfield, TRUE);
-        gwy_file_pass_image(file, chid, dfield);
-        if (maskfield)
-            gwy_file_set_image_mask(file, chid, maskfield);
+        field = igor_read_field(igorfile, buffer, i, zunits, FALSE);
+        mask = gwy_mask_nans_in_field(field, TRUE);
+        gwy_file_pass_image(file, chid, field);
+        if (mask)
+            gwy_file_set_image_mask(file, chid, mask);
         if (meta)
             gwy_file_pass_meta(file, GWY_FILE_IMAGE, chid, meta);
 
@@ -644,19 +645,19 @@ igor_read_images(IgorFile *igorfile, const gchar *buffer, const gchar *filename,
 
         if (wave5->type & IGOR_COMPLEX) {
             chid++;
-            dfield = igor_read_field(igorfile, buffer, i, zunits, TRUE);
-            gwy_file_pass_image(file, chid, dfield);
+            field = igor_read_field(igorfile, buffer, i, zunits, TRUE);
+            gwy_file_pass_image(file, chid, field);
             if (meta)
-                gwy_file_pass_meta(file, GWY_FILE_IMAGE, chid, gwy_container_copy(meta));
-            if (maskfield)
-                gwy_file_pass_image_mask(file, chid, gwy_field_copy(maskfield));
+                gwy_file_pass_meta(file, GWY_FILE_IMAGE, chid, gwy_dict_copy(meta));
+            if (mask)
+                gwy_file_pass_image_mask(file, chid, gwy_nield_copy(mask));
 
             if (title)
                 gwy_file_set_title(file, GWY_FILE_IMAGE, chid, title, FALSE);
             gwy_image_title_fall_back(file, chid);
             gwy_log_add_import(file, GWY_FILE_IMAGE, chid, NULL, filename);
         }
-        g_clear_object(&maskfield);
+        g_clear_object(&mask);
     }
     *nfields = chid - idfrom;
 }
@@ -667,7 +668,7 @@ igor_read_volumes(IgorFile *igorfile, const gchar *buffer, const gchar *filename
 {
     IgorWaveHeader5 *wave5 = &igorfile->wave5;
     GwyBrick *brick;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     gint i, chid;
 
     for (i = 0, chid = idfrom; i < igorfile->nchannels; i++, chid++) {
@@ -677,7 +678,7 @@ igor_read_volumes(IgorFile *igorfile, const gchar *buffer, const gchar *filename
         if (igorfile->channel_info) {
             AsylumChannelInfo *chinfo = igorfile->channel_info + i;
             wunits = chinfo->units;
-            meta = igor_get_metadata(igorfile, i + 1);
+            meta = get_metadata(igorfile, i + 1);
         }
         brick = igor_read_brick(igorfile, buffer, i, wunits, FALSE);
         gwy_file_pass_volume(file, chid, brick);
@@ -693,7 +694,7 @@ igor_read_volumes(IgorFile *igorfile, const gchar *buffer, const gchar *filename
             brick = igor_read_brick(igorfile, buffer, i, wunits, TRUE);
             gwy_file_pass_volume(file, chid, brick);
             if (meta)
-                gwy_file_pass_meta(file, GWY_FILE_VOLUME, chid, gwy_container_copy(meta));
+                gwy_file_pass_meta(file, GWY_FILE_VOLUME, chid, gwy_dict_copy(meta));
 
             if (title)
                 gwy_file_set_title(file, GWY_FILE_VOLUME, chid, title, FALSE);
@@ -1037,7 +1038,7 @@ igor_read_field(const IgorFile *igorfile,
     GwyRawDataType rawtype;
     GwyByteOrder byteorder;
     guint n, xres, yres;
-    GwyField *dfield;
+    GwyField *field;
     gdouble *data;
     const guchar *p;
     gint power10, stride;
@@ -1049,10 +1050,10 @@ igor_read_field(const IgorFile *igorfile,
     n = xres*yres;
     p = buffer + igorfile->headers_size + n*igorfile->type_size*i;
 
-    dfield = gwy_field_new(xres, yres, wave5->sfA[0]*xres, wave5->sfA[1]*yres, FALSE);
-    data = gwy_field_get_data(dfield);
+    field = gwy_field_new(xres, yres, wave5->sfA[0]*xres, wave5->sfA[1]*yres, FALSE);
+    data = gwy_field_get_data(field);
 
-    g_return_val_if_fail(!is_imaginary || (wave5->type & IGOR_COMPLEX), dfield);
+    g_return_val_if_fail(!is_imaginary || (wave5->type & IGOR_COMPLEX), field);
     if (is_imaginary) {
         stride = 2;
         p += igorfile->type_size/2;
@@ -1061,21 +1062,21 @@ igor_read_field(const IgorFile *igorfile,
         stride = 1;
 
     rawtype = igor_data_type_to_raw_type(wave5->type);
-    g_return_val_if_fail(rawtype != (GwyRawDataType)-1, dfield);
+    g_return_val_if_fail(rawtype != (GwyRawDataType)-1, field);
     byteorder = (igorfile->lsb ? GWY_BYTE_ORDER_LITTLE_ENDIAN : GWY_BYTE_ORDER_BIG_ENDIAN);
 
     /* TODO: Support extended units */
-    power10 = gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), wave5->dim_units[0]);
-    gwy_field_set_xreal(dfield, gwy_exp10(power10)*wave5->sfA[0]*xres);
-    gwy_field_set_yreal(dfield, gwy_exp10(power10)*wave5->sfA[1]*yres);
+    power10 = gwy_unit_set_from_string(gwy_field_get_unit_xy(field), wave5->dim_units[0]);
+    gwy_field_set_xreal(field, gwy_exp10(power10)*wave5->sfA[0]*xres);
+    gwy_field_set_yreal(field, gwy_exp10(power10)*wave5->sfA[1]*yres);
 
-    power10 = gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), zunits ? zunits : wave5->data_units);
+    power10 = gwy_unit_set_from_string(gwy_field_get_unit_z(field), zunits ? zunits : wave5->data_units);
     q = gwy_exp10(power10);
 
     gwy_convert_raw_data(p, n, stride, rawtype, byteorder, data, q, 0.0);
-    gwy_field_flip(dfield, FALSE, TRUE);
+    gwy_field_flip(field, FALSE, TRUE);
 
-    return dfield;
+    return field;
 }
 
 static GwyBrick*
@@ -1293,12 +1294,12 @@ gather_channel_meta(gpointer hkey,
         value = gwy_convert_to_utf8(value, -1, "ISO-8859-1");
 
     if (value)
-        gwy_container_set_string_by_name(igorfile->channelmeta, key, value);
+        gwy_dict_set_string_by_name(igorfile->channelmeta, key, value);
 }
 
-static GwyContainer*
-igor_get_metadata(IgorFile *igorfile,
-                  G_GNUC_UNUSED guint id)
+static GwyDict*
+get_metadata(IgorFile *igorfile,
+             G_GNUC_UNUSED guint id)
 {
     static const gchar *ignore_prefixes[] = {
         "Channel", "ColorMap", "Display", "Flatten", "PlaneFit", "Planefit", NULL
@@ -1310,7 +1311,7 @@ igor_get_metadata(IgorFile *igorfile,
     if (!igorfile->ignore_prefixes)
         igorfile->ignore_prefixes = ignore_prefixes;
 
-    igorfile->channelmeta = gwy_container_new_in_construction();
+    igorfile->channelmeta = gwy_dict_new_in_construction();
     g_hash_table_foreach(igorfile->meta, gather_channel_meta, igorfile);
 
     return igorfile->channelmeta;
@@ -1389,7 +1390,7 @@ ibwfile_export(GwyFile *data,
                GError **error)
 {
     GByteArray *header = NULL;
-    GwyField *dfield;
+    GwyField *field;
     GwyUnit *xyunit, *zunit;
     const gdouble *d, *drow;
     gfloat *dfl = NULL, *frow;
@@ -1403,13 +1404,13 @@ ibwfile_export(GwyFile *data,
     gchar *title, *title_latin1, *unitstr;
     gchar bname[MAX_WAVE_NAME5+1];
 
-    gwy_data_browser_get_current(GWY_APP_FIELD, &dfield, 0);
-    if (!dfield) {
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field, 0);
+    if (!field) {
         err_NO_CHANNEL_EXPORT(error);
         return FALSE;
     }
 
-    ids = find_compatible_channels(data, dfield, &nchannels);
+    ids = find_compatible_channels(data, field, &nchannels);
     g_return_val_if_fail(nchannels > 0, FALSE);
 
     if (!(fh = gwy_fopen(filename, "wb"))) {
@@ -1418,12 +1419,12 @@ ibwfile_export(GwyFile *data,
         return FALSE;
     }
 
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    xreal = gwy_field_get_xreal(dfield);
-    yreal = gwy_field_get_yreal(dfield);
-    xyunit = gwy_field_get_unit_xy(dfield);
-    zunit = gwy_field_get_unit_z(dfield);
+    xres = gwy_field_get_xres(field);
+    yres = gwy_field_get_yres(field);
+    xreal = gwy_field_get_xreal(field);
+    yreal = gwy_field_get_yreal(field);
+    xyunit = gwy_field_get_unit_xy(field);
+    zunit = gwy_field_get_unit_z(field);
 
     n = xres*yres;
     npts = nchannels*n;
@@ -1516,8 +1517,8 @@ ibwfile_export(GwyFile *data,
 
     dfl = g_new(gfloat, n);
     for (k = 0; ids[k] >= 0; k++) {
-        dfield = gwy_file_get_image(data, ids[k]);
-        d = gwy_field_get_data_const(dfield);
+        field = gwy_file_get_image(data, ids[k]);
+        d = gwy_field_get_data_const(field);
         for (i = 0; i < yres; i++) {
             frow = dfl + i*xres;
             drow = d + (yres-1 - i)*xres;
@@ -1576,7 +1577,7 @@ fail:
 
 static gint*
 find_compatible_channels(GwyFile *file,
-                         GwyField *dfield,
+                         GwyField *field,
                          guint *pn)
 {
     gint *ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
@@ -1584,7 +1585,7 @@ find_compatible_channels(GwyFile *file,
 
     for (guint i = 0; ids[i] >= 0; i++) {
         GwyField *otherfield = gwy_file_get_image(file, ids[i]);
-        if (gwy_field_is_incompatible(dfield, otherfield, GWY_DATA_MISMATCH_ALL) != 0)
+        if (gwy_field_is_incompatible(field, otherfield, GWY_DATA_MISMATCH_ALL) != 0)
             continue;
 
         ids[n++] = ids[i];
