@@ -1,5 +1,5 @@
 /*
- *  $Id: intelliwave.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: intelliwave.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -220,7 +220,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports IntelliWave interferometric ESD data."),
     "Yeti <yeti@gwyddion.net>",
-    "0.2",
+    "0.3",
     "David Nečas (Yeti)",
     "2016",
 };
@@ -310,7 +310,7 @@ load_file(const gchar *filename,
     if ((offset = check_data_block(&intwfile, i, size, N_INTERFEROGRAMS*sizeof(gint16))))
         read_field_fringes(file, &id, &intwfile, buffer + offset);
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
     }
@@ -458,28 +458,24 @@ read_field_opd(GwyFile *file, gint *id,
     guint xres = intwfile->info.nx;
     guint yres = intwfile->info.ny;
     guint n = intwfile->info.nz;
-    guint k;
-    GwyField *dfield, *mask;
-    gdouble *d, *m;
     gdouble q = 1e-6 * intwfile->info.wavelength, invalid = intwfile->info.invalid_value;
 
-    dfield = gwy_field_new(xres, yres, xres, yres, FALSE);
-    d = gwy_field_get_data(dfield);
+    GwyField *field = gwy_field_new(xres, yres, xres, yres, FALSE);
+    gdouble *d = gwy_field_get_data(field);
     gwy_convert_raw_data(p, n, 1, GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN, d, 1.0, 0.0);
 
-    mask = gwy_field_new_alike(dfield, TRUE);
-    m = gwy_field_get_data(mask);
-    for (k = 0; k < n; k++) {
-        if (d[k] != invalid) {
-            m[k] = 1.0;
+    GwyNield *mask = gwy_field_new_nield_alike(field);
+    gint *m = gwy_nield_get_data(mask);
+    for (guint k = 0; k < n; k++) {
+        if (d[k] != invalid)
             d[k] *= q;
-        }
+        else
+            m[k] = 1;
     }
-    if (!gwy_app_channel_remove_bad_data(dfield, mask))
-        g_clear_object(&mask);
+    mask = gwy_remove_bad_image_data(field, mask);
 
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), "m");
-    gwy_file_pass_image(file, *id, dfield);
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
+    gwy_file_pass_image(file, *id, field);
     gwy_file_set_title(file, GWY_FILE_IMAGE, *id, "OPD", FALSE);
     if (mask)
         gwy_file_pass_image_mask(file, *id, mask);
@@ -497,27 +493,23 @@ read_field_fringes(GwyFile *file,
     guint xres = intwfile->info.nx;
     guint yres = intwfile->info.ny;
     guint n = intwfile->info.nz;
-    guint i, k;
-    GwyField *dfield, *mask;
-    gdouble *d, *m;
     gdouble invalid = intwfile->info.invalid_value;
 
-    for (i = 0; i < N_INTERFEROGRAMS; i++) {
-        dfield = gwy_field_new(xres, yres, xres, yres, FALSE);
-        d = gwy_field_get_data(dfield);
+    for (guint i = 0; i < N_INTERFEROGRAMS; i++) {
+        GwyField *field = gwy_field_new(xres, yres, xres, yres, FALSE);
+        gdouble *d = gwy_field_get_data(field);
         gwy_convert_raw_data(p + i*n*sizeof(gint16), n, 1, GWY_RAW_DATA_SINT16, GWY_BYTE_ORDER_LITTLE_ENDIAN,
                              d, 1.0, 0.0);
 
-        mask = gwy_field_new_alike(dfield, TRUE);
-        m = gwy_field_get_data(mask);
-        for (k = 0; k < n; k++) {
-            if (d[k] != invalid)
-                m[k] = 1.0;
+        GwyNield *mask = gwy_field_new_nield_alike(field);
+        gint *m = gwy_nield_get_data(mask);
+        for (guint k = 0; k < n; k++) {
+            if (d[k] == invalid)
+                m[k] = 1;
         }
-        if (!gwy_app_channel_remove_bad_data(dfield, mask))
-            g_clear_object(&mask);
+        mask = gwy_remove_bad_image_data(field, mask);
 
-        gwy_file_pass_image(file, *id, dfield);
+        gwy_file_pass_image(file, *id, field);
         gwy_file_pass_title(file, GWY_FILE_IMAGE, *id, g_strdup_printf("Interferogram %u", i+1));
         if (mask)
             gwy_file_pass_image_mask(file, *id, mask);
