@@ -1,5 +1,5 @@
 /*
- *  $Id: iso28600.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: iso28600.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -183,7 +183,7 @@ static GwyFile*            load_spectra_graphs(ISO28600FieldValue *header,
                                                guint nord,
                                                guint npts,
                                                GError **error);
-static GwyContainer*       get_meta           (ISO28600FieldValue *header,
+static GwyDict*            get_meta           (ISO28600FieldValue *header,
                                                gchar **strings,
                                                guint id);
 static gchar*              convert_unit       (GwyUnit *unit);
@@ -574,7 +574,7 @@ load_channels(ISO28600FieldValue *header,
 
     file = gwy_file_new_in_construction();
     for (id = 0; id < nchannels; id++) {
-        GwyContainer *meta;
+        GwyDict *meta;
         const gchar *title;
 
         gwy_file_set_image(file, id, fields[id]);
@@ -656,7 +656,7 @@ load_xyz_data(ISO28600FieldValue *header,
     file = gwy_file_new_in_construction();
     k = alldata->len/(nchannels + 2);
     for (id = 0; id < nchannels; id++) {
-        GwyContainer *meta;
+        GwyDict *meta;
         const gchar *title;
         GwySurface *surface;
         GwyUnit *unit;
@@ -807,7 +807,7 @@ fail:
     return file;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(ISO28600FieldValue *header,
          gchar **strings,
          guint id)
@@ -824,7 +824,7 @@ get_meta(ISO28600FieldValue *header,
         { "deg", 60 }, { "deg", 61 },
     };
     gint year, month, day, hour, minute, second, offset;
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     guint k;
 
     for (k = 0; k < G_N_ELEMENTS(fields); k++) {
@@ -837,15 +837,15 @@ get_meta(ISO28600FieldValue *header,
               || header_fields[i].type == ISO28600_ENUM) && strlen(strings[i]))
             || (header_fields[i].type == ISO28600_INTEGER && header[i].i)
             || (header_fields[i].type == ISO28600_REAL_NUM && header[i].d))
-            gwy_container_set_const_string_by_name(meta, header_fields[i].name, strings[i]);
+            gwy_dict_set_const_string_by_name(meta, header_fields[i].name, strings[i]);
     }
 
     for (k = 0; k < G_N_ELEMENTS(fields_with_units)/2; k++) {
         guint i = fields_with_units[2*k], j = fields_with_units[2*k + 1];
 
         if (header[i].d) {
-            gwy_container_set_string_by_name(meta, header_fields[i].name,
-                                             g_strconcat(strings[i], " ", strings[j], NULL));
+            gwy_dict_set_string_by_name(meta, header_fields[i].name,
+                                        g_strconcat(strings[i], " ", strings[j], NULL));
         }
     }
 
@@ -854,7 +854,7 @@ get_meta(ISO28600FieldValue *header,
         guint i = fields_without_units[k].value;
 
         if (header[i].d)
-            gwy_container_set_string_by_name(meta, header_fields[i].name, g_strconcat(strings[i], " ", units, NULL));
+            gwy_dict_set_string_by_name(meta, header_fields[i].name, g_strconcat(strings[i], " ", units, NULL));
     }
 
     year = header[8].i;
@@ -867,19 +867,21 @@ get_meta(ISO28600FieldValue *header,
     if (year >= 0 && month >= 0 && day >= 0 && hour >= 0 && minute >= 0 && second >= 0) {
         gchar *value;
 
-        if (offset)
+        if (offset) {
             value = g_strdup_printf("%04u-%02u-%02u %02u:%02u:%02u (+%u)",
                                     year, month, day, hour, minute, second, offset);
-        else
+        }
+        else {
             value = g_strdup_printf("%04u-%02u-%02u %02u:%02u:%02u",
-                                                 year, month, day, hour, minute, second);
-        gwy_container_set_string_by_name(meta, "Date", value);
+                                    year, month, day, hour, minute, second);
+        }
+        gwy_dict_set_string_by_name(meta, "Date", value);
     }
 
     if (*(strings[96 + 3*id]))
-        gwy_container_set_const_string_by_name(meta, "Comment", strings[96 + 3*id]);
+        gwy_dict_set_const_string_by_name(meta, "Comment", strings[96 + 3*id]);
 
-    if (!gwy_container_get_n_items(meta)) {
+    if (!gwy_dict_get_n_items(meta)) {
         g_object_unref(meta);
         meta = NULL;
     }
