@@ -1,5 +1,5 @@
 /*
- *  $Id: jeol.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: jeol.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -341,7 +341,7 @@ static void          read_image_header(const guchar *p,
                                        JEOLImageHeader *header);
 static GwyField*     read_field       (const guchar *buffer,
                                        const JEOLImageHeader *header);
-static GwyContainer* get_metadata     (const JEOLImageHeader *header);
+static GwyDict* get_metadata     (const JEOLImageHeader *header);
 
 static const GwyEnum data_sources[] = {
     { "Topography",        JEOL_DATA_SOURCE_Z,                 },
@@ -728,7 +728,7 @@ read_field(const guchar *buffer,
 }
 
 static void
-format_meta(GwyContainer *meta,
+format_meta(GwyDict *meta,
             const gchar *name,
             const gchar *format,
             ...)
@@ -739,11 +739,11 @@ format_meta(GwyContainer *meta,
     va_start(ap, format);
     s = g_strdup_vprintf(format, ap);
     va_end(ap);
-    gwy_container_set_string_by_name(meta, name, s);
+    gwy_dict_set_string_by_name(meta, name, s);
 }
 
 static void
-format_bit(GwyContainer *meta,
+format_bit(GwyDict *meta,
            const gchar *name,
            guint n,
            const GwyEnum *table,
@@ -753,21 +753,21 @@ format_bit(GwyContainer *meta,
 
     t = gwy_flags_to_string(value, table, n, NULL);
     if (t)
-        gwy_container_set_string_by_name(meta, name, t);
+        gwy_dict_set_string_by_name(meta, name, t);
     else
         g_free(t);
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(const JEOLImageHeader *header)
 {
     const JEOLSPMParam *spm_param;
     const JEOLDate *date;
     const JEOLTime *time_;
-    GwyContainer *meta;
+    GwyDict *meta;
     const gchar *s;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     spm_param = &header->spm_param;
     format_meta(meta, "WinSPM Version", "%.2f", header->winspm_version/100.0);
