@@ -1,5 +1,5 @@
 /*
- *  $Id: jeoltem.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: jeoltem.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -107,7 +107,7 @@ static GwyFile*            load_data      (JEOLTEMFile *jtfile,
                                            GError **error);
 static gboolean            load_header    (JEOLTEMFile *jtfile,
                                            GError **error);
-static GwyContainer*       get_meta       (JEOLTEMFile *jtfile);
+static GwyDict*       get_meta       (JEOLTEMFile *jtfile);
 static void                free_file      (JEOLTEMFile *jtfile);
 static void                read_other_tags(JEOLTEMTags *tags,
                                            GwyTIFF *tiff);
@@ -477,7 +477,7 @@ static GwyFile*
 load_data(JEOLTEMFile *jtfile, GError **error)
 {
     GwyFile *file;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield;
     GwyTIFFImageReader *reader;
     gdouble xstep, ystep, q;
@@ -516,10 +516,10 @@ load_data(JEOLTEMFile *jtfile, GError **error)
 
 /* NB: This consumes string values in blocks.  We do not have to free them later, but we cannot access them later
  * either. */
-static GwyContainer*
+static GwyDict*
 get_meta(JEOLTEMFile *jtfile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     GArray *blocks = jtfile->blocks;
     guint i, n = blocks->len;
 
@@ -530,20 +530,20 @@ get_meta(JEOLTEMFile *jtfile)
             continue;
 
         if (bci->data_type == CONTENT_INT16 || bci->data_type == CONTENT_INT32)
-            gwy_container_set_string_by_name(meta, bci->name, g_strdup_printf("%d", bci->value.i));
+            gwy_dict_set_string_by_name(meta, bci->name, g_strdup_printf("%d", bci->value.i));
         else if (bci->data_type == CONTENT_BOOLEAN)
-            gwy_container_set_const_string_by_name(meta, bci->name, bci->value.b ? "True" : "False");
+            gwy_dict_set_const_string_by_name(meta, bci->name, bci->value.b ? "True" : "False");
         else if (bci->data_type == CONTENT_DOUBLE)
-            gwy_container_set_string_by_name(meta, bci->name, g_strdup_printf("%g", bci->value.d));
+            gwy_dict_set_string_by_name(meta, bci->name, g_strdup_printf("%g", bci->value.d));
         else if (bci->data_type == CONTENT_UTF16) {
             if (*bci->value.s) {
-                gwy_container_set_string_by_name(meta, bci->name, bci->value.s);
+                gwy_dict_set_string_by_name(meta, bci->name, bci->value.s);
                 bci->value.s = NULL;
             }
         }
     }
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
