@@ -1,5 +1,5 @@
 /*
- *  $Id: jpkscan.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: jpkscan.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Loader for JPK Image Scans.
  *  Copyright (C) 2005  JPK Instruments AG.
  *  Written by Sven Neumann <neumann@jpk.com>.
@@ -152,22 +152,22 @@ static void     jpk_load_channel    (const GwyTIFF *tiff,
                                      GwyTIFFImageReader *reader,
                                      const gchar *filename,
                                      GwyFile *file,
-                                     GwyContainer *meta,
+                                     GwyDict *meta,
                                      guint idx,
                                      gdouble ulen,
                                      gdouble vlen);
 static void     jpk_load_meta       (GwyTIFF *tiff,
-                                     GwyContainer *file);
+                                     GwyDict *file);
 static void     jpk_load_meta_string(GwyTIFF *tiff,
-                                     GwyContainer *file,
+                                     GwyDict *file,
                                      guint tag,
                                      const gchar *name);
 static void     jpk_load_meta_double(GwyTIFF *tiff,
-                                     GwyContainer *file,
+                                     GwyDict *file,
                                      guint tag,
                                      const gchar *unit,
                                      const gchar *name);
-static void     meta_store_double   (GwyContainer *file,
+static void     meta_store_double   (GwyDict *file,
                                      const gchar *name,
                                      gdouble value,
                                      const gchar *unit);
@@ -337,7 +337,7 @@ jpkscan_load(const gchar *filename,
              GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyTIFF *tiff;
     GwyTIFFImageReader *reader = NULL;
     GError *err = NULL;
@@ -361,7 +361,7 @@ jpkscan_load(const gchar *filename,
     sanitise_real_size(&vlen, "y size");
 
     file = gwy_file_new_in_construction();
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     /* FIXME: I'm unable to meaningfully sort out the metadata to channels, so each one receives an identical copy of
      * the global metadata now. */
     jpk_load_meta(tiff, meta);
@@ -397,7 +397,7 @@ jpkscan_load(const gchar *filename,
     gwy_tiff_free(tiff);
     g_object_unref(meta);
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         err_NO_DATA(error);
         g_clear_object(&file);
     }
@@ -412,7 +412,7 @@ jpk_load_channel(const GwyTIFF *tiff,
                  GwyTIFFImageReader *reader,
                  const gchar *filename,
                  GwyFile *file,
-                 GwyContainer *meta,
+                 GwyDict *meta,
                  guint idx, gdouble ulen, gdouble vlen)
 {
     GwyField *dfield;
@@ -497,13 +497,13 @@ jpk_load_channel(const GwyTIFF *tiff,
     /* Add the GwyField to the file */
     gwy_file_pass_image(file, idx, dfield);
     gwy_file_pass_title(file, GWY_FILE_IMAGE, idx, channel);
-    if (gwy_container_get_n_items(meta))
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, idx, gwy_container_copy(meta));
+    if (gwy_dict_get_n_items(meta))
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, idx, gwy_dict_copy(meta));
     gwy_log_add_import(file, GWY_FILE_IMAGE, idx, NULL, filename);
 }
 
 static void
-jpk_load_meta(GwyTIFF *tiff, GwyContainer *file)
+jpk_load_meta(GwyTIFF *tiff, GwyDict *file)
 {
     gchar *string;
     gdouble frequency;
@@ -558,17 +558,17 @@ jpk_load_meta(GwyTIFF *tiff, GwyContainer *file)
 
 static void
 jpk_load_meta_string(GwyTIFF *tiff,
-                     GwyContainer *file, guint tag, const gchar *name)
+                     GwyDict *file, guint tag, const gchar *name)
 {
     gchar *string;
 
     if (gwy_tiff_get_string0(tiff, tag, &string))
-        gwy_container_set_string_by_name(file, name, string);
+        gwy_dict_set_string_by_name(file, name, string);
 }
 
 static void
 jpk_load_meta_double(GwyTIFF *tiff,
-                     GwyContainer *file,
+                     GwyDict *file,
                      guint tag, const gchar *unit, const gchar *name)
 {
     gdouble value;
@@ -578,14 +578,14 @@ jpk_load_meta_double(GwyTIFF *tiff,
 }
 
 static void
-meta_store_double(GwyContainer *file,
+meta_store_double(GwyDict *file,
                   const gchar *name, gdouble value, const gchar *unit)
 {
     GwyUnit *siunit = gwy_unit_new(unit);
     GwyValueFormat *format = gwy_unit_get_format(siunit, GWY_UNIT_FORMAT_MARKUP, value, NULL);
 
-    gwy_container_set_string_by_name(file, name,
-                                     g_strdup_printf("%5.3f %s", value/format->magnitude, format->units));
+    gwy_dict_set_string_by_name(file, name,
+                                g_strdup_printf("%5.3f %s", value/format->magnitude, format->units));
     g_object_unref(siunit);
     gwy_value_format_free(format);
 }
@@ -726,7 +726,7 @@ zipfile_load(const gchar *filename,
         }
     }
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
         goto fail;
@@ -782,7 +782,7 @@ read_embedded_image_file(GwyFile *file,
     embfile = jpkscan_load(filename, GWY_RUN_NONINTERACTIVE, NULL);
     close(fd);
     if (embfile) {
-        gwy_container_transfer(GWY_CONTAINER(embfile), GWY_CONTAINER(file), "/", "/", FALSE, FALSE);
+        gwy_dict_transfer(GWY_DICT(embfile), GWY_DICT(file), "/", "/", FALSE, FALSE);
         g_object_unref(embfile);
 
         ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
@@ -1130,12 +1130,12 @@ analyse_height_channel_range(JPKForceData *data, const guint *pointmap,
                              gint height_cid,
                              GwyField *min_field,
                              GwyField *range_field,
-                             GwyField *mask)
+                             GwyNield *mask)
 {
     guint ij, k, ndata = data->ndata, measured_ndata, np;
     gdouble *dm = gwy_field_get_data(min_field);
     gdouble *dr = gwy_field_get_data(range_field);
-    gdouble *m = gwy_field_get_data(mask);
+    gint *m = gwy_nield_get_data(mask);
 
     np = 0;
     /* ij indexes image points (so the fields are already unshuffled); we then analyse the curve at pointmap[ij] */
@@ -1155,11 +1155,11 @@ analyse_height_channel_range(JPKForceData *data, const guint *pointmap,
             }
             dm[ij] = zmin;
             dr[ij] = zmax - zmin;
-            m[ij] = 1.0;
+            m[ij] = 1;
             np++;
         }
         else {
-            dm[ij] = dr[ij] = m[ij] = 0.0;
+            dm[ij] = dr[ij] = m[ij] = 0;
         }
     }
     if (!np)
@@ -1328,7 +1328,7 @@ create_sps_data(GwyFile *file, JPKForceFile *jpkfile,
     guint nspec, ij, k, nchannels = jpkfile->nchannels;
     guint xres = jpkfile->xres, yres = jpkfile->yres;
     guint noutdata, ndata;
-    GwyField *min_field, *range_field, *mask;
+    GwyField *min_field, *range_field;
     gdouble *abscissa = NULL;
     gdouble progres_denom, zmin, zrange;
     GwyXY *curve = NULL;
@@ -1339,8 +1339,7 @@ create_sps_data(GwyFile *file, JPKForceFile *jpkfile,
     gwy_unit_set_from_string(gwy_field_get_unit_xy(min_field), "m");
     gwy_unit_set_from_string(gwy_field_get_unit_z(min_field), "m");
     range_field = gwy_field_new_alike(min_field, FALSE);
-    mask = gwy_field_new_alike(min_field, FALSE);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
+    GwyNield *mask = gwy_field_new_nield_alike(min_field);
 
     /* FIXME: Pessimistic.  But that is probably better than the opposite. */
     progres_denom = jpkfile->nsegs*(nchannels - 1.0)*xres*yres;
@@ -1360,8 +1359,8 @@ create_sps_data(GwyFile *file, JPKForceFile *jpkfile,
         }
 
         ndata = data->ndata;
-        hstep = gwy_field_area_get_median(range_field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres)/ndata;
-        gwy_field_area_get_min_max(range_field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, NULL, &zrange);
+        hstep = gwy_field_area_median(range_field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres)/ndata;
+        zrange = gwy_field_area_max(range_field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
         noutdata = GWY_ROUND(zrange/hstep);
         noutdata = MIN(noutdata, 2*ndata);
 
@@ -1658,7 +1657,6 @@ read_forcemap_data(GwyZipFile zipfile, JPKForceFile *jpkfile,
 
 finish_map_point:
         free_last_hash(jpkfile);
-
     } while (gwyzip_next_file(zipfile, NULL));
 
     for (ptid = 0; ptid < jpkfile->npoints; ptid++) {
