@@ -1,5 +1,5 @@
 /*
- *  $Id: jspmfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: jspmfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -565,7 +565,7 @@ add_field(const JSPMFile *jspmfile,
 }
 
 static void
-format_meta(GwyContainer *meta,
+format_meta(GwyDict *meta,
             const gchar *name,
             const gchar *format,
             ...)
@@ -576,13 +576,13 @@ format_meta(GwyContainer *meta,
     va_start(ap, format);
     s = g_strdup_vprintf(format, ap);
     va_end(ap);
-    gwy_container_set_string_by_name(meta, name, s);
+    gwy_dict_set_string_by_name(meta, name, s);
 }
 
 static void
 add_meta(JSPMFile *jspmfile, GwyFile *file)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     format_meta(meta, "WinSPM Version", "%.2f", jspmfile->winspm_version/100.0);
     if (jspmfile->comment)
