@@ -1,6 +1,6 @@
 /*
- *  $Id: keyence.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2015-2025 David Necas (Yeti).
+ *  $Id: keyence.c 29520 2026-02-23 09:32:20Z yeti-dn $
+ *  Copyright (C) 2015-2026 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
  *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
@@ -332,96 +332,95 @@ typedef struct {
 } Keyence4File;
 
 typedef struct {
-    GwyContainer *meta;
+    GwyDict *meta;
     GString *path;
     GString *curr_element;
     GArray *compdepths;
     gint depth;
 } Keyence6Meta;
 
-static gboolean      module_register     (void);
-static gint          keyence3_detect     (const GwyFileDetectInfo *fileinfo,
-                                          gboolean only_name);
-static gint          keyence4_detect     (const GwyFileDetectInfo *fileinfo,
-                                          gboolean only_name);
-static GwyFile*      keyence3_load       (const gchar *filename,
-                                          GwyRunModeFlags mode,
-                                          GError **error);
-static GwyFile*      keyence4_load       (const gchar *filename,
-                                          GwyRunModeFlags mode,
-                                          GError **error);
-static GwyFile*      keyence4_load_membuf(const guchar *buffer,
-                                          gsize size,
-                                          gint version,
-                                          const gchar *filename,
-                                          GError **error);
-static void          keyence4_free       (Keyence4File *kfile);
-static gboolean      read_header         (const guchar **p,
-                                          gsize *size,
-                                          Keyence4Header *header,
-                                          gint version,
-                                          GError **error);
-static gboolean      read_offset_table   (const guchar **p,
-                                          gsize *size,
-                                          Keyence4OffsetTable *offsettable,
-                                          GError **error);
-static gboolean      read_meas_conds     (const guchar **p,
-                                          gsize *size,
-                                          Keyence4MeasurementConditions *measconds,
-                                          gint version,
-                                          GError **error);
-static gboolean      read_assembly_info  (Keyence4File *kfile,
-                                          GError **error);
-static gboolean      read_data_images    (Keyence4File *kfile,
-                                          GError **error);
-static gboolean      read_color_images   (Keyence4File *kfile,
-                                          GError **error);
-static gboolean      read_line_meas      (Keyence4File *kfile,
-                                          GError **error);
-static gboolean      read_character_strs (Keyence4File *kfile,
-                                          GError **error);
-static GwyField*     create_field        (const Keyence4FalseColorImage *image,
-                                          const Keyence4MeasurementConditions *measconds,
-                                          gboolean is_height);
-static GwyField*     create_color_field  (const Keyence4TrueColorImage *image,
-                                          const Keyence4MeasurementConditions *measconds,
-                                          gint channelid);
-static GwyContainer* create_meta         (const Keyence4File *kfile);
-static void          add_field           (GwyFile *file,
-                                          gint *id,
-                                          GwyField *dfield,
-                                          GwyContainer *meta,
-                                          const gchar *title,
-                                          const gchar *filename,
-                                          gint i,
-                                          const gchar *gradient);
-
+static gboolean  module_register           (void);
+static gint      keyence3_detect           (const GwyFileDetectInfo *fileinfo,
+                                            gboolean only_name);
+static gint      keyence4_detect           (const GwyFileDetectInfo *fileinfo,
+                                            gboolean only_name);
+static GwyFile*  keyence3_load             (const gchar *filename,
+                                            GwyRunModeFlags mode,
+                                            GError **error);
+static GwyFile*  keyence4_load             (const gchar *filename,
+                                            GwyRunModeFlags mode,
+                                            GError **error);
+static GwyFile*  keyence4_load_membuf      (const guchar *buffer,
+                                            gsize size,
+                                            gint version,
+                                            const gchar *filename,
+                                            GError **error);
+static void      keyence4_free             (Keyence4File *kfile);
+static gboolean  read_header               (const guchar **p,
+                                            gsize *size,
+                                            Keyence4Header *header,
+                                            gint version,
+                                            GError **error);
+static gboolean  read_offset_table         (const guchar **p,
+                                            gsize *size,
+                                            Keyence4OffsetTable *offsettable,
+                                            GError **error);
+static gboolean  read_meas_conds           (const guchar **p,
+                                            gsize *size,
+                                            Keyence4MeasurementConditions *measconds,
+                                            gint version,
+                                            GError **error);
+static gboolean  read_assembly_info        (Keyence4File *kfile,
+                                            GError **error);
+static gboolean  read_data_images          (Keyence4File *kfile,
+                                            GError **error);
+static gboolean  read_color_images         (Keyence4File *kfile,
+                                            GError **error);
+static gboolean  read_line_meas            (Keyence4File *kfile,
+                                            GError **error);
+static gboolean  read_character_strs       (Keyence4File *kfile,
+                                            GError **error);
+static GwyField* create_field              (const Keyence4FalseColorImage *image,
+                                            const Keyence4MeasurementConditions *measconds,
+                                            gboolean is_height);
+static GwyField* create_color_field        (const Keyence4TrueColorImage *image,
+                                            const Keyence4MeasurementConditions *measconds,
+                                            gint channelid);
+static GwyDict*  create_meta               (const Keyence4File *kfile);
+static void      add_field                 (GwyFile *file,
+                                            gint *id,
+                                            GwyField *dfield,
+                                            GwyDict *meta,
+                                            const gchar *title,
+                                            const gchar *filename,
+                                            gint i,
+                                            const gchar *gradient);
 #ifdef HAVE_GWYZIP
-static gint          keyence6_detect           (const GwyFileDetectInfo *fileinfo,
-                                                gboolean only_name);
-static GwyFile*      keyence6_load             (const gchar *filename,
-                                                GwyRunModeFlags mode,
-                                                GError **error);
-static gint          keyence7_detect           (const GwyFileDetectInfo *fileinfo,
-                                                gboolean only_name);
-static GwyFile*      keyence7_load             (const gchar *filename,
-                                                GwyRunModeFlags mode,
-                                                GError **error);
-static GwyFile*      keyence67_load_common     (const gchar *filename,
-                                                gint version,
-                                                GError **error);
-static void          add_vk6_hdr_images        (GwyFile *data,
-                                                GwyZipFile zipfile,
-                                                const gchar *filename);
-static gboolean      read_vk6_hdr_images       (const guchar *buffer,
-                                                gsize size,
-                                                GwyField **fields,
-                                                guint nf);
-static void          distribute_meta6          (GwyFile *data,
-                                                GwyContainer *addmeta);
-static GwyContainer* read_vk6_measure_condition(GwyZipFile zipfile);
-static GwyContainer* parse_xml_metadata        (const gchar *buffer,
-                                                gsize size);
+static gint      keyence6_detect           (const GwyFileDetectInfo *fileinfo,
+                                            gboolean only_name);
+static GwyFile*  keyence6_load             (const gchar *filename,
+                                            GwyRunModeFlags mode,
+                                            GError **error);
+static gint      keyence7_detect           (const GwyFileDetectInfo *fileinfo,
+                                            gboolean only_name);
+static GwyFile*  keyence7_load             (const gchar *filename,
+                                            GwyRunModeFlags mode,
+                                            GError **error);
+static GwyFile*  keyence67_load_common     (const gchar *filename,
+                                            gint version,
+                                            GError **error);
+static void      add_vk6_hdr_images        (GwyFile *data,
+                                            GwyZipFile zipfile,
+                                            const gchar *filename);
+static gboolean  read_vk6_hdr_images       (const guchar *buffer,
+                                            gsize size,
+                                            GwyField **fields,
+                                            guint nf);
+static void      distribute_meta6          (GwyFile *data,
+                                            GwyDict *addmeta);
+static GwyDict*  read_vk6_measure_condition(GwyZipFile zipfile);
+static GwyDict*  parse_xml_metadata        (const gchar *buffer,
+                                            gsize size);
 #endif
 
 static const gchar *peaknames[3] =     { "Peak Red",  "Peak Green",  "Peak Blue" };
@@ -436,7 +435,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Keyence VK3, VK4, VK6 and VK7 files."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -573,7 +572,7 @@ keyence4_load_membuf(const guchar *buffer,
     Keyence4File *kfile;
     GwyField *dfield;
     GwyFile *data = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     const guchar *p;
     guint i, id;
 
@@ -1196,41 +1195,41 @@ create_color_field(const Keyence4TrueColorImage *image,
 
 #define store_int(c,n,i) \
     g_snprintf(buf, sizeof(buf), "%d", (i)); \
-    gwy_container_set_const_string_by_name((c), (n), buf);
+    gwy_dict_set_const_string_by_name((c), (n), buf);
 
 #define store_uint(c,n,i) \
     g_snprintf(buf, sizeof(buf), "%u", (i)); \
-    gwy_container_set_const_string_by_name((c), (n), buf);
+    gwy_dict_set_const_string_by_name((c), (n), buf);
 
 #define store_int2(c,n,i,u) \
     g_snprintf(buf, sizeof(buf), "%d %s", (i), (u)); \
-    gwy_container_set_const_string_by_name((c), (n), buf);
+    gwy_dict_set_const_string_by_name((c), (n), buf);
 
 #define store_uint2(c,n,i,u) \
     g_snprintf(buf, sizeof(buf), "%u %s", (i), (u)); \
-    gwy_container_set_const_string_by_name((c), (n), buf);
+    gwy_dict_set_const_string_by_name((c), (n), buf);
 
 #define store_float(c,n,v) \
     g_snprintf(buf, sizeof(buf), "%g", (v)); \
-    gwy_container_set_const_string_by_name((c), (n), buf);
+    gwy_dict_set_const_string_by_name((c), (n), buf);
 
-static GwyContainer*
+static GwyDict*
 create_meta(const Keyence4File *kfile)
 {
     const Keyence4MeasurementConditions *measconds = &kfile->meas_conds;
     const Keyence4CharacterStrings *charstrs = &kfile->char_strs;
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     gchar buf[48];
 
     g_snprintf(buf, sizeof(buf), "%u.%u.%u.%u",
                kfile->header.dll_version[3], kfile->header.dll_version[2],
                kfile->header.dll_version[1], kfile->header.dll_version[0]);
-    gwy_container_set_const_string_by_name(meta, "DLL version", buf);
+    gwy_dict_set_const_string_by_name(meta, "DLL version", buf);
 
     g_snprintf(buf, sizeof(buf), "%04u-%02u-%02u %02u:%02u:%02u",
                measconds->year, measconds->month, measconds->day,
                measconds->hour, measconds->minute, measconds->second);
-    gwy_container_set_const_string_by_name(meta, "Date", buf);
+    gwy_dict_set_const_string_by_name(meta, "Date", buf);
 
     store_int2(meta, "Time difference to UTC", measconds->diff_utc_by_minutes, "min");
     store_uint(meta, "Image attributes", measconds->image_attributes);
@@ -1286,16 +1285,16 @@ create_meta(const Keyence4File *kfile)
     store_uint(meta, "Height effective bit depth", measconds->height_effective_bit_depth);
 
     if (charstrs->title && strlen(charstrs->title))
-        gwy_container_set_const_string_by_name(meta, "Title", charstrs->title);
+        gwy_dict_set_const_string_by_name(meta, "Title", charstrs->title);
     if (charstrs->lens_name && strlen(charstrs->lens_name))
-        gwy_container_set_const_string_by_name(meta, "Lens name", charstrs->lens_name);
+        gwy_dict_set_const_string_by_name(meta, "Lens name", charstrs->lens_name);
 
     return meta;
 }
 
 static void
 add_field(GwyFile *file, gint *id,
-          GwyField *dfield, GwyContainer *meta,
+          GwyField *dfield, GwyDict *meta,
           const gchar *title, const gchar *filename,
           gint i, const gchar *gradient)
 {
@@ -1310,7 +1309,7 @@ add_field(GwyFile *file, gint *id,
         gwy_file_set_title(file, GWY_FILE_IMAGE, *id, title, FALSE);
 
     if (meta)
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, gwy_dict_copy(meta));
 
     if (gradient)
         gwy_file_set_palette(file, GWY_FILE_IMAGE, *id, gradient);
@@ -1341,9 +1340,8 @@ keyence67_load_common(const gchar *filename,
                       GError **error)
 {
     GwyFile *data = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GError *err = NULL;
-    gchar *zipfilename = NULL;
     guchar *buffer = NULL, *vk4buf = NULL;
     const guchar *p;
     guint vk6skip, bmpsize;
@@ -1395,7 +1393,7 @@ keyence67_load_common(const gchar *filename,
     p = buffer + KEYENCE6_HEADER_SIZE + bmpsize;
 
     /* There is a VK4 file inside, called Vk4File.  That's what we want to read, really. */
-    if (!(zipfile = gwyzip_make_temporary_archive(p, zipsize, "gwyddion-keyence6-XXXXXX.zip", &zipfilename, error))
+    if (!(zipfile = gwyzip_make_temporary_archive(p, zipsize, "gwyddion-keyence6-XXXXXX.zip", error))
         || !(gwyzip_locate_file(zipfile, "Vk4File", 0, error))
         || !(vk4buf = gwyzip_get_file_content(zipfile, &vk4size, error)))
         goto fail;
@@ -1412,10 +1410,6 @@ fail:
     g_free(vk4buf);
     if (zipfile)
         gwyzip_close(zipfile);
-    if (zipfilename) {
-        g_unlink(zipfilename);
-        g_free(zipfilename);
-    }
     gwy_file_abandon_contents(buffer, size, NULL);
 
     return data;
@@ -1425,26 +1419,23 @@ static void
 add_vk6_hdr_images(GwyFile *data, GwyZipFile zipfile, const gchar *filename)
 {
     GwyZipFile hdrzipfile;
-    GwyField *rgbfield[3] = { NULL, NULL, NULL }, *errfield = NULL, *field = NULL, *mask;
-    GwyContainer *meta = NULL;
-    guchar *buffer;
-    gchar *hdrfilename;
-    gsize size;
+    GwyField *rgbfield[3] = { NULL, NULL, NULL }, *errfield = NULL, *field = NULL;
+    GwyDict *meta = NULL;
+    guchar *hdrbuffer, *buffer;
+    gsize hdrsize, size;
     gint *ids;
     guint i;
     gint id;
 
     if (!gwyzip_locate_file(zipfile, "Vk6ImageData", 0, NULL)
-        || !(buffer = gwyzip_get_file_content(zipfile, &size, NULL)))
+        || !(hdrbuffer = gwyzip_get_file_content(zipfile, &hdrsize, NULL)))
         return;
 
     gwy_debug("found Vk6ImageData");
-    if (!(hdrzipfile = gwyzip_make_temporary_archive(buffer, size,
-                                                     "gwyddion-keyence6hdr-XXXXXX.zip", &hdrfilename, NULL))) {
-        g_free(buffer);
+    if (!(hdrzipfile = gwyzip_make_temporary_archive(hdrbuffer, hdrsize, "gwyddion-keyence6hdr-XXXXXX.zip", NULL))) {
+        g_free(hdrbuffer);
         return;
     }
-    g_free(buffer);
 
     if (gwyzip_locate_file(hdrzipfile, "HdrImageData", 0, NULL)
         && (buffer = gwyzip_get_file_content(hdrzipfile, &size, NULL))) {
@@ -1460,7 +1451,7 @@ add_vk6_hdr_images(GwyFile *data, GwyZipFile zipfile, const gchar *filename)
         g_free(buffer);
 
         /* Don't create masks if the error field is empty. */
-        if (gwy_field_get_max(errfield) <= 0.0)
+        if (gwy_field_max(errfield) <= 0.0)
             g_clear_object(&errfield);
     }
 
@@ -1492,9 +1483,8 @@ add_vk6_hdr_images(GwyFile *data, GwyZipFile zipfile, const gchar *filename)
     ids = gwy_file_get_ids(data, GWY_FILE_IMAGE);
     for (i = 0; ids[i] >= 0; i++) {
         if (errfield && !gwy_field_is_incompatible(field, errfield, GWY_DATA_MISMATCH_RES)) {
-            mask = gwy_field_new_alike(field, FALSE);
-            gwy_unit_clear(gwy_field_get_unit_z(mask));
-            gwy_field_copy_data(errfield, mask);
+            GwyNield *mask = gwy_field_new_nield_alike(field);
+            gwy_nield_mark_by_threshold(mask, errfield, 0.5, TRUE);
             /* FIXME: Should we apply Laplace interpolation here, as usual? */
             gwy_file_pass_image_mask(data, ids[i], mask);
         }
@@ -1504,8 +1494,7 @@ add_vk6_hdr_images(GwyFile *data, GwyZipFile zipfile, const gchar *filename)
     g_clear_object(&errfield);
 
     gwyzip_close(hdrzipfile);
-    g_unlink(hdrfilename);
-    g_free(hdrfilename);
+    g_free(hdrbuffer);
 }
 
 static gboolean
@@ -1560,41 +1549,38 @@ read_vk6_hdr_images(const guchar *buffer, gsize size,
 }
 
 static void
-distribute_meta6(GwyFile *file, GwyContainer *addmeta)
+distribute_meta6(GwyFile *file, GwyDict *addmeta)
 {
     gint *ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
 
     for (gint i = 0; ids[i] >= 0; i++) {
-        GwyContainer *meta;
+        GwyDict *meta;
 
         if ((meta = gwy_file_get_meta(file, GWY_FILE_IMAGE, ids[i])))
-            gwy_container_transfer(addmeta, meta, "", "", FALSE, FALSE);
+            gwy_dict_transfer(addmeta, meta, "", "", FALSE, FALSE);
         else
-            gwy_file_pass_meta(file, GWY_FILE_IMAGE, ids[i], gwy_container_copy(addmeta));
+            gwy_file_pass_meta(file, GWY_FILE_IMAGE, ids[i], gwy_dict_copy(addmeta));
     }
     g_free(ids);
 }
 
-static GwyContainer*
+static GwyDict*
 read_vk6_measure_condition(GwyZipFile zipfile)
 {
     GwyZipFile mczipfile;
-    GwyContainer *meta = NULL;
-    guchar *buffer;
-    gchar *mcfilename;
-    gsize size;
+    GwyDict *meta = NULL;
+    guchar *mcbuffer, *buffer;
+    gsize mcsize, size;
 
     if (!gwyzip_locate_file(zipfile, "VK6MeasureCondition", 0, NULL)
-        || !(buffer = gwyzip_get_file_content(zipfile, &size, NULL)))
+        || !(mcbuffer = gwyzip_get_file_content(zipfile, &mcsize, NULL)))
         return NULL;
 
     gwy_debug("found VK6MeasureCondition");
-    if (!(mczipfile = gwyzip_make_temporary_archive(buffer, size,
-                                                    "gwyddion-keyence6mc-XXXXXX.zip", &mcfilename, NULL))) {
-        g_free(buffer);
+    if (!(mczipfile = gwyzip_make_temporary_archive(mcbuffer, mcsize, "gwyddion-keyence6mc-XXXXXX.zip", NULL))) {
+        g_free(mcbuffer);
         return NULL;
     }
-    g_free(buffer);
 
     if (gwyzip_locate_file(mczipfile, "FocusCompositionCondition", 0, NULL)
         && (buffer = gwyzip_get_file_content(mczipfile, &size, NULL))) {
@@ -1604,8 +1590,7 @@ read_vk6_measure_condition(GwyZipFile zipfile)
     }
 
     gwyzip_close(mczipfile);
-    g_unlink(mcfilename);
-    g_free(mcfilename);
+    g_free(mcbuffer);
 
     return meta;
 }
@@ -1710,16 +1695,16 @@ keyence6_text(G_GNUC_UNUSED GMarkupParseContext *context,
     }
     else if (gwy_strequal(vk6meta->curr_element->str, "Value") && !string_is_uuid(text, text_len)) {
         gwy_debug("%s <%s>", path->str, text);
-        if (gwy_container_contains_by_name(vk6meta->meta, path->str)) {
-            gchar *s = g_strconcat(gwy_container_get_string_by_name(vk6meta->meta, path->str), ", ", text, NULL);
-            gwy_container_set_string_by_name(vk6meta->meta, path->str, s);
+        if (gwy_dict_contains_by_name(vk6meta->meta, path->str)) {
+            gchar *s = g_strconcat(gwy_dict_get_string_by_name(vk6meta->meta, path->str), ", ", text, NULL);
+            gwy_dict_set_string_by_name(vk6meta->meta, path->str, s);
         }
         else
-            gwy_container_set_const_string_by_name(vk6meta->meta, path->str, text);
+            gwy_dict_set_const_string_by_name(vk6meta->meta, path->str, text);
     }
 }
 
-static GwyContainer*
+static GwyDict*
 parse_xml_metadata(const gchar *buffer, gsize size)
 {
     GMarkupParser parser = {
@@ -1728,7 +1713,7 @@ parse_xml_metadata(const gchar *buffer, gsize size)
     GMarkupParseContext *context = NULL;
     Keyence6Meta vk6meta;
 
-    vk6meta.meta = gwy_container_new_in_construction();
+    vk6meta.meta = gwy_dict_new_in_construction();
     vk6meta.path = g_string_new(NULL);
     vk6meta.curr_element = g_string_new(NULL);
     vk6meta.compdepths = g_array_new(FALSE, FALSE, sizeof(gint));
@@ -1742,7 +1727,7 @@ parse_xml_metadata(const gchar *buffer, gsize size)
     g_string_free(vk6meta.path, TRUE);
     g_string_free(vk6meta.curr_element, TRUE);
     g_array_free(vk6meta.compdepths, TRUE);
-    if (!gwy_container_get_n_items(vk6meta.meta))
+    if (!gwy_dict_get_n_items(vk6meta.meta))
         g_clear_object(&vk6meta.meta);
 
     return vk6meta.meta;
