@@ -1,5 +1,5 @@
 /*
- *  $Id: leica.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: leica.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2025 Daniil Bratashov (dn2010), David Necas (Yeti).
  *
  *  E-mail: dn2010@gmail.com.
@@ -115,7 +115,7 @@ typedef struct {
     gchar  *memid;
     GArray *channels;
     GArray *dimensions;
-    GwyContainer *metadata;
+    GwyDict *metadata;
 } LIFElement;
 
 typedef struct {
@@ -354,7 +354,7 @@ fail:
 
     if (!ok)
         g_clear_object(&file);
-    else if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    else if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         err_NO_DATA(error);
         g_clear_object(&file);
     }
@@ -449,7 +449,7 @@ create_images(LIFElement *element, LIFMemBlock *memblock, gint *channelno,
         if (element->name)
             gwy_file_set_title(file, GWY_FILE_IMAGE, *channelno, element->name, FALSE);
         if (element->metadata)
-            gwy_file_pass_meta(file, GWY_FILE_IMAGE, *channelno, gwy_container_copy(element->metadata));
+            gwy_file_pass_meta(file, GWY_FILE_IMAGE, *channelno, gwy_dict_copy(element->metadata));
         if ((lutname = lut_name_to_palette(channel->lut)))
             gwy_file_set_palette(file, GWY_FILE_IMAGE, *channelno, lutname);
 
@@ -605,7 +605,7 @@ create_volumes(LIFElement *element, LIFMemBlock *memblock, gint *channelno,
         if (element->name)
             gwy_file_set_title(file, GWY_FILE_VOLUME, *channelno, element->name, FALSE);
         if (element->metadata)
-            gwy_file_pass_meta(file, GWY_FILE_VOLUME, *channelno, gwy_container_copy(element->metadata));
+            gwy_file_pass_meta(file, GWY_FILE_VOLUME, *channelno, gwy_dict_copy(element->metadata));
         if ((lutname = lut_name_to_palette(channel->lut)))
             gwy_file_set_palette(file, GWY_FILE_VOLUME, *channelno, lutname);
 
@@ -910,10 +910,10 @@ header_start_element(G_GNUC_UNUSED GMarkupParseContext *context,
             goto fail_xml;
 
         if (!element->metadata)
-            element->metadata = gwy_container_new_in_construction();
+            element->metadata = gwy_dict_new_in_construction();
 
         while (*name_cursor) {
-            gwy_container_set_const_string_by_name(element->metadata, *name_cursor, *value_cursor);
+            gwy_dict_set_const_string_by_name(element->metadata, *name_cursor, *value_cursor);
             name_cursor++;
             value_cursor++;
         }
