@@ -1,5 +1,5 @@
 /*
- *  $Id: lextfile.c 28938 2025-12-02 15:09:14Z yeti-dn $
+ *  $Id: lextfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -56,7 +56,7 @@ typedef struct {
     GString *path;
     GHashTable *hash;
     const gchar *toplevel;
-    GwyContainer *meta;
+    GwyDict *meta;
     gdouble xcal;
     gdouble ycal;
     gdouble zcal;
@@ -363,7 +363,7 @@ lext_load_tiff(const GwyTIFF *tiff, const gchar *filename, GError **error)
             gwy_file_set_title(file, GWY_FILE_IMAGE, id, channeltitle, FALSE);
 
             if (lfile.meta)
-                gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_container_copy(lfile.meta));
+                gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_dict_copy(lfile.meta));
 
             if (spp == 3)
                 gwy_file_set_palette(file, GWY_FILE_IMAGE, id, colour_channel_gradients[ch]);
@@ -545,16 +545,16 @@ add_metadata(gpointer hkey, gpointer hvalue, gpointer user_data)
         g_string_erase(str, 0, strlen("/ExifTagDescData/"));
 
     gwy_gstring_replace(str, "/", "::", -1);
-    gwy_container_set_const_string_by_name(lfile->meta, str->str, value);
+    gwy_dict_set_const_string_by_name(lfile->meta, str->str, value);
 }
 
 static void
 create_metadata(LextFile *lfile)
 {
-    lfile->meta = gwy_container_new_in_construction();
+    lfile->meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(lfile->hash, add_metadata, lfile);
 
-    if (!gwy_container_get_n_items(lfile->meta))
+    if (!gwy_dict_get_n_items(lfile->meta))
         g_clear_object(&lfile->meta);
 
     /* XXX: We could also extract date & time from EXIT TIFF tags and put them to the metadata... */
