@@ -1,5 +1,5 @@
 /*
- *  $Id: magellan.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: magellan.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2013-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -49,7 +49,7 @@ static GwyFile*      load_file      (const gchar *filename,
 static GwyFile*      mgl_load_tiff  (const GwyTIFF *tiff,
                                      const gchar *filename,
                                      GError **error);
-static GwyContainer* get_meta       (GHashTable *hash);
+static GwyDict* get_meta       (GHashTable *hash);
 static void          add_meta       (gpointer hkey,
                                      gpointer hvalue,
                                      gpointer user_data);
@@ -127,7 +127,7 @@ static GwyFile*
 mgl_load_tiff(const GwyTIFF *tiff, const gchar *filename, GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield;
     GwyTIFFImageReader *reader = NULL;
     GwyTextHeaderParser parser;
@@ -231,12 +231,12 @@ fail:
     return file;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
@@ -256,7 +256,7 @@ add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 
     value = gwy_convert_to_utf8(value, -1, "ISO-8859-1");
     if (value)
-        gwy_container_set_string_by_name(GWY_CONTAINER(user_data), skey, value);
+        gwy_dict_set_string_by_name(GWY_DICT(user_data), skey, value);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
