@@ -1,5 +1,5 @@
 /*
- *  $Id: mapvue.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: mapvue.c 29329 2026-01-23 16:22:18Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -405,7 +405,7 @@ static GwyField* read_field                (gconstpointer p,
                                             gint xres,
                                             gint yres,
                                             guint bpp,
-                                            GwyField **maskfield);
+                                            GwyNield **maskfield);
 static gboolean  calculate_scales_from_fids(const MapVueGroup155 *group155,
                                             gdouble aspratio,
                                             gdouble *xscale,
@@ -455,7 +455,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports MapVue data files (.map)."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -500,7 +500,8 @@ load_file(const gchar *filename,
     const guchar *p;
     gsize header_size, expected_size, size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL, *mfield;
+    GwyField *field = NULL;
+    GwyNield *mask;
     gint xres, yres;
     guint bpp;
     gdouble xreal, yreal;
@@ -577,16 +578,16 @@ load_file(const gchar *filename,
     if (err_DIMENSION(error, xres) || err_DIMENSION(error, yres))
         goto fail;
 
-    dfield = read_field((gconstpointer)p, xres, yres, bpp, &mfield);
-    gwy_field_set_xreal(dfield, xreal);
-    gwy_field_set_yreal(dfield, yreal);
+    field = read_field((gconstpointer)p, xres, yres, bpp, &mask);
+    gwy_field_set_xreal(field, xreal);
+    gwy_field_set_yreal(field, yreal);
 
     file = gwy_file_new_in_construction();
-    gwy_file_pass_image(file, 0, dfield);
+    gwy_file_pass_image(file, 0, field);
     gwy_image_title_fall_back(file, 0);
 
-    if (mfield)
-        gwy_file_pass_image_mask(file, 0, mfield);
+    if (mask)
+        gwy_file_pass_image_mask(file, 0, mask);
 
     /*
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, get_metadata(&ufile));
@@ -1656,24 +1657,21 @@ static GwyField*
 read_field(gconstpointer p,
            gint xres, gint yres,
            guint bpp,
-           GwyField **maskfield)
+           GwyNield **maskfield)
 {
-    GwyField *dfield, *mfield;
-    gdouble *data, *mdata;
-    gint i, j, mcount;
+    gint i, j;
 
     if (maskfield)
         *maskfield = NULL;
 
-    dfield = gwy_field_new(xres, yres, 1.0, 1.0, FALSE);
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), "m");
+    GwyField *field = gwy_field_new(xres, yres, 1.0, 1.0, FALSE);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
-    gwy_field_fill(mfield, 1.0);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
 
-    data = gwy_field_get_data(dfield);
-    mdata = gwy_field_get_data(mfield);
+    gdouble *data = gwy_field_get_data(field);
+    gint *mdata = gwy_nield_get_data(mask);
     if (bpp == 4) {
         const guint32 *d32 = p;
         for (i = 0; i < yres; i++) {
@@ -1682,7 +1680,7 @@ read_field(gconstpointer p,
                 if (v != G_MAXINT32)
                     data[i*xres + j] = v/(gdouble)G_MAXINT32/5.625e4;
                 else
-                    mdata[i*xres + j] = 0.0;
+                    mdata[i*xres + j] = 1;
                 d32++;
             }
         }
@@ -1696,20 +1694,18 @@ read_field(gconstpointer p,
                 if (v != G_MAXINT16)
                     data[i*xres + j] = v/(gdouble)G_MAXINT16/5.625e4/7.61;
                 else
-                    mdata[i*xres + j] = 0.0;
+                    mdata[i*xres + j] = 1;
                 d16++;
             }
         }
     }
 
-    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
-
-    if (maskfield && mcount)
-        *maskfield = mfield;
+    if (maskfield)
+        *maskfield = gwy_remove_bad_image_data(field, mask);
     else
-        g_object_unref(mfield);
+        g_clear_object(&mask);
 
-    return dfield;
+    return field;
 }
 
 static gboolean
