@@ -1,5 +1,5 @@
 /*
- *  $Id: metropro.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: metropro.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -292,9 +292,9 @@ typedef struct {
     guint infinity;
     const gchar *filename;
     GwyField **intensity_data;
-    GwyField **intensity_mask;
+    GwyNield **intensity_mask;
     GwyField *phase_data;
-    GwyField *phase_mask;
+    GwyNield *phase_mask;
 } MProFile;
 
 static gboolean      module_register      (void);
@@ -313,7 +313,7 @@ static gboolean      mprofile_read_header (const guchar *buffer,
                                            GError **error);
 static gint          fill_fields          (MProFile *mprofile,
                                            const guchar *buffer);
-static GwyContainer* mprofile_get_metadata(MProFile *mprofile);
+static GwyDict* mprofile_get_metadata(MProFile *mprofile);
 
 static const struct {
     guint format;
@@ -419,7 +419,8 @@ mprofile_load_data(MProFile *mprofile,
                    const guchar *buffer, gsize size, GError **error)
 {
     GwyFile *file = NULL;
-    GwyField *dfield = NULL, *vpmask = NULL;
+    GwyField *dfield = NULL;
+    GwyNield *vpmask = NULL;
     gsize expected;
     const gchar *title;
     guint n, i, ac_npix, cn_npix;
@@ -781,8 +782,10 @@ static gint
 fill_fields(MProFile *mprofile,
             const guchar *buffer)
 {
-    GwyField *dfield, *vpmask;
-    gdouble *data, *mask;
+    GwyField *dfield;
+    GwyNield *vpmask;
+    gdouble *data;
+    gint *mask;
     gdouble xreal, yreal, q;
     const guchar *p;
     guint n, id, i, j, ndata;
@@ -807,7 +810,7 @@ fill_fields(MProFile *mprofile,
         const guint16 *d16;
 
         mprofile->intensity_data = g_new(GwyField*, mprofile->ac_n_buckets);
-        mprofile->intensity_mask = g_new(GwyField*, mprofile->ac_n_buckets);
+        mprofile->intensity_mask = g_new(GwyNield*, mprofile->ac_n_buckets);
 
         q = mprofile->sign ? -1.0 : 1.0;
 
@@ -825,26 +828,24 @@ fill_fields(MProFile *mprofile,
             ndata++;
             dfield = gwy_field_new(mprofile->ac_width, mprofile->ac_height, xreal, yreal, FALSE);
             set_units(dfield, mprofile, "");
-            vpmask = gwy_field_new_alike(dfield, FALSE);
-            gwy_field_fill(vpmask, 1.0);
+            vpmask = gwy_field_new_nield_alike(dfield);
             data = gwy_field_get_data(dfield);
-            mask = gwy_field_get_data(vpmask);
+            mask = gwy_nield_get_data(vpmask);
             d16 = (const guint16*)p;
             for (i = 0; i < mprofile->ac_height; i++) {
                 for (j = 0; j < mprofile->ac_width; j++) {
                     guint v16 = GUINT16_FROM_BE(*d16);
-                    if (v16 >= 65412) {
-                        mask[i*mprofile->ac_width + j] = 0.0;
-                    }
+                    if (v16 >= 65412)
+                        mask[i*mprofile->ac_width + j] = 1;
                     else
                         *data = q*v16;
+
                     d16++;
                     data++;
                 }
             }
 
-            if (!gwy_app_channel_remove_bad_data(dfield, vpmask))
-                g_clear_object(&vpmask);
+            vpmask = gwy_remove_bad_image_data(dfield, vpmask);
 
             mprofile->intensity_data[id] = dfield;
             mprofile->intensity_mask[id] = vpmask;
@@ -887,27 +888,25 @@ fill_fields(MProFile *mprofile,
             yreal = mprofile->cn_height;
         }
         dfield = gwy_field_new(mprofile->cn_width, mprofile->cn_height, xreal, yreal, FALSE);
-        vpmask = gwy_field_new_alike(dfield, FALSE);
-        gwy_field_fill(vpmask, 1.0);
+        vpmask = gwy_field_new_nield_alike(dfield);
         data = gwy_field_get_data(dfield);
-        mask = gwy_field_get_data(vpmask);
+        mask = gwy_nield_get_data(vpmask);
         d32 = (const gint32*)p;
         for (i = 0; i < mprofile->cn_height; i++) {
             for (j = 0; j < mprofile->cn_width; j++) {
                 d = GINT32_FROM_BE(*d32);
-                if (d >= 2147483640) {
-                    mask[i*mprofile->cn_width + j] = 0.0;
-                }
+                if (d >= 2147483640)
+                    mask[i*mprofile->cn_width + j] = 1;
                 else
                     *data = q*d;
+
                 d32++;
                 data++;
             }
         }
 
         set_units(dfield, mprofile, "m");
-        if (!gwy_app_channel_remove_bad_data(dfield, vpmask))
-            g_clear_object(&vpmask);
+        vpmask = gwy_remove_bad_image_data(dfield, vpmask);
 
         mprofile->phase_data = dfield;
         mprofile->phase_mask = vpmask;
@@ -918,12 +917,12 @@ fill_fields(MProFile *mprofile,
 }
 
 #define HASH_STORE(key, fmt, field) \
-    gwy_container_set_string_by_name(meta, key, g_strdup_printf(fmt, mprofile->field))
+    gwy_dict_set_string_by_name(meta, key, g_strdup_printf(fmt, mprofile->field))
 
 #define HASH_STORE_ENUM(key, field, e) \
     s = gwy_enum_to_string(mprofile->field, e, G_N_ELEMENTS(e)); \
     if (s && *s) \
-        gwy_container_set_string_by_name(meta, key, g_strdup(s));
+        gwy_dict_set_string_by_name(meta, key, g_strdup(s));
 
 #define HASH_STORE_STRING(key, field) \
     store_meta_string(meta, key, mprofile->field)
@@ -937,7 +936,7 @@ fill_fields(MProFile *mprofile,
     } while (FALSE)
 
 static void
-store_meta_string(GwyContainer *meta,
+store_meta_string(GwyDict *meta,
                   const gchar *key,
                   gchar *field)
 {
@@ -946,11 +945,11 @@ store_meta_string(GwyContainer *meta,
     g_strstrip(field);
     /* XXX: This gives inconsistent results on different systems. But it may be what the user expects. */
     if (field[0] && (p = g_locale_to_utf8(field, strlen(field), NULL, NULL, NULL)))
-        gwy_container_set_string_by_name(meta, key, p);
+        gwy_dict_set_string_by_name(meta, key, p);
 }
 
 /* Quite incomplete... */
-static GwyContainer*
+static GwyDict*
 mprofile_get_metadata(MProFile *mprofile)
 {
     static const GwyEnum software_types[] = {
@@ -974,7 +973,7 @@ mprofile_get_metadata(MProFile *mprofile)
         { "NewView/GP",              7, },
         { "Mark to GPI conversion",  8, },
     };
-    GwyContainer *meta;
+    GwyDict *meta;
     time_t tp;
     struct tm *tm;
     const gchar *s;
@@ -982,20 +981,20 @@ mprofile_get_metadata(MProFile *mprofile)
     gchar *p;
     guint i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     /* Version */
     p = g_strdup_printf("%d.%d.%d", mprofile->swinfo_vers_maj, mprofile->swinfo_vers_min, mprofile->swinfo_vers_bug);
-    gwy_container_set_string_by_name(meta, "Version", p);
+    gwy_dict_set_string_by_name(meta, "Version", p);
 
     p = g_strdup_printf("%u (%08x)", mprofile->header_format, mprofile->magic_number);
-    gwy_container_set_string_by_name(meta, "Header format", p);
+    gwy_dict_set_string_by_name(meta, "Header format", p);
 
     /* Timestamp */
     tp = mprofile->time_stamp;
     tm = localtime(&tp);
     strftime(buffer, sizeof(buffer), "%Y-%m-%d %H:%M:%S", tm);
-    gwy_container_set_const_string_by_name(meta, "Date", buffer);
+    gwy_dict_set_const_string_by_name(meta, "Date", buffer);
 
     /* Comments */
     store_meta_string(meta, "Software date", mprofile->swinfo_date);
@@ -1008,7 +1007,7 @@ mprofile_get_metadata(MProFile *mprofile)
     HASH_STORE_ENUM("System type", sys_type, system_types);
 
     p = g_strdup_printf("%.2g", mprofile->min_mod/10.23);
-    gwy_container_set_string_by_name(meta, "Minimum modulation", p);
+    gwy_dict_set_string_by_name(meta, "Minimum modulation", p);
 
     /* Generated code for simple fields */
     HASH_STORE("Acquired origin x", "%d", ac_org_x);
