@@ -1,5 +1,5 @@
 /*
- *  $Id: mifile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: mifile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005 Chris Anderson, Molecular Imaging Corp.
  *  E-mail: sidewinder.asu@gmail.com
  *
@@ -974,13 +974,13 @@ process_metadata(MIFile *mifile,
     gwy_field_set_yreal(dfield, yLength);
 
     /* Store Metadata */
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     /* Global */
     for (i = 0; i < G_N_ELEMENTS(global_metadata); i++) {
         if ((p = g_hash_table_lookup(mifile->meta, global_metadata[i].key))) {
             name = global_metadata[i].meta ? global_metadata[i].meta : global_metadata[i].key;
-            gwy_container_set_const_string_by_name(meta, name, p);
+            gwy_dict_set_const_string_by_name(meta, name, p);
         }
     }
 
@@ -988,7 +988,7 @@ process_metadata(MIFile *mifile,
     for (i = 0; i < G_N_ELEMENTS(local_metadata); i++) {
         if ((p = g_hash_table_lookup(data->meta, local_metadata[i].key))) {
             name = local_metadata[i].meta ? local_metadata[i].meta : local_metadata[i].key;
-            gwy_container_set_const_string_by_name(meta, name, p);
+            gwy_dict_set_const_string_by_name(meta, name, p);
         }
     }
 
@@ -996,26 +996,26 @@ process_metadata(MIFile *mifile,
     /*
     if ((p = g_hash_table_lookup(data->meta, "Date"))
         && (s = g_hash_table_lookup(data->meta, "time")))
-        gwy_container_set_string_by_name(meta, "Date", g_strconcat(p, " ", s, NULL));
+        gwy_dict_set_string_by_name(meta, "Date", g_strconcat(p, " ", s, NULL));
     */
 
     if ((p = g_hash_table_lookup(mifile->meta, "scanUp"))) {
         if (g_str_equal(p, "FALSE"))
-            gwy_container_set_const_string_by_name(meta, "Scanning direction", "Top to bottom");
+            gwy_dict_set_const_string_by_name(meta, "Scanning direction", "Top to bottom");
         else if (g_str_equal(p, "TRUE"))
-            gwy_container_set_const_string_by_name(meta, "Scanning direction", "Bottom to top");
+            gwy_dict_set_const_string_by_name(meta, "Scanning direction", "Bottom to top");
     }
 
     /*
     if ((p = g_hash_table_lookup(data->meta, "collect_mode"))) {
         if (!strcmp(p, "1"))
-            gwy_container_set_string_by_name(meta, "Line direction", g_strdup("Left to right"));
+            gwy_dict_set_string_by_name(meta, "Line direction", g_strdup("Left to right"));
         else if (!strcmp(p, "2"))
-            gwy_container_set_string_by_name(meta, "Line direction", g_strdup("Right to left"));
+            gwy_dict_set_string_by_name(meta, "Line direction", g_strdup("Right to left"));
     }
     */
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     else
         g_object_unref(meta);
