@@ -1,5 +1,5 @@
 /*
- *  $Id: mulfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: mulfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -143,7 +143,7 @@ static void          read_image      (GwyFile *file,
                                       const MulIndexEntry *entry,
                                       const MulImageLabel *label,
                                       const gchar *filename);
-static GwyContainer* get_meta        (const MulImageLabel *label);
+static GwyDict* get_meta        (const MulImageLabel *label);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -219,7 +219,7 @@ load_file(const gchar *filename,
         read_image(file, buffer, image_index + i, &label, filename);
     }
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         err_NO_DATA(error);
         g_clear_object(&file);
     }
@@ -465,32 +465,32 @@ read_image(GwyFile *file,
     gwy_log_add_import(file, GWY_FILE_IMAGE, label->id, NULL, filename);
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(const MulImageLabel *label)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_string_by_name(meta, "Date",
-                                     g_strdup_printf("%u-%02u-%02u %02u:%02u:%02u",
-                                                     label->year, label->month, label->day,
-                                                     label->hour, label->minute, label->second));
-    gwy_container_set_string_by_name(meta, "X-Offset", g_strdup_printf("%g nm", label->xoff/10.0));
-    gwy_container_set_string_by_name(meta, "Y-Offset", g_strdup_printf("%g nm", label->yoff/10.0));
-    gwy_container_set_string_by_name(meta, "Z-Scale", g_strdup_printf("%u V", label->zscale));
-    gwy_container_set_string_by_name(meta, "Tilt", g_strdup_printf("%u deg", label->tilt));
-    gwy_container_set_string_by_name(meta, "Scan duration", g_strdup_printf("%g s", label->speed/100.0));
-    gwy_container_set_string_by_name(meta, "Bias", g_strdup_printf("%g V", -10.0*label->bias/32768.0));
-    gwy_container_set_string_by_name(meta, "Current", g_strdup_printf("%g nA", label->current/100.0));
-    gwy_container_set_string_by_name(meta, "Bias (corrected)",
-                                     g_strdup_printf("%g V", -10.0*label->bias/32768.0 - 1e-6*label->current));
-    gwy_container_set_string_by_name(meta, "Postprocessing", g_strdup_printf("%u", label->postpr));
-    gwy_container_set_string_by_name(meta, "Current factor", g_strdup_printf("%u", label->curr_factor));
-    gwy_container_set_string_by_name(meta, "Mode", g_strdup_printf("%u", label->mode));
-    gwy_container_set_string_by_name(meta, "R_Nr", g_strdup_printf("%u", label->n_point_scans));
-    gwy_container_set_string_by_name(meta, "Unit number", g_strdup_printf("%u", label->unitnr));
-    gwy_container_set_string_by_name(meta, "Version", g_strdup_printf("%u", label->version));
-    gwy_container_set_string_by_name(meta, "Gain", g_strdup_printf("%u", label->spare_60));
-    gwy_container_set_string_by_name(meta, "STM", g_strdup_printf("%u", label->spare_61));
+    gwy_dict_set_string_by_name(meta, "Date",
+                                g_strdup_printf("%u-%02u-%02u %02u:%02u:%02u",
+                                                label->year, label->month, label->day,
+                                                label->hour, label->minute, label->second));
+    gwy_dict_set_string_by_name(meta, "X-Offset", g_strdup_printf("%g nm", label->xoff/10.0));
+    gwy_dict_set_string_by_name(meta, "Y-Offset", g_strdup_printf("%g nm", label->yoff/10.0));
+    gwy_dict_set_string_by_name(meta, "Z-Scale", g_strdup_printf("%u V", label->zscale));
+    gwy_dict_set_string_by_name(meta, "Tilt", g_strdup_printf("%u deg", label->tilt));
+    gwy_dict_set_string_by_name(meta, "Scan duration", g_strdup_printf("%g s", label->speed/100.0));
+    gwy_dict_set_string_by_name(meta, "Bias", g_strdup_printf("%g V", -10.0*label->bias/32768.0));
+    gwy_dict_set_string_by_name(meta, "Current", g_strdup_printf("%g nA", label->current/100.0));
+    gwy_dict_set_string_by_name(meta, "Bias (corrected)",
+                                g_strdup_printf("%g V", -10.0*label->bias/32768.0 - 1e-6*label->current));
+    gwy_dict_set_string_by_name(meta, "Postprocessing", g_strdup_printf("%u", label->postpr));
+    gwy_dict_set_string_by_name(meta, "Current factor", g_strdup_printf("%u", label->curr_factor));
+    gwy_dict_set_string_by_name(meta, "Mode", g_strdup_printf("%u", label->mode));
+    gwy_dict_set_string_by_name(meta, "R_Nr", g_strdup_printf("%u", label->n_point_scans));
+    gwy_dict_set_string_by_name(meta, "Unit number", g_strdup_printf("%u", label->unitnr));
+    gwy_dict_set_string_by_name(meta, "Version", g_strdup_printf("%u", label->version));
+    gwy_dict_set_string_by_name(meta, "Gain", g_strdup_printf("%u", label->spare_60));
+    gwy_dict_set_string_by_name(meta, "STM", g_strdup_printf("%u", label->spare_61));
 
     return meta;
 }
