@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoeducator.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: nanoeducator.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -270,7 +270,7 @@ static GwySpectra*    read_iz_spectra(const guchar *pos_buffer,
                                       gdouble iscale,
                                       gint sp_type,
                                       GError **error);
-static GwyContainer*  read_meta      (const NanoeduFileHeader *header,
+static GwyDict*       read_meta      (const NanoeduFileHeader *header,
                                       const NanoeduParameterHeader *param);
 
 static GwyModuleInfo module_info = {
@@ -320,7 +320,7 @@ load_file(const gchar *filename,
     NanoeduFileHeader header;
     NanoeduParameterHeader params;
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     guchar *buffer = NULL;
     const guchar *p;
     gsize len, size = 0;
@@ -394,7 +394,7 @@ load_file(const gchar *filename,
 
         gwy_file_pass_image(file, 0, dfield);
         gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "Topography", FALSE);
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, gwy_dict_copy(meta));
         gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
         nobjects++;
     }
@@ -575,7 +575,7 @@ load_file(const gchar *filename,
         if (title && *title)
             gwy_file_set_title(file, GWY_FILE_IMAGE, 1, title, FALSE);
 
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, 1, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, 1, gwy_dict_copy(meta));
         gwy_log_add_import(file, GWY_FILE_IMAGE, 1, NULL, filename);
         nobjects++;
     }
@@ -1126,37 +1126,36 @@ read_iz_spectra(const guchar *pos_buffer, gsize pos_size,
     return spectra;
 }
 
-static GwyContainer*
+static GwyDict*
 read_meta(const NanoeduFileHeader *header,
           const NanoeduParameterHeader *param)
 {
-    GwyContainer *meta;
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    meta = gwy_container_new_in_construction();
-    gwy_container_set_string_by_name(meta, "Version",
-                                     g_strdup_printf("%u", header->version));
-    gwy_container_set_string_by_name(meta, "Date",
-                                     g_strdup_printf("%u-%02u-%02u %02u:%02u:%02u",
-                                                     param->year, param->month, param->day,
-                                                     param->hour, param->minute, param->second));
+    gwy_dict_set_string_by_name(meta, "Version",
+                                g_strdup_printf("%u", header->version));
+    gwy_dict_set_string_by_name(meta, "Date",
+                                g_strdup_printf("%u-%02u-%02u %02u:%02u:%02u",
+                                                param->year, param->month, param->day,
+                                                param->hour, param->minute, param->second));
     if (*param->material)
-        gwy_container_set_string_by_name(meta, "Material", gwy_convert_to_utf8(param->material, -1, "cp1251"));
+        gwy_dict_set_string_by_name(meta, "Material", gwy_convert_to_utf8(param->material, -1, "cp1251"));
     if (*param->scanner_name)
-        gwy_container_set_const_string_by_name(meta, "Scanner number", param->scanner_name);
-    gwy_container_set_string_by_name(meta, "Scan rate", g_strdup_printf("%g nm/s", param->scan_rate));
-    gwy_container_set_string_by_name(meta, "X offset", g_strdup_printf("%g nm", param->x_offset));
-    gwy_container_set_string_by_name(meta, "Y offset", g_strdup_printf("%g nm", param->y_offset));
-    gwy_container_set_string_by_name(meta, "X sensitivity", g_strdup_printf("%g nm/V", param->sens_x));
-    gwy_container_set_string_by_name(meta, "Y sensitivity", g_strdup_printf("%g nm/V", param->sens_y));
-    gwy_container_set_string_by_name(meta, "Z sensitivity", g_strdup_printf("%g nm/V", param->sens_z));
-    gwy_container_set_string_by_name(meta, "X gain", g_strdup_printf("%g", param->gain_x));
-    gwy_container_set_string_by_name(meta, "Y gain", g_strdup_printf("%g", param->gain_y));
-    gwy_container_set_string_by_name(meta, "Z gain", g_strdup_printf("%g", param->amp_zgain));
-    gwy_container_set_string_by_name(meta, "Tunnel current", g_strdup_printf("%g nA", param->scan_current));
-    gwy_container_set_string_by_name(meta, "Tunnel voltage", g_strdup_printf("%g V", param->scan_voltage));
-    gwy_container_set_string_by_name(meta, "Resonance frequency", g_strdup_printf("%g kHz", param->f0/1.0));
-    gwy_container_set_string_by_name(meta, "Amplitude suppression", g_strdup_printf("%g", param->ampl_suppress));
-    gwy_container_set_string_by_name(meta, "Linearization", g_strdup_printf(param->linear ? "yes" : "no"));
+        gwy_dict_set_const_string_by_name(meta, "Scanner number", param->scanner_name);
+    gwy_dict_set_string_by_name(meta, "Scan rate", g_strdup_printf("%g nm/s", param->scan_rate));
+    gwy_dict_set_string_by_name(meta, "X offset", g_strdup_printf("%g nm", param->x_offset));
+    gwy_dict_set_string_by_name(meta, "Y offset", g_strdup_printf("%g nm", param->y_offset));
+    gwy_dict_set_string_by_name(meta, "X sensitivity", g_strdup_printf("%g nm/V", param->sens_x));
+    gwy_dict_set_string_by_name(meta, "Y sensitivity", g_strdup_printf("%g nm/V", param->sens_y));
+    gwy_dict_set_string_by_name(meta, "Z sensitivity", g_strdup_printf("%g nm/V", param->sens_z));
+    gwy_dict_set_string_by_name(meta, "X gain", g_strdup_printf("%g", param->gain_x));
+    gwy_dict_set_string_by_name(meta, "Y gain", g_strdup_printf("%g", param->gain_y));
+    gwy_dict_set_string_by_name(meta, "Z gain", g_strdup_printf("%g", param->amp_zgain));
+    gwy_dict_set_string_by_name(meta, "Tunnel current", g_strdup_printf("%g nA", param->scan_current));
+    gwy_dict_set_string_by_name(meta, "Tunnel voltage", g_strdup_printf("%g V", param->scan_voltage));
+    gwy_dict_set_string_by_name(meta, "Resonance frequency", g_strdup_printf("%g kHz", param->f0/1.0));
+    gwy_dict_set_string_by_name(meta, "Amplitude suppression", g_strdup_printf("%g", param->ampl_suppress));
+    gwy_dict_set_string_by_name(meta, "Linearization", g_strdup_printf(param->linear ? "yes" : "no"));
 
     return meta;
 }
