@@ -1,5 +1,5 @@
 /*
- *  $Id: nanonics.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: nanonics.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -575,7 +575,7 @@ read_fields(const NanonicsFile *nfile,
 
     /* Use first channel min, max and formula to calibrate data */
     if (get_double_value(nfile->pagemeta[id], "CMX", &cmx) && get_double_value(nfile->pagemeta[id], "CMN", &cmn)) {
-        gwy_field_get_min_max(fields[0], &min, &max);
+        gwy_field_min_max(fields[0], &min, &max);
         have_minmax = TRUE;
     }
     c = read_formula(nfile, id);
