@@ -1,5 +1,5 @@
 /*
- *  $Id: nanonis.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: nanonis.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2006,2015-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -92,22 +92,22 @@ typedef struct {
     gboolean bogus_scan_time;
 } SXMFile;
 
-static gboolean      module_register     (void);
-static GwyParamDef*  define_module_params(void);
-static gint          detect_file         (const GwyFileDetectInfo *fileinfo,
-                                          gboolean only_name);
-static GwyFile*      load_file           (const gchar *filename,
-                                          GwyRunModeFlags mode,
-                                          GError **error);
-static GwyContainer* sxm_build_meta      (const SXMFile *sxmfile,
-                                          guint id);
+static gboolean     module_register     (void);
+static GwyParamDef* define_module_params(void);
+static gint         detect_file         (const GwyFileDetectInfo *fileinfo,
+                                         gboolean only_name);
+static GwyFile*     load_file           (const gchar *filename,
+                                         GwyRunModeFlags mode,
+                                         GError **error);
+static GwyDict*     build_meta          (const SXMFile *sxmfile,
+                                         guint id);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Imports Nanonis SXM data files."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -393,18 +393,20 @@ read_field(GwyFile *file,
            const guchar **p)
 {
     gboolean preserve_coordinates = gwy_params_get_boolean(params, PARAM_PRESRRVE_COORDINATES);
-    GwyContainer *meta;
-    GwyField *dfield, *mfield = NULL;
-    gdouble *data, *mdata;
+    GwyDict *meta;
+    GwyField *field;
+    GwyNield *mask = NULL;
+    gdouble *data;
+    gint *mdata;
     gint j, n;
     gchar *s;
     gboolean flip_vertically = FALSE, flip_horizontally = FALSE;
 
-    dfield = gwy_field_new(sxmfile->xres, sxmfile->yres, sxmfile->xreal, sxmfile->yreal, FALSE);
+    field = gwy_field_new(sxmfile->xres, sxmfile->yres, sxmfile->xreal, sxmfile->yreal, FALSE);
     /* This is correct for both preserved and non-preserved coordinates? */
-    gwy_field_set_xoffset(dfield, sxmfile->xoff - 0.5*sxmfile->xreal);
-    gwy_field_set_yoffset(dfield, sxmfile->yoff - 0.5*sxmfile->yreal);
-    data = gwy_field_get_data(dfield);
+    gwy_field_set_xoffset(field, sxmfile->xoff - 0.5*sxmfile->xreal);
+    gwy_field_set_yoffset(field, sxmfile->yoff - 0.5*sxmfile->yreal);
+    data = gwy_field_get_data(field);
 
     n = sxmfile->xres*sxmfile->yres;
     for (j = 0; j < n; j++) {
@@ -417,29 +419,27 @@ read_field(GwyFile *file,
     }
 
     if (j < n) {
-        mfield = gwy_field_new_alike(dfield, TRUE);
-        mdata = gwy_field_get_data(mfield);
+        mask = gwy_field_new_nield_alike(field);
+        mdata = gwy_nield_get_data(mask);
         while (j < n) {
             if (((*p)[0] & 0x7f) == 0x7f && (*p)[1] == 0xff) {
-                mdata[j] = -1.0;
                 *p += sizeof(gfloat);
+                mdata[j] = 1;
             }
-            else
+            else {
                 data[j] = gwy_get_gfloat_be(p);
+            }
             j++;
         }
-        gwy_field_add(mfield, 1.0);
-        gwy_app_channel_remove_bad_data(dfield, mfield);
+        mask = gwy_remove_bad_image_data(field, mask);
     }
 
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), data_info->unit);
-    gwy_file_set_image(file, *id, dfield);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), data_info->unit);
+    gwy_file_set_image(file, *id, field);
 
-    if (mfield) {
-        gwy_unit_set_from_string(gwy_field_get_unit_xy(mfield), "m");
-        gwy_file_set_image_mask(file, *id, mfield);
-    }
+    if (mask)
+        gwy_file_set_image_mask(file, *id, mask);
 
     if (!dir) {
         gwy_file_set_title(file, GWY_FILE_IMAGE, *id, data_info->name, FALSE);
@@ -452,7 +452,7 @@ read_field(GwyFile *file,
         /* Don't free title, file eats it */
     }
 
-    if ((meta = sxm_build_meta(sxmfile, *id))) {
+    if ((meta = build_meta(sxmfile, *id))) {
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, meta);
     }
 
@@ -469,12 +469,12 @@ read_field(GwyFile *file,
             flip_vertically = TRUE;
     }
 
-    gwy_field_flip(dfield, flip_horizontally, flip_vertically);
-    g_object_unref(dfield);
+    gwy_field_flip(field, flip_horizontally, flip_vertically);
+    g_object_unref(field);
 
-    if (mfield) {
-        gwy_field_flip(mfield, flip_horizontally, flip_vertically);
-        g_object_unref(mfield);
+    if (mask) {
+        gwy_nield_flip(mask, flip_horizontally, flip_vertically);
+        g_object_unref(mask);
     }
 
     gwy_log_add_import(file, GWY_FILE_IMAGE, *id, NULL, filename);
@@ -767,35 +767,35 @@ add_metadata(gpointer hkey,
 
     t = g_strsplit(key, ">", 0);
     key = g_strjoinv("::", t);
-    gwy_container_set_const_string_by_name(GWY_CONTAINER(user_data), key, value);
+    gwy_dict_set_const_string_by_name(GWY_DICT(user_data), key, value);
     g_free(key);
     g_strfreev(t);
 }
 
-static GwyContainer*
-sxm_build_meta(const SXMFile *sxmfile,
-               G_GNUC_UNUSED guint id)
+static GwyDict*
+build_meta(const SXMFile *sxmfile,
+           G_GNUC_UNUSED guint id)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     GHashTable *hash = sxmfile->meta;
     const gchar *value;
 
     if ((value = g_hash_table_lookup(hash, "COMMENT")))
-        gwy_container_set_const_string_by_name(meta, "Comment", value);
+        gwy_dict_set_const_string_by_name(meta, "Comment", value);
     if ((value = g_hash_table_lookup(hash, "REC_DATE")))
-        gwy_container_set_const_string_by_name(meta, "Date", value);
+        gwy_dict_set_const_string_by_name(meta, "Date", value);
     if ((value = g_hash_table_lookup(hash, "REC_TIME")))
-        gwy_container_set_const_string_by_name(meta, "Time", value);
+        gwy_dict_set_const_string_by_name(meta, "Time", value);
     if ((value = g_hash_table_lookup(hash, "REC_TEMP")))
-        gwy_container_set_string_by_name(meta, "Temperature", reformat_float("%g K", value));
+        gwy_dict_set_string_by_name(meta, "Temperature", reformat_float("%g K", value));
     if ((value = g_hash_table_lookup(hash, "ACQ_TIME")))
-        gwy_container_set_string_by_name(meta, "Acquistion time", reformat_float("%g s", value));
+        gwy_dict_set_string_by_name(meta, "Acquistion time", reformat_float("%g s", value));
     if ((value = g_hash_table_lookup(hash, "SCAN_FILE")))
-        gwy_container_set_const_string_by_name(meta, "File name", value);
+        gwy_dict_set_const_string_by_name(meta, "File name", value);
     if ((value = g_hash_table_lookup(hash, "BIAS")))
-        gwy_container_set_string_by_name(meta, "Bias", reformat_float("%g V", value));
+        gwy_dict_set_string_by_name(meta, "Bias", reformat_float("%g V", value));
     if ((value = g_hash_table_lookup(hash, "SCAN_DIR")))
-        gwy_container_set_const_string_by_name(meta, "Direction", value);
+        gwy_dict_set_const_string_by_name(meta, "Direction", value);
 
     if (sxmfile->z_controller_headers && sxmfile->z_controller_values) {
         gchar **cvalues = sxmfile->z_controller_values;
@@ -804,14 +804,14 @@ sxm_build_meta(const SXMFile *sxmfile,
 
         for (i = 0; cheaders[i] && cvalues[i]; i++) {
             gchar *key = g_strconcat("Z controller ", cheaders[i], NULL);
-            gwy_container_set_const_string_by_name(meta, key, cvalues[i]);
+            gwy_dict_set_const_string_by_name(meta, key, cvalues[i]);
             g_free(key);
         }
     }
 
     g_hash_table_foreach(hash, add_metadata, meta);
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
