@@ -1,6 +1,6 @@
 /*
- *  $Id: nanoobserver.c 28848 2025-11-10 18:54:08Z yeti-dn $
- *  Copyright (C) 2012-2015 David Necas (Yeti).
+ *  $Id: nanoobserver.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2012-2026 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
  *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
@@ -121,7 +121,7 @@ typedef struct {
     GArray *streams;
     GArray *spectra;
     GHashTable *hash;
-    GwyContainer *meta;
+    GwyDict *meta;
     /* Workspace */
     GString *path;
     gchar *current_name;
@@ -151,11 +151,12 @@ static GwyFile*     nao133_spectro_load     (GwyZipFile zipfile,
 static void         add_meta                (gpointer hkey,
                                              gpointer hvalue,
                                              gpointer user_data);
-static GwyField*    nao_read_field          (GwyZipFile zipfile,
+static GwyField*    read_field              (GwyZipFile zipfile,
                                              NAOFile *naofile,
                                              guint id,
+                                             GwyNield **pmask,
                                              GError **error);
-static gboolean     nao_parse_xml_header    (GwyZipFile zipfile,
+static gboolean     parse_xml_header        (GwyZipFile zipfile,
                                              NAOFile *naofile,
                                              const gchar *filename,
                                              GMarkupParser *parser,
@@ -164,7 +165,8 @@ static gboolean     nao133_parse_spectrum   (GwyZipFile zipfile,
                                              NAOSpectrum *spectrum,
                                              GError **error);
 static void         create_channel          (NAOFile *naofile,
-                                             GwyField *dfield,
+                                             GwyField *field,
+                                             GwyNield *mask,
                                              NAOStream *stream,
                                              guint channelno,
                                              GwyFile *file);
@@ -186,15 +188,15 @@ static gboolean     find_spectrum_abscissa  (NAOSpectrum *spectrum,
 static const gchar* find_attribute          (const gchar **attribute_names,
                                              const gchar **attribute_values,
                                              const gchar *attrname);
-static void         nao_file_free           (NAOFile *naofile);
-static void         nao_free_spectrum       (NAOSpectrum *spectrum);
+static void         free_nao_file           (NAOFile *naofile);
+static void         free_spectrum           (NAOSpectrum *spectrum);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Reads Nano-Solution/NanoObserver .nao files."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.3",
     "David Nečas (Yeti)",
     "2012",
 };
@@ -377,7 +379,7 @@ load_file(const gchar *filename,
     }
 
     gwyzip_close(zipfile);
-    nao_file_free(&naofile);
+    free_nao_file(&naofile);
 
     return file;
 }
@@ -385,59 +387,88 @@ load_file(const gchar *filename,
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    gwy_container_set_const_string_by_name(GWY_CONTAINER(user_data), (gchar *)hkey, (gchar *)hvalue);
+    gwy_dict_set_const_string_by_name(GWY_DICT(user_data), (gchar *)hkey, (gchar *)hvalue);
 }
 
 static GwyField*
-nao_read_field(GwyZipFile zipfile, NAOFile *naofile, guint id, GError **error)
+read_field(GwyZipFile zipfile, NAOFile *naofile, guint id, GwyNield **pmask,
+           GError **error)
 {
-    gsize size, expected_size;
-    guint width, G_GNUC_UNUSED height, nscanlines, i;
+    gsize size;
     guchar *buffer;
-    const guchar *p;
-    const gchar *units;
-    GwyField *field;
-    gdouble *data;
 
     if (!(buffer = gwyzip_get_file_content(zipfile, &size, error)))
         return NULL;
 
     if (size < 3*4 + 4 + 4) {
-        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA, _("Data block is truncated"));
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("Data block is truncated"));
         g_free(buffer);
         return NULL;
     }
 
-    p = buffer;
-    width = gwy_get_guint32_le(&p);
-    height = gwy_get_guint32_le(&p);
-    nscanlines = gwy_get_guint32_le(&p);
+    const guchar *p = buffer;
+    guint width = gwy_get_guint32_le(&p);
+    guint height = gwy_get_guint32_le(&p);
+    guint nscanlines = gwy_get_guint32_le(&p);
     gwy_debug("[%u] %u %u %u", id, width, height, nscanlines);
+    if (!nscanlines) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("There are no valid scan lines."));
+        g_free(buffer);
+        return NULL;
+    }
 
-    expected_size = 3*4 + 4*nscanlines*(width + 1);
+    gsize expected_size = 3*4 + 4*nscanlines*(width + 1);
     if (err_SIZE_MISMATCH(error, expected_size, size, TRUE)) {
         g_free(buffer);
         return NULL;
     }
 
-    field = gwy_field_new(width, nscanlines, naofile->xreal, naofile->yreal*nscanlines/naofile->yres, TRUE);
-    data = gwy_field_get_data(field);
+    GwyField *field = gwy_field_new(width, nscanlines, naofile->xreal, naofile->yreal, TRUE);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
+    gdouble *data = gwy_field_get_data(field);
 
-    for (i = 0; i < nscanlines; i++) {
+    guint firstvalid = height, lastvalid = 0;
+    for (guint i = 0; i < nscanlines; i++) {
         guint lineno = gwy_get_guint32_le(&p);
 
-        lineno = MIN(lineno, nscanlines-1);
-        gwy_convert_raw_data(p, width, 1, GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN,
-                             data + (nscanlines-1 - lineno)*width, 1.0, 0.0);
+        gwy_debug("scan line %u (flipped)", lineno);
+        if (lineno >= height)
+            g_warning("Scan line number %u larger outside [0, %u].", lineno, height-1);
+        else {
+            /* Flip image vertically. */
+            lineno = height-1 - lineno;
+            gwy_convert_raw_data(p, width, 1, GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN,
+                                 data + lineno*width, 1.0, 0.0);
+            gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, lineno, width, 1, 1);
+            firstvalid = MIN(firstvalid, lineno);
+            lastvalid = MAX(lastvalid, lineno);
+        }
         p += width*sizeof(gfloat);
     }
 
     g_free(buffer);
 
+    if (lastvalid < firstvalid) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("There are no valid scan lines."));
+        g_object_unref(field);
+        g_object_unref(mask);
+        return NULL;
+    }
+
+    gwy_debug("valid lines [%u..%u]", firstvalid, lastvalid);
+    guint cutheight = lastvalid+1 - firstvalid;
+    gwy_field_crop(field, 0, firstvalid, width, cutheight);
+    gwy_nield_crop(mask, 0, firstvalid, width, cutheight);
+    gwy_nield_invert(mask);
+    *pmask = gwy_remove_bad_image_data(field, mask);
+
     /* Older versions of the format had human-readable units there but we disregard these. */
-    units = g_array_index(naofile->streams, NAOStream, id).units;
-    gwy_unit_set_from_string(gwy_field_get_unit_z(field), units);
+    const gchar *units = g_array_index(naofile->streams, NAOStream, id).units;
     gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), units);
 
     return field;
 }
@@ -529,7 +560,7 @@ nao123_load(GwyZipFile zipfile, NAOFile *naofile, GError **error)
     guint len, id, channelno = 0;
     gboolean status;
 
-    if (!nao_parse_xml_header(zipfile, naofile, "Scan/Measure.xml", &parser, error))
+    if (!parse_xml_header(zipfile, naofile, "Scan/Measure.xml", &parser, error))
         goto fail;
 
     status = gwyzip_first_file(zipfile, error);
@@ -556,10 +587,11 @@ nao123_load(GwyZipFile zipfile, NAOFile *naofile, GError **error)
                     break;
             }
             if (stream->dir) {
-                GwyField *dfield = nao_read_field(zipfile, naofile, id, error);
-                if (!dfield)
+                GwyNield *mask = NULL;
+                GwyField *field = read_field(zipfile, naofile, id, &mask, error);
+                if (!field)
                     goto fail;
-                create_channel(naofile, dfield, stream, channelno, file);
+                create_channel(naofile, field, mask, stream, channelno, file);
                 channelno++;
             }
         }
@@ -568,7 +600,7 @@ nao123_load(GwyZipFile zipfile, NAOFile *naofile, GError **error)
     }
 
 fail:
-    if (!file || !gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!file || !gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         if (error && !*error)
             err_NO_DATA(error);
@@ -728,22 +760,23 @@ nao133_imaging_load(GwyZipFile zipfile, NAOFile *naofile, GError **error)
         NULL,
     };
     GwyFile *file = NULL;
-    GwyField *dfield;
     guint id;
 
-    if (!nao_parse_xml_header(zipfile, naofile, "Data/Imaging.xml", &parser, error))
+    if (!parse_xml_header(zipfile, naofile, "Data/Imaging.xml", &parser, error))
         goto fail;
 
     file = gwy_file_new_in_construction();
     for (id = 0; id < naofile->streams->len; id++) {
         NAOStream *stream = &g_array_index(naofile->streams, NAOStream, id);
+        GwyField *field;
+        GwyNield *mask;
 
         if (!gwyzip_locate_file(zipfile, stream->filename, 1, error))
             goto fail;
-        if (!(dfield = nao_read_field(zipfile, naofile, id, error)))
+        if (!(field = read_field(zipfile, naofile, id, &mask, error)))
             goto fail;
 
-        create_channel(naofile, dfield, stream, id, file);
+        create_channel(naofile, field, mask, stream, id, file);
     }
 
     for (id = 0; id < naofile->spectra->len; id++) {
@@ -759,7 +792,7 @@ nao133_imaging_load(GwyZipFile zipfile, NAOFile *naofile, GError **error)
     }
     create_spectra(naofile, file);
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         err_NO_DATA(error);
         goto fail;
     }
@@ -829,9 +862,9 @@ fail:
 }
 
 static gboolean
-nao_parse_xml_header(GwyZipFile zipfile, NAOFile *naofile,
-                     const gchar *filename, GMarkupParser *parser,
-                     GError **error)
+parse_xml_header(GwyZipFile zipfile, NAOFile *naofile,
+                 const gchar *filename, GMarkupParser *parser,
+                 GError **error)
 {
     GMarkupParseContext *context = NULL;
     guchar *content = NULL, *s;
@@ -866,7 +899,7 @@ nao_parse_xml_header(GwyZipFile zipfile, NAOFile *naofile,
     ok = TRUE;
 
     if (g_hash_table_size(naofile->hash)) {
-        naofile->meta = gwy_container_new_in_construction();
+        naofile->meta = gwy_dict_new_in_construction();
         g_hash_table_foreach(naofile->hash, &add_meta, naofile->meta);
     }
 
@@ -1048,28 +1081,27 @@ fail:
     if (context)
         g_markup_parse_context_free(context);
     if (!ok)
-        nao_free_spectrum(spectrum);
+        free_spectrum(spectrum);
     g_free(content);
 
     return ok;
 }
 
 static void
-create_channel(NAOFile *naofile, GwyField *dfield,
+create_channel(NAOFile *naofile,
+               GwyField *field, GwyNield *mask,
                NAOStream *stream, guint channelno, GwyFile *file)
 {
-    GwyContainer *meta;
-    gchar *title;
+    gwy_file_pass_image(file, channelno, field);
 
-    gwy_file_pass_image(file, channelno, dfield);
-
-    title = g_strconcat(stream->name, " ", stream->dir, NULL);
+    gchar *title = g_strconcat(stream->name, " ", stream->dir, NULL);
     gwy_file_pass_title(file, GWY_FILE_IMAGE, channelno, title);
 
-    if (naofile->meta) {
-        meta = gwy_container_copy(naofile->meta);
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, channelno, meta);
-    }
+    if (naofile->meta)
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, channelno, gwy_dict_copy(naofile->meta));
+    if (mask)
+        gwy_file_pass_image_mask(file, channelno, mask);
+
     gwy_log_add_import(file, GWY_FILE_IMAGE, channelno, NULL, naofile->filename);
 }
 
@@ -1078,14 +1110,14 @@ create_channel(NAOFile *naofile, GwyField *dfield,
 static void
 create_spectra(NAOFile *naofile, GwyFile *file)
 {
-    GwyField *dfield = NULL;
+    GwyField *field = NULL;
     GPtrArray *sps;
     guint i, j, id;
 
     if (!naofile->spectra || !naofile->spectra->len)
         return;
 
-    if (!(dfield = gwy_file_get_image(file, 0))) {
+    if (!(field = gwy_file_get_image(file, 0))) {
         g_warning("Cannot convert spectra pixel coordinates to real because there is no image.");
     }
 
@@ -1098,9 +1130,9 @@ create_spectra(NAOFile *naofile, GwyFile *file)
         if (!spectrum->specdata)
             continue;
 
-        if (dfield) {
-            spectrum->x = gwy_field_jtor(dfield, spectrum->x + 0.5);
-            spectrum->y = gwy_field_itor(dfield, dfield->yres - 0.5 - spectrum->y);
+        if (field) {
+            spectrum->x = gwy_field_jtor(field, spectrum->x + 0.5);
+            spectrum->y = gwy_field_itor(field, field->yres - 0.5 - spectrum->y);
         }
 
         xtitle = g_hash_table_lookup(spectrum->hash, "SweepSignal");
@@ -1277,7 +1309,7 @@ find_attribute(const gchar **attribute_names, const gchar **attribute_values,
 }
 
 static void
-nao_file_free(NAOFile *naofile)
+free_nao_file(NAOFile *naofile)
 {
     guint i;
 
@@ -1295,7 +1327,7 @@ nao_file_free(NAOFile *naofile)
     if (naofile->spectra) {
         GArray *spectra = naofile->spectra;
         for (i = 0; i < spectra->len; i++)
-            nao_free_spectrum(&g_array_index(spectra, NAOSpectrum, i));
+            free_spectrum(&g_array_index(spectra, NAOSpectrum, i));
         g_array_free(naofile->spectra, TRUE);
     }
     if (naofile->hash) {
@@ -1312,7 +1344,7 @@ nao_file_free(NAOFile *naofile)
 }
 
 static void
-nao_free_spectrum(NAOSpectrum *spectrum)
+free_spectrum(NAOSpectrum *spectrum)
 {
     guint j;
 
