@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscan.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: nanoscan.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -182,7 +182,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports NanoScan XML files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.10",
+    "0.11",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -353,9 +353,8 @@ add_channel(GwyFile *file,
             NanoScanChannel *channel,
             gint id)
 {
-    GwyField *dfield, *mask = NULL;
+    GwyField *field;
     GwyUnit *unit;
-    gdouble *d;
     gchar *title;
     gdouble yreal, q = 1.0;
     gint nrows, i, power10;
@@ -363,41 +362,38 @@ add_channel(GwyFile *file,
     nrows = (channel->ndata + nfile->xres-1)/nfile->xres;
     gwy_debug("nrows %d, yres %d", nrows, nfile->yres);
     yreal = nfile->yreal*nrows/nfile->yres;
-    dfield = gwy_field_new(nfile->xres, nrows, nfile->xreal, yreal, FALSE);
+    field = gwy_field_new(nfile->xres, nrows, nfile->xreal, yreal, FALSE);
     if (nfile->xyunits) {
-        unit = gwy_field_get_unit_xy(dfield);
+        unit = gwy_field_get_unit_xy(field);
         power10 = gwy_unit_set_from_string(unit, nfile->xyunits);
-        gwy_field_set_xreal(dfield, gwy_exp10(power10)*nfile->xreal);
-        gwy_field_set_yreal(dfield, gwy_exp10(power10)*yreal);
+        gwy_field_set_xreal(field, gwy_exp10(power10)*nfile->xreal);
+        gwy_field_set_yreal(field, gwy_exp10(power10)*yreal);
     }
     if (channel->zunits) {
-        unit = gwy_field_get_unit_z(dfield);
+        unit = gwy_field_get_unit_z(field);
         power10 = gwy_unit_set_from_string(unit, channel->zunits);
         q = gwy_exp10(power10);
     }
 
-    d = gwy_field_get_data(dfield);
+    gdouble *d = gwy_field_get_data(field);
     for (i = 0; i < channel->ndata; i++)
         d[i] = q*channel->data[i];
-    gwy_field_flip(dfield, FALSE, TRUE);
+    gwy_field_flip(field, FALSE, TRUE);
 
     /* Create a mask that is the union of invalid and missing values. */
-    mask = gwy_app_channel_mask_of_nans(dfield, FALSE);
+    GwyNield *mask = gwy_mask_nans_in_field(field, FALSE);
     if (channel->ndata % nfile->xres != 0) {
         if (!mask)
-            mask = gwy_field_new_alike(dfield, TRUE);
+            mask = gwy_field_new_nield_alike(field);
 
-        d = gwy_field_get_data(mask);
+        gint *m = gwy_nield_get_data(mask);
         for (i = channel->ndata; i < nfile->xres*nrows; i++)
-            d[i] = 1.0;
+            m[i] = 1;
     }
 
-    if (mask) {
-        gwy_field_grains_invert(mask);
-        gwy_app_channel_remove_bad_data(dfield, mask);
-    }
+    mask = gwy_remove_bad_image_data(field, mask);
 
-    gwy_file_pass_image(file, id, dfield);
+    gwy_file_pass_image(file, id, field);
     if (mask)
         gwy_file_pass_image_mask(file, id, mask);
 
@@ -633,18 +629,18 @@ add_metadata(GwyFile *file,
              NanoScanFile *nfile,
              gint id)
 {
-    GwyContainer *metadata;
+    GwyDict *metadata;
     guint i;
 
     if (!nfile->meta->len)
         return;
 
-    metadata = gwy_container_new_in_construction();
+    metadata = gwy_dict_new_in_construction();
     for (i = 0; i < nfile->meta->len; i++) {
         NanoScanMeta *meta = &g_array_index(nfile->meta, NanoScanMeta, i);
 
         if (meta->value)
-            gwy_container_set_const_string_by_name(metadata, meta->name, meta->value);
+            gwy_dict_set_const_string_by_name(metadata, meta->name, meta->value);
     }
 
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, metadata);
