@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscantech.c 28803 2025-11-05 11:58:19Z yeti-dn $
+ *  $Id: nanoscantech.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2012-2025 David Necas (Yeti), Daniil Bratashov (dn2010).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -104,7 +104,7 @@ static GwyFile*       load_file      (const gchar *filename,
 static GwyField*      nst_read_3d    (const gchar *buffer,
                                       gsize size,
                                       gboolean is_utf,
-                                      GwyContainer **metadata,
+                                      GwyDict **metadata,
                                       gchar **title);
 static GwyGraphModel* nst_read_2d    (const gchar *buffer,
                                       guint channel,
@@ -112,7 +112,7 @@ static GwyGraphModel* nst_read_2d    (const gchar *buffer,
 static GwyBrick*      nst_read_4d    (const gchar *buffer,
                                       gsize datasize,
                                       gboolean is_utf,
-                                      GwyContainer **metadata,
+                                      GwyDict **metadata,
                                       gchar **title);
 
 static GwyModuleInfo module_info = {
@@ -175,7 +175,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *metadata = NULL;
+    GwyDict *metadata = NULL;
     GwyField *dfield;
     GwyGraphModel *gmodel;
     GwyBrick *brick;
@@ -291,10 +291,10 @@ decode_string(const gchar *s, gboolean is_utf)
 
 static GwyField *
 nst_read_3d(const gchar *buffer, gsize size, gboolean is_utf,
-            GwyContainer **metadata, gchar **title)
+            GwyDict **metadata, gchar **title)
 {
     GwyField *dfield = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyUnit *siunitxy = NULL, *siunitz = NULL;
     gchar *p, *line, *unit, *key, *value;
     gchar **lineparts, **attributes;
@@ -310,7 +310,7 @@ nst_read_3d(const gchar *buffer, gsize size, gboolean is_utf,
 
     p = (gchar*)buffer;
     dataarray = g_array_new(FALSE, TRUE, sizeof(gdouble));
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     while ((line = gwy_str_next_line(&p))) {
         if (gwy_strequal(line, "[BeginOfItem]")) {
             if (is_binary) {
@@ -410,7 +410,7 @@ nst_read_3d(const gchar *buffer, gsize size, gboolean is_utf,
                 key = decode_string(key, is_utf);
                 value = decode_string(value, is_utf);
                 gwy_debug("%s: %s", key, value);
-                gwy_container_set_const_string_by_name(meta, key, value);
+                gwy_dict_set_const_string_by_name(meta, key, value);
 
                 if (g_str_has_prefix(key, "Name")) {
                     if (!*title)
@@ -655,10 +655,10 @@ fail:
 
 static GwyBrick*
 nst_read_4d(const gchar *buffer, gsize datasize, gboolean is_utf,
-            GwyContainer **metadata, gchar **title)
+            GwyDict **metadata, gchar **title)
 {
     GwyBrick *brick = NULL, *brick_cropped = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyLine *calibration = NULL;
     NST4DHeader *header = NULL;
     guint xres, yres, zres, zcrop;
@@ -800,7 +800,7 @@ nst_read_4d(const gchar *buffer, gsize datasize, gboolean is_utf,
             break;
         }
         else if (g_str_has_prefix(line, "Attributes")) {
-            meta = gwy_container_new_in_construction();
+            meta = gwy_dict_new_in_construction();
             if (!(lineparts = split_to_nparts(line, " ", 2)))
                 goto exit;
             attributes = g_strsplit(lineparts[1], "*_*|^_^", 1024);
@@ -810,7 +810,7 @@ nst_read_4d(const gchar *buffer, gsize datasize, gboolean is_utf,
                 key = decode_string(key, is_utf);
                 value = decode_string(value, is_utf);
                 gwy_debug("%s: %s", key, value);
-                gwy_container_set_const_string_by_name(meta, key, value);
+                gwy_dict_set_const_string_by_name(meta, key, value);
 
                 if (g_str_has_prefix(key, "Name")) {
                     if (!*title)
