@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscope-ii.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: nanoscope-ii.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -70,7 +70,7 @@ static GwyField*     hash_to_field         (GHashTable *hash,
                                             GError **error);
 static GHashTable*   read_hash             (gchar *buffer,
                                             GError **error);
-static GwyContainer* nanoscope_get_metadata(GHashTable *hash);
+static GwyDict* nanoscope_get_metadata(GHashTable *hash);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -116,7 +116,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield;
     GError *err = NULL;
     guchar *buffer = NULL;
@@ -249,7 +249,7 @@ read_hash(gchar *buffer,
     return hash;
 }
 
-static GwyContainer*
+static GwyDict*
 nanoscope_get_metadata(GHashTable *hash)
 {
     static const struct {
@@ -263,16 +263,16 @@ nanoscope_get_metadata(GHashTable *hash)
         { "time", "Date", NULL },
     };
 
-    GwyContainer *meta;
+    GwyDict *meta;
     const gchar *val;
     guint i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     for (i = 0; i < G_N_ELEMENTS(metadata); i++) {
         if ((val = g_hash_table_lookup(hash, metadata[i].key)))
-            gwy_container_set_string_by_name(meta, metadata[i].name, g_strconcat(val, metadata[i].unit, NULL));
+            gwy_dict_set_string_by_name(meta, metadata[i].name, g_strconcat(val, metadata[i].unit, NULL));
     }
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
