@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscope.c 29065 2026-01-02 15:31:11Z yeti-dn $
+ *  $Id: nanoscope.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -233,7 +233,7 @@ static guint           get_samples_per_curve  (GHashTable *hash,
                                                GHashTable *forcelist,
                                                guint *hold_samples,
                                                guint *retract_samples);
-static GwyContainer*   nanoscope_get_metadata (GHashTable *hash,
+static GwyDict*        get_metadata           (GHashTable *hash,
                                                GList *list);
 static NanoscopeValue* parse_value            (const gchar *key,
                                                gchar *line);
@@ -302,7 +302,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GError *err = NULL;
     guchar *buffer = NULL;
     gchar *header = NULL, *p;
@@ -566,7 +566,7 @@ load_file(const gchar *filename,
                 if ((name = get_image_data_name(ndata->hash)))
                     gwy_file_set_title(file, GWY_FILE_IMAGE, i, name, FALSE);
 
-                meta = nanoscope_get_metadata(ndata->hash, list);
+                meta = get_metadata(ndata->hash, list);
                 gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, meta);
 
                 gwy_check_nonsquare_image(file, i);
@@ -705,22 +705,21 @@ add_metadata(gpointer hkey, gpointer hvalue, gpointer user_data)
         g_free(v);
         v = w;
     }
-    gwy_container_set_string_by_name(GWY_CONTAINER(user_data), key, v);
+    gwy_dict_set_string_by_name(GWY_DICT(user_data), key, v);
 }
 
 /* FIXME: This is a bit simplistic */
-static GwyContainer*
-nanoscope_get_metadata(GHashTable *hash,
-                       GList *list)
+static GwyDict*
+get_metadata(GHashTable *hash, GList *list)
 {
     static const gchar *hashes[] = {
         "File list", "EC File list", "Scanner list", "Equipment list", "Ciao scan list",
     };
-    GwyContainer *meta;
+    GwyDict *meta;
     GList *l;
     guint i;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     for (l = list; l; l = g_list_next(l)) {
         GHashTable *h = ((NanoscopeData*)l->data)->hash;
