@@ -1,5 +1,5 @@
 /*
- *  $Id: nanosystemz.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: nanosystemz.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2018-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -81,7 +81,7 @@ static gsize         read_header    (NanosystemzHeader *header,
                                      GError **error);
 static void          header_free    (NanosystemzHeader *header);
 static gboolean      check_datetime (const NanosystemzHeader *header);
-static GwyContainer* create_meta    (const NanosystemzHeader *header);
+static GwyDict* create_meta    (const NanosystemzHeader *header);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -151,7 +151,6 @@ load_file(const gchar *filename,
     gsize imagesize, masksize, n, hlen, size = 0;
     GError *err = NULL;
     NanosystemzHeader header;
-    GwyField *dfield, *mask;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -178,17 +177,17 @@ load_file(const gchar *filename,
         goto fail;
 
     file = gwy_file_new_in_construction();
-    dfield = gwy_field_new(header.xres, header.yres,
-                           header.xres*header.dx, header.yres*header.dy,
-                           FALSE);
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    mask = gwy_field_new_alike(dfield, FALSE);
+    GwyField *field = gwy_field_new(header.xres, header.yres,
+                                    header.xres*header.dx, header.yres*header.dy,
+                                    FALSE);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    GwyNield *mask = gwy_field_new_nield_alike(field);
 
     gwy_convert_raw_data(buffer + hlen, n, 1, GWY_RAW_DATA_FLOAT, G_LITTLE_ENDIAN,
-                         gwy_field_get_data(dfield), 1e-6, 0.0);
-    gwy_field_flip(dfield, FALSE, TRUE);
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), "m");
-    gwy_file_pass_image(file, 0, dfield);
+                         gwy_field_get_data(field), 1e-6, 0.0);
+    gwy_field_flip(field, FALSE, TRUE);
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
+    gwy_file_pass_image(file, 0, field);
 
     /* FIXME: I see values
      * - 1 for good data
@@ -196,10 +195,10 @@ load_file(const gchar *filename,
      * - 8 for some kind of bad data (PSI and WSIE)
      * Or something like that.  The probably correspond to some bits set -- masking anything that is not equal to
      * 1 (presumably good data) seems reasonable. */
-    gwy_convert_raw_data(buffer + hlen + imagesize, n, 1,
-                         GWY_RAW_DATA_UINT8, G_LITTLE_ENDIAN,
-                         gwy_field_get_data(mask), 1.0, -1.0);
-    gwy_field_flip(mask, FALSE, TRUE);
+    gint *m = gwy_nield_get_data(mask);
+    for (gsize k = 0; k < n; k++)
+        m[k] = (buffer[hlen + imagesize + k] != 1);
+    gwy_nield_flip(mask, FALSE, TRUE);
     gwy_file_pass_image_mask(file, 0, mask);
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, create_meta(&header));
     gwy_image_title_fall_back(file, 0);
@@ -313,30 +312,30 @@ check_datetime(const NanosystemzHeader *header)
     return TRUE;
 }
 
-static GwyContainer*
+static GwyDict*
 create_meta(const NanosystemzHeader *header)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     const gchar *s;
     gchar *v;
 
     if ((s = header->comment))
-        gwy_container_set_const_string_by_name(meta, "Comment", s);
+        gwy_dict_set_const_string_by_name(meta, "Comment", s);
     if ((s = header->datetime))
-        gwy_container_set_const_string_by_name(meta, "Date and Time", s);
+        gwy_dict_set_const_string_by_name(meta, "Date and Time", s);
     if ((s = header->setup))
-        gwy_container_set_const_string_by_name(meta, "Setup", s);
+        gwy_dict_set_const_string_by_name(meta, "Setup", s);
     if ((s = header->string1))
-        gwy_container_set_const_string_by_name(meta, "String1", s);
+        gwy_dict_set_const_string_by_name(meta, "String1", s);
 
     v = g_strdup_printf("%g", header->scale);
-    gwy_container_set_string_by_name(meta, "Value1", v);
+    gwy_dict_set_string_by_name(meta, "Value1", v);
 
     v = g_strdup_printf("%.1f nm", header->dx/1e-9);
-    gwy_container_set_string_by_name(meta, "Pixel size X", v);
+    gwy_dict_set_string_by_name(meta, "Pixel size X", v);
 
     v = g_strdup_printf("%.1f nm", header->dy/1e-9);
-    gwy_container_set_string_by_name(meta, "Pixel size Y", v);
+    gwy_dict_set_string_by_name(meta, "Pixel size Y", v);
 
     return meta;
 }
