@@ -1,5 +1,5 @@
 /*
- *  $Id: netcdf.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: netcdf.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek, Niv Levy.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, nivl2000@gmail.com.
  *
@@ -156,8 +156,8 @@ static GwyBrick*         read_brick      (const guchar *buffer,
                                           gint yres,
                                           gint zres,
                                           NetCDFType type);
-static GwyContainer*     create_meta     (const NetCDF cdffile);
-static void              add_size_to_meta(GwyContainer* meta,
+static GwyDict*     create_meta     (const NetCDF cdffile);
+static void              add_size_to_meta(GwyDict* meta,
                                           GwyField* dfield);
 
 static GwyModuleInfo module_info = {
@@ -232,7 +232,7 @@ load_file(const gchar *filename,
 {
     static const gchar *dimensions[] = { "time", "value", "dimy", "dimx" };
     GwyFile *data = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyField *dfield;
     GwyBrick *dbrick;
     GwyUnit *siunit;
@@ -383,17 +383,17 @@ load_file(const gchar *filename,
                 gwy_brick_flip(dbrick, FALSE, FALSE, TRUE);
                 real = -real;
                 offset = values[dim_value-1];
-                gwy_container_set_const_string_by_name(meta, "Z flipped", "True");
-                gwy_container_set_string_by_name(meta, "Z values",
-                                                 g_strdup_printf("%g, %g... %g",
-                                                                 values[dim_value-1], values[dim_value-2], values[0]));
+                gwy_dict_set_const_string_by_name(meta, "Z flipped", "True");
+                gwy_dict_set_string_by_name(meta, "Z values",
+                                            g_strdup_printf("%g, %g... %g",
+                                                            values[dim_value-1], values[dim_value-2], values[0]));
             }
             else {
                 offset = values[0];
-                gwy_container_set_const_string_by_name(meta, "Z flipped", "False");
-                gwy_container_set_string_by_name(meta, "Z values",
-                                                 g_strdup_printf("%g, %g... %g",
-                                                                 values[0], values[1], values[dim_value-1]));
+                gwy_dict_set_const_string_by_name(meta, "Z flipped", "False");
+                gwy_dict_set_string_by_name(meta, "Z values",
+                                            g_strdup_printf("%g, %g... %g",
+                                                            values[0], values[1], values[dim_value-1]));
             }
 
             gwy_brick_set_zoffset(dbrick, offset);
@@ -488,18 +488,18 @@ load_file(const gchar *filename,
                 gwy_debug("gxsm netcdf: flip data field since basename contains '-Xm-' and not '-Xp-'");
                 g_warning("netcdf brick: inverting across y");
                 gwy_brick_flip(dbrick, FALSE, TRUE, FALSE);
-                gwy_container_set_const_string_by_name(meta, "Fast scan", "right to left");
+                gwy_dict_set_const_string_by_name(meta, "Fast scan", "right to left");
             }
             else {
                 /* just assume it left to right (default scan direction) in this case */
-                gwy_container_set_const_string_by_name(meta, "Fast scan", "left to right");
+                gwy_dict_set_const_string_by_name(meta, "Fast scan", "left to right");
             }
         }
 
         // Add the 2D preview. We do not have to do it manually nowadays, but we use the field below.
         dfield = gwy_field_new(1, 1, 1.0, 1.0, FALSE);
         gwy_brick_mean_xy_plane(dbrick, dfield);
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(0), dfield);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_volume_picture(0), dfield);
         if ((attr = get_attr(field_var->attrs, field_var->nattrs, "long_name"))
             && attr->type == NC_CHAR
             && attr->nelems) {
@@ -595,19 +595,19 @@ load_file(const gchar *filename,
                         gwy_debug("gxsm netcdf: data field since basename contains '-Xm-' and not '-Xp-'");
                         // flip horizontally
                         gwy_field_flip(dfield, TRUE, FALSE);
-                        gwy_container_set_const_string_by_name(meta, "Fast scan", "right to left");
+                        gwy_dict_set_const_string_by_name(meta, "Fast scan", "right to left");
                     }
                     else {
                         /* just assume it left to right (default scan direction) in this case */
-                        gwy_container_set_const_string_by_name(meta, "Fast scan", "left to right");
+                        gwy_dict_set_const_string_by_name(meta, "Fast scan", "left to right");
                     }
                 }
 
                 if (dim_value > 1)
-                    gwy_container_set_string_by_name(meta, "layer value", g_strdup_printf("%5.2f", values[value_i]));
+                    gwy_dict_set_string_by_name(meta, "layer value", g_strdup_printf("%5.2f", values[value_i]));
 
                 if (dim_time > 1)
-                    gwy_container_set_string_by_name(meta, "time", g_strdup_printf("%5.2f", times[time_i]));
+                    gwy_dict_set_string_by_name(meta, "time", g_strdup_printf("%5.2f", times[time_i]));
 
                 gwy_file_pass_meta(data, GWY_FILE_IMAGE, frame_i, meta);
                 meta = NULL;
@@ -748,56 +748,56 @@ read_brick(const guchar *buffer,
     return brick;
 }
 
-static GwyContainer*
+static GwyDict*
 create_meta(const NetCDF cdffile)
 {
-    GwyContainer *meta;
+    GwyDict *meta;
     const NetCDFVar *var;
     GwyUnit* siunit;
     gdouble real;
     gint power10;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     if ((var = get_var(&cdffile, "comment"))) {
         /* not sure if this would be a valid string, so create a new one with
          * fixed length */
-        gwy_container_set_string_by_name(meta, "Comments",
+        gwy_dict_set_string_by_name(meta, "Comments",
                                          g_strndup(cdffile.buffer + var->begin, var->vsize));
     }
     if ((var = get_var(&cdffile, "dateofscan"))) {
         /* not sure if this would be a valid string, so create a new one with
          * fixed length */
-        gwy_container_set_string_by_name(meta, "Date and time",
-                                         g_strndup(cdffile.buffer + var->begin, var->vsize));
+        gwy_dict_set_string_by_name(meta, "Date and time",
+                                    g_strndup(cdffile.buffer + var->begin, var->vsize));
     }
     if ((siunit = read_real_size(&cdffile, "time", TRUE, &real, &power10))) {
-        gwy_container_set_string_by_name(meta, "Scan time",
-                                         g_strdup_printf("%5.2f s", real));
+        gwy_dict_set_string_by_name(meta, "Scan time",
+                                    g_strdup_printf("%5.2f s", real));
         g_object_unref(siunit);
     }
     /* NOTE: i know this is bad as it's hardware dependent (i.e. only someone using the sranger 2 dsp gets this); but
      * since these details depend in gxsm on the plugin, i see no better option */
     if ((siunit = read_real_size(&cdffile, "sranger_mk2_hwi_bias", TRUE, &real, &power10))) {
-        gwy_container_set_string_by_name(meta, "V_bias",
-                                         g_strdup_printf("%5.2g V", real*gwy_exp10(power10)));
+        gwy_dict_set_string_by_name(meta, "V_bias",
+                                    g_strdup_printf("%5.2g V", real*gwy_exp10(power10)));
         g_object_unref(siunit);
     }
 
     if ((siunit = read_real_size(&cdffile, "sranger_mk2_hwi_mix0_set_point", TRUE, &real, &power10))) {
-        gwy_container_set_string_by_name(meta, "I_setpoint",
-                                         g_strdup_printf("%5.2g A", real*gwy_exp10(power10)));
+        gwy_dict_set_string_by_name(meta, "I_setpoint",
+                                    g_strdup_printf("%5.2g A", real*gwy_exp10(power10)));
         g_object_unref(siunit);
     }
     else if ((siunit = read_real_size(&cdffile, "sranger_mk2_hwi_mix0_current_set_point", TRUE, &real, &power10))) {
-        gwy_container_set_string_by_name(meta, "I_setpoint",
-                                         g_strdup_printf("%5.2g A", real*gwy_exp10(power10)));
+        gwy_dict_set_string_by_name(meta, "I_setpoint",
+                                    g_strdup_printf("%5.2g A", real*gwy_exp10(power10)));
         g_object_unref(siunit);
     }
 
     if ((var = get_var(&cdffile, "spm_scancontrol"))) {
-        gwy_container_set_string_by_name(meta, "Slow scan",
-                                         g_strndup(cdffile.buffer + var->begin, var->vsize));
+        gwy_dict_set_string_by_name(meta, "Slow scan",
+                                    g_strndup(cdffile.buffer + var->begin, var->vsize));
     }
     return meta;
 }
@@ -805,14 +805,14 @@ create_meta(const NetCDF cdffile)
 
 /* Add the lateral size information to the meta data; used for both brick and field option */
 static void
-add_size_to_meta(GwyContainer* meta, GwyField* dfield)
+add_size_to_meta(GwyDict* meta, GwyField* dfield)
 {
     gchar *unitstr = gwy_unit_get_string(gwy_field_get_unit_xy(dfield), GWY_UNIT_FORMAT_PLAIN);
-    gwy_container_set_string_by_name(meta, "Size",
-                                     g_strdup_printf("%0.2g x %0.2g %s",
-                                                     gwy_field_get_xreal(dfield),
-                                                     gwy_field_get_yreal(dfield),
-                                                     unitstr));
+    gwy_dict_set_string_by_name(meta, "Size",
+                                g_strdup_printf("%0.2g x %0.2g %s",
+                                                gwy_field_get_xreal(dfield),
+                                                gwy_field_get_yreal(dfield),
+                                                unitstr));
     g_free(unitstr);
     /* Should work, but it seems there's a problem when the units are um,
      * so i'm using the simpler, inelegant solution above
@@ -821,16 +821,16 @@ add_size_to_meta(GwyContainer* meta, GwyField* dfield)
      siunit = gwy_field_get_unit_xy(dfield);
      vf = gwy_unit_get_format(siunit, GWY_UNIT_FORMAT_VFMARKUP,
      sqrt(xreal*yreal), NULL);
-     gwy_container_set_string_by_name(meta, "Size",
+     gwy_dict_set_string_by_name(meta, "Size",
      g_strdup_printf("%.*f×%.*f%s%s",
      vf->precision, xreal/vf->magnitude,
      vf->precision, yreal/vf->magnitude,
      (vf->units && *vf->units) ? " " : "", vf->units));
      g_object_unref(siunit);
      gwy_value_format_free(vf);*/
-    gwy_container_set_string_by_name(meta, "Resolution",
-                                     g_strdup_printf("%u x %u",
-                                                     gwy_field_get_xres(dfield), gwy_field_get_yres(dfield)));
+    gwy_dict_set_string_by_name(meta, "Resolution",
+                                g_strdup_printf("%u x %u",
+                                                gwy_field_get_xres(dfield), gwy_field_get_yres(dfield)));
 }
 
 static gboolean
@@ -889,7 +889,7 @@ cdffile_load(NetCDF *cdffile,
 
     /* Variables */
     if (!read_var_array(&cdffile->vars, &cdffile->nvars, cdffile->version,
-                                cdffile->buffer, cdffile->size, &p, error)) {
+                        cdffile->buffer, cdffile->size, &p, error)) {
         cdffile_free(cdffile);
         gwy_file_abandon_contents(cdffile->buffer, cdffile->size, NULL);
         return FALSE;
