@@ -1,5 +1,5 @@
 /*
- *  $Id: nmmxyz.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: nmmxyz.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -153,7 +153,7 @@ static void             rotate_points_xy            (GwyXYZ *points,
                                                      guint ndata,
                                                      gdouble angle);
 static void             create_field                (GwyFile *file,
-                                                     GwyContainer *meta,
+                                                     GwyDict *meta,
                                                      ModuleArgs *args,
                                                      GwyDoubleArray *data,
                                                      GwyXYZ *points,
@@ -174,7 +174,7 @@ static void             free_profile_descriptions   (GArray *dscs,
                                                      gboolean free_array);
 static void             copy_profile_descriptions   (GArray *source,
                                                      GArray *dest);
-static GwyContainer*    parse_dsc_file              (const gchar *filename);
+static GwyDict*    parse_dsc_file              (const gchar *filename);
 static GwyDoubleArray*  gwy_double_array_new        (gsize prealloc);
 static void             gwy_double_array_ensure_size(GwyDoubleArray *array,
                                                      gsize n);
@@ -296,7 +296,7 @@ load_file(const gchar *filename, GwyRunModeFlags mode, GError **error)
     ModuleArgs args;
     GwyParams *params;
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyDialogOutcome outcome;
     GwyParamDef *pardef = NULL;
     GwyDoubleArray *data = NULL;
@@ -387,7 +387,7 @@ load_file(const gchar *filename, GwyRunModeFlags mode, GError **error)
 
     s = NULL;
     align_scanlines = gwy_params_get_boolean(params, PARAM_ALIGN_SCANLINES);
-    if (align_scanlines && meta && gwy_container_gis_string_by_name(meta, "Scan field::Scan angle", &s)) {
+    if (align_scanlines && meta && gwy_dict_gis_string_by_name(meta, "Scan field::Scan angle", &s)) {
         /* The value should be in radians. */
         angle = g_ascii_strtod(s, NULL);
     }
@@ -636,7 +636,7 @@ rotate_points_xy(GwyXYZ *points, guint ndata, gdouble angle)
 
 static void
 create_field(GwyFile *file,
-             GwyContainer *meta,
+             GwyDict *meta,
              ModuleArgs *args,
              GwyDoubleArray *data,
              GwyXYZ *points,
@@ -727,13 +727,13 @@ create_field(GwyFile *file,
     gwy_file_pass_image(file, id, dfield);
 
     if (physically_square)
-        gwy_container_set_boolean(GWY_CONTAINER(file), gwy_file_key_image_real_square(id), TRUE);
+        gwy_dict_set_boolean(GWY_DICT(file), gwy_file_key_image_real_square(id), TRUE);
 
     gwy_file_set_title(file, GWY_FILE_IMAGE, id, dsc->long_name, FALSE);
     gwy_log_add_import(file, GWY_FILE_IMAGE, id, NULL, info->filename);
 
     if (meta) {
-        meta = gwy_container_copy(meta);
+        meta = gwy_dict_copy(meta);
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     }
 
@@ -748,7 +748,7 @@ create_field(GwyFile *file,
     gwy_log_add_import(file, GWY_FILE_IMAGE, id, NULL, info->filename);
 
     if (meta) {
-        meta = gwy_container_copy(meta);
+        meta = gwy_dict_copy(meta);
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     }
 }
@@ -1095,10 +1095,10 @@ copy_profile_descriptions(GArray *source, GArray *dest)
     }
 }
 
-static GwyContainer*
+static GwyDict*
 parse_dsc_file(const gchar *filename)
 {
-    GwyContainer *meta;
+    GwyDict *meta;
     gchar *buffer, *line, *p, *colon, *section = NULL;
     GError *err = NULL;
     GString *str;
@@ -1110,7 +1110,7 @@ parse_dsc_file(const gchar *filename)
         return NULL;
     }
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     str = g_string_new(NULL);
     p = buffer;
     while ((line = gwy_str_next_line(&p))) {
@@ -1126,7 +1126,7 @@ parse_dsc_file(const gchar *filename)
         else if (section && gwy_strequal(section, "Additional comments")) {
             ncom++;
             g_string_printf(str, "%s::%d", section, ncom);
-            gwy_container_set_const_string_by_name(meta, str->str, line);
+            gwy_dict_set_const_string_by_name(meta, str->str, line);
         }
         else if (section && g_str_has_prefix(line, "  ") && (colon = strstr(line, " : "))) {
             gchar *key = line + 2, *value = colon + 3;
@@ -1135,18 +1135,18 @@ parse_dsc_file(const gchar *filename)
             g_strstrip(key);
             g_strstrip(value);
             g_string_printf(str, "%s::%s", section, key);
-            gwy_container_set_const_string_by_name(meta, str->str, value);
+            gwy_dict_set_const_string_by_name(meta, str->str, value);
         }
         else if (g_str_has_prefix(line, "Creation time     :")) {
             gchar *value = line + strlen("Creation time     :");
-            gwy_container_set_const_string_by_name(meta, "Creation time", value);
+            gwy_dict_set_const_string_by_name(meta, "Creation time", value);
         }
     }
 
     g_free(buffer);
     g_string_free(str, TRUE);
 
-    if (!gwy_container_get_n_items(meta))
+    if (!gwy_dict_get_n_items(meta))
         g_clear_object(&meta);
 
     return meta;
