@@ -1,5 +1,5 @@
 /*
- *  $Id: nrrdfile.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: nrrdfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -146,7 +146,7 @@ static GwyBrick*     read_raw_brick      (guint xres,
                                           GwyByteOrder byteorder,
                                           GHashTable *fields,
                                           const guchar *data);
-static GwyContainer* nrrd_make_meta      (GHashTable *keyvalue);
+static GwyDict* nrrd_make_meta      (GHashTable *keyvalue);
 static gboolean      parse_uint_vector   (const gchar *value,
                                           guint n,
                                           ...);
@@ -213,7 +213,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GHashTable *hash, *fields = NULL, *keyvalue = NULL;
     GwyField *dfield = NULL;
     GSList *l, *buffers_to_free = NULL;
@@ -465,7 +465,7 @@ load_file(const gchar *filename,
             if ((value = g_hash_table_lookup(fields, "content")))
                 gwy_file_set_title(file, GWY_FILE_IMAGE, i, value, FALSE);
             if (meta)
-                gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(meta));
+                gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(meta));
             gwy_log_add_import(file, GWY_FILE_IMAGE, i, NULL, filename);
         }
     }
@@ -1320,18 +1320,18 @@ add_meta(gpointer key, gpointer value, gpointer user_data)
 {
     const gchar *strkey = (const gchar*)key;
     const gchar *strvalue = (const gchar*)value;
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
-    gwy_container_set_const_string_by_name(meta, strkey, strvalue);
+    gwy_dict_set_const_string_by_name(meta, strkey, strvalue);
 }
 
-static GwyContainer*
+static GwyDict*
 nrrd_make_meta(GHashTable *keyvalue)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(keyvalue, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
     g_object_unref(meta);
 
