@@ -1,5 +1,5 @@
 /*
- *  $Id: oirfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: oirfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -1113,22 +1113,22 @@ get_meta_or_fail(GHashTable *hash,
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *value = hvalue, *skey = hkey;
 
     if (!*value)
         return;
 
-    gwy_container_set_const_string_by_name(meta, skey, value);
+    gwy_dict_set_const_string_by_name(meta, skey, value);
 }
 
-static GwyContainer*
+static GwyDict*
 make_metadata(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
