@@ -1,5 +1,5 @@
 /*
- *  $Id: omicron.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: omicron.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2006-2025 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -146,7 +146,7 @@ static GwySpectra*   read_cs_data       (OmicronFile *ofile,
 static GwySpectra*   read_be_data       (OmicronFile *ofile,
                                          OmicronSpectroChannel *channel,
                                          GError **error);
-static GwyContainer* make_meta          (OmicronFile *ofile);
+static GwyDict* make_meta          (OmicronFile *ofile);
 static void          free_omicronfile   (OmicronFile *ofile);
 
 static GwyModuleInfo module_info = {
@@ -222,7 +222,7 @@ load_file(const gchar *filename,
 {
     OmicronFile ofile;
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     gchar *text = NULL;
     GError *err = NULL;
     GwyField *dfield = NULL;
@@ -1047,18 +1047,18 @@ add_meta(gpointer key, gpointer value, gpointer user_data)
 {
     const gchar *strkey = (const gchar*)key;
     const gchar *strvalue = (const gchar*)value;
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
-    gwy_container_set_const_string_by_name(meta, strkey, strvalue);
+    gwy_dict_set_const_string_by_name(meta, strkey, strvalue);
 }
 
-static GwyContainer*
+static GwyDict*
 make_meta(OmicronFile *ofile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(ofile->meta, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
     g_object_unref(meta);
 
