@@ -1,5 +1,5 @@
 /*
- *  $Id: omicronflat.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: omicronflat.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2015-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -256,7 +256,7 @@ static gboolean           parse_filename                 (const gchar *filename,
 static gboolean           find_related_files             (const gchar *filename,
                                                           OmicronFlatFileList *filelist,
                                                           GError **error);
-static GwyContainer*      construct_metadata             (OmicronFlatFile *fff,
+static GwyDict*           construct_metadata             (OmicronFlatFile *fff,
                                                           OmicronFlatFileId *id);
 static gboolean           load_as_channel                (OmicronFlatFileList *filelist,
                                                           guint fileid,
@@ -674,7 +674,7 @@ add_filename(GwyFile *file, OmicronFlatFile *fff)
     if (t == s)
         return;
 
-    gwy_container_set_string_by_name(GWY_CONTAINER(file), "/filename", g_strndup(s, (t-s)+1));
+    gwy_dict_set_string_by_name(GWY_DICT(file), "/filename", g_strndup(s, (t-s)+1));
 }
 
 /* Checks if the specified view is present. */
@@ -859,8 +859,9 @@ load_as_channel(OmicronFlatFileList *filelist, guint fileid,
     }
 
     for (i = 0; i < nfields; i++) {
-        GwyField *dfield = field_specs[i].dfield, *mask;
-        GwyContainer *meta;
+        GwyField *dfield = field_specs[i].dfield;
+        GwyNield *mask;
+        GwyDict *meta;
         gchar *title;
 
         /* gwy_field_flip() has a strange XY convention. */
@@ -882,7 +883,7 @@ load_as_channel(OmicronFlatFileList *filelist, guint fileid,
         meta = construct_metadata(fff, filelist->ids + fileid);
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, meta);
 
-        if ((mask = gwy_app_channel_mask_of_nans(dfield, TRUE)))
+        if ((mask = gwy_mask_nans_in_field(dfield, TRUE)))
             gwy_file_pass_image_mask(file, *id, mask);
 
         if (filelist->offsets->len) {
@@ -897,7 +898,7 @@ load_as_channel(OmicronFlatFileList *filelist, guint fileid,
             }
             gwy_selection_set_data(selection, n, seldata);
             g_free(seldata);
-            gwy_container_pass_object(GWY_CONTAINER(file), gwy_file_key_image_selection(*id, "line"), selection);
+            gwy_dict_pass_object(GWY_DICT(file), gwy_file_key_image_selection(*id, "line"), selection);
         }
 
         gwy_log_add_import(file, GWY_FILE_IMAGE, *id, NULL, fff->filename);
@@ -1124,7 +1125,7 @@ merge_continuous_curves(GwyFile *file, gint ngraphs)
         for (k = 0; k < ncurves; k++)
             concatenate_graph_curves(gmodels + i, j - i, k);
         for (k = i+1; k < j; k++) {
-            gwy_container_remove(GWY_CONTAINER(file), gwy_file_key_graph(k+1));
+            gwy_dict_remove(GWY_DICT(file), gwy_file_key_graph(k+1));
             gmodels[k] = NULL;
         }
         i = j;
@@ -1420,7 +1421,7 @@ load_as_volume(OmicronFlatFileList *filelist,
 
     for (i = 0; i < 8; i++) {
         GwyBrick *brick = brick_specs[i].brick;
-        GwyContainer *meta;
+        GwyDict *meta;
         gchar *title;
 
         if (!brick)
@@ -1656,11 +1657,11 @@ fail:
     return FALSE;
 }
 
-static GwyContainer*
+static GwyDict*
 construct_metadata(OmicronFlatFile *fff,
                    OmicronFlatFileId *id)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     OmicronFlatChannel *channel = &fff->channel;
     OmicronFlatExperiment *experiment = &fff->experiment;
     GString *key = g_string_new(NULL);
@@ -1671,88 +1672,88 @@ construct_metadata(OmicronFlatFile *fff,
     guint i, j;
 
     g_string_printf(value, "%.4s", fff->identification.magic);
-    gwy_container_set_const_string_by_name(meta, "File::Magic", value->str);
+    gwy_dict_set_const_string_by_name(meta, "File::Magic", value->str);
 
     g_string_printf(value, "%.4s", fff->identification.file_structure_level);
-    gwy_container_set_const_string_by_name(meta, "File::Structure level", value->str);
+    gwy_dict_set_const_string_by_name(meta, "File::Structure level", value->str);
 
-    gwy_container_set_const_string_by_name(meta, "File::Base name", id->stem);
+    gwy_dict_set_const_string_by_name(meta, "File::Base name", id->stem);
     g_string_printf(value, "%u", id->run_cycle);
-    gwy_container_set_const_string_by_name(meta, "File::Run cycle", value->str);
+    gwy_dict_set_const_string_by_name(meta, "File::Run cycle", value->str);
     g_string_printf(value, "%u", id->scan_cycle);
-    gwy_container_set_const_string_by_name(meta, "File::Scan cycle", value->str);
-    gwy_container_set_const_string_by_name(meta, "File::Extension", id->extension);
+    gwy_dict_set_const_string_by_name(meta, "File::Scan cycle", value->str);
+    gwy_dict_set_const_string_by_name(meta, "File::Extension", id->extension);
 
     for (i = 0; i < fff->axis_count; i++) {
         OmicronFlatAxis *axis = fff->axis_descriptions + i;
         if (*(axis->parent_name)) {
             g_string_printf(key, "Axis::%s::Parent axis", axis->name);
-            gwy_container_set_const_string_by_name(meta, key->str, axis->parent_name);
+            gwy_dict_set_const_string_by_name(meta, key->str, axis->parent_name);
         }
 
         g_string_printf(key, "Axis::%s::Mirrored", axis->name);
-        gwy_container_set_const_string_by_name(meta, key->str, axis->is_mirrored ? "Yes" : "No");
+        gwy_dict_set_const_string_by_name(meta, key->str, axis->is_mirrored ? "Yes" : "No");
 
         g_string_printf(key, "Axis::%s::Units", axis->name);
-        gwy_container_set_const_string_by_name(meta, key->str, axis->unit_name);
+        gwy_dict_set_const_string_by_name(meta, key->str, axis->unit_name);
 
         for (j = 0; j < axis->table_set_count; j++) {
             OmicronFlatTableSet *table_set = axis->table_set_fields + j;
 
             g_string_printf(key, "Axis::%s::TableSet %u::Name", axis->name, j+1);
-            gwy_container_set_const_string_by_name(meta, key->str, table_set->name);
+            gwy_dict_set_const_string_by_name(meta, key->str, table_set->name);
 
             g_string_printf(key, "Axis::%s::TableSet %u::Interval count", axis->name, j+1);
             g_string_printf(value, "%u", table_set->interval_count);
-            gwy_container_set_const_string_by_name(meta, key->str, value->str);
+            gwy_dict_set_const_string_by_name(meta, key->str, value->str);
         }
     }
 
-    gwy_container_set_const_string_by_name(meta, "Channel::Name", channel->name);
-    gwy_container_set_const_string_by_name(meta, "Channel::Transfer function", channel->transfer_func_name);
-    gwy_container_set_const_string_by_name(meta, "Channel::Units", channel->unit_name);
+    gwy_dict_set_const_string_by_name(meta, "Channel::Name", channel->name);
+    gwy_dict_set_const_string_by_name(meta, "Channel::Transfer function", channel->transfer_func_name);
+    gwy_dict_set_const_string_by_name(meta, "Channel::Units", channel->unit_name);
 
     for (i = 0; i < channel->parameter_count; i++) {
         OmicronFlatTransferParam *param = channel->parameters + i;
         g_string_printf(key, "Channel::Transfer function::%s", param->name);
         g_string_printf(value, "%g", param->value);
-        gwy_container_set_const_string_by_name(meta, key->str, value->str);
+        gwy_dict_set_const_string_by_name(meta, key->str, value->str);
     }
 
     for (i = 0; i < channel->data_view_type_count; i++) {
         g_string_printf(key, "Channel::View type %u", i+1);
         g_string_printf(value, "%u", channel->view_types[i]);
-        gwy_container_set_const_string_by_name(meta, key->str, value->str);
+        gwy_dict_set_const_string_by_name(meta, key->str, value->str);
     }
 
     g_string_printf(value, "%" G_GUINT64_FORMAT, (guint64)fff->creation.timestamp);
-    gwy_container_set_const_string_by_name(meta, "Creation::Timestamp", value->str);
+    gwy_dict_set_const_string_by_name(meta, "Creation::Timestamp", value->str);
     timestamp = fff->creation.timestamp;
     t = localtime(&timestamp);
     strftime(creation_time, sizeof(creation_time), "%Y-%m-%d %H:%M:%S", t);
-    gwy_container_set_const_string_by_name(meta, "Creation::Date and time", creation_time);
+    gwy_dict_set_const_string_by_name(meta, "Creation::Date and time", creation_time);
 
     if (*(fff->creation.info)) {
-        gwy_container_set_const_string_by_name(meta, "Creation::Info", fff->creation.info);
+        gwy_dict_set_const_string_by_name(meta, "Creation::Info", fff->creation.info);
     }
 
-    gwy_container_set_const_string_by_name(meta, "Experiment::Name", experiment->name);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Version", experiment->version);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Description", experiment->description);
-    gwy_container_set_const_string_by_name(meta, "Experiment::File specification", experiment->file_spec);
-    gwy_container_set_const_string_by_name(meta, "Experiment::File creator ID", experiment->file_creator_id);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Result file creator ID",
-                                           experiment->result_file_creator_id);
-    gwy_container_set_const_string_by_name(meta, "Experiment::User name", experiment->user_name);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Account name", experiment->account_name);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Result data file specification",
-                                           experiment->result_data_file_spec);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Name", experiment->name);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Version", experiment->version);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Description", experiment->description);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::File specification", experiment->file_spec);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::File creator ID", experiment->file_creator_id);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Result file creator ID",
+                                      experiment->result_file_creator_id);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::User name", experiment->user_name);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Account name", experiment->account_name);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Result data file specification",
+                                      experiment->result_data_file_spec);
 
     g_string_printf(value, "%u", experiment->run_cycle_id);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Run cycle ID", value->str);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Run cycle ID", value->str);
 
     g_string_printf(value, "%u", experiment->scan_cycle_id);
-    gwy_container_set_const_string_by_name(meta, "Experiment::Scan cycle ID", value->str);
+    gwy_dict_set_const_string_by_name(meta, "Experiment::Scan cycle ID", value->str);
 
     for (i = 0; i < fff->exp_instance_count; i++) {
         OmicronFlatExperimentParamInstance *instance = fff->exp_instances + i;
@@ -1760,7 +1761,7 @@ construct_metadata(OmicronFlatFile *fff,
             OmicronFlatExperimentParam *param = instance->parameters + j;
             g_string_printf(key, "Experiment::%s::%s", instance->name, param->name);
             g_string_printf(value, "%s %s", param->value, param->unit);
-            gwy_container_set_const_string_by_name(meta, key->str, value->str);
+            gwy_dict_set_const_string_by_name(meta, key->str, value->str);
         }
     }
 
@@ -1769,7 +1770,7 @@ construct_metadata(OmicronFlatFile *fff,
         for (j = 0; j < instance->parameter_count; j++) {
             OmicronFlatDeploymentParam *param = instance->parameters + j;
             g_string_printf(key, "Deployment::%s::%s", instance->name, param->name);
-            gwy_container_set_const_string_by_name(meta, key->str, param->value);
+            gwy_dict_set_const_string_by_name(meta, key->str, param->value);
         }
     }
 
