@@ -1,5 +1,5 @@
 /*
- *  $Id: omicronmatrix.c 28858 2025-11-13 14:32:56Z yeti-dn $
+ *  $Id: omicronmatrix.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2008-2025 Philipp Rahe, David Necas
  *  E-mail: hquerquadrat@gmail.com
  *
@@ -114,7 +114,7 @@ typedef struct {
 } MatrixField;
 
 /** Stores data for quick access.
- *  All supplement data is stored in a GwyContainer called meta
+ *  All supplement data is stored in a GwyDict called meta
  */
 typedef struct {
     guint32 xpoints;
@@ -185,9 +185,9 @@ static gchar*       readstr        (const guchar **buffer,
                                     guint32 *size);
 static gboolean     read_meta_value(const guchar **fp,
                                     const guchar *end,
-                                    GwyContainer *hash,
+                                    GwyDict *hash,
                                     const gchar *hprefix,
-                                    GwyContainer *meta,
+                                    GwyDict *meta,
                                     const gchar *mprefix,
                                     const gchar *inst,
                                     const gchar *prop,
@@ -195,15 +195,15 @@ static gboolean     read_meta_value(const guchar **fp,
                                     gboolean check);
 static guint32      scanparamfile  (const guchar **buffer,
                                     const guchar *end,
-                                    GwyContainer *hash,
-                                    GwyContainer *meta,
+                                    GwyDict *hash,
+                                    GwyDict *meta,
                                     MatrixData *matrixdata);
 static gboolean     scandatafile   (const guchar **buffer,
                                     const guchar *end,
                                     const gchar *filename,
                                     GwyFile *file,
-                                    GwyContainer *meta,
-                                    GwyContainer *hash,
+                                    GwyDict *meta,
+                                    GwyDict *hash,
                                     MatrixData *matrixdata,
                                     gint depth);
 static const gchar* sstrconcat     (const gchar *s,
@@ -298,7 +298,7 @@ read_ident(const guchar **p, const guchar *end, gchar *ident)
 }
 
 static void
-set_structured_meta_value(GwyContainer *meta,
+set_structured_meta_value(GwyDict *meta,
                           const gchar *prefix,
                           const gchar *inst,
                           const gchar *prop,
@@ -314,11 +314,11 @@ set_structured_meta_value(GwyContainer *meta,
         key = sstrconcat(prefix, ":", inst, ".", prop, " [", unit, "]", NULL);
     else
         key = sstrconcat(prefix, ":", inst, ".", prop, NULL);
-    gwy_container_set_const_string_by_name(meta, key, value);
+    gwy_dict_set_const_string_by_name(meta, key, value);
 }
 
 static void
-set_structured_meta_uint32(GwyContainer *meta,
+set_structured_meta_uint32(GwyDict *meta,
                            const gchar *prefix,
                            const gchar *inst,
                            const gchar *prop,
@@ -334,7 +334,7 @@ set_structured_meta_uint32(GwyContainer *meta,
 }
 
 static void
-set_structured_meta_double(GwyContainer *meta,
+set_structured_meta_double(GwyDict *meta,
                            const gchar *prefix,
                            const gchar *inst,
                            const gchar *prop,
@@ -381,8 +381,8 @@ read_check(const guchar **fp, const guchar *end, gboolean check)
  */
 static gboolean
 read_meta_value(const guchar **fp, const guchar *end,
-                GwyContainer *hash, const gchar *hprefix,
-                GwyContainer *meta, const gchar *mprefix,
+                GwyDict *hash, const gchar *hprefix,
+                GwyDict *meta, const gchar *mprefix,
                 const gchar *inst,
                 const gchar *prop,
                 const gchar *unit,
@@ -397,24 +397,24 @@ read_meta_value(const guchar **fp, const guchar *end,
 
     if (gwy_strequal(id, "LONG") && end - *fp >= sizeof(guint32)) {
         guint32 v = gwy_get_guint32_le(fp);
-        gwy_container_set_int32_by_name(hash, name, v);
+        gwy_dict_set_int32_by_name(hash, name, v);
         set_structured_meta_uint32(meta, mprefix, inst, prop, unit, v);
     }
     else if (gwy_strequal(id, "BOOL") && end - *fp >= sizeof(guint32)) {
         gboolean a = !!gwy_get_guint32_le(fp);
-        gwy_container_set_boolean_by_name(hash, name, a);
+        gwy_dict_set_boolean_by_name(hash, name, a);
         set_structured_meta_uint32(meta, mprefix, inst, prop, unit, a);
     }
     else if (gwy_strequal(id, "DOUB") && end - *fp >= sizeof(gdouble)) {
         gdouble v = gwy_get_gdouble_le(fp);
-        gwy_container_set_double_by_name(hash, name, v);
+        gwy_dict_set_double_by_name(hash, name, v);
         set_structured_meta_double(meta, mprefix, inst, prop, unit, v);
     }
     else if (gwy_strequal(id, "STRG")) {
         gchar *str = readstr(fp, end, NULL);
         set_structured_meta_value(meta, mprefix, inst, prop, unit, str);
         /* This consumes str. */
-        gwy_container_set_string_by_name(hash, name, (guchar*)str);
+        gwy_dict_set_string_by_name(hash, name, (guchar*)str);
     }
     else
         return FALSE;
@@ -503,7 +503,7 @@ read_string(gchar **value, const guchar **fp, const guchar *end,
 
 static gboolean
 read_prop_fields(const guchar **fp, const guchar *end,
-                 MatrixData *matrixdata, GwyContainer *meta,
+                 MatrixData *matrixdata, GwyDict *meta,
                  const gchar *ident,
                  const gchar *inst, const gchar *prop,
                  const gchar *unit,
@@ -544,7 +544,7 @@ read_prop_fields(const guchar **fp, const guchar *end,
 
 static gboolean
 handle_xyscanner_props(const guchar **fp, const guchar *end,
-                       MatrixData *matrixdata, GwyContainer *meta,
+                       MatrixData *matrixdata, GwyDict *meta,
                        const gchar *ident,
                        const gchar *inst, const gchar *prop,
                        const gchar *unit)
@@ -575,7 +575,7 @@ handle_xyscanner_props(const guchar **fp, const guchar *end,
 
 static gboolean
 handle_spectroscopy_props(const guchar **fp, const guchar *end,
-                          MatrixData *matrixdata, GwyContainer *meta,
+                          MatrixData *matrixdata, GwyDict *meta,
                           const gchar *ident,
                           const gchar *inst, const gchar *prop,
                           const gchar *unit)
@@ -597,7 +597,7 @@ handle_spectroscopy_props(const guchar **fp, const guchar *end,
 
 static gboolean
 handle_regulator_props(const guchar **fp, const guchar *end,
-                       MatrixData *matrixdata, GwyContainer *meta, GwyContainer *hash,
+                       MatrixData *matrixdata, GwyDict *meta, GwyDict *hash,
                        const gchar *ident,
                        const gchar *inst, const gchar *prop,
                        const gchar *unit)
@@ -610,7 +610,7 @@ handle_regulator_props(const guchar **fp, const guchar *end,
                 matrixdata->preamp_range = g_strtod(t+1, NULL);
             set_structured_meta_value(meta, ident, inst, prop, unit, str);
             /* This consumes str. */
-            gwy_container_set_string_by_name(hash, name, (guchar*)str);
+            gwy_dict_set_string_by_name(hash, name, (guchar*)str);
         }
         return TRUE;
     }
@@ -621,8 +621,8 @@ handle_regulator_props(const guchar **fp, const guchar *end,
 static guint32
 scanparamfile(const guchar **buffer,
               const guchar *end,
-              GwyContainer *hash,
-              GwyContainer *meta,
+              GwyDict *hash,
+              GwyDict *meta,
               MatrixData *matrixdata)
 {
     const guchar *fp = NULL;
@@ -671,17 +671,17 @@ scanparamfile(const guchar **buffer,
 
         // program
         programmname = readstr(&fp, end, NULL);
-        gwy_container_set_string_by_name(meta, "META: Program", programmname);
+        gwy_dict_set_string_by_name(meta, "META: Program", programmname);
         // version
         version = readstr(&fp, end, NULL);
-        gwy_container_set_string_by_name(meta, "META: Version", version);
+        gwy_dict_set_string_by_name(meta, "META: Version", version);
         fp += 4;
         // profile name
         profil = readstr(&fp, end, NULL);
-        gwy_container_set_string_by_name(meta, "META: Profil", profil);
+        gwy_dict_set_string_by_name(meta, "META: Profil", profil);
         // username
         user = readstr(&fp, end, NULL);
-        gwy_container_set_string_by_name(meta, "META: User", user);
+        gwy_dict_set_string_by_name(meta, "META: User", user);
     }
     else if (gwy_strequal(ident, "EXPD")) {
         // Description and project files
@@ -694,7 +694,7 @@ scanparamfile(const guchar **buffer,
             gchar key[30];
             g_snprintf(key, sizeof(key), "EXPD: s%d", i);
             s1 = readstr(&fp, end, NULL);
-            gwy_container_set_string_by_name(meta, key, (guchar*)s1);
+            gwy_dict_set_string_by_name(meta, key, (guchar*)s1);
         }
     }
     else if (gwy_strequal(ident, "FSEQ")) {
@@ -714,7 +714,7 @@ scanparamfile(const guchar **buffer,
             gchar key[30];
             g_snprintf(key, sizeof(key), "GENL: s%d", i);
             s1 = readstr(&fp, end, NULL);
-            gwy_container_set_string_by_name(meta, key, (guchar*)s1);
+            gwy_dict_set_string_by_name(meta, key, (guchar*)s1);
         }
     }
     else if (gwy_strequal(ident, "INST")) {
@@ -743,7 +743,7 @@ scanparamfile(const guchar **buffer,
                 t1 = readstr(&fp, end, NULL);
                 t2 = readstr(&fp, end, NULL);
                 g_snprintf(key2, sizeof(key2), "%s.%s", key, t1);
-                gwy_container_set_string_by_name(meta, key2, (guchar*)t2);
+                gwy_dict_set_string_by_name(meta, key2, (guchar*)t2);
                 g_free(t1);
                 count--;
             }
@@ -845,7 +845,7 @@ scanparamfile(const guchar **buffer,
         // Calibration of system
         gchar *cal = NULL;
         cal = readstr(&fp, end, NULL);
-        gwy_container_set_string_by_name(meta, "MARK: Calibration", (guchar*)cal);
+        gwy_dict_set_string_by_name(meta, "MARK: Calibration", (guchar*)cal);
     }
     else if (gwy_strequal(ident, "VIEW")) {
         // deals with the scanning windows
@@ -859,7 +859,7 @@ scanparamfile(const guchar **buffer,
         // Filename of images
         fp += 4;
         filename = readstr(&fp, end, NULL);
-        savedname = gwy_container_get_string_by_name(hash, "/meta/datafilename");
+        savedname = gwy_dict_get_string_by_name(hash, "/meta/datafilename");
         gwy_debug("filename <%s> vs <%s>", filename, savedname);
         if (g_str_has_suffix(savedname, filename) || g_str_has_suffix(filename, savedname)) {
             // Image is found
@@ -907,10 +907,10 @@ scanparamfile(const guchar **buffer,
             name = readstr(&fp, end, NULL);
             unit = readstr(&fp, end, NULL);
             gwy_debug("channel%u <%s> %s", i, name, unit);
-            // store information in GwyContainer
+            // store information in GwyDict
             g_snprintf(key, sizeof(key), "/channels/%u/", a);
-            gwy_container_set_string_by_name(hash, sstrconcat(key, "name", NULL), (guchar*)name);
-            gwy_container_set_string_by_name(hash, sstrconcat(key, "unit", NULL), (guchar*)unit);
+            gwy_dict_set_string_by_name(hash, sstrconcat(key, "name", NULL), (guchar*)name);
+            gwy_dict_set_string_by_name(hash, sstrconcat(key, "unit", NULL), (guchar*)unit);
         }
     }
     else if (gwy_strequal(ident, "CHCS")) {
@@ -932,7 +932,7 @@ scanparamfile(const guchar **buffer,
             name = readstr(&fp, end, NULL);
             g_snprintf(key, sizeof(key), "/channels/%u/tff", number);
             // set string by name requires gchar *key
-            gwy_container_set_const_string_by_name(hash, key, name);
+            gwy_dict_set_const_string_by_name(hash, key, name);
             unit = readstr(&fp, end, NULL);
             a = gwy_get_guint32_le(&fp);
             for (i = 0; i < a; i++) {
@@ -987,19 +987,19 @@ find_scaling_foreach(GQuark quark, GValue *gvalue, gpointer data)
 }
 
 static inline gdouble
-get_prefixed_double(GwyContainer *hash, const gchar *prefix, const gchar *key)
+get_prefixed_double(GwyDict *hash, const gchar *prefix, const gchar *key)
 {
-    return gwy_container_get_double_by_name(hash, sstrconcat(prefix, key, NULL));
+    return gwy_dict_get_double_by_name(hash, sstrconcat(prefix, key, NULL));
 }
 
 static inline const gchar*
-get_prefixed_string(GwyContainer *hash, const gchar *prefix, const gchar *key)
+get_prefixed_string(GwyDict *hash, const gchar *prefix, const gchar *key)
 {
-    return gwy_container_get_string_by_name(hash, sstrconcat(prefix, key, NULL));
+    return gwy_dict_get_string_by_name(hash, sstrconcat(prefix, key, NULL));
 }
 
 static const gchar*
-figure_out_tff(GwyContainer *hash, MatrixData *matrixdata, ValueScaling *zscale,
+figure_out_tff(GwyDict *hash, MatrixData *matrixdata, ValueScaling *zscale,
                const gchar **zunit)
 {
     static const GwyEnum tffs[] = {
@@ -1023,7 +1023,7 @@ figure_out_tff(GwyContainer *hash, MatrixData *matrixdata, ValueScaling *zscale,
     zscale->channelname = matrixdata->channelname;
     zscale->cnumber = G_MAXUINT32;
     // look for correct Z/I/Df/.... scaling
-    gwy_container_foreach(hash, "/channels/", find_scaling_foreach, zscale);
+    gwy_dict_foreach(hash, "/channels/", find_scaling_foreach, zscale);
     if (zscale->cnumber == G_MAXUINT32) {
         g_warning("cannot find zscale for channel %s", zscale->channelname);
         return " (raw)";
@@ -1079,7 +1079,7 @@ figure_out_tff(GwyContainer *hash, MatrixData *matrixdata, ValueScaling *zscale,
 }
 
 static void
-add_field_to_container(GwyFile *file, GwyContainer *meta,
+add_field_to_container(GwyFile *file, GwyDict *meta,
                        GwyField *dfield, const gchar *zunit,
                        gboolean fliph, gboolean flipv,
                        gint *id, const MatrixData *matrixdata,
@@ -1099,7 +1099,7 @@ add_field_to_container(GwyFile *file, GwyContainer *meta,
     title = g_strdup_printf("%u-%u %s %s %s",
                             matrixdata->session, matrixdata->trace, matrixdata->channelname, basename, inverted);
     gwy_file_pass_title(file, GWY_FILE_IMAGE, *id, title);
-    gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, gwy_container_copy(meta));
+    gwy_file_pass_meta(file, GWY_FILE_IMAGE, *id, gwy_dict_copy(meta));
     gwy_log_add_import(file, GWY_FILE_IMAGE, *id, NULL, filename);
 
     gwy_debug("Image %d saved to file", *id);
@@ -1107,7 +1107,7 @@ add_field_to_container(GwyFile *file, GwyContainer *meta,
 }
 
 static void
-add_brick_to_container(GwyFile *file, GwyContainer *meta,
+add_brick_to_container(GwyFile *file, GwyDict *meta,
                        GwyBrick *brick,
                        gdouble zfrom, gdouble zto,
                        const gchar *zunit, const gchar *wunit,
@@ -1136,7 +1136,7 @@ add_brick_to_container(GwyFile *file, GwyContainer *meta,
     title = g_strdup_printf("%u-%u %s %s %s",
                             matrixdata->session, matrixdata->trace, matrixdata->channelname, basename, inverted);
     gwy_file_pass_title(file, GWY_FILE_VOLUME, *id, title);
-    gwy_file_pass_meta(file, GWY_FILE_VOLUME, *id, gwy_container_copy(meta));
+    gwy_file_pass_meta(file, GWY_FILE_VOLUME, *id, gwy_dict_copy(meta));
     gwy_log_add_import(file, GWY_FILE_VOLUME, *id, NULL, filename);
 
     gwy_debug("Brick %d saved to file", *id);
@@ -1244,7 +1244,7 @@ read_image_data(GwyField *trace_field, GwyField *retrace_field,
 
 // Extract image data from the data file
 static void
-create_image_data(GwyFile *file, GwyContainer *meta, GwyContainer *hash,
+create_image_data(GwyFile *file, GwyDict *meta, GwyDict *hash,
                   const guchar **fp, const guchar *end,
                   MatrixData *matrixdata, const gchar *filename)
 {
@@ -1356,7 +1356,7 @@ create_image_data(GwyFile *file, GwyContainer *meta, GwyContainer *hash,
 
 // Create SPS data from the data file
 static void
-create_spectra_graph(GwyFile *file, GwyContainer *hash,
+create_spectra_graph(GwyFile *file, GwyDict *hash,
                      const guchar **fp, const guchar *end,
                      const gchar *filename,
                      MatrixData *matrixdata)
@@ -1502,7 +1502,7 @@ read_volume_data(GwyBrick *trace_brick, GwyBrick *trace_rbrick, GwyBrick *retrac
 
 // Extract volume spectroscopy data from the data file
 static void
-create_volume_data(GwyFile *file, GwyContainer *meta, GwyContainer *hash,
+create_volume_data(GwyFile *file, GwyDict *meta, GwyDict *hash,
                    const guchar **fp, const guchar *end,
                    MatrixData *matrixdata, const gchar *filename)
 {
@@ -1642,8 +1642,8 @@ static gboolean
 scandatafile(const guchar **fp, const guchar *end,
              const gchar *filename,
              GwyFile *file,
-             GwyContainer *meta,
-             GwyContainer *hash,
+             GwyDict *meta,
+             GwyDict *hash,
              MatrixData *matrixdata,
              gint depth)
 {
@@ -1673,7 +1673,7 @@ scandatafile(const guchar **fp, const guchar *end,
         struct tm *sdate = localtime(&timestamp);
         strftime(times, sizeof(times), "%H:%M:%S %d.%m.%Y", sdate);
         //g_snprintf(times, sizeof(times), "%i", date);
-        gwy_container_set_string_by_name(meta, "Image ended at", (guchar*)g_strdup(times));
+        gwy_dict_set_string_by_name(meta, "Image ended at", (guchar*)g_strdup(times));
         len += 8;
         *fp += 4;
         while (scandatafile(fp, end, filename, file, meta, hash, matrixdata, depth+1)) {
@@ -1770,7 +1770,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL, *hash = NULL;
+    GwyDict *meta = NULL, *hash = NULL;
     guchar *imgbuffer = NULL;
     guchar *parbuffer = NULL;
     const guchar *fp = NULL;
@@ -1830,9 +1830,9 @@ load_file(const gchar *filename,
 
     gwy_debug("omicronmatrix: parameter file: %s", paramfilename);
     file = gwy_file_new_in_construction();
-    meta = gwy_container_new_in_construction();
-    /* Use a GwyContainer also for various auxiliary information. */
-    hash = gwy_container_new();
+    meta = gwy_dict_new_in_construction();
+    /* Use a GwyDict also for various auxiliary information. */
+    hash = gwy_dict_new();
 
     if (g_strv_length(fsplit) == 2) {
         /* Parse image filename to obtain numbers and channel
@@ -1862,7 +1862,7 @@ load_file(const gchar *filename,
     if (matrixdata.use_paramfile) {
         // parameter file seems to be valid
         fp = parbuffer + FILEIDENT_SIZE;
-        gwy_container_set_const_string_by_name(hash, "/meta/datafilename", filename);
+        gwy_dict_set_const_string_by_name(hash, "/meta/datafilename", filename);
         gwy_debug("omicronmatrix::load Scanning parameterfile");
         while (fp < parbuffer + parsize
                && scanparamfile(&fp, parbuffer + parsize, hash, meta, &matrixdata))
@@ -1897,7 +1897,7 @@ load_file(const gchar *filename,
     g_object_unref(hash);
     sstrconcat(NULL);
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         /* This is lame but we are not sure what is the primary problem. */
         err_NO_DATA(error);
