@@ -1,5 +1,5 @@
 /*
- *  $Id: opdfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: opdfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2008-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -153,7 +153,7 @@ static GwyField*     get_field       (const OPDBlock *datablock,
                                       gdouble aspect,
                                       gdouble wavelength,
                                       const gchar *zunits,
-                                      GwyField **maskfield,
+                                      GwyNield **maskfield,
                                       GError **error);
 static void          store_asc_meta  (gpointer key,
                                       gpointer value,
@@ -166,8 +166,8 @@ static GwyField*     get_asc_field   (gchar **p,
                                       gdouble aspect,
                                       gdouble wavelength,
                                       const gchar *zunits,
-                                      GwyField **maskfield);
-static GwyContainer* get_meta        (const OPDBlock *header,
+                                      GwyNield **maskfield);
+static GwyDict*      get_meta        (const OPDBlock *header,
                                       guint nblocks);
 static gboolean      check_sizes     (const OPDBlock *header,
                                       guint nblocks,
@@ -180,7 +180,7 @@ static const guchar* get_array_params(const guchar *p,
                                       guint *yres,
                                       OPDArrayType *type);
 static void          clone_meta      (GwyFile *file,
-                                      GwyContainer *meta,
+                                      GwyDict *meta,
                                       guint nchannels);
 
 static GwyModuleInfo module_info = {
@@ -188,7 +188,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Wyko OPD and ASC files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.13",
+    "0.14",
     "David Nečas (Yeti)",
     "2008",
 };
@@ -233,7 +233,8 @@ opd_load(const gchar *filename,
     OPDBlock directory_block, *header = NULL;
     gsize size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL, *mfield = NULL;
+    GwyField *field = NULL;
+    GwyNield *mfield = NULL;
     const guchar *p;
     guint nblocks, offset, i, j, k;
     gdouble pixel_size, wavelength, aspect = 1.0;
@@ -325,18 +326,19 @@ opd_load(const gchar *filename,
             continue;
         }
 
-        dfield = mfield = NULL;
+        field = NULL;
+        mfield = NULL;
         gboolean is_intensity = gwy_stramong(header[i].name, "Image", "Intensity", "SecArr_0", NULL);
         if (is_intensity) {
-            if (!(dfield = get_field(header + i, pixel_size, aspect, 1.0, NULL, NULL, error)))
+            if (!(field = get_field(header + i, pixel_size, aspect, 1.0, NULL, NULL, error)))
                 goto fail;
         }
         else {
-            if (!(dfield = get_field(header + i, pixel_size, aspect, wavelength, "m", &mfield, error)))
+            if (!(field = get_field(header + i, pixel_size, aspect, wavelength, "m", &mfield, error)))
                 goto fail;
         }
 
-        gwy_file_pass_image(file, j, dfield);
+        gwy_file_pass_image(file, j, field);
         if (mfield)
             gwy_file_pass_image_mask(file, j, mfield);
 
@@ -347,7 +349,7 @@ opd_load(const gchar *filename,
         else
             gwy_image_title_fall_back(file, j);
 
-        gwy_container_set_boolean(GWY_CONTAINER(file), gwy_file_key_image_real_square(j), TRUE);
+        gwy_dict_set_boolean(GWY_DICT(file), gwy_file_key_image_real_square(j), TRUE);
 
         gwy_log_add_import(file, GWY_FILE_IMAGE, j, NULL, filename);
 
@@ -355,7 +357,7 @@ opd_load(const gchar *filename,
     }
 
     if (j) {
-        GwyContainer *meta = get_meta(header, nblocks);
+        GwyDict *meta = get_meta(header, nblocks);
 
         clone_meta(file, meta, j);
         g_object_unref(meta);
@@ -451,13 +453,15 @@ static GwyField*
 get_field(const OPDBlock *datablock,
           gdouble pixel_size, gdouble aspect, gdouble wavelength,
           const gchar *zunits,
-          GwyField **maskfield,
+          GwyNield **maskfield,
           GError **error)
 {
     OPDArrayType datatype;
-    GwyField *dfield, *mfield;
-    gdouble *data, *mdata;
-    guint xres, yres, mcount;
+    GwyField *field;
+    GwyNield *mask;
+    gdouble *data;
+    gint *mdata;
+    guint xres, yres;
     const guchar *p;
     guint i, j;
 
@@ -465,16 +469,15 @@ get_field(const OPDBlock *datablock,
         *maskfield = NULL;
 
     p = get_array_params(datablock->data, &xres, &yres, &datatype);
-    dfield = gwy_field_new(xres, yres, xres*pixel_size, aspect*yres*pixel_size, FALSE);
+    field = gwy_field_new(xres, yres, xres*pixel_size, aspect*yres*pixel_size, FALSE);
 
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), zunits);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), zunits);
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
-    gwy_field_fill(mfield, 1.0);
+    mask = gwy_field_new_nield_alike(field);
 
-    data = gwy_field_get_data(dfield);
-    mdata = gwy_field_get_data(mfield);
+    data = gwy_field_get_data(field);
+    mdata = gwy_nield_get_data(mask);
     for (i = 0; i < xres; i++) {
         if (datatype == OPD_ARRAY_FLOAT) {
             for (j = yres; j; j--) {
@@ -482,7 +485,7 @@ get_field(const OPDBlock *datablock,
                 if (v < OPD_BAD_FLOAT)
                     data[(j - 1)*xres + i] = wavelength*v;
                 else
-                    mdata[(j - 1)*xres + i] = 0.0;
+                    mdata[(j - 1)*xres + i] = 1;
             }
         }
         else if (datatype == OPD_ARRAY_INT16) {
@@ -491,7 +494,7 @@ get_field(const OPDBlock *datablock,
                 if (v < OPD_BAD_INT16)
                     data[(j - 1)*xres + i] = wavelength*v;
                 else
-                    mdata[(j - 1)*xres + i] = 0.0;
+                    mdata[(j - 1)*xres + i] = 1;
             }
         }
         else if (datatype == OPD_ARRAY_BYTE) {
@@ -502,26 +505,25 @@ get_field(const OPDBlock *datablock,
         }
         else {
             err_DATA_TYPE(error, datatype);
-            g_object_unref(dfield);
-            g_object_unref(mfield);
+            g_object_unref(field);
+            g_object_unref(mask);
             return NULL;
         }
     }
-    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
 
-    if (maskfield && mcount)
-        *maskfield = mfield;
+    if (maskfield)
+        *maskfield = gwy_remove_bad_image_data(field, mask);
     else
-        g_object_unref(mfield);
+        g_clear_object(&mask);
 
-    return dfield;
+    return field;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(const OPDBlock *header,
          guint nblocks)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     guint i, type;
     const guchar *p;
     gchar *s;
@@ -547,7 +549,7 @@ get_meta(const OPDBlock *header,
         }
         /* Ignore all other types */
         if (s)
-            gwy_container_set_string_by_name(meta, header[i].name, s);
+            gwy_dict_set_string_by_name(meta, header[i].name, s);
     }
 
     return meta;
@@ -663,7 +665,8 @@ opd_asc_load(const gchar *filename,
              GError **error)
 {
     GwyFile *file = NULL;
-    GwyField *dfield = NULL, *mfield = NULL;
+    GwyField *field = NULL;
+    GwyNield *mask = NULL;
     gchar *line, *p, *s, *buffer = NULL;
     GHashTable *hash = NULL;
     guint j, xres = 0, yres = 0;
@@ -765,19 +768,20 @@ opd_asc_load(const gchar *filename,
             if (!is_intensity && !real_units)
                 zcalib *= wavelength;
 
-            dfield = mfield = NULL;
-            dfield = get_asc_field(&p, format, xres, yres, pixel_size, aspect, zcalib,
-                                   is_intensity ? "" : "m",
-                                   is_intensity ? NULL : &mfield);
-            if (!dfield) {
+            field = NULL;
+            mask = NULL;
+            field = get_asc_field(&p, format, xres, yres, pixel_size, aspect, zcalib,
+                                  is_intensity ? "" : "m",
+                                  is_intensity ? NULL : &mask);
+            if (!field) {
                 err_TRUNCATED_PART(error, line);
                 g_clear_object(&file);
                 goto fail;
             }
 
-            gwy_file_set_image(file, j, dfield);
-            if (mfield)
-                gwy_file_set_image_mask(file, j, mfield);
+            gwy_file_set_image(file, j, field);
+            if (mask)
+                gwy_file_set_image_mask(file, j, mask);
 
             if (is_intensity)
                 gwy_file_set_title(file, GWY_FILE_IMAGE, j, line, FALSE);
@@ -786,7 +790,7 @@ opd_asc_load(const gchar *filename,
             else
                 gwy_image_title_fall_back(file, j);
 
-            gwy_container_set_boolean(GWY_CONTAINER(file), gwy_file_key_image_real_square(j), TRUE);
+            gwy_dict_set_boolean(GWY_DICT(file), gwy_file_key_image_real_square(j), TRUE);
 
             gwy_log_add_import(file, GWY_FILE_IMAGE, j, NULL, filename);
 
@@ -803,7 +807,7 @@ opd_asc_load(const gchar *filename,
     }
 
     if (j) {
-        GwyContainer *meta = gwy_container_new_in_construction();
+        GwyDict *meta = gwy_dict_new_in_construction();
 
         g_hash_table_foreach(hash, store_asc_meta, meta);
         clone_meta(file, meta, j);
@@ -815,8 +819,8 @@ opd_asc_load(const gchar *filename,
     }
 
 fail:
-    g_clear_object(&dfield);
-    g_clear_object(&mfield);
+    g_clear_object(&field);
+    g_clear_object(&mask);
     g_free(buffer);
     if (hash)
         g_hash_table_destroy(hash);
@@ -827,12 +831,12 @@ fail:
 static void
 store_asc_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *cval;
 
     if (!(cval = gwy_convert_to_utf8(value, -1, "ISO-8859-1")))
         return;
-    gwy_container_set_string_by_name(meta, key, cval);
+    gwy_dict_set_string_by_name(meta, key, cval);
 }
 
 static GwyField*
@@ -840,27 +844,28 @@ get_asc_field(gchar **p,
               OPDArrayFormat format, guint xres, guint yres,
               gdouble pixel_size, gdouble aspect, gdouble zcalib,
               const gchar *zunits,
-              GwyField **maskfield)
+              GwyNield **maskfield)
 {
-    GwyField *dfield, *mfield;
-    gdouble *data, *mdata;
+    GwyField *field;
+    GwyNield *mask;
+    gdouble *data;
+    gint *mdata;
     const gchar *sprev;
-    guint mcount, i, j;
+    guint i, j;
     gchar *s;
 
     if (maskfield)
         *maskfield = NULL;
 
-    dfield = gwy_field_new(xres, yres, xres*pixel_size, aspect*yres*pixel_size, FALSE);
+    field = gwy_field_new(xres, yres, xres*pixel_size, aspect*yres*pixel_size, FALSE);
 
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), zunits);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), zunits);
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
-    gwy_field_fill(mfield, 1.0);
+    mask = gwy_field_new_nield_alike(field);
 
-    data = gwy_field_get_data(dfield);
-    mdata = gwy_field_get_data(mfield);
+    data = gwy_field_get_data(field);
+    mdata = gwy_nield_get_data(mask);
 
     if (format == OPD_XYZ_PIXEL || format == OPD_XYZ_REAL) {
         gwy_debug("assuming XYZ format");
@@ -879,7 +884,7 @@ get_asc_field(gchar **p,
 
                 sprev = s;
                 if (strncmp(s, "Bad", 3) == 0) {
-                    mdata[(i - 1)*xres + j] = 0.0;
+                    mdata[(i - 1)*xres + j] = 1;
                     s += 3;
                 }
                 else
@@ -899,7 +904,7 @@ get_asc_field(gchar **p,
             for (i = yres; i; i--) {
                 sprev = s;
                 if (strncmp(s, "Bad", 3) == 0) {
-                    mdata[(i - 1)*xres + j] = 0.0;
+                    mdata[(i - 1)*xres + j] = 1;
                     s += 3;
                 }
                 else
@@ -917,32 +922,30 @@ get_asc_field(gchar **p,
         g_assert_not_reached();
     }
 
-    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
-
-    if (maskfield && mcount)
-        *maskfield = mfield;
+    if (maskfield)
+        *maskfield = gwy_remove_bad_image_data(field, mask);
     else
-        g_object_unref(mfield);
+        g_clear_object(&mask);
 
-    return dfield;
+    return field;
 
 fail:
-    g_object_unref(dfield);
-    g_object_unref(mfield);
+    g_object_unref(field);
+    g_object_unref(mask);
     return NULL;
 }
 
 /***** Common *********************************************************/
 
 static void
-clone_meta(GwyFile *file, GwyContainer *meta, guint nchannels)
+clone_meta(GwyFile *file, GwyDict *meta, guint nchannels)
 {
-    if (!gwy_container_get_n_items(meta))
+    if (!gwy_dict_get_n_items(meta))
         return;
 
     /* Simply store identical metadata for each channel */
     for (guint i = 0; i < nchannels; i++)
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(meta));
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
