@@ -1,5 +1,5 @@
 /*
- *  $Id: opengps.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: opengps.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -111,7 +111,7 @@ static gboolean      data_start      (X3PFile *x3pfile,
 static gboolean      read_binary_data(X3PFile *x3pfile,
                                       GwyZipFile zipfile,
                                       GError **error);
-static GwyContainer* get_meta        (const X3PFile *x3pfile);
+static GwyDict* get_meta        (const X3PFile *x3pfile);
 static void          add_meta_record (gpointer hkey,
                                       gpointer hvalue,
                                       gpointer user_data);
@@ -248,12 +248,12 @@ create_images(const X3PFile *x3pfile, GwyFile *file)
         gwy_check_nonsquare_image(file, id);
         gwy_log_add_import(file, GWY_FILE_IMAGE, id, NULL, x3pfile->filename);
 
-        GwyField *mask;
-        if ((mask = gwy_app_channel_mask_of_nans(dfield, TRUE)))
+        GwyNield *mask;
+        if ((mask = gwy_mask_nans_in_field(dfield, TRUE)))
             gwy_file_pass_image_mask(file, id, mask);
         g_object_unref(dfield);
 
-        GwyContainer *meta;
+        GwyDict *meta;
         if ((meta = get_meta(x3pfile)))
             gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     }
@@ -678,13 +678,13 @@ read_binary_data(X3PFile *x3pfile, GwyZipFile zipfile, GError **error)
     return TRUE;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(const X3PFile *x3pfile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(x3pfile->hash, add_meta_record, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
@@ -696,7 +696,7 @@ add_meta_record(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
     const gchar *key = (const gchar*)hkey;
     const gchar *value = (const gchar*)hvalue;
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
     if (!gwy_stramong(key,
                       "/ISO5436_2/Record1/Revision",
@@ -719,7 +719,7 @@ add_meta_record(gpointer hkey, gpointer hvalue, gpointer user_data)
     key = strrchr(key, '/');
     g_return_if_fail(key);
     key++;
-    gwy_container_set_string_by_name(meta, key, g_strdup(value));
+    gwy_dict_set_string_by_name(meta, key, g_strdup(value));
 }
 
 static void
