@@ -1,5 +1,5 @@
 /*
- *  $Id: phoenix.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: phoenix.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2018-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -201,7 +201,7 @@ static GwyField*      read_table_file   (const PhoenixTableFileInfo *table,
 static gboolean       parse_afm_d_header(gchar *line,
                                          PhoenixAFMHeader *header,
                                          GError **error);
-static GwyContainer*  create_meta       (const PhoenixFile *phfile,
+static GwyDict*       create_meta       (const PhoenixFile *phfile,
                                          const PhoenixBinaryHeader *bheader,
                                          const PhoenixAFMHeader *theader);
 
@@ -298,7 +298,7 @@ load_file(const gchar *filename,
 
             set_channel_meta(file, i, &phfile, &header, NULL);
         }
-        if (gwy_container_get_n_items(GWY_CONTAINER(file)))
+        if (gwy_dict_get_n_items(GWY_DICT(file)))
             ok = TRUE;
         else
             err_NO_DATA(error);
@@ -336,7 +336,7 @@ load_file(const gchar *filename,
             }
 
             /* Skip constant-value images.  They are present for some reason or another but carry no information. */
-            gwy_field_get_min_max(dfield, &min, &max);
+            gwy_field_min_max(dfield, &min, &max);
             if (max > min) {
                 gwy_file_pass_image(file, i, dfield);
                 gwy_log_add_import(file, GWY_FILE_IMAGE, i, NULL, filename);
@@ -353,7 +353,7 @@ load_file(const gchar *filename,
             GWY_FREE(header.oimage_after);
         }
 
-        if (gwy_container_get_n_items(GWY_CONTAINER(file)))
+        if (gwy_dict_get_n_items(GWY_DICT(file)))
             ok = TRUE;
         else
             err_NO_DATA(error);
@@ -1012,7 +1012,7 @@ fail:
 }
 
 static void
-add_time_meta(GwyContainer *meta, const guchar *name,
+add_time_meta(GwyDict *meta, const guchar *name,
               guint secs, guint frac)
 {
     gdouble t;
@@ -1020,15 +1020,15 @@ add_time_meta(GwyContainer *meta, const guchar *name,
 
     t = secs + frac/4294967296.0;
     g_snprintf(buf, sizeof(buf), "%.8f s", t);
-    gwy_container_set_const_string_by_name(meta, name, buf);
+    gwy_dict_set_const_string_by_name(meta, name, buf);
 }
 
-static GwyContainer*
+static GwyDict*
 create_meta(const PhoenixFile *phfile,
             const PhoenixBinaryHeader *bheader,
             const PhoenixAFMHeader *theader)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     GArray *records = phfile->records;
 
     for (guint i = 0; i < records->len; i++) {
@@ -1037,7 +1037,7 @@ create_meta(const PhoenixFile *phfile,
         if (rec->records || !rec->name || rec->name[0] == '^')
             continue;
 
-        gwy_container_set_const_string_by_name(meta, rec->name, rec->value);
+        gwy_dict_set_const_string_by_name(meta, rec->name, rec->value);
     }
 
     if (bheader) {
