@@ -1,5 +1,5 @@
 /*
- *  $Id: pixmap.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: pixmap.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -375,7 +375,7 @@ load_file(const gchar *filename,
     args.params = params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, name);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL) {
@@ -520,28 +520,23 @@ pixmap_pixbuf_to_field(GdkPixbuf *pixbuf,
                        PixmapMapType maptype,
                        gdouble hue_offset)
 {
-    gint width, height, rowstride, i, bpp;
-    guchar *pixels;
-    gdouble *val;
-
     gwy_debug("%d", maptype);
-    pixels = gdk_pixbuf_get_pixels(pixbuf);
-    width = gdk_pixbuf_get_width(pixbuf);
-    height = gdk_pixbuf_get_height(pixbuf);
-    rowstride = gdk_pixbuf_get_rowstride(pixbuf);
-    bpp = gdk_pixbuf_get_has_alpha(pixbuf) ? 4 : 3;
+
+    guchar *pixels = gdk_pixbuf_get_pixels(pixbuf);
+    gint width = gdk_pixbuf_get_width(pixbuf);
+    gint height = gdk_pixbuf_get_height(pixbuf);
+    gint rowstride = gdk_pixbuf_get_rowstride(pixbuf);
+    gint bpp = gdk_pixbuf_get_has_alpha(pixbuf) ? 4 : 3;
     gwy_field_resize(field, width, height);
-    val = gwy_field_get_data(field);
+    gdouble *val = gwy_field_get_data(field);
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(pixels,val,width,height,rowstride,bpp,maptype,hue_offset)
 #endif
-    for (i = 0; i < height; i++) {
+    for (gint i = 0; i < height; i++) {
         guchar *p = pixels + i*rowstride;
         gdouble *r = val + i*width;
-        gint j;
 
         switch (maptype) {
             case PIXMAP_MAP_ALPHA:
@@ -552,12 +547,12 @@ pixmap_pixbuf_to_field(GdkPixbuf *pixbuf,
             p++;
             case PIXMAP_MAP_RED:
             case PIXMAP_MAP_GREY:
-            for (j = 0; j < width; j++)
+            for (gint j = 0; j < width; j++)
                 r[j] = p[bpp*j]/255.0;
             break;
 
             case PIXMAP_MAP_VALUE:
-            for (j = 0; j < width; j++) {
+            for (gint j = 0; j < width; j++) {
                 guchar red = p[bpp*j], green = p[bpp*j+1], blue = p[bpp*j+2];
                 guchar v = MAX(MAX(red, green), blue);
 
@@ -566,7 +561,7 @@ pixmap_pixbuf_to_field(GdkPixbuf *pixbuf,
             break;
 
             case PIXMAP_MAP_SUM:
-            for (j = 0; j < width; j++) {
+            for (gint j = 0; j < width; j++) {
                 guchar red = p[bpp*j], green = p[bpp*j+1], blue = p[bpp*j+2];
 
                 r[j] = (red + green + blue)/(3*255.0);
@@ -574,7 +569,7 @@ pixmap_pixbuf_to_field(GdkPixbuf *pixbuf,
             break;
 
             case PIXMAP_MAP_LUMA:
-            for (j = 0; j < width; j++) {
+            for (gint j = 0; j < width; j++) {
                 guchar red = p[bpp*j], green = p[bpp*j+1], blue = p[bpp*j+2];
 
                 r[j] = (0.2126*red + 0.7152*green + 0.0722*blue)/255.0;
@@ -582,7 +577,7 @@ pixmap_pixbuf_to_field(GdkPixbuf *pixbuf,
             break;
 
             case PIXMAP_MAP_HUE:
-            for (j = 0; j < width; j++) {
+            for (gint j = 0; j < width; j++) {
                 guchar red = p[bpp*j], green = p[bpp*j+1], blue = p[bpp*j+2];
                 gint cmax = MAX(MAX(red, green), blue);
                 gint cmin = MIN(MIN(red, green), blue);
@@ -842,15 +837,15 @@ pixmap_add_import_log(GwyFile *file,
     g_free(fskey);
 
     /* Eats myfilename. */
-    GwyContainer *settings = gwy_app_settings_get();
-    gwy_container_set_string(settings, quark, myfilename);
+    GwyDict *settings = gwy_app_settings_get();
+    gwy_dict_set_string(settings, quark, myfilename);
 
     qualname = g_strconcat("file::", filetype, NULL);
     gwy_log_add_full(file, GWY_FILE_IMAGE, -1, id, qualname, NULL);
     g_free(qualname);
 
     /* We know pixmap functions have no such setting as "filename". */
-    gwy_container_remove(settings, quark);
+    gwy_dict_remove(settings, quark);
 }
 
 static PixmapFormatInfo*
