@@ -1,5 +1,5 @@
 /*
- *  $Id: psia.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: psia.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2006-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -192,30 +192,30 @@ typedef struct {
     gint reserved[30];
 } PSIASpectroscopyHeader;
 
-static gboolean      module_register  (void);
-static gint          detect_file      (const GwyFileDetectInfo *fileinfo,
-                                       gboolean only_name);
-static GwyFile*      load_file        (const gchar *filename,
-                                       GwyRunModeFlags mode,
-                                       GError **error);
-static GwyFile*      load_tiff        (GwyTIFF *tiff,
-                                       GError **error);
-static void          free_image_header(PSIAImageHeader *header);
-static void          read_field       (GwyField *dfield,
-                                       const guchar *p,
-                                       PSIADataType data_type,
-                                       gdouble q,
-                                       gdouble z_scale,
-                                       gdouble z0);
-static guint         read_image_header(const guchar *p,
-                                       gsize size,
-                                       guint version,
-                                       PSIAImageHeader *header,
-                                       GError **error);
-static gchar*        wchar_to_utf8    (const guchar **src,
-                                       guint len);
-static GwyContainer* get_metadata     (PSIAImageHeader *header,
-                                       guint version);
+static gboolean module_register  (void);
+static gint     detect_file      (const GwyFileDetectInfo *fileinfo,
+                                  gboolean only_name);
+static GwyFile* load_file        (const gchar *filename,
+                                  GwyRunModeFlags mode,
+                                  GError **error);
+static GwyFile* load_tiff        (GwyTIFF *tiff,
+                                  GError **error);
+static void     free_image_header(PSIAImageHeader *header);
+static void     read_field       (GwyField *dfield,
+                                  const guchar *p,
+                                  PSIADataType data_type,
+                                  gdouble q,
+                                  gdouble z_scale,
+                                  gdouble z0);
+static guint    read_image_header(const guchar *p,
+                                  gsize size,
+                                  guint version,
+                                  PSIAImageHeader *header,
+                                  GError **error);
+static gchar*   wchar_to_utf8    (const guchar **src,
+                                  guint len);
+static GwyDict* get_metadata     (PSIAImageHeader *header,
+                                  guint version);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -293,7 +293,7 @@ load_tiff(GwyTIFF *tiff, GError **error)
     const GwyTIFFEntry *entry;
     PSIAImageHeader header;
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyField *dfield;
     GwyUnit *siunit;
     guint magic, version, bps, i;
@@ -383,11 +383,11 @@ load_tiff(GwyTIFF *tiff, GError **error)
     meta = get_metadata(&header, version);
     if (comment && *comment) {
         /* FIXME: Charset conversion. But from what? */
-        gwy_container_set_string_by_name(meta, "Comment", comment);
+        gwy_dict_set_string_by_name(meta, "Comment", comment);
         comment = NULL;
     }
     g_free(comment);
-    gwy_container_set_string_by_name(meta, "Version", g_strdup_printf("%08x", version));
+    gwy_dict_set_string_by_name(meta, "Version", g_strdup_printf("%08x", version));
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
 
     free_image_header(&header);
@@ -784,62 +784,62 @@ wchar_to_utf8(const guchar **src, guint len)
     return s ? s : g_strdup("");
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(PSIAImageHeader *header, guint version)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     if (header->source_name && *header->source_name) {
-        gwy_container_set_string_by_name(meta, "Source name", header->source_name);
+        gwy_dict_set_string_by_name(meta, "Source name", header->source_name);
         header->source_name = NULL;
     }
     if (header->image_mode && *header->image_mode) {
-        gwy_container_set_string_by_name(meta, "Image mode", header->image_mode);
+        gwy_dict_set_string_by_name(meta, "Image mode", header->image_mode);
         header->image_mode = NULL;
     }
 
-    gwy_container_set_string_by_name(meta, "Version",
+    gwy_dict_set_string_by_name(meta, "Version",
                                      g_strdup_printf("%u.%u.%u",
                                                      version >> 24, (version >> 12) & 0xfff, version & 0xfff));
-    gwy_container_set_string_by_name(meta, "Overscan", g_strdup_printf("%g %%", 100*header->overscan_rate));
-    gwy_container_set_const_string_by_name(meta, "Fast direction", header->swap_xy ? "Y" : "X");
-    gwy_container_set_string_by_name(meta, "Angle", g_strdup_printf("%g°", header->angle));
-    gwy_container_set_const_string_by_name(meta, "Scanning direction",
-                                           header->scan_up ? "Bottom to top" : "Top to bottom");
-    gwy_container_set_const_string_by_name(meta, "Line direction", header->forward ? "Left to right" : "Right to left");
-    gwy_container_set_const_string_by_name(meta, "Sine scan", header->sine_scan ? "Yes" : "No");
-    gwy_container_set_string_by_name(meta, "Scan rate", g_strdup_printf("%g Hz", header->scan_rate));
-    gwy_container_set_string_by_name(meta, "Set point",
-                                     g_strdup_printf("%g %s", header->set_point, header->set_point_unit));
-    gwy_container_set_string_by_name(meta, "Tip bias", g_strdup_printf("%g V", header->tip_bias));
-    gwy_container_set_string_by_name(meta, "Sample bias", g_strdup_printf("%g V", header->sample_bias));
+    gwy_dict_set_string_by_name(meta, "Overscan", g_strdup_printf("%g %%", 100*header->overscan_rate));
+    gwy_dict_set_const_string_by_name(meta, "Fast direction", header->swap_xy ? "Y" : "X");
+    gwy_dict_set_string_by_name(meta, "Angle", g_strdup_printf("%g°", header->angle));
+    gwy_dict_set_const_string_by_name(meta, "Scanning direction",
+                                      header->scan_up ? "Bottom to top" : "Top to bottom");
+    gwy_dict_set_const_string_by_name(meta, "Line direction", header->forward ? "Left to right" : "Right to left");
+    gwy_dict_set_const_string_by_name(meta, "Sine scan", header->sine_scan ? "Yes" : "No");
+    gwy_dict_set_string_by_name(meta, "Scan rate", g_strdup_printf("%g Hz", header->scan_rate));
+    gwy_dict_set_string_by_name(meta, "Set point",
+                                g_strdup_printf("%g %s", header->set_point, header->set_point_unit));
+    gwy_dict_set_string_by_name(meta, "Tip bias", g_strdup_printf("%g V", header->tip_bias));
+    gwy_dict_set_string_by_name(meta, "Sample bias", g_strdup_printf("%g V", header->sample_bias));
 
     if (version == PSIA_VERSION1)
         return meta;
 
     if (header->xy_voltage_mode && *header->xy_voltage_mode) {
-        gwy_container_set_string_by_name(meta, "XY voltage mode", header->xy_voltage_mode);
+        gwy_dict_set_string_by_name(meta, "XY voltage mode", header->xy_voltage_mode);
         header->xy_voltage_mode = NULL;
     }
 
     if (header->z_voltage_mode && *header->z_voltage_mode) {
-        gwy_container_set_string_by_name(meta, "Z voltage mode", header->z_voltage_mode);
+        gwy_dict_set_string_by_name(meta, "Z voltage mode", header->z_voltage_mode);
         header->z_voltage_mode = NULL;
     }
 
     if (header->xy_servo_mode && *header->xy_servo_mode) {
-        gwy_container_set_string_by_name(meta, "XY servo mode", header->xy_servo_mode);
+        gwy_dict_set_string_by_name(meta, "XY servo mode", header->xy_servo_mode);
         header->xy_servo_mode = NULL;
     }
 
     if (header->cantilever_name && *header->cantilever_name) {
-        gwy_container_set_string_by_name(meta, "Cantilever", header->cantilever_name);
+        gwy_dict_set_string_by_name(meta, "Cantilever", header->cantilever_name);
         header->cantilever_name = NULL;
     }
 
-    gwy_container_set_string_by_name(meta, "Z scanner range", g_strdup_printf("%g", header->z_scanner_range));
-    gwy_container_set_string_by_name(meta, "Z servo gain", g_strdup_printf("%g", header->z_servo_gain));
-    gwy_container_set_string_by_name(meta, "Head tilt angle", g_strdup_printf("%g°", header->head_rotation_angle));
+    gwy_dict_set_string_by_name(meta, "Z scanner range", g_strdup_printf("%g", header->z_scanner_range));
+    gwy_dict_set_string_by_name(meta, "Z servo gain", g_strdup_printf("%g", header->z_servo_gain));
+    gwy_dict_set_string_by_name(meta, "Head tilt angle", g_strdup_printf("%g°", header->head_rotation_angle));
 
     return meta;
 }
