@@ -1,5 +1,5 @@
 /*
- *  $Id: psppt.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: psppt.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -114,7 +114,7 @@ typedef struct {
     GString *str;
     GArray *databuf;
     GwyLawn *lawn;
-    GwyContainer *meta;
+    GwyDict *meta;
 } PSPPTFile;
 
 static gboolean module_register       (void);
@@ -557,18 +557,18 @@ check_string_list_item(JsonObject *root, const gchar *name, gchar **values, guin
 }
 
 static gboolean
-format_atomic_json_meta(JsonNode *node, GwyContainer *meta, const gchar *path)
+format_atomic_json_meta(JsonNode *node, GwyDict *meta, const gchar *path)
 {
     GType type = json_node_get_value_type(node);
 
     if (type == G_TYPE_STRING)
-        gwy_container_set_const_string_by_name(meta, path, json_node_get_string(node));
+        gwy_dict_set_const_string_by_name(meta, path, json_node_get_string(node));
     else if (type == G_TYPE_INT64)
-        gwy_container_set_string_by_name(meta, path, g_strdup_printf("%" G_GINT64_FORMAT, json_node_get_int(node)));
+        gwy_dict_set_string_by_name(meta, path, g_strdup_printf("%" G_GINT64_FORMAT, json_node_get_int(node)));
     else if (type == G_TYPE_DOUBLE)
-        gwy_container_set_string_by_name(meta, path, g_strdup_printf("%g", json_node_get_double(node)));
+        gwy_dict_set_string_by_name(meta, path, g_strdup_printf("%g", json_node_get_double(node)));
     else if (type == G_TYPE_BOOLEAN)
-        gwy_container_set_const_string_by_name(meta, path, json_node_get_boolean(node) ? "True" : "False");
+        gwy_dict_set_const_string_by_name(meta, path, json_node_get_boolean(node) ? "True" : "False");
     else
         return FALSE;
 
@@ -576,7 +576,7 @@ format_atomic_json_meta(JsonNode *node, GwyContainer *meta, const gchar *path)
 }
 
 static void
-add_one_meta(GwyContainer *meta, JsonObject *object, GString *path)
+add_one_meta(GwyDict *meta, JsonObject *object, GString *path)
 {
     guint len = path->len;
 
@@ -672,7 +672,7 @@ load_file(const gchar *filename,
             goto fail;
     }
 
-    pfile.meta = gwy_container_new_in_construction();
+    pfile.meta = gwy_dict_new_in_construction();
     g_string_assign(pfile.str, "Param");
     add_one_meta(pfile.meta, pfile.param.root, pfile.str);
     g_string_assign(pfile.str, "Scan");
