@@ -1,5 +1,5 @@
 /*
- *  $Id: pt3file.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: pt3file.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -275,7 +275,7 @@ static GwyField*      extract_counts            (const PicoHarpFile *pt3file,
                                                  const guchar *p);
 static GwyGraphModel* extract_decay             (const PicoHarpFile *pt3file,
                                                  const guchar *p);
-static GwyContainer*  get_metadata              (PicoHarpFile *pt3file);
+static GwyDict*  get_metadata              (PicoHarpFile *pt3file);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -859,15 +859,15 @@ extract_decay(const PicoHarpFile *pt3file,
 }
 
 #define add_meta_str(name, field) \
-    gwy_container_set_string_by_name(meta, name, g_strndup(pt3file->field, sizeof(pt3file->field)))
+    gwy_dict_set_string_by_name(meta, name, g_strndup(pt3file->field, sizeof(pt3file->field)))
 
 #define add_meta_uint(name, field) \
-    gwy_container_set_string_by_name(meta, name, g_strdup_printf("%u", pt3file->field))
+    gwy_dict_set_string_by_name(meta, name, g_strdup_printf("%u", pt3file->field))
 
-static GwyContainer*
+static GwyDict*
 get_metadata(PicoHarpFile *pt3file)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     add_meta_str("Format Version", format_version);
     add_meta_str("Creator Name", creator_name);
@@ -878,13 +878,13 @@ get_metadata(PicoHarpFile *pt3file)
     add_meta_str("Hardware Version", board.hardware_version);
 
     add_meta_uint("Measurement Mode", measurement_mode);
-    gwy_container_set_string_by_name(meta, "Offset", g_strdup_printf("%d ns", pt3file->offset));
-    gwy_container_set_string_by_name(meta, "Acquisition Time", g_strdup_printf("%d ms", pt3file->acquisition_time));
+    gwy_dict_set_string_by_name(meta, "Offset", g_strdup_printf("%d ns", pt3file->offset));
+    gwy_dict_set_string_by_name(meta, "Acquisition Time", g_strdup_printf("%d ms", pt3file->acquisition_time));
     add_meta_uint("Hardware Serial Number", board.hardware_serial);
-    gwy_container_set_const_string_by_name(meta, "Imaging Device",
-                                           gwy_enuml_to_string(pt3file->imaging.common.instrument,
-                                                               "PI E710", 1, "KDT180-100-Im", 2, "LSM", 3,
-                                                               NULL));
+    gwy_dict_set_const_string_by_name(meta, "Imaging Device",
+                                      gwy_enuml_to_string(pt3file->imaging.common.instrument,
+                                                          "PI E710", 1, "KDT180-100-Im", 2, "LSM", 3,
+                                                          NULL));
 
     return meta;
 }
