@@ -1,5 +1,5 @@
 /*
- *  $Id: quazarnpic.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: quazarnpic.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -1115,7 +1115,7 @@ static void
 gather_units(GQuark quark, G_GNUC_UNUSED GValue *gvalue, gpointer user_data)
 {
     GPtrArray *a = (GPtrArray*)user_data;
-    GwyContainer *meta = g_ptr_array_index(a, 0);
+    GwyDict *meta = g_ptr_array_index(a, 0);
     GString *str = g_ptr_array_index(a, 1);
     const gchar *strkey = g_quark_to_string(quark);
 
@@ -1124,7 +1124,7 @@ gather_units(GQuark quark, G_GNUC_UNUSED GValue *gvalue, gpointer user_data)
 
     g_string_assign(str, strkey);
     g_string_truncate(str, str->len-4);
-    if (!gwy_container_contains_by_name(meta, str->str))
+    if (!gwy_dict_contains_by_name(meta, str->str))
         return;
 
     g_ptr_array_add(a, (gpointer)strkey);
@@ -1172,11 +1172,11 @@ gather_units(GQuark quark, G_GNUC_UNUSED GValue *gvalue, gpointer user_data)
  *
  * This is an abridged version.  There are many more fields.
  */
-static GwyContainer*
+static GwyDict*
 extract_metadata(PickleObject *root, NpicFileInfo *info)
 {
     PickleObject *keyobj, *valobj, *obj;
-    GwyContainer *meta;
+    GwyDict *meta;
     const gchar *key;
     GPtrArray *a;
     GString *str;
@@ -1187,7 +1187,7 @@ extract_metadata(PickleObject *root, NpicFileInfo *info)
 
     a = root->v.a;
     len = a->len;
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     str = g_string_new(NULL);
     for (i = 0; i+1 < len; i += 2) {
         keyobj = g_ptr_array_index(a, i);
@@ -1198,18 +1198,18 @@ extract_metadata(PickleObject *root, NpicFileInfo *info)
 
         key = keyobj->v.s;
         if (valobj->type == OBJECT_STRING) {
-            gwy_container_set_const_string_by_name(meta, key, valobj->v.s);
+            gwy_dict_set_const_string_by_name(meta, key, valobj->v.s);
             if (gwy_strequal(key, "XCalibrationUnit"))
                 info->xcalunit = valobj->v.s;
             else if (gwy_strequal(key, "ZCalibrationUnit"))
                 info->zcalunit = valobj->v.s;
         }
         else if (valobj->type == OBJECT_BOOL)
-            gwy_container_set_const_string_by_name(meta, key, valobj->v.b ? "True" : "False");
+            gwy_dict_set_const_string_by_name(meta, key, valobj->v.b ? "True" : "False");
         else if (valobj->type == OBJECT_INT)
-            gwy_container_set_string_by_name(meta, key, g_strdup_printf("%ld", (glong)valobj->v.i));
+            gwy_dict_set_string_by_name(meta, key, g_strdup_printf("%ld", (glong)valobj->v.i));
         else if (valobj->type == OBJECT_FLOAT) {
-            gwy_container_set_string_by_name(meta, key, g_strdup_printf("%g", valobj->v.d));
+            gwy_dict_set_string_by_name(meta, key, g_strdup_printf("%g", valobj->v.d));
             if (gwy_strequal(key, "XCalibration"))
                 info->xcal = fabs(valobj->v.d);
             else if (gwy_strequal(key, "YCalibration"))
@@ -1225,8 +1225,8 @@ extract_metadata(PickleObject *root, NpicFileInfo *info)
                 if (!(obj = get_object_from_seq(valobj, 1, OBJECT_FLOAT)))
                     continue;
                 info->ystep = obj->v.d;
-                gwy_container_set_string_by_name(meta, "StepSizeX", g_strdup_printf("%g", info->xstep));
-                gwy_container_set_string_by_name(meta, "StepSizeY", g_strdup_printf("%g", info->ystep));
+                gwy_dict_set_string_by_name(meta, "StepSizeX", g_strdup_printf("%g", info->xstep));
+                gwy_dict_set_string_by_name(meta, "StepSizeY", g_strdup_printf("%g", info->ystep));
                 gwy_debug("steps %g, %g", info->xstep, info->ystep);
             }
             else if (gwy_strequal(key, "ImageSize") && valobj->v.a->len == 2) {
@@ -1239,7 +1239,7 @@ extract_metadata(PickleObject *root, NpicFileInfo *info)
                         g_ptr_array_add(info->channel_names, obj->v.s);
                         g_string_assign(str, key);
                         g_string_append_printf(str, "[%u]", j);
-                        gwy_container_set_const_string_by_name(meta, str->str, obj->v.s);
+                        gwy_dict_set_const_string_by_name(meta, str->str, obj->v.s);
                     }
                 }
             }
@@ -1256,17 +1256,17 @@ extract_metadata(PickleObject *root, NpicFileInfo *info)
     a = g_ptr_array_new();
     g_ptr_array_add(a, meta);
     g_ptr_array_add(a, str);
-    gwy_container_foreach(meta, NULL, gather_units, a);
+    gwy_dict_foreach(meta, NULL, gather_units, a);
     for (i = 2; i < a->len; i++) {
         const gchar *unit, *value;
 
         g_string_assign(str, g_ptr_array_index(a, i));
-        unit = gwy_container_get_string_by_name(meta, str->str);
+        unit = gwy_dict_get_string_by_name(meta, str->str);
         g_string_truncate(str, str->len-4);
-        value = gwy_container_get_string_by_name(meta, str->str);
+        value = gwy_dict_get_string_by_name(meta, str->str);
 
-        gwy_container_set_string_by_name(meta, str->str, g_strconcat(value, " ", unit, NULL));
-        gwy_container_remove_by_name(meta, g_ptr_array_index(a, i));
+        gwy_dict_set_string_by_name(meta, str->str, g_strconcat(value, " ", unit, NULL));
+        gwy_dict_remove_by_name(meta, g_ptr_array_index(a, i));
     }
 
     g_string_free(str, TRUE);
@@ -1282,7 +1282,7 @@ load_file(const gchar *filename,
 {
     NpicFileInfo info;
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GPtrArray *fields = NULL;
     GwyField *field;
     guchar *buffer = NULL;
@@ -1362,7 +1362,7 @@ load_file(const gchar *filename,
         if (s)
             gwy_file_pass_title(file, GWY_FILE_IMAGE, i, s);
 
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(meta));
     }
     g_object_unref(unit);
     g_object_unref(volt);
