@@ -1,5 +1,5 @@
 /*
- *  $Id: rawfile.c 29029 2025-12-19 14:55:48Z yeti-dn $
+ *  $Id: rawfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -159,7 +159,7 @@ typedef struct {
     GwyParams *params;
     RawFileFile file;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -377,7 +377,7 @@ detect_file(G_GNUC_UNUSED const GwyFileDetectInfo *fileinfo,
     gboolean takeover = FALSE;
 
     /* Read the setting direcly. Avoid instantiating a GwyParams object in file type detection. */
-    gwy_container_gis_boolean_by_name(gwy_app_settings_get(), "/module/rawfile/takeover", &takeover);
+    gwy_dict_gis_boolean_by_name(gwy_app_settings_get(), "/module/rawfile/takeover", &takeover);
 
     return takeover ? 1 : 0;
 }
@@ -393,7 +393,7 @@ load_file(const gchar *filename,
     GError *err = NULL;
     gsize size = 0;
 
-    if (mode !=GWY_RUN_INTERACTIVE) {
+    if (mode != GWY_RUN_INTERACTIVE) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_INTERACTIVE,
                     _("Raw data import must be run as interactive."));
         return FALSE;
@@ -875,7 +875,7 @@ preview(gpointer user_data)
     if ((field = read_field(args, &error))) {
         /* Fix any NaNs in the data for preview and remember the mask for later. */
         g_clear_object(&args->mask);
-        args->mask = gwy_app_channel_mask_of_nans(field, TRUE);
+        args->mask = gwy_mask_nans_in_field(field, TRUE);
         gwy_field_assign(args->field, field);
         g_object_unref(field);
         gtk_label_set_text(GTK_LABEL(gui->error), "");
