@@ -1,5 +1,5 @@
 /*
- *  $Id: renishaw.c 28803 2025-11-05 11:58:19Z yeti-dn $
+ *  $Id: renishaw.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2014-2025 Daniil Bratashov (dn2010), David Necas (Yeti)..
  *  Data structures and constants are copyright (c) 2011 Renishaw plc.
  *
@@ -333,11 +333,11 @@ typedef struct {
 typedef struct {
     GHashTable *keys;
     GHashTable *values;
-    GwyContainer *data;
+    GwyDict *data;
 } WdfPsetData;
 
 typedef struct {
-    GwyContainer *pset;
+    GwyDict *pset;
     guint64 numpoints;
     gfloat *data;
 } WdfMapData;
@@ -358,25 +358,25 @@ typedef struct {
     WdfMapData   **maps;
 } WdfFile;
 
-static gboolean      module_register   (void);
-static gint          detect_file       (const GwyFileDetectInfo *fileinfo,
-                                        gboolean only_name);
-static GwyFile*      load_file         (const gchar *filename,
-                                        GwyRunModeFlags mode,
-                                        GError **error);
-static gsize         read_header       (const guchar *buffer,
-                                        gsize size,
-                                        WdfHeader *header,
-                                        GError **error);
-static gsize         read_block_header (const guchar *buffer,
-                                        gsize size,
-                                        WdfBlock *header,
-                                        GError **error);
-static void          read_maparea_block(const guchar *buffer,
-                                        WdfMapArea *maparea);
-static GwyContainer* read_pset         (const guchar *buffer,
-                                        gsize size);
-static gchar*        read_datetime     (gint64 ticks);
+static gboolean module_register   (void);
+static gint     detect_file       (const GwyFileDetectInfo *fileinfo,
+                                   gboolean only_name);
+static GwyFile* load_file         (const gchar *filename,
+                                   GwyRunModeFlags mode,
+                                   GError **error);
+static gsize    read_header       (const guchar *buffer,
+                                   gsize size,
+                                   WdfHeader *header,
+                                   GError **error);
+static gsize    read_block_header (const guchar *buffer,
+                                   gsize size,
+                                   WdfBlock *header,
+                                   GError **error);
+static void     read_maparea_block(const guchar *buffer,
+                                   WdfMapArea *maparea);
+static GwyDict* read_pset         (const guchar *buffer,
+                                   gsize size);
+static gchar*   read_datetime     (gint64 ticks);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -422,7 +422,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *metadata = NULL, *pset_data;
+    GwyDict *metadata = NULL, *pset_data;
     gchar *buffer = NULL;
     gsize len, size = 0;
     GError *err = NULL;
@@ -476,7 +476,7 @@ load_file(const gchar *filename,
               fileheader.nspectra);
 
     filedata.xlistunits = WDF_DATAUNITS_ARBITRARY;
-    metadata = gwy_container_new_in_construction();
+    metadata = gwy_dict_new_in_construction();
     file = gwy_file_new_in_construction();
 
     while (size > 0) {
@@ -601,7 +601,7 @@ load_file(const gchar *filename,
                     key = g_strdup_printf("/data");
                 else
                     key = g_strdup_printf("/");
-                gwy_container_transfer(pset_data, metadata, "/", key, FALSE, TRUE);
+                gwy_dict_transfer(pset_data, metadata, "/", key, FALSE, TRUE);
                 g_free(key);
                 g_object_unref(pset_data);
             }
@@ -757,7 +757,7 @@ load_file(const gchar *filename,
         for (m = 0; m < filedata.nummaps; m++) { /* z maps */
             zres = filedata.maps[m]->numpoints;
 
-            if (gwy_container_gis_string_by_name(filedata.maps[m]->pset, "/Label", &label)) {
+            if (gwy_dict_gis_string_by_name(filedata.maps[m]->pset, "/Label", &label)) {
                 title = g_strdup_printf("%s", label);
             }
             else
@@ -1017,7 +1017,7 @@ load_file(const gchar *filename,
                                         z);
             }
             gwy_file_pass_title(file, GWY_FILE_VOLUME, z, title);
-            gwy_file_pass_meta(file, GWY_FILE_VOLUME, z, gwy_container_copy(metadata));
+            gwy_file_pass_meta(file, GWY_FILE_VOLUME, z, gwy_dict_copy(metadata));
 
             gwy_log_add_import(file, GWY_FILE_VOLUME, z, NULL, filename);
             if (filedata.maparea->flags & WDF_MAPAREA_XYLINE) {
@@ -1130,12 +1130,12 @@ load_file(const gchar *filename,
             gwy_file_pass_image(file, m + 1, dfield);
             pset_data = filedata.maps[m]->pset;
 
-            if (gwy_container_gis_string_by_name(pset_data, "/Label", &label))
+            if (gwy_dict_gis_string_by_name(pset_data, "/Label", &label))
                 gwy_file_set_title(file, GWY_FILE_IMAGE, m + 1, label, FALSE);
 
             hasspectrum = FALSE;
             ydata = g_new(gdouble, zres);
-            if (gwy_container_gis_string_by_name(pset_data, "/overlaySpectrum", &spectrum)) {
+            if (gwy_dict_gis_string_by_name(pset_data, "/overlaySpectrum", &spectrum)) {
                 mapspectra++;
                 hasspectrum = TRUE;
                 specvalues = g_strsplit(spectrum, ";", -1);
@@ -1151,7 +1151,7 @@ load_file(const gchar *filename,
             }
 
             siunitsp = NULL;
-            if (gwy_container_gis_string_by_name(pset_data, "/overlayXListUnits", &specxunit)) {
+            if (gwy_dict_gis_string_by_name(pset_data, "/overlayXListUnits", &specxunit)) {
                 xunits = atoi(specxunit);
                 unit = gwy_enum_to_string(xunits, wdf_units, 26);
                 siunitsp = gwy_unit_new_parse(unit, &power10x);
@@ -1163,7 +1163,7 @@ load_file(const gchar *filename,
             }
 
             xdata = g_new(gdouble, zres);
-            if (gwy_container_gis_string_by_name(pset_data, "/overlayXList", &spectrumx)) {
+            if (gwy_dict_gis_string_by_name(pset_data, "/overlayXList", &spectrumx)) {
                 specvalues = g_strsplit(spectrumx, ";", -1);
                 specp = specvalues;
                 numvalues = 0;
@@ -1180,7 +1180,7 @@ load_file(const gchar *filename,
             }
 
 
-            if (gwy_container_gis_string_by_name(pset_data, "/overlayLabel", &speclabel)) {
+            if (gwy_dict_gis_string_by_name(pset_data, "/overlayLabel", &speclabel)) {
                 title = g_strdup_printf("%s", speclabel);
             }
             else {
@@ -1210,7 +1210,7 @@ load_file(const gchar *filename,
             g_free(xdata);
             g_free(ydata);
 
-            gwy_file_pass_meta(file, GWY_FILE_IMAGE, m + 1, gwy_container_copy(pset_data));
+            gwy_file_pass_meta(file, GWY_FILE_IMAGE, m + 1, gwy_dict_copy(pset_data));
             gwy_log_add_import(file, GWY_FILE_IMAGE, m + 1, NULL, filename);
         }
         g_object_unref(siunitz);
@@ -1428,11 +1428,11 @@ extract_metadata_from_values(gpointer key, gpointer value,
     gwy_debug("value = %s", (char *)value);
     value_value = g_hash_table_lookup(pdata->values, key);
     if (value && value_value) {
-        gwy_container_set_const_string_by_name(pdata->data, value, value_value);
+        gwy_dict_set_const_string_by_name(pdata->data, value, value_value);
     }
 }
 
-static GwyContainer*
+static GwyDict*
 read_pset(const guchar *buffer, gsize size)
 {
     gsize size2;
@@ -1448,8 +1448,8 @@ read_pset(const guchar *buffer, gsize size)
     GHashTable *keys = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
     GHashTable *values = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
 
-    GwyContainer *data = gwy_container_new_in_construction();
-    GwyContainer *nested = NULL;
+    GwyDict *data = gwy_dict_new_in_construction();
+    GwyDict *nested = NULL;
 
     while (remaining > 0) {
         pset.type = *(buffer++);
@@ -1548,7 +1548,7 @@ read_pset(const guchar *buffer, gsize size)
                     nested = NULL;
                     nested = read_pset(buffer, size2);
                     if (nested)
-                        gwy_container_transfer(nested, data, "/", "/", FALSE, FALSE);
+                        gwy_dict_transfer(nested, data, "/", "/", FALSE, FALSE);
                     gwy_debug("buffer after = %p", buffer);
                     buffer += size2;
                     remaining -= size2;
