@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-sm3.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: rhk-sm3.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -216,7 +216,7 @@ static gint          detect_file    (const GwyFileDetectInfo *fileinfo,
 static GwyFile*      load_file      (const gchar *filename,
                                      GwyRunModeFlags mode,
                                      GError **error);
-static GwyContainer* get_metadata   (RHKPage *rhkpage);
+static GwyDict* get_metadata   (RHKPage *rhkpage);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -530,7 +530,7 @@ load_file(const gchar *filename,
     GPtrArray *rhkfile;
     RHKPage *rhkpage;
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     gsize fullsize, size = 0;
     GError *err = NULL;
@@ -664,14 +664,14 @@ load_file(const gchar *filename,
     return file;
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(RHKPage *rhkpage)
 {
     const gchar *s;
     gchar *str;
     guint i;
 
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     s = gwy_enuml_to_string(rhkpage->page_type,
                             "Topographic", RHK_PAGE_TOPOGRAPHIC,
@@ -703,11 +703,11 @@ get_metadata(RHKPage *rhkpage)
                             "AFM using AFM-100", RHK_PAGE_AFM_100,
                             NULL);
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Type", s);
+        gwy_dict_set_const_string_by_name(meta, "Type", s);
 
     s = gwy_enum_to_string(rhkpage->scan_dir, scan_directions, G_N_ELEMENTS(scan_directions));
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Scan Direction", s);
+        gwy_dict_set_const_string_by_name(meta, "Scan Direction", s);
 
     s = gwy_enuml_to_string(rhkpage->source_type,
                             "Raw", RHK_SOURCE_RAW_PAGE,
@@ -716,37 +716,37 @@ get_metadata(RHKPage *rhkpage)
                             "Imported", RHK_SOURCE_IMPORTED_PAGE,
                             NULL);
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Source", s);
+        gwy_dict_set_const_string_by_name(meta, "Source", s);
 
-    gwy_container_set_string_by_name(meta, "Bias", g_strdup_printf("%g V", rhkpage->bias));
-    gwy_container_set_string_by_name(meta, "Rotation angle", g_strdup_printf("%f", rhkpage->angle));
-    gwy_container_set_string_by_name(meta, "Period", g_strdup_printf("%f s", rhkpage->period));
+    gwy_dict_set_string_by_name(meta, "Bias", g_strdup_printf("%g V", rhkpage->bias));
+    gwy_dict_set_string_by_name(meta, "Rotation angle", g_strdup_printf("%f", rhkpage->angle));
+    gwy_dict_set_string_by_name(meta, "Period", g_strdup_printf("%f s", rhkpage->period));
 
     s = rhkpage->strings[RHK_STRING_DATE];
     if (s && *s) {
         str = g_strconcat(s, " ", rhkpage->strings[RHK_STRING_TIME], NULL);
-        gwy_container_set_string_by_name(meta, "Date", str);
+        gwy_dict_set_string_by_name(meta, "Date", str);
     }
 
     s = rhkpage->strings[RHK_STRING_LABEL];
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Label", s);
+        gwy_dict_set_const_string_by_name(meta, "Label", s);
 
     s = rhkpage->strings[RHK_STRING_PATH];
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Path", s);
+        gwy_dict_set_const_string_by_name(meta, "Path", s);
 
     s = rhkpage->strings[RHK_STRING_SYSTEM_TEXT];
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "System comment", s);
+        gwy_dict_set_const_string_by_name(meta, "System comment", s);
 
     s = rhkpage->strings[RHK_STRING_SESSION_TEXT];
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Session comment", s);
+        gwy_dict_set_const_string_by_name(meta, "Session comment", s);
 
     s = rhkpage->strings[RHK_STRING_USER_TEXT];
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "User comment", s);
+        gwy_dict_set_const_string_by_name(meta, "User comment", s);
 
     str = g_new(gchar, 33);
     for (i = 0; i < 16; i++) {
@@ -756,7 +756,7 @@ get_metadata(RHKPage *rhkpage)
         str[2*i + 1] = hex[rhkpage->page_id[i] % 16];
     }
     str[32] = '\0';
-    gwy_container_set_string_by_name(meta, "Page ID", str);
+    gwy_dict_set_string_by_name(meta, "Page ID", str);
 
     return meta;
 }
