@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-sm4.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: rhk-sm4.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -416,12 +416,12 @@ static const gchar*         describe_object        (RHKObjectType type);
 static void                 free_rhkfile           (RHKFile *rhkfile);
 static GwyField*            page_to_field          (const RHKPage *page);
 static GwyGraphModel*       page_to_graph_model    (const RHKPage *page);
-static GwyContainer*        get_metadata           (const RHKPageIndex *pi,
+static GwyDict*             get_metadata           (const RHKPageIndex *pi,
                                                     const RHKPage *page,
-                                                    GwyContainer *basemeta);
+                                                    GwyDict *basemeta);
 static void                 add_ppl_pro_status_meta(const RHKPage *page,
-                                                    GwyContainer *meta);
-static GwyContainer*        read_prm               (const RHKObject *prmheader,
+                                                    GwyDict *meta);
+static GwyDict*             read_prm               (const RHKObject *prmheader,
                                                     const RHKObject *prm,
                                                     const guchar *buffer);
 
@@ -477,7 +477,7 @@ load_file(const gchar *filename,
     RHKFile rhkfile;
     RHKObject *obj, o;
     GwyFile *file = NULL;
-    GwyContainer *prmmeta = NULL;
+    GwyDict *prmmeta = NULL;
     guchar *buffer = NULL;
     gsize size = 0;
     GError *err = NULL;
@@ -597,7 +597,7 @@ load_file(const gchar *filename,
             if (page->page_type == RHK_PAGE_TOPOGRAPHIC) {
                 g_string_assign(key, g_quark_to_string(quark));
                 g_string_append(key, "/visible");
-                gwy_container_set_boolean_by_name(file, key->str, TRUE);
+                gwy_dict_set_boolean_by_name(file, key->str, TRUE);
             }
             */
 
@@ -1182,13 +1182,13 @@ page_to_graph_model(const RHKPage *page)
 }
 
 static void
-meta_string(const RHKPage *page, RHKStringType stringid, const gchar *name, GwyContainer *meta)
+meta_string(const RHKPage *page, RHKStringType stringid, const gchar *name, GwyDict *meta)
 {
     const gchar *s;
 
     g_return_if_fail(stringid < RHK_STRING_NSTRINGS);
     if ((s = page->strings[stringid]))
-        gwy_container_set_const_string_by_name(meta, name, s);
+        gwy_dict_set_const_string_by_name(meta, name, s);
 }
 
 static const gchar*
@@ -1203,36 +1203,36 @@ make_prefix(GString *str, const gchar *prefix, const gchar *name)
 }
 
 static void
-set_meta_double(GwyContainer *meta, GString *str, const gchar *prefix, const gchar *name,
+set_meta_double(GwyDict *meta, GString *str, const gchar *prefix, const gchar *name,
                 gdouble value, const gchar *unit)
 {
     gchar *s = g_strdup_printf("%g%s%s", value, unit ? " " : "", unit ? unit : "");
-    gwy_container_set_string_by_name(meta, make_prefix(str, prefix, name), s);
+    gwy_dict_set_string_by_name(meta, make_prefix(str, prefix, name), s);
 }
 
 static void
-set_meta_int(GwyContainer *meta, GString *str, const gchar *prefix, const gchar *name,
+set_meta_int(GwyDict *meta, GString *str, const gchar *prefix, const gchar *name,
              gint value)
 {
     gchar *s = g_strdup_printf("%d", value);
-    gwy_container_set_string_by_name(meta, make_prefix(str, prefix, name), s);
+    gwy_dict_set_string_by_name(meta, make_prefix(str, prefix, name), s);
 }
 
-static GwyContainer*
-get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta)
+static GwyDict*
+get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyDict *basemeta)
 {
     static const gchar hex[] = "0123456789abcdef";
 
-    GwyContainer *meta;
+    GwyDict *meta;
     GString *key;
     const gchar *s;
     gchar *str;
     guint i, w;
 
     if (basemeta)
-        meta = gwy_container_copy(basemeta);
+        meta = gwy_dict_copy(basemeta);
     else
-        meta = gwy_container_new_in_construction();
+        meta = gwy_dict_new_in_construction();
 
     key = g_string_new(NULL);
     s = gwy_enuml_to_string(page->page_type,
@@ -1277,11 +1277,11 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
                             "Discrete spectroscopy (relative points)", RHK_PAGE_DISCRETE_SPECTROSCOPY_RP,
                             NULL);
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Type", s);
+        gwy_dict_set_const_string_by_name(meta, "Type", s);
 
     s = gwy_enum_to_string(page->scan_dir, scan_directions, G_N_ELEMENTS(scan_directions));
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Scan Direction", s);
+        gwy_dict_set_const_string_by_name(meta, "Scan Direction", s);
 
     s = gwy_enuml_to_string(pi->source,
                             "Raw", RHK_SOURCE_RAW,
@@ -1290,7 +1290,7 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
                             "Imported", RHK_SOURCE_IMPORTED,
                             NULL);
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Source", s);
+        gwy_dict_set_const_string_by_name(meta, "Source", s);
 
     set_meta_double(meta, key, NULL, "Bias", page->bias, "V");
     set_meta_double(meta, key, NULL, "Rotation angle", page->angle, "deg");
@@ -1319,7 +1319,7 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
     s = page->strings[RHK_STRING_DATE];
     if (s && *s) {
         str = g_strconcat(s, " ", page->strings[RHK_STRING_TIME], NULL);
-        gwy_container_set_string_by_name(meta, "Date", str);
+        gwy_dict_set_string_by_name(meta, "Date", str);
     }
 
     meta_string(page, RHK_STRING_LABEL, "Label", meta);
@@ -1345,7 +1345,7 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
         str[2*i + 1] = hex[pi->id[i] % 16];
     }
     str[32] = '\0';
-    gwy_container_set_string_by_name(meta, "Page ID", str);
+    gwy_dict_set_string_by_name(meta, "Page ID", str);
 
     str = g_new(gchar, 9);
     w = page->group_id;
@@ -1354,7 +1354,7 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
         w = w >> 4;
     }
     str[8] = '\0';
-    gwy_container_set_string_by_name(meta, "Group ID", str);
+    gwy_dict_set_string_by_name(meta, "Group ID", str);
 
     g_string_free(key, TRUE);
 
@@ -1362,7 +1362,7 @@ get_metadata(const RHKPageIndex *pi, const RHKPage *page, GwyContainer *basemeta
 }
 
 static void
-add_ppl_pro_status_meta(const RHKPage *page, GwyContainer *meta)
+add_ppl_pro_status_meta(const RHKPage *page, GwyDict *meta)
 {
     GString *key;
     gchar **lines;
@@ -1397,7 +1397,7 @@ add_ppl_pro_status_meta(const RHKPage *page, GwyContainer *meta)
                 g_string_append(key, "::");
             }
             g_string_append(key, lines[i]);
-            gwy_container_set_const_string_by_name(meta, key->str, value);
+            gwy_dict_set_const_string_by_name(meta, key->str, value);
             looking_for_second_prefix = FALSE;
         }
         else if (looking_for_second_prefix) {
@@ -1410,10 +1410,10 @@ add_ppl_pro_status_meta(const RHKPage *page, GwyContainer *meta)
     g_strfreev(lines);
 }
 
-static GwyContainer*
+static GwyDict*
 read_prm(const RHKObject *prmheader, const RHKObject *prm, const guchar *buffer)
 {
-    GwyContainer *prmmeta = NULL;
+    GwyDict *prmmeta = NULL;
     gchar *prmtext = NULL, *q, *line;
     gchar *header1 = NULL, *header2 = NULL, *header3 = NULL;
     gboolean compressed;
@@ -1469,7 +1469,7 @@ read_prm(const RHKObject *prmheader, const RHKObject *prm, const guchar *buffer)
     metaregex = g_regex_new("^<[0-9]{4}>\\s+(.+?)\\s+::(.*)$", G_REGEX_OPTIMIZE, 0, NULL);
     g_assert(metaregex);
 
-    prmmeta = gwy_container_new_in_construction();
+    prmmeta = gwy_dict_new_in_construction();
     key = g_string_new(NULL);
     q = prmtext;
     while ((line = gwy_str_next_line(&q))) {
@@ -1489,7 +1489,7 @@ read_prm(const RHKObject *prmheader, const RHKObject *prm, const guchar *buffer)
                 }
                 g_string_append(key, "::");
                 g_string_append(key, name);
-                gwy_container_set_string_by_name(prmmeta, key->str, value);
+                gwy_dict_set_string_by_name(prmmeta, key->str, value);
             }
             else
                 g_free(value);
