@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-spm32.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: rhk-spm32.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -157,7 +157,7 @@ static gboolean       read_range      (const gchar *buffer,
                                        const gchar *name,
                                        RHKRange *range);
 static void           free_rhkpage    (RHKPage *rhkpage);
-static GwyContainer*  get_metadata    (RHKPage *rhkpage);
+static GwyDict*  get_metadata    (RHKPage *rhkpage);
 static GwyField*      read_data       (RHKPage *rhkpage);
 static GwySpectra*    read_spectra    (RHKPage *rhkpage);
 static GwyGraphModel* spectra_to_graph(GwySpectra *spectra);
@@ -214,7 +214,7 @@ load_file(const gchar *filename,
     GArray *rhkfile;
     RHKPage *rhkpage;
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     gsize size = 0;
     GError *err = NULL;
@@ -494,31 +494,31 @@ free_rhkpage(RHKPage *rhkpage)
     g_free(rhkpage->comment);
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(RHKPage *rhkpage)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     const gchar *s;
 
-    gwy_container_set_string_by_name(meta, "Tunneling voltage", g_strdup_printf("%g mV", 1e3*rhkpage->iv.offset));
-    gwy_container_set_string_by_name(meta, "Current", g_strdup_printf("%g nA", 1e9*rhkpage->iv.scale));
+    gwy_dict_set_string_by_name(meta, "Tunneling voltage", g_strdup_printf("%g mV", 1e3*rhkpage->iv.offset));
+    gwy_dict_set_string_by_name(meta, "Current", g_strdup_printf("%g nA", 1e9*rhkpage->iv.scale));
     if (rhkpage->id)
-        gwy_container_set_string_by_name(meta, "Id", g_strdup_printf("%u", rhkpage->id));
+        gwy_dict_set_string_by_name(meta, "Id", g_strdup_printf("%u", rhkpage->id));
     if (rhkpage->date && *rhkpage->date)
-        gwy_container_set_const_string_by_name(meta, "Date", rhkpage->date);
+        gwy_dict_set_const_string_by_name(meta, "Date", rhkpage->date);
     if (rhkpage->comment && *rhkpage->comment)
-        gwy_container_set_const_string_by_name(meta, "Comment", rhkpage->comment);
+        gwy_dict_set_const_string_by_name(meta, "Comment", rhkpage->comment);
     if (rhkpage->label && *rhkpage->label)
-        gwy_container_set_const_string_by_name(meta, "Label", rhkpage->label);
+        gwy_dict_set_const_string_by_name(meta, "Label", rhkpage->label);
 
     s = gwy_enum_to_string(rhkpage->page_type, scan_directions, G_N_ELEMENTS(scan_directions));
     if (s && *s)
-        gwy_container_set_const_string_by_name(meta, "Image type", s);
+        gwy_dict_set_const_string_by_name(meta, "Image type", s);
 
     // FIXME - seems one can read 0 for spectra as well, but maybe it's not that important - it should be clear that
     // this is a nonsense value
     if (rhkpage->e_alpha)
-        gwy_container_set_string_by_name(meta, "Angle", g_strdup_printf("%g deg", rhkpage->alpha));
+        gwy_dict_set_string_by_name(meta, "Angle", g_strdup_printf("%g deg", rhkpage->alpha));
 
     return meta;
 }
