@@ -1,5 +1,5 @@
 /*
- *  $Id: rmitmd.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: rmitmd.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -118,7 +118,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     guchar *buffer = NULL;
     const guchar *p;
     gsize pos, size = 0;
@@ -148,13 +148,13 @@ load_file(const gchar *filename,
     gwy_file_pass_image(file, 0, field);
     gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "Topography", FALSE);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     if (tmdfile.comment) {
-        gwy_container_set_string_by_name(meta, "Comment", tmdfile.comment);
+        gwy_dict_set_string_by_name(meta, "Comment", tmdfile.comment);
         tmdfile.comment = NULL;
     }
-    gwy_container_set_string_by_name(meta, "X offset", g_strdup_printf("%g mm", tmdfile.xoffset));
-    gwy_container_set_string_by_name(meta, "Y offset", g_strdup_printf("%g mm", tmdfile.yoffset));
+    gwy_dict_set_string_by_name(meta, "X offset", g_strdup_printf("%g mm", tmdfile.xoffset));
+    gwy_dict_set_string_by_name(meta, "Y offset", g_strdup_printf("%g mm", tmdfile.yoffset));
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
 
