@@ -1,5 +1,5 @@
 /*
- *  $Id: robotics.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: robotics.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2011 Miroslav Valtr (Mira).
  *  E-mail: miraval@seznam.cz.
  *
@@ -237,21 +237,21 @@ load_file(const gchar *filename,
         gwy_log_add_import(file, GWY_FILE_IMAGE, i, NULL, filename);
     }
 
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    //gwy_container_set_string_by_name(meta, "File version:", g_strdup_printf("%d", version));
-    gwy_container_set_string_by_name(meta, "Comment:", comment);
+    //gwy_dict_set_string_by_name(meta, "File version:", g_strdup_printf("%d", version));
+    gwy_dict_set_string_by_name(meta, "Comment:", comment);
 
     if ((s = gwy_enuml_to_string(origin, "Refl", 0, "Transm", 1, "Extern", 2, NULL)))
-        gwy_container_set_const_string_by_name(meta, "Carto origin:", s);
+        gwy_dict_set_const_string_by_name(meta, "Carto origin:", s);
 
-    gwy_container_set_string_by_name(meta, "Nbs Points (x,y):",
-                                     g_strdup_printf("%u,%u", xres, yres));
-    gwy_container_set_string_by_name(meta, "Size (x,y in mm):",
-                                     g_strdup_printf("%.3lf,%.3lf", xreal*1000.0, yreal*1000.0));
+    gwy_dict_set_string_by_name(meta, "Nbs Points (x,y):",
+                                g_strdup_printf("%u,%u", xres, yres));
+    gwy_dict_set_string_by_name(meta, "Size (x,y in mm):",
+                                g_strdup_printf("%.3lf,%.3lf", xreal*1000.0, yreal*1000.0));
 
     for (i = 0; i < NUM_DFIELDS; i++)
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(meta));
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(meta));
 
     g_clear_object(&meta);
 
