@@ -1,5 +1,5 @@
 /*
- *  $Id: s94file.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: s94file.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2013-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -88,7 +88,7 @@ static gboolean      read_header    (S94File *s94file,
                                      const guchar *p,
                                      gsize size,
                                      GError **error);
-static GwyContainer* get_meta       (const S94File *s94file);
+static GwyDict* get_meta       (const S94File *s94file);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -249,28 +249,28 @@ read_header(S94File *s94file,
     return TRUE;
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(const S94File *s94file)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_string_by_name(meta, "Image number (original)", g_strdup_printf("%u", s94file->orig_imageno));
-    gwy_container_set_string_by_name(meta, "Image mode", g_strdup_printf("%u", s94file->mode));
-    gwy_container_set_string_by_name(meta, "X points", g_strdup_printf("%u", s94file->xres));
-    gwy_container_set_string_by_name(meta, "Y points", g_strdup_printf("%u", s94file->yres));
-    gwy_container_set_string_by_name(meta, "X size", g_strdup_printf("%g nm", s94file->xreal));
-    gwy_container_set_string_by_name(meta, "Y size", g_strdup_printf("%g nm", s94file->yreal));
-    gwy_container_set_string_by_name(meta, "X offset", g_strdup_printf("%g nm", s94file->xoff));
-    gwy_container_set_string_by_name(meta, "Y offset", g_strdup_printf("%g nm", s94file->yoff));
-    gwy_container_set_const_string_by_name(meta, "X/Y swapped", s94file->swapxy ? "Yes" : "No");
-    gwy_container_set_string_by_name(meta, "Scan angle", g_strdup_printf("%u deg", s94file->angle));
-    gwy_container_set_string_by_name(meta, "Scan speed", g_strdup_printf("%g nm/s", s94file->scanspeed));
-    gwy_container_set_string_by_name(meta, "Z gain", g_strdup_printf("%u", s94file->zgain));
-    gwy_container_set_string_by_name(meta, "Section", g_strdup_printf("%u", s94file->section));
-    gwy_container_set_string_by_name(meta, "Kp", g_strdup_printf("%g", s94file->Kp));
-    gwy_container_set_string_by_name(meta, "Tn", g_strdup_printf("%g", s94file->Tn));
-    gwy_container_set_string_by_name(meta, "Tv", g_strdup_printf("%g", s94file->Tv));
-    gwy_container_set_string_by_name(meta, "It", g_strdup_printf("%g", s94file->It));
+    gwy_dict_set_string_by_name(meta, "Image number (original)", g_strdup_printf("%u", s94file->orig_imageno));
+    gwy_dict_set_string_by_name(meta, "Image mode", g_strdup_printf("%u", s94file->mode));
+    gwy_dict_set_string_by_name(meta, "X points", g_strdup_printf("%u", s94file->xres));
+    gwy_dict_set_string_by_name(meta, "Y points", g_strdup_printf("%u", s94file->yres));
+    gwy_dict_set_string_by_name(meta, "X size", g_strdup_printf("%g nm", s94file->xreal));
+    gwy_dict_set_string_by_name(meta, "Y size", g_strdup_printf("%g nm", s94file->yreal));
+    gwy_dict_set_string_by_name(meta, "X offset", g_strdup_printf("%g nm", s94file->xoff));
+    gwy_dict_set_string_by_name(meta, "Y offset", g_strdup_printf("%g nm", s94file->yoff));
+    gwy_dict_set_const_string_by_name(meta, "X/Y swapped", s94file->swapxy ? "Yes" : "No");
+    gwy_dict_set_string_by_name(meta, "Scan angle", g_strdup_printf("%u deg", s94file->angle));
+    gwy_dict_set_string_by_name(meta, "Scan speed", g_strdup_printf("%g nm/s", s94file->scanspeed));
+    gwy_dict_set_string_by_name(meta, "Z gain", g_strdup_printf("%u", s94file->zgain));
+    gwy_dict_set_string_by_name(meta, "Section", g_strdup_printf("%u", s94file->section));
+    gwy_dict_set_string_by_name(meta, "Kp", g_strdup_printf("%g", s94file->Kp));
+    gwy_dict_set_string_by_name(meta, "Tn", g_strdup_printf("%g", s94file->Tn));
+    gwy_dict_set_string_by_name(meta, "Tv", g_strdup_printf("%g", s94file->Tv));
+    gwy_dict_set_string_by_name(meta, "It", g_strdup_printf("%g", s94file->It));
 
     return meta;
 }
