@@ -1,5 +1,5 @@
 /*
- *  $Id: sdfile.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: sdfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -139,7 +139,7 @@ static gchar*    sdfile_next_line  (gchar **buffer,
                                     const gchar *key,
                                     GError **error);
 static GwyField* read_data_bin     (SDFile *sdfile,
-                                    GwyField **mfield);
+                                    GwyNield **mfield);
 static GwyField* read_data_text    (SDFile *sdfile,
                                     GError **error);
 
@@ -148,7 +148,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Surfstand group SDF (Surface Data File) files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.15",
+    "0.16",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
@@ -258,11 +258,11 @@ micromap_detect(const GwyFileDetectInfo *fileinfo, gboolean only_name)
 
 static void
 sdfile_set_units(SDFile *sdfile,
-                 GwyField *dfield)
+                 GwyField *field)
 {
-    gwy_field_multiply(dfield, sdfile->zscale);
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
-    gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), "m");
+    gwy_field_multiply(field, sdfile->zscale);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
+    gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
 }
 
 static GwyFile*
@@ -276,7 +276,8 @@ sdfile_load_bin(const gchar *filename,
     const guchar *p;
     gsize len, size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL, *mfield = NULL;
+    GwyField *field = NULL;
+    GwyNield *mask = NULL;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -287,19 +288,19 @@ sdfile_load_bin(const gchar *filename,
     p = buffer;
     if (read_header_bin(&p, &len, &sdfile, error)) {
         if (check_params(&sdfile, len, error))
-            dfield = read_data_bin(&sdfile, &mfield);
+            field = read_data_bin(&sdfile, &mask);
     }
 
     gwy_file_abandon_contents(buffer, size, NULL);
-    if (!dfield)
+    if (!field)
         return NULL;
 
-    sdfile_set_units(&sdfile, dfield);
+    sdfile_set_units(&sdfile, field);
 
     file = gwy_file_new_in_construction();
-    gwy_file_pass_image(file, 0, dfield);
-    if (mfield)
-        gwy_file_pass_image_mask(file, 0, mfield);
+    gwy_file_pass_image(file, 0, field);
+    if (mask)
+        gwy_file_pass_image_mask(file, 0, mask);
     gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "Topography", FALSE);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
 
@@ -309,12 +310,12 @@ sdfile_load_bin(const gchar *filename,
 static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *cval;
 
     if (!(cval = gwy_convert_to_utf8(value, -1, "ISO-8859-1")))
         return;
-    gwy_container_set_string_by_name(meta, key, cval);
+    gwy_dict_set_string_by_name(meta, key, cval);
 }
 
 static GwyFile*
@@ -327,7 +328,7 @@ sdfile_load_text(const gchar *filename,
     gchar *p, *buffer = NULL;
     gsize len, size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL;
+    GwyField *field = NULL;
 
     if (!g_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -337,22 +338,22 @@ sdfile_load_text(const gchar *filename,
     p = buffer;
     if (read_header_text(&p, &len, &sdfile, error)) {
         if (check_params(&sdfile, len, error))
-            dfield = read_data_text(&sdfile, error);
+            field = read_data_text(&sdfile, error);
     }
 
-    if (!dfield) {
+    if (!field) {
         g_free(buffer);
         return NULL;
     }
 
-    sdfile_set_units(&sdfile, dfield);
+    sdfile_set_units(&sdfile, field);
 
     file = gwy_file_new_in_construction();
-    gwy_file_pass_image(file, 0, dfield);
+    gwy_file_pass_image(file, 0, field);
     gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "Topography", FALSE);
 
     if (sdfile.extras) {
-        GwyContainer *meta = gwy_container_new_in_construction();
+        GwyDict *meta = gwy_dict_new_in_construction();
         g_hash_table_foreach(sdfile.extras, store_meta, meta);
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
         g_hash_table_destroy(sdfile.extras);
@@ -389,7 +390,7 @@ sdfile_export_text(G_GNUC_UNUSED GwyFile *data,
         "NanPresent  = 0\n"
         "*\n";
 
-    GwyField *dfield;
+    GwyField *field;
     const gdouble *d;
     gint xres, yres, i;
     const struct tm *ttm;
@@ -397,8 +398,8 @@ sdfile_export_text(G_GNUC_UNUSED GwyFile *data,
     time_t t;
     FILE *fh;
 
-    gwy_data_browser_get_current(GWY_APP_FIELD, &dfield, 0);
-    if (!dfield) {
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field, 0);
+    if (!field) {
         err_NO_CHANNEL_EXPORT(error);
         return FALSE;
     }
@@ -408,9 +409,9 @@ sdfile_export_text(G_GNUC_UNUSED GwyFile *data,
         return FALSE;
     }
 
-    d = gwy_field_get_data_const(dfield);
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
+    d = gwy_field_get_data_const(field);
+    xres = gwy_field_get_xres(field);
+    yres = gwy_field_get_yres(field);
 
     /* We do not keep date information, just use the current time */
     time(&t);
@@ -419,8 +420,8 @@ sdfile_export_text(G_GNUC_UNUSED GwyFile *data,
                 ttm->tm_mday, ttm->tm_mon, ttm->tm_year, ttm->tm_hour, ttm->tm_min,
                 ttm->tm_mday, ttm->tm_mon, ttm->tm_year, ttm->tm_hour, ttm->tm_min,
                 xres, yres,
-                gwy_field_get_dx(dfield),
-                gwy_field_get_dy(dfield),
+                gwy_field_get_dx(field),
+                gwy_field_get_dy(field),
                 1.0,
                 SDF_FLOAT);
     for (i = 0; i < xres*yres; i++) {
@@ -443,7 +444,7 @@ micromap_load(const gchar *filename,
     gchar *p, *buffer = NULL;
     gsize len, size = 0;
     GError *err = NULL;
-    GwyField *dfield = NULL;
+    GwyField *field = NULL;
     gdouble objectivemag, tubemag, cameraxpixel, cameraypixel;
 
     if (!g_file_get_contents(filename, &buffer, &size, &err)) {
@@ -454,9 +455,9 @@ micromap_load(const gchar *filename,
     p = buffer;
     if (read_header_text(&p, &len, &sdfile, error)) {
         if (check_params(&sdfile, len, error))
-            dfield = read_data_text(&sdfile, error);
+            field = read_data_text(&sdfile, error);
     }
-    if (!dfield) {
+    if (!field) {
         g_free(buffer);
         return NULL;
     }
@@ -476,17 +477,17 @@ micromap_load(const gchar *filename,
     cameraxpixel = g_ascii_strtod(g_hash_table_lookup(sdfile.extras, "CAMERAXPIXEL"), NULL);
     cameraypixel = g_ascii_strtod(g_hash_table_lookup(sdfile.extras, "CAMERAYPIXEL"), NULL);
 
-    sdfile_set_units(&sdfile, dfield);
-    gwy_field_set_xreal(dfield, Micrometer * sdfile.xres * objectivemag * tubemag * cameraxpixel);
-    gwy_field_set_yreal(dfield, Micrometer * sdfile.yres * objectivemag * tubemag * cameraypixel);
+    sdfile_set_units(&sdfile, field);
+    gwy_field_set_xreal(field, Micrometer * sdfile.xres * objectivemag * tubemag * cameraxpixel);
+    gwy_field_set_yreal(field, Micrometer * sdfile.yres * objectivemag * tubemag * cameraypixel);
 
     file = gwy_file_new_in_construction();
-    gwy_file_set_image(file, 0, dfield);
+    gwy_file_set_image(file, 0, field);
     gwy_file_set_title(file, GWY_FILE_IMAGE, 0, "Topography", FALSE);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
 
 fail:
-    g_object_unref(dfield);
+    g_object_unref(field);
     g_free(buffer);
     if (sdfile.extras)
         g_hash_table_destroy(sdfile.extras);
@@ -710,7 +711,7 @@ sdfile_next_line(gchar **buffer,
 }
 
 static GwyField*
-read_data_bin(SDFile *sdfile, GwyField **mfield)
+read_data_bin(SDFile *sdfile, GwyNield **mfield)
 {
     static const struct {
         SDFDataType sdftype;
@@ -728,61 +729,57 @@ read_data_bin(SDFile *sdfile, GwyField **mfield)
         { SDF_DOUBLE, GWY_RAW_DATA_DOUBLE, NAN,         },
     };
 
-    GwyField *dfield, *mask = NULL;
-    gdouble *data, *m;
-    guint i, n, idt;
+    GwyField *field = gwy_field_new(sdfile->xres, sdfile->yres,
+                                    sdfile->xres * sdfile->xscale, sdfile->yres * sdfile->yscale,
+                                    FALSE);
+    GwyNield *mask = NULL;
+    gint *m = NULL;
+    guint idt;
 
-    dfield = gwy_field_new(sdfile->xres, sdfile->yres,
-                           sdfile->xres * sdfile->xscale, sdfile->yres * sdfile->yscale,
-                           FALSE);
     for (idt = 0; idt < G_N_ELEMENTS(data_types); idt++) {
         if (sdfile->data_type == data_types[idt].sdftype)
             break;
     }
-    g_return_val_if_fail(idt < G_N_ELEMENTS(data_types), dfield);
+    g_return_val_if_fail(idt < G_N_ELEMENTS(data_types), field);
 
-    data = gwy_field_get_data(dfield);
-    n = sdfile->xres * sdfile->yres;
+    gdouble *data = gwy_field_get_data(field);
+    guint n = sdfile->xres * sdfile->yres;
     /* We assume Intel byteorder, although the format does not specify any order.  But it was developed in PC
      * context... */
     gwy_convert_raw_data(sdfile->data, n, 1, data_types[idt].gwytype, GWY_BYTE_ORDER_LITTLE_ENDIAN, data, 1.0, 0.0);
     if (!gwy_isnan(data_types[idt].bad_data)) {
-        for (i = 0; i < n; i++) {
+        for (guint i = 0; i < n; i++) {
             if (data[i] == data_types[idt].bad_data) {
                 if (!mask) {
-                    mask = gwy_field_new_alike(dfield, TRUE);
-                    m = gwy_field_get_data(mask);
+                    mask = gwy_field_new_nield_alike(field);
+                    m = gwy_nield_get_data(mask);
                 }
-                m[i] = 1.0;
+                m[i] = 1;
             }
         }
-        if (mask) {
-            gwy_field_grains_invert(mask);
-            gwy_app_channel_remove_bad_data(dfield, mask);
-        }
+        mask = gwy_remove_bad_image_data(field, mask);
     }
     else
-        mask = gwy_app_channel_mask_of_nans(dfield, TRUE);
+        mask = gwy_mask_nans_in_field(field, TRUE);
 
     *mfield = mask;
 
-    return dfield;
+    return field;
 }
 
 static GwyField*
 read_data_text(SDFile *sdfile, GError **error)
 {
     gint i, n;
-    GwyField *dfield;
+    GwyField *field;
     gdouble *data;
     GError *err = NULL;
     gchar *p, *end, *line;
 
-    dfield = gwy_field_new(sdfile->xres, sdfile->yres,
-                           sdfile->xres * sdfile->xscale,
-                           sdfile->yres * sdfile->yscale,
-                           FALSE);
-    data = gwy_field_get_data(dfield);
+    field = gwy_field_new(sdfile->xres, sdfile->yres,
+                          sdfile->xres * sdfile->xscale, sdfile->yres * sdfile->yscale,
+                          FALSE);
+    data = gwy_field_get_data(field);
     n = sdfile->xres * sdfile->yres;
     p = sdfile->data;
     switch (sdfile->data_type) {
@@ -795,7 +792,7 @@ read_data_text(SDFile *sdfile, GError **error)
         for (i = 0; i < n; i++) {
             data[i] = strtol(p, (gchar**)&end, 10);
             if (p == end) {
-                g_object_unref(dfield);
+                g_object_unref(field);
                 g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                             _("End of file reached when reading sample #%d of %d"), i, n);
                 return NULL;
@@ -808,7 +805,7 @@ read_data_text(SDFile *sdfile, GError **error)
         case SDF_DOUBLE:
         if (!gwy_parse_doubles(p, data, GWY_PARSE_DOUBLES_FREE_FORM, &sdfile->yres, &sdfile->xres, &end, &err)) {
             err_PARSE_DOUBLES(error, &err);
-            g_object_unref(dfield);
+            g_object_unref(field);
             return NULL;
         }
         break;
@@ -823,14 +820,14 @@ read_data_text(SDFile *sdfile, GError **error)
         end++;
     if (!*end) {
         gwy_debug("Missing end-of-data marker `*' was ignored");
-        return dfield;
+        return field;
     }
 
     do {
         end++;
     } while (g_ascii_isspace(*end));
     if (!*end)
-        return dfield;
+        return field;
 
     /* Read the extra stuff */
     end--;
@@ -854,7 +851,7 @@ read_data_text(SDFile *sdfile, GError **error)
         g_hash_table_insert(sdfile->extras, line, p);
     }
 
-    return dfield;
+    return field;
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
