@@ -1,5 +1,5 @@
 /*
- *  $Id: sensofar.c 28805 2025-11-05 12:28:20Z yeti-dn $
+ *  $Id: sensofar.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek, Jan Horak.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, xhorak@gmail.com.
  *
@@ -549,7 +549,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Sensofar PLu file format, version 2000 or newer."),
     "Jan Hořák <xhorak@gmail.com>, Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Jan Hořák",
     "2008",
 };
@@ -768,9 +768,11 @@ read_float_field(SensofarDataDesc *data_desc, guint nrgb,
                  const guchar **p, gsize size,
                  GError **error)
 {
-    GwyField *dfield, *mfield;
-    guint xres, yres, i, mcount;
-    gdouble *data, *mdata;
+    GwyField *field;
+    GwyNield *mask;
+    guint xres, yres, i;
+    gdouble *data;
+    gint *mdata;
     const guchar *buf = *p;
 
     yres = gwy_get_guint32_le(p);
@@ -783,28 +785,28 @@ read_float_field(SensofarDataDesc *data_desc, guint nrgb,
     sanitise_real_size(&data_desc->axes_config.mppx, "x size");
     sanitise_real_size(&data_desc->axes_config.mppy, "y size");
 
-    dfield = gwy_field_new(xres, yres,
-                           data_desc->axes_config.mppx * xres * Micrometer,
-                           data_desc->axes_config.mppy * yres * Micrometer,
-                           FALSE);
-    gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
+    field = gwy_field_new(xres, yres,
+                          data_desc->axes_config.mppx * xres * Micrometer,
+                          data_desc->axes_config.mppy * yres * Micrometer,
+                          FALSE);
+    gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
+    mask = gwy_field_new_nield_alike(field);
 
     /* In older files we can get here with both TOPO and IMGTE types. */
     if (data_desc->measure_config.type == MES_TOPO)
-        gwy_unit_set_from_string(gwy_field_get_unit_z(dfield), "m");
+        gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
 
-    data = gwy_field_get_data(dfield);
-    mdata = gwy_field_get_data(mfield);
+    data = gwy_field_get_data(field);
+    mdata = gwy_nield_get_data(mask);
     gwy_convert_raw_data(p, xres*yres, 1, GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN, data, 1.0, 0.0);
     for (i = 0; i < xres*yres; i++)
-        mdata[i] = (data[i] != LOST_PIXELS);
+        mdata[i] = (data[i] == LOST_PIXELS);
 
     *p += (xres*yres + 2)*sizeof(gfloat);   /* Plus data min and data max. */
 
     if (data_desc->measure_config.type == MES_TOPO)
-        gwy_field_multiply(dfield, Micrometer);
+        gwy_field_multiply(field, Micrometer);
 
     gwy_debug("Offset: %g %g",
               data_desc->axes_config.x_0, data_desc->axes_config.y_0);
@@ -812,18 +814,16 @@ read_float_field(SensofarDataDesc *data_desc, guint nrgb,
     //gwy_field_set_xoffset(d, gwy_exp10(power10)*data_desc.axes_config.x_0);
     //gwy_field_set_yoffset(d, gwy_exp10(power10)*data_desc.axes_config.y_0);
 
-    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
+    mask = gwy_remove_bad_image_data(field, mask);
 
-    gwy_file_pass_image(file, *channelno, dfield);
-    if (mcount)
-        gwy_file_set_image_mask(file, *channelno, mfield);
+    gwy_file_pass_image(file, *channelno, field);
+    if (mask)
+        gwy_file_pass_image_mask(file, *channelno, mask);
     gwy_image_title_fall_back(file, *channelno);
     add_image_meta(data_desc, file, *channelno);
     gwy_log_add_import(file, GWY_FILE_IMAGE, *channelno, NULL, filename);
     (*channelno)++;
 
-    g_object_unref(mfield);
-
     if (!nrgb)
         return TRUE;
 
@@ -1033,13 +1033,13 @@ read_profiles(SensofarDataDesc *data_desc,
 }
 
 static void
-set_meta_enum(GwyContainer *meta, guint value, const gchar *name,
+set_meta_enum(GwyDict *meta, guint value, const gchar *name,
               const GwyEnum *table, guint n)
 {
     const gchar *s;
 
     if ((s = gwy_enum_to_string(value, table, n)) && *s)
-        gwy_container_set_const_string_by_name(meta, name, s);
+        gwy_dict_set_const_string_by_name(meta, name, s);
 }
 
 static void
@@ -1049,22 +1049,22 @@ add_image_meta(SensofarDataDesc *data_desc,
     SensofarCalibratEixos_Arxiu *axes_config = &data_desc->axes_config;
     SensofarConfigMesura *measure_config = &data_desc->measure_config;
     SensofarFOVScanSettings *fov = &measure_config->settings.fov;
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
-    gwy_container_set_const_string_by_name(meta, "Date", data_desc->date.str);
+    gwy_dict_set_const_string_by_name(meta, "Date", data_desc->date.str);
     if (*(data_desc->user_comment)) {
-        gwy_container_set_const_string_by_name(meta, "Comment", data_desc->user_comment);
+        gwy_dict_set_const_string_by_name(meta, "Comment", data_desc->user_comment);
     }
-    gwy_container_set_string_by_name(meta, "X0", g_strdup_printf("%g µm", axes_config->x_0));
-    gwy_container_set_string_by_name(meta, "Y0", g_strdup_printf("%g µm", axes_config->y_0));
-    gwy_container_set_string_by_name(meta, "Z0", g_strdup_printf("%g µm", axes_config->z_0));
-    gwy_container_set_string_by_name(meta, "Number of FOVs", g_strdup_printf("%d", fov->na));
-    gwy_container_set_string_by_name(meta, "Dz step", g_strdup_printf("%g µm", fov->incr_z));
-    gwy_container_set_string_by_name(meta, "Scan Z range", g_strdup_printf("%g µm", fov->range));
-    gwy_container_set_string_by_name(meta, "Number of planes", g_strdup_printf("%d", fov->n_planes));
-    gwy_container_set_string_by_name(meta, "Acquisition threshold", g_strdup_printf("%d %%", fov->tpc_umbral_F));
-    gwy_container_set_string_by_name(meta, "Number of layers", g_strdup_printf("%d", measure_config->num_layers));
-    gwy_container_set_string_by_name(meta, "Decimation factor", g_strdup_printf("%d", measure_config->factor_delmacio));
+    gwy_dict_set_string_by_name(meta, "X0", g_strdup_printf("%g µm", axes_config->x_0));
+    gwy_dict_set_string_by_name(meta, "Y0", g_strdup_printf("%g µm", axes_config->y_0));
+    gwy_dict_set_string_by_name(meta, "Z0", g_strdup_printf("%g µm", axes_config->z_0));
+    gwy_dict_set_string_by_name(meta, "Number of FOVs", g_strdup_printf("%d", fov->na));
+    gwy_dict_set_string_by_name(meta, "Dz step", g_strdup_printf("%g µm", fov->incr_z));
+    gwy_dict_set_string_by_name(meta, "Scan Z range", g_strdup_printf("%g µm", fov->range));
+    gwy_dict_set_string_by_name(meta, "Number of planes", g_strdup_printf("%d", fov->n_planes));
+    gwy_dict_set_string_by_name(meta, "Acquisition threshold", g_strdup_printf("%d %%", fov->tpc_umbral_F));
+    gwy_dict_set_string_by_name(meta, "Number of layers", g_strdup_printf("%d", measure_config->num_layers));
+    gwy_dict_set_string_by_name(meta, "Decimation factor", g_strdup_printf("%d", measure_config->factor_delmacio));
 
     set_meta_enum(meta, measure_config->version, "Format version", versions, G_N_ELEMENTS(versions));
     set_meta_enum(meta, measure_config->type, "Measurement type", meas_types, G_N_ELEMENTS(meas_types));
