@@ -1,5 +1,5 @@
 /*
- *  $Id: sensolytics.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: sensolytics.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -86,7 +86,7 @@ typedef struct {
 
 typedef struct {
     gint *pixel_index;
-    GwyField *mask;
+    GwyNield *mask;
     gint ndata;
     gboolean add_mask;
 } SensolyticsGridMap;
@@ -102,7 +102,7 @@ typedef struct {
     const gchar *unit;
     /* Only for lawns. */
     gchar *title;
-    GwyContainer *specmeta;
+    GwyDict *specmeta;
 } SensolyticsChannel;
 
 static gboolean       module_register         (void);
@@ -136,13 +136,13 @@ static void           create_lawns            (GArray *channels,
                                                const gchar *parent_filename);
 static GwyGraphModel* create_graph_model      (SensolyticsChannel *abscissa,
                                                SensolyticsChannel *ordinate);
-static GwyContainer*  get_meta                (GHashTable *hash);
+static GwyDict*  get_meta                (GHashTable *hash);
 static void           clone_field_meta        (GwyFile *file,
-                                               GwyContainer *meta,
+                                               GwyDict *meta,
                                                gint id);
 static void           clone_lawn_meta         (GwyFile *file,
-                                               GwyContainer *meta,
-                                               GwyContainer *specmeta,
+                                               GwyDict *meta,
+                                               GwyDict *specmeta,
                                                gint id);
 static gboolean       check_coordinate_columns(GArray *channels,
                                                gint required_value_cols,
@@ -222,7 +222,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     gchar *buffer = NULL;
     GError *err = NULL;
     GHashTable *hash = NULL;
@@ -231,7 +231,7 @@ load_file(const gchar *filename,
     SensolyticsChannel *channel, *channel2;
     SensolyticsGridMap map;
     GwyGraphModel *gmodel;
-    GwyField *mask, *preview;
+    GwyField *preview;
     Dimensions dimensions;
     guint i, abscissa, startfrom;
     gint j, id;
@@ -272,10 +272,8 @@ load_file(const gchar *filename,
                 continue;
             gwy_file_set_image(file, id, channel->dfield);
             gwy_check_nonsquare_image(file, id);
-            if (map.add_mask) {
-                mask = gwy_field_copy(map.mask);
-                gwy_file_pass_image_mask(file, id, mask);
-            }
+            if (map.add_mask)
+                gwy_file_pass_image_mask(file, id, gwy_nield_copy(map.mask));
             if (channel->name)
                 gwy_file_set_title(file, GWY_FILE_IMAGE, id, channel->name, FALSE);
             else
@@ -297,7 +295,7 @@ load_file(const gchar *filename,
             j = gwy_lawn_get_n_curves(channel->lawn) - 1;
             gwy_lawn_reduce_to_plane(channel->lawn, preview, lawn_reduce_avg, GINT_TO_POINTER(j));
             gwy_unit_assign(gwy_field_get_unit_z(preview), gwy_lawn_get_unit_curve(channel->lawn, j));
-            gwy_container_pass_object(GWY_CONTAINER(file), gwy_file_key_cmap_picture(id), preview);
+            gwy_dict_pass_object(GWY_DICT(file), gwy_file_key_cmap_picture(id), preview);
             gwy_log_add_import(file, GWY_FILE_CMAP, id, NULL, filename);
             clone_lawn_meta(file, meta, channel->specmeta, id);
             id++;
@@ -704,7 +702,6 @@ map_to_grid(GArray *channels, const Dimensions *dimensions,
     SensolyticsChannel *xrel, *yrel;
     gint k, ndata, col, row;
     gint *pixel_index;
-    gdouble *m;
 
     /* Skip X, Y and Z, each being two values. Can something useful be in Z? */
     ndata = map->ndata = g_array_index(channels, SensolyticsChannel, 0).n;
@@ -719,9 +716,8 @@ map_to_grid(GArray *channels, const Dimensions *dimensions,
         g_warning("Column 4 is not \"Y rel.\", mapping to pixels will be nonsense.");
 
     map->pixel_index = pixel_index = g_new(gint, ndata);
-    map->mask = gwy_field_new(dimensions->xres, dimensions->yres,
-                              fabs(dimensions->xreal), fabs(dimensions->yreal), TRUE);
-    m = gwy_field_get_data(map->mask);
+    map->mask = gwy_nield_new(dimensions->xres, dimensions->yres);
+    gint *m = gwy_nield_get_data(map->mask);
     /* Figure out which data row corresponds to which pixel in the image.
      * NB: The increments and lengths can be negative. If the step is negative the relative coordinates seem to
      * indeed go into negative. */
@@ -733,7 +729,7 @@ map_to_grid(GArray *channels, const Dimensions *dimensions,
         pixel_index[k] = row*dimensions->xres + col;
         gwy_debug("index %d = (%d, %d) :: %g %g :: %g %g",
                   k, row, col, xrel->data[k], dimensions->dx, yrel->data[k], dimensions->dy);
-        m[pixel_index[k]] += 1.0;
+        m[pixel_index[k]] += 1;
     }
 }
 
@@ -742,13 +738,12 @@ create_fields(GArray *channels, const Dimensions *dimensions, SensolyticsGridMap
 {
     SensolyticsChannel *channel;
     GwyField *field;
-    gint n, k, ndata = map->ndata;
-    gdouble *d, *m;
+    gint k, ndata = map->ndata;
     guint i, ncols = channels->len;
     gint *pixel_index = map->pixel_index;
 
-    n = dimensions->xres * dimensions->yres;
-    m = gwy_field_get_data(map->mask);
+    gint n = dimensions->xres * dimensions->yres;
+    gint *m = gwy_nield_get_data(map->mask);
     for (i = 5; i < ncols; i++) {
         channel = &g_array_index(channels, SensolyticsChannel, i);
         /* Skip string channels for now, we need to create Lawns from them later. */
@@ -761,13 +756,13 @@ create_fields(GArray *channels, const Dimensions *dimensions, SensolyticsGridMap
          * of 10 again. */
         gwy_unit_set_from_string(gwy_field_get_unit_xy(field), dimensions->xyunit);
         gwy_unit_set_from_string(gwy_field_get_unit_z(field), channel->unit);
-        d = gwy_field_get_data(field);
+        gdouble *d = gwy_field_get_data(field);
         for (k = 0; k < ndata; k++)
             d[pixel_index[k]] += channel->data[k];
         for (k = 0; k < n; k++)
-            d[k] = m[k] > 0.0 ? d[k]/m[k] : 0.0;
+            d[k] = m[k] > 0 ? d[k]/m[k] : 0.0;
 
-        if (gwy_field_get_rms(field) == 0.0) {
+        if (gwy_field_rms(field) == 0.0) {
             g_object_unref(field);
             continue;
         }
@@ -775,12 +770,12 @@ create_fields(GArray *channels, const Dimensions *dimensions, SensolyticsGridMap
         gwy_field_flip(field, TRUE, FALSE);
         channel->dfield = field;
     }
-    if (gwy_field_get_min(map->mask) < 1.0) {
-        gwy_field_grains_invert(map->mask);
+    if (gwy_nield_count(map->mask) != n) {
+        gwy_nield_invert(map->mask);
         for (i = 5; i < ncols; i++) {
             channel = &g_array_index(channels, SensolyticsChannel, i);
             if (channel->dfield)
-                gwy_field_laplace_solve(channel->dfield, map->mask, -1, 0.5);
+                gwy_field_laplace_solve(channel->dfield, map->mask, GWY_LAPLACE_MASKED, 0.5);
         }
         map->add_mask = TRUE;
     }
@@ -976,7 +971,7 @@ create_graph_model(SensolyticsChannel *abscissa, SensolyticsChannel *ordinate)
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *key = (gchar*)hkey, *value = (gchar*)hvalue;
     gchar *storage = NULL;
 
@@ -992,14 +987,14 @@ add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
         value = gwy_convert_to_utf8(value, -1, "ISO-8859-1");
 
     if (value)
-        gwy_container_set_string_by_name(meta, key, value);
+        gwy_dict_set_string_by_name(meta, key, value);
     g_free(storage);
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     g_hash_table_foreach(hash, add_meta, meta);
 
@@ -1007,18 +1002,18 @@ get_meta(GHashTable *hash)
 }
 
 static void
-clone_field_meta(GwyFile *file, GwyContainer *meta, gint id)
+clone_field_meta(GwyFile *file, GwyDict *meta, gint id)
 {
-    if (gwy_container_get_n_items(meta))
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_container_copy(meta));
+    if (gwy_dict_get_n_items(meta))
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, gwy_dict_copy(meta));
 }
 
 static void
-clone_lawn_meta(GwyFile *file, GwyContainer *meta, GwyContainer *specmeta, gint id)
+clone_lawn_meta(GwyFile *file, GwyDict *meta, GwyDict *specmeta, gint id)
 {
-    GwyContainer *metacopy = gwy_container_copy(meta);
-    gwy_container_transfer(specmeta, metacopy, NULL, NULL, FALSE, FALSE);
-    if (gwy_container_get_n_items(metacopy))
+    GwyDict *metacopy = gwy_dict_copy(meta);
+    gwy_dict_transfer(specmeta, metacopy, NULL, NULL, FALSE, FALSE);
+    if (gwy_dict_get_n_items(metacopy))
         gwy_file_pass_meta(file, GWY_FILE_CMAP, id, metacopy);
     else
         g_object_unref(metacopy);
