@@ -1,5 +1,5 @@
 /*
- *  $Id: shimadzu.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: shimadzu.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2007-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -110,7 +110,7 @@ static gboolean      get_scales      (GHashTable *hash,
                                       gdouble *zoff,
                                       GwyUnit *unit_z,
                                       GError **error);
-static GwyContainer* get_metadata    (GHashTable *hash);
+static GwyDict* get_metadata    (GHashTable *hash);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -560,16 +560,16 @@ static void
 add_metadata(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
     const gchar *key = (const gchar*)hkey, *value = (const gchar*)hvalue;
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
     if (g_utf8_validate(key, -1, NULL) && g_utf8_validate(value, -1, NULL))
-        gwy_container_set_const_string_by_name(meta, key, value);
+        gwy_dict_set_const_string_by_name(meta, key, value);
 }
 
-static GwyContainer*
+static GwyDict*
 get_metadata(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, add_metadata, meta);
     return meta;
 }
