@@ -1,5 +1,5 @@
 /*
- *  $Id: sicmfile.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: sicmfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  IonScope SICM file format importer
  *  Copyright (C) 2008-2010 Matthew Caldwell.
  *  E-mail: m.caldwell@ucl.ac.uk
@@ -164,17 +164,17 @@ static gint     detect_file    (const GwyFileDetectInfo *fileinfo,
 static GwyFile* load_file      (const gchar *filename,
                                 GwyRunModeFlags mode,
                                 GError **error);
-static void     set_string_meta(GwyContainer *meta,
+static void     set_string_meta(GwyDict *meta,
                                 const gchar *name,
                                 const gchar *latin1value);
-static void     set_double_meta(GwyContainer *meta,
+static void     set_double_meta(GwyDict *meta,
                                 const gchar *name,
                                 const gchar *unit,
                                 gdouble value);
-static void     set_int_meta   (GwyContainer *meta,
+static void     set_int_meta   (GwyDict *meta,
                                 const gchar *name,
                                 gint value);
-static void     set_yesno_meta (GwyContainer *meta,
+static void     set_yesno_meta (GwyDict *meta,
                                 const gchar *name,
                                 gboolean value);
 
@@ -233,7 +233,7 @@ load_file(const gchar *filename,
 {
     SICMImage sicm;
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyField *dfield;
     guchar *buffer;
     const guchar *p, *unit_name;
@@ -426,7 +426,7 @@ load_file(const gchar *filename,
     /* add pretty much all metadata from the header a bunch of this doesn't seem to be used meaningfully; we prefix
      * probably useless or placeholder fields with a tilde so they sort to the bottom of the browser -- these should
      * probably be omitted entirely when we're sure they're not needed */
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
 
     set_string_meta(meta, "Title", sicm.title);
     set_string_meta(meta, "Comment", sicm.comment);
@@ -460,18 +460,18 @@ load_file(const gchar *filename,
     set_double_meta(meta, "~ Slope Y", NULL, sicm.ySlope);
     set_double_meta(meta, "~ Range", NULL, sicm.range);
 
-    gwy_container_set_string_by_name(meta,
-                                     "~ vArray",
-                                     g_strdup_printf("[%g, %g, %g, %g, %g, %g, %g, %g]",
-                                                     sicm.vArray[0], sicm.vArray[1], sicm.vArray[2], sicm.vArray[3],
-                                                     sicm.vArray[4], sicm.vArray[4], sicm.vArray[6], sicm.vArray[7]));
-    gwy_container_set_string_by_name(meta,
-                                     "~ offArray",
-                                     g_strdup_printf("[%g, %g, %g, %g, %g, %g, %g, %g]",
-                                                     sicm.offArray[0], sicm.offArray[1],
-                                                     sicm.offArray[2], sicm.offArray[3],
-                                                     sicm.offArray[4], sicm.offArray[4],
-                                                     sicm.offArray[6], sicm.offArray[7]));
+    gwy_dict_set_string_by_name(meta,
+                                "~ vArray",
+                                g_strdup_printf("[%g, %g, %g, %g, %g, %g, %g, %g]",
+                                                sicm.vArray[0], sicm.vArray[1], sicm.vArray[2], sicm.vArray[3],
+                                                sicm.vArray[4], sicm.vArray[4], sicm.vArray[6], sicm.vArray[7]));
+    gwy_dict_set_string_by_name(meta,
+                                "~ offArray",
+                                g_strdup_printf("[%g, %g, %g, %g, %g, %g, %g, %g]",
+                                                sicm.offArray[0], sicm.offArray[1],
+                                                sicm.offArray[2], sicm.offArray[3],
+                                                sicm.offArray[4], sicm.offArray[4],
+                                                sicm.offArray[6], sicm.offArray[7]));
     set_double_meta(meta, "~ V Start", NULL, sicm.vStart);
     set_double_meta(meta, "~ V End", NULL, sicm.vEnd);
     set_double_meta(meta, "~ Threshold", NULL, sicm.threshold);
@@ -492,7 +492,7 @@ load_file(const gchar *filename,
     set_int_meta(meta, "Loop Mode", sicm.loopMode);
 
     set_yesno_meta(meta, "~ Fitting", sicm.fitting);
-    gwy_container_set_const_string_by_name(meta, "Polarity", sicm.polarity ? "positive" : "negative");
+    gwy_dict_set_const_string_by_name(meta, "Polarity", sicm.polarity ? "positive" : "negative");
     set_yesno_meta(meta, "~ 1D Scan", sicm.scan1D);
     set_yesno_meta(meta, "Start Center", sicm.startCenter);
 
@@ -510,20 +510,20 @@ load_file(const gchar *filename,
     set_double_meta(meta, "* Minimum Hop Amplitude", "nm", sicm.minHopAmp);
     set_yesno_meta(meta, "* Absolute Hopping Mode", sicm.absHopMode);
     set_yesno_meta(meta, "* Fast Prescan Mode", sicm.fastPrescanMode);
-    gwy_container_set_string_by_name(meta,
-                                     "* Resolution Levels",
-                                     g_strdup_printf("[%d, %d, %d, %d, %d, %d, %d, %d] (pixels)",
-                                                     sicm.resLevels[0], sicm.resLevels[1],
-                                                     sicm.resLevels[2], sicm.resLevels[3],
-                                                     sicm.resLevels[4], sicm.resLevels[4],
-                                                     sicm.resLevels[6], sicm.resLevels[7]));
-    gwy_container_set_string_by_name(meta,
-                                     "* Resolution Thresholds",
-                                     g_strdup_printf("[%d, %d, %d, %d, %d, %d, %d, %d] (nm)",
-                                                     sicm.resThresholds[0], sicm.resThresholds[1],
-                                                     sicm.resThresholds[2], sicm.resThresholds[3],
-                                                     sicm.resThresholds[4], sicm.resThresholds[4],
-                                                     sicm.resThresholds[6], sicm.resThresholds[7]));
+    gwy_dict_set_string_by_name(meta,
+                                "* Resolution Levels",
+                                g_strdup_printf("[%d, %d, %d, %d, %d, %d, %d, %d] (pixels)",
+                                                sicm.resLevels[0], sicm.resLevels[1],
+                                                sicm.resLevels[2], sicm.resLevels[3],
+                                                sicm.resLevels[4], sicm.resLevels[4],
+                                                sicm.resLevels[6], sicm.resLevels[7]));
+    gwy_dict_set_string_by_name(meta,
+                                "* Resolution Thresholds",
+                                g_strdup_printf("[%d, %d, %d, %d, %d, %d, %d, %d] (nm)",
+                                                sicm.resThresholds[0], sicm.resThresholds[1],
+                                                sicm.resThresholds[2], sicm.resThresholds[3],
+                                                sicm.resThresholds[4], sicm.resThresholds[4],
+                                                sicm.resThresholds[6], sicm.resThresholds[7]));
     set_int_meta(meta, "* Resolution Levels Used", sicm.numResLevels);
 
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
@@ -536,36 +536,36 @@ load_file(const gchar *filename,
 
 /* Metadata helpers. */
 static inline void
-set_string_meta(GwyContainer *meta, const gchar *name, const gchar *latin1value)
+set_string_meta(GwyDict *meta, const gchar *name, const gchar *latin1value)
 {
     gchar *s = gwy_convert_to_utf8(latin1value, -1, "ISO-8859-1");
     if (s) {
         if (*s)
-            gwy_container_set_string_by_name(meta, name, s);
+            gwy_dict_set_string_by_name(meta, name, s);
         else
             g_free(s);
     }
 }
 
 static inline void
-set_double_meta(GwyContainer *meta, const gchar *name, const gchar *unit, gdouble value)
+set_double_meta(GwyDict *meta, const gchar *name, const gchar *unit, gdouble value)
 {
     gboolean has_unit = unit && *unit;
     gchar *s = g_strdup_printf("%g%s%s", value, has_unit ? " " : "", has_unit ? unit : "");
-    gwy_container_set_string_by_name(meta, name, s);
+    gwy_dict_set_string_by_name(meta, name, s);
 }
 
 static inline void
-set_int_meta(GwyContainer *meta, const gchar *name, gint value)
+set_int_meta(GwyDict *meta, const gchar *name, gint value)
 {
     gchar *s = g_strdup_printf("%d", value);
-    gwy_container_set_string_by_name(meta, name, s);
+    gwy_dict_set_string_by_name(meta, name, s);
 }
 
 static inline void
-set_yesno_meta(GwyContainer *meta, const gchar *name, gboolean value)
+set_yesno_meta(GwyDict *meta, const gchar *name, gboolean value)
 {
-    gwy_container_set_const_string_by_name(meta, name, value ? "yes" : "no");
+    gwy_dict_set_const_string_by_name(meta, name, value ? "yes" : "no");
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
