@@ -1,5 +1,5 @@
 /*
- *  $Id: sis.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: sis.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -444,14 +444,14 @@ add_metadata(SISFile *sisfile,
     static const guint good_metadata[] = {
         0, 1, 9, 10, 12, 13, 14, 15, 16, 18, 20, 21, 22, 23, 24, 25, 26, 27,
     };
-    GwyContainer *meta;
+    GwyDict *meta;
     SISChannel *channel;
     guint i, j;
     guchar *value;
     const gchar *s;
     gpointer *p;
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     channel = sisfile->channels + ch;
     for (i = 0; i < G_N_ELEMENTS(good_metadata); i++) {
         for (j = 0; j < G_N_ELEMENTS(sis_parameters); j++) {
@@ -481,7 +481,7 @@ add_metadata(SISFile *sisfile,
             g_assert_not_reached();
             value = NULL;
         }
-        gwy_container_set_string_by_name(meta, sis_parameters[j].meta, value);
+        gwy_dict_set_string_by_name(meta, sis_parameters[j].meta, value);
     }
 
     /* Special metadata */
@@ -504,7 +504,7 @@ add_metadata(SISFile *sisfile,
                                 "Non contact", 2,
                                 NULL);
         if (s)
-            gwy_container_set_const_string_by_name(meta, "Aqusition type", s);
+            gwy_dict_set_const_string_by_name(meta, "Aqusition type", s);
     }
 
     s = gwy_enuml_to_string(channel->signal_source,
@@ -526,7 +526,7 @@ add_metadata(SISFile *sisfile,
                             "User", 16,
                             NULL);
     if (s)
-        gwy_container_set_const_string_by_name(meta, "Signal source", s);
+        gwy_dict_set_const_string_by_name(meta, "Signal source", s);
 
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
 }
