@@ -1,5 +1,5 @@
 /*
- *  $Id: spip-asc.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: spip-asc.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -87,7 +87,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports and exports SPIP ASC files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.9",
+    "0.10",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -199,7 +199,8 @@ read_image_data(GHashTable *hash, gchar *p, const gchar *filename,
                 GError **error)
 {
     GwyFile *file = NULL;
-    GwyField *field = NULL, *mfield = NULL;
+    GwyField *field = NULL;
+    GwyNield *mask = NULL;
     GError *err = NULL;
     gdouble xreal, yreal, q;
     gchar *value;
@@ -238,21 +239,22 @@ read_image_data(GHashTable *hash, gchar *p, const gchar *filename,
     gwy_field_multiply(field, q);
 
     if ((value = g_hash_table_lookup(hash, "voidpixels")) && atoi(value)) {
-        mfield = gwy_field_new_alike(field, FALSE);
-        if (gwy_parse_doubles(p, gwy_field_get_data(mfield), GWY_PARSE_DOUBLES_FREE_FORM,
+        GwyField *mask_field = gwy_field_new_alike(field, FALSE);
+        if (gwy_parse_doubles(p, gwy_field_get_data(mask_field), GWY_PARSE_DOUBLES_FREE_FORM,
                               &yres, &xres, &p, NULL)) {
-            gwy_field_grains_invert(mfield);
-            if (!gwy_app_channel_remove_bad_data(field, mfield))
-                g_clear_object(&mfield);
+            mask = gwy_field_new_nield_alike(mask_field);
+            gwy_nield_mark_by_threshold(mask, mask_field, 0.5, TRUE);
+            mask = gwy_remove_bad_image_data(field, mask);
         }
         else
-            g_clear_object(&mfield);
+            g_clear_object(&mask);
+        g_object_unref(mask_field);
     }
 
     file = gwy_file_new_in_construction();
     gwy_file_pass_image(file, 0, field);
-    if (mfield)
-        gwy_file_pass_image_mask(file, 0, mfield);
+    if (mask)
+        gwy_file_pass_image_mask(file, 0, mask);
 
     gwy_image_title_fall_back(file, 0);
     gwy_log_add_import(file, GWY_FILE_IMAGE, 0, NULL, filename);
@@ -488,7 +490,7 @@ format_header(GwyFile *file, GwyField *field, gboolean *zunit_is_nm)
     else
         zunit_line = g_strdup_printf("# z-unit = %s\n", zunit_str);
 
-    gwy_container_gis_string(GWY_CONTAINER(file), gwy_file_key_filename(), &filename);
+    gwy_dict_gis_string(GWY_DICT(file), gwy_file_key_filename(), &filename);
 
     header = g_strdup_printf(header_template,
                              gwy_version_string(), filename,
