@@ -1,5 +1,5 @@
 /*
- *  $Id: spmlab.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: spmlab.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -504,36 +504,36 @@ read_field(SPMLabFile *slfile, const guchar *buffer,
 static void
 add_meta(SPMLabFile *slfile, GwyFile *file, guint i)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     const gchar *s;
 
     if ((s = slfile->datetime) && *s)
-        gwy_container_set_const_string_by_name(meta, "Date and time", s);
+        gwy_dict_set_const_string_by_name(meta, "Date and time", s);
     if ((s = slfile->description) && *s)
-        gwy_container_set_const_string_by_name(meta, "Description", s);
+        gwy_dict_set_const_string_by_name(meta, "Description", s);
     if ((s = slfile->scantype) && *s)
-        gwy_container_set_const_string_by_name(meta, "Scan type", s);
+        gwy_dict_set_const_string_by_name(meta, "Scan type", s);
     if ((s = slfile->model_str) && *s)
-        gwy_container_set_const_string_by_name(meta, "Scan type", s);
+        gwy_dict_set_const_string_by_name(meta, "Scan type", s);
 
     if (slfile->release && (s = strrchr(slfile->release, '#')))
-        gwy_container_set_string_by_name(meta, "Version", g_strndup(slfile->release, s+1 - slfile->release));
+        gwy_dict_set_string_by_name(meta, "Version", g_strndup(slfile->release, s+1 - slfile->release));
 
     if (((s = slfile->datatype_str) && *s) || (s = datatype_to_string(slfile->datatype)))
-        gwy_container_set_const_string_by_name(meta, "Data type", s);
+        gwy_dict_set_const_string_by_name(meta, "Data type", s);
 
     if (((s = slfile->datamode_str) && *s) || (s = datamode_to_string(slfile->datamode)))
-        gwy_container_set_const_string_by_name(meta, "Data mode", s);
+        gwy_dict_set_const_string_by_name(meta, "Data mode", s);
 
     if (((s = slfile->probetype_str) && *s) || (s = probetype_to_string(slfile->probetype)))
-        gwy_container_set_const_string_by_name(meta, "Probe type", s);
+        gwy_dict_set_const_string_by_name(meta, "Probe type", s);
 
     if ((s = stagetype_to_string(slfile->stagetype)))
-        gwy_container_set_const_string_by_name(meta, "Stage type", s);
+        gwy_dict_set_const_string_by_name(meta, "Stage type", s);
     if ((s = direction_to_string(slfile->direction)))
-        gwy_container_set_const_string_by_name(meta, "Direction", s);
+        gwy_dict_set_const_string_by_name(meta, "Direction", s);
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, meta);
     else
         g_object_unref(meta);
