@@ -1,5 +1,5 @@
 /*
- *  $Id: spmlabf.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: spmlabf.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2008-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -56,14 +56,14 @@
 
 #define EXTENSION ".flt"
 
-static gboolean      module_register(void);
-static gint          detect_file    (const GwyFileDetectInfo *fileinfo,
-                                     gboolean only_name);
-static GwyFile*      load_file      (const gchar *filename,
-                                     GwyRunModeFlags mode,
-                                     GError **error);
-static GwyContainer* add_metadata   (GHashTable *hash,
-                                     ...);
+static gboolean module_register(void);
+static gint     detect_file    (const GwyFileDetectInfo *fileinfo,
+                                gboolean only_name);
+static GwyFile* load_file      (const gchar *filename,
+                                GwyRunModeFlags mode,
+                                GError **error);
+static GwyDict* add_metadata   (GHashTable *hash,
+                                ...);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -105,7 +105,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyTextHeaderParser parser;
     GHashTable *hash = NULL;
     guchar *buffer = NULL;
@@ -264,25 +264,25 @@ fail:
     return file;
 }
 
-static GwyContainer*
+static GwyDict*
 add_metadata(GHashTable *hash,
              ...)
 {
     va_list ap;
     const gchar *key, *value;
     gchar *v;
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     va_start(ap, hash);
     while ((key = va_arg(ap, const gchar *))) {
         if ((value = g_hash_table_lookup(hash, key))) {
             if ((v = gwy_convert_to_utf8(value, -1, "ISO-8859-1")))
-                gwy_container_set_string_by_name(meta, key, v);
+                gwy_dict_set_string_by_name(meta, key, v);
         }
     }
     va_end(ap);
 
-    if (!gwy_container_get_n_items(meta))
+    if (!gwy_dict_get_n_items(meta))
         g_clear_object(&meta);
 
     return meta;
