@@ -1,5 +1,5 @@
 /*
- *  $Id: stmprg.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: stmprg.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004 Rok Zitko
  *  E-mail: rok.zitko@ijs.si
  *
@@ -553,16 +553,16 @@ read_field(const guchar *buffer,
 #define HASH_STORE(format, keystr, val) \
     value = g_strdup_printf(format, stmprgfile->val); \
     gwy_debug("key = %s, val = %s", keystr, value); \
-    gwy_container_set_string_by_name(meta, keystr, value);
+    gwy_dict_set_string_by_name(meta, keystr, value);
 
 #define HASH_STORE_F(keystr, valf) HASH_STORE("%f", keystr, valf)
 #define HASH_STORE_S(keystr, vals) HASH_STORE("%s", keystr, vals)
 #define HASH_STORE_I(keystr, vali) HASH_STORE("%i", keystr, vali)
 
-static GwyContainer*
+static GwyDict*
 get_metadata(const StmprgFile *stmprgfile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     gchar *value;
 
     HASH_STORE_F("inc_x", mainfield.inc_x);
