@@ -1,5 +1,5 @@
 /*
- *  $Id: stpfile.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: stpfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klstptek.
  *  E-mail: yeti@gwyddion.net, klstptek@gwyddion.net.
  *
@@ -418,7 +418,7 @@ process_metadata(STPFile *stpfile,
     gwy_field_set_yreal(dfield, r*Angstrom);
 
     /* Metadata */
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     GString *str = g_string_new(NULL);
 
     /* Global */
@@ -427,7 +427,7 @@ process_metadata(STPFile *stpfile,
             continue;
 
         g_string_printf(str, global_metadata[i].format, p);
-        gwy_container_set_const_string_by_name(meta, global_metadata[i].meta, str->str);
+        gwy_dict_set_const_string_by_name(meta, global_metadata[i].meta, str->str);
     }
 
     /* Local */
@@ -436,26 +436,26 @@ process_metadata(STPFile *stpfile,
             continue;
 
         g_string_printf(str, local_metadata[i].format, p);
-        gwy_container_set_const_string_by_name(meta, local_metadata[i].meta, str->str);
+        gwy_dict_set_const_string_by_name(meta, local_metadata[i].meta, str->str);
     }
 
     /* Special */
     if ((p = g_hash_table_lookup(data->meta, "Date")) && (s = g_hash_table_lookup(data->meta, "time")))
-        gwy_container_set_string_by_name(meta, "Date", g_strconcat(p, " ", s, NULL));
+        gwy_dict_set_string_by_name(meta, "Date", g_strconcat(p, " ", s, NULL));
     if ((p = g_hash_table_lookup(data->meta, "scan_dir"))) {
         if (gwy_strequal(p, "0"))
-            gwy_container_set_const_string_by_name(meta, "Scanning direction", "Top to bottom");
+            gwy_dict_set_const_string_by_name(meta, "Scanning direction", "Top to bottom");
         else if (gwy_strequal(p, "1"))
-            gwy_container_set_const_string_by_name(meta, "Scanning direction", "Bottom to top");
+            gwy_dict_set_const_string_by_name(meta, "Scanning direction", "Bottom to top");
     }
     if ((p = g_hash_table_lookup(data->meta, "collect_mode"))) {
         if (gwy_strequal(p, "1"))
-            gwy_container_set_const_string_by_name(meta, "Line direction", "Left to right");
+            gwy_dict_set_const_string_by_name(meta, "Line direction", "Left to right");
         else if (gwy_strequal(p, "2"))
-            gwy_container_set_const_string_by_name(meta, "Line direction", "Right to left");
+            gwy_dict_set_const_string_by_name(meta, "Line direction", "Right to left");
     }
 
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
     else
         g_object_unref(meta);
