@@ -1,5 +1,5 @@
 /*
- *  $Id: surffile.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: surffile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2005-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -284,7 +284,7 @@ static gsize         load_one_surffile      (const guchar *buffer,
 static gboolean      fill_fields            (SurfFile *surffile,
                                              const guchar *buffer,
                                              GError **error);
-static GwyContainer* surffile_get_metadata  (SurfFile *surffile);
+static GwyDict* surffile_get_metadata  (SurfFile *surffile);
 static guchar*       decompress_chunked_data(const guchar *buffer,
                                              gsize size,
                                              gsize expected_size,
@@ -663,12 +663,12 @@ fill_fields(SurfFile *surffile,
 }
 
 #define HASH_STORE(key, fmt, field) \
-    gwy_container_set_string_by_name(meta, key, g_strdup_printf(fmt, surffile->field))
+    gwy_dict_set_string_by_name(meta, key, g_strdup_printf(fmt, surffile->field))
 
-static GwyContainer*
+static GwyDict*
 surffile_get_metadata(SurfFile *surffile)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     char date[40];
 
     g_snprintf(date, sizeof(date), "%d. %d. %d",
@@ -677,10 +677,10 @@ surffile_get_metadata(SurfFile *surffile)
     HASH_STORE("Version", "%u", version);
     HASH_STORE("Operator name", "%s", operator_name);
     HASH_STORE("Object name", "%s", object_name);
-    gwy_container_set_const_string_by_name(meta, "Date", date);
-    gwy_container_set_const_string_by_name(meta, "Acquisition type",
-                                           gwy_enum_to_string(surffile->acquisition,
-                                                              acq_modes, G_N_ELEMENTS(acq_modes)));
+    gwy_dict_set_const_string_by_name(meta, "Date", date);
+    gwy_dict_set_const_string_by_name(meta, "Acquisition type",
+                                      gwy_enum_to_string(surffile->acquisition,
+                                                         acq_modes, G_N_ELEMENTS(acq_modes)));
 
     return meta;
 }
@@ -850,8 +850,8 @@ export_file(G_GNUC_UNUSED GwyFile *data,
     g_free(dzunittmp);
 
     /*extrema*/
-    zmaxreal = gwy_field_get_max(dfield);
-    zminreal = gwy_field_get_min(dfield);
+    zmaxreal = gwy_field_max(dfield);
+    zminreal = gwy_field_min(dfield);
     surf.xres = gwy_field_get_xres(dfield);
     surf.yres = gwy_field_get_yres(dfield);
     surf.nofpoints = surf.xres * surf.yres;
