@@ -1,5 +1,5 @@
 /*
- *  $Id: tescan.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: tescan.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2013-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -99,7 +99,7 @@ static void                parse_text_fields     (GHashTable *globalhash,
 static void                copy_with_prefix      (gpointer hkey,
                                                   gpointer hvalue,
                                                   gpointer user_data);
-static GwyContainer*       get_meta              (GHashTable *hash);
+static GwyDict*       get_meta              (GHashTable *hash);
 static void                add_meta              (gpointer hkey,
                                                   gpointer hvalue,
                                                   gpointer user_data);
@@ -228,7 +228,7 @@ static GwyFile*
 tsctif_load_tiff(GwyTIFF *tiff, const GwyTIFFEntry *entry, GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield;
     GwyTIFFImageReader *reader = NULL;
     GHashTable *hash = NULL;
@@ -385,7 +385,7 @@ load_pngfile(const gchar *filename,
              GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GHashTable *hash = NULL;
     gchar *header = NULL;
     GString *imagefilename = NULL;
@@ -511,12 +511,12 @@ copy_with_prefix(gpointer hkey, gpointer hvalue, gpointer user_data)
     g_hash_table_insert(block_copy_info->target, key, g_strdup(hvalue));
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
@@ -526,13 +526,13 @@ get_meta(GHashTable *hash)
 static void
 add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
     gchar *value = hvalue, *skey = hkey;
 
     if (!*value)
         return;
 
-    gwy_container_set_const_string_by_name(meta, skey, value);
+    gwy_dict_set_const_string_by_name(meta, skey, value);
 }
 
 static GwyField*
