@@ -1,5 +1,5 @@
 /*
- *  $Id: tiaser.c 28803 2025-11-05 11:58:19Z yeti-dn $
+ *  $Id: tiaser.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2012-2025 David Necas (Yeti), Daniil Bratashov (dn2010).
  *  E-mail: yeti@gwyddion.net, dn2010@gmail.com.
  *
@@ -469,7 +469,7 @@ fail2:
     g_free(header);
 fail:
     gwy_file_abandon_contents(buffer, size, NULL);
-    if (file && !gwy_container_get_n_items(GWY_CONTAINER(file)))
+    if (file && !gwy_dict_get_n_items(GWY_DICT(file)))
         g_clear_object(&file);
 
     return file;
