@@ -1,5 +1,5 @@
 /*
- *  $Id: ttffile.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: ttffile.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2019-2025 David Necas (Yeti), Thomas Wagner.
  *  E-mail: yeti@gwyddion.net, hirschbeutel@gmail.com.
  *
@@ -135,49 +135,49 @@ typedef struct {
     gchar *units;
 } CorningCSVHeader;
 
-static gboolean      module_register        (void);
-static gint          ttf_detect             (const GwyFileDetectInfo *fileinfo,
-                                             gboolean only_name);
-static GwyFile*      ttf_load               (const gchar *filename,
-                                             GwyRunModeFlags mode,
-                                             GError **error);
-static gboolean      ttf_load_image         (GwyTIFF *tiff,
-                                             GwyFile *file,
-                                             gint dirno,
-                                             GError **error);
-static guint         read_image_data        (const guchar *p,
-                                             gulong size,
-                                             gdouble *data,
-                                             gdouble *mdata,
-                                             guint delta_nbits,
-                                             guint data_nbits,
-                                             guint nan_count_nbits,
-                                             guint n,
-                                             gdouble q);
-static gboolean      fix_corning_double_tags(GwyTIFF *tiff,
-                                             GError **error);
-static GwyContainer* ttf_get_meta           (GwyTIFF *tiff,
-                                             gint dirno);
-static gint          ccsv_detect            (const GwyFileDetectInfo *fileinfo,
-                                             gboolean only_name);
-static GwyFile*      ccsv_load              (const gchar *filename,
-                                             GwyRunModeFlags mode,
-                                             GError **error);
-static gchar*        ccsv_read_header       (CorningCSVHeader *header,
-                                             gchar *p,
-                                             GError **error);
-static gboolean      ccsv_read_images       (const CorningCSVHeader *header,
-                                             gchar *p,
-                                             GwyField **dfield,
-                                             GwyField **mask,
-                                             GError **error);
+static gboolean module_register        (void);
+static gint     ttf_detect             (const GwyFileDetectInfo *fileinfo,
+                                        gboolean only_name);
+static GwyFile* ttf_load               (const gchar *filename,
+                                        GwyRunModeFlags mode,
+                                        GError **error);
+static gboolean ttf_load_image         (GwyTIFF *tiff,
+                                        GwyFile *file,
+                                        gint dirno,
+                                        GError **error);
+static guint    read_image_data        (const guchar *p,
+                                        gulong size,
+                                        gdouble *data,
+                                        gint *mdata,
+                                        guint delta_nbits,
+                                        guint data_nbits,
+                                        guint nan_count_nbits,
+                                        guint n,
+                                        gdouble q);
+static gboolean fix_corning_double_tags(GwyTIFF *tiff,
+                                        GError **error);
+static GwyDict* ttf_get_meta           (GwyTIFF *tiff,
+                                        gint dirno);
+static gint     ccsv_detect            (const GwyFileDetectInfo *fileinfo,
+                                        gboolean only_name);
+static GwyFile* ccsv_load              (const gchar *filename,
+                                        GwyRunModeFlags mode,
+                                        GError **error);
+static gchar*   ccsv_read_header       (CorningCSVHeader *header,
+                                        gchar *p,
+                                        GError **error);
+static gboolean ccsv_read_images       (const CorningCSVHeader *header,
+                                        gchar *p,
+                                        GwyField **dfield,
+                                        GwyNield **mask,
+                                        GError **error);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     module_register,
     N_("Imports Corning Tropel UltraSort files."),
     "Yeti <yeti@gwyddion.net>, Thomas Wagner <hirschbeutel@gmail.com>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti), Thomas Wagner",
     "2019",
 };
@@ -304,7 +304,8 @@ fail:
 static gboolean
 ttf_load_image(GwyTIFF *tiff, GwyFile *file, gint dirno, GError **error)
 {
-    GwyField *field = NULL, *mask = NULL;
+    GwyField *field = NULL;
+    GwyNield *mask = NULL;
     const GwyTIFFEntry *entry;
     const guchar *p;
     gulong size, offset;
@@ -380,10 +381,9 @@ ttf_load_image(GwyTIFF *tiff, GwyFile *file, gint dirno, GError **error)
     gwy_unit_set_from_string(gwy_field_get_unit_xy(field), "m");
     gwy_unit_set_from_string(gwy_field_get_unit_z(field), "m");
 
-    mask = gwy_field_new_alike(field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
-
-    nread = read_image_data(p, size, gwy_field_get_data(field), gwy_field_get_data(mask),
+    mask = gwy_field_new_nield_alike(field);
+    gwy_nield_fill(mask, 1);
+    nread = read_image_data(p, size, gwy_field_get_data(field), gwy_nield_get_data(mask),
                             delta_nbits, data_nbits, nan_count_nbits, n, sens/scale * Micrometre);
     if (nread < n) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA, _("Data block is truncated."));
@@ -392,13 +392,11 @@ ttf_load_image(GwyTIFF *tiff, GwyFile *file, gint dirno, GError **error)
         return FALSE;
     }
 
-    if (!gwy_app_channel_remove_bad_data(field, mask))
-        g_clear_object(&mask);
+    mask = gwy_remove_bad_image_data(field, mask);
 
     gwy_file_pass_image(file, dirno, field);
-    if (mask) {
+    if (mask)
         gwy_file_pass_image_mask(file, dirno, mask);
-    }
 
     if (gwy_tiff_get_string(tiff, dirno, CORNING_TIFFTAG_MAPID, &title))
         gwy_file_pass_title(file, GWY_FILE_IMAGE, dirno, title);
@@ -415,7 +413,7 @@ fix_to_signed(guint64 t, guint nbits)
 
 static guint
 read_image_data(const guchar *p, gulong size,
-                gdouble *data, gdouble *mdata,
+                gdouble *data, gint *mdata,
                 guint delta_nbits, guint data_nbits, guint nan_count_nbits,
                 guint n, gdouble q)
 {
@@ -498,7 +496,7 @@ read_image_data(const guchar *p, gulong size,
         }
 
         /* Output the current value. */
-        mdata[i] = 1.0;
+        mdata[i] = 0;
         data[i] = q*current_value;
         i++;
     }
@@ -529,7 +527,7 @@ fix_corning_double_tags(GwyTIFF *tiff, GError **error)
     return gwy_tiff_tags_valid(tiff, error);
 }
 
-static GwyContainer*
+static GwyDict*
 ttf_get_meta(GwyTIFF *tiff, gint dirno)
 {
     /* Strings present only in directory 0. */
@@ -576,26 +574,26 @@ ttf_get_meta(GwyTIFF *tiff, gint dirno)
     guint i, u;
     gchar buf[32];
 
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
 
     for (i = 0; i < G_N_ELEMENTS(dir0_tags); i++) {
         if (gwy_tiff_get_string0(tiff, dir0_tags[i].value, &s))
-            gwy_container_set_string_by_name(meta, dir0_tags[i].name, s);
+            gwy_dict_set_string_by_name(meta, dir0_tags[i].name, s);
     }
     for (i = 0; i < G_N_ELEMENTS(string_tags); i++) {
         if (gwy_tiff_get_string(tiff, dirno, string_tags[i].value, &s))
-            gwy_container_set_string_by_name(meta, string_tags[i].name, s);
+            gwy_dict_set_string_by_name(meta, string_tags[i].name, s);
     }
     for (i = 0; i < G_N_ELEMENTS(uint_tags); i++) {
         if (gwy_tiff_get_uint(tiff, dirno, uint_tags[i].value, &u)) {
             g_snprintf(buf, sizeof(buf), "%u", u);
-            gwy_container_set_const_string_by_name(meta, uint_tags[i].name, buf);
+            gwy_dict_set_const_string_by_name(meta, uint_tags[i].name, buf);
         }
     }
     for (i = 0; i < G_N_ELEMENTS(double_tags); i++) {
         if (gwy_tiff_get_float(tiff, dirno, double_tags[i].value, &d)) {
             g_snprintf(buf, sizeof(buf), "%g", d);
-            gwy_container_set_const_string_by_name(meta, double_tags[i].name, buf);
+            gwy_dict_set_const_string_by_name(meta, double_tags[i].name, buf);
         }
     }
 
@@ -609,7 +607,8 @@ ccsv_load(const gchar *filename,
 {
     CorningCSVHeader header;
     GwyFile *file = NULL;
-    GwyField *dfield = NULL, *mask = NULL;
+    GwyField *dfield = NULL;
+    GwyNield *mask = NULL;
     GError *err = NULL;
     gchar *buffer, *p;
     gsize size;
@@ -732,25 +731,22 @@ fail:
 static gboolean
 ccsv_read_images(const CorningCSVHeader *header,
                  gchar *p,
-                 GwyField **dfield, GwyField **mask,
+                 GwyField **dfield, GwyNield **mask,
                  GError **error)
 {
-    gdouble *d, *m;
     gchar *line, *end;
-    gint xres, yres, i, j;
-
-    xres = header->xres;
-    yres = header->yres;
+    gint xres = header->xres, yres = header->yres;
+    gint i, j;
 
     *dfield = gwy_field_new(xres, yres, header->xreal, header->yreal, TRUE);
     gwy_unit_set_from_string(gwy_field_get_unit_xy(*dfield), "m");
-    *mask = gwy_field_new_alike(*dfield, TRUE);
     if (!gwy_strequal(header->units, "Microns")) {
         g_warning("Units are not Microns, setting to metre anyway.");
     }
     gwy_unit_set_from_string(gwy_field_get_unit_z(*dfield), "m");
-    d = gwy_field_get_data(*dfield);
-    m = gwy_field_get_data(*mask);
+    *mask = gwy_field_new_nield_alike(*dfield);
+    gdouble *d = gwy_field_get_data(*dfield);
+    gint *m = gwy_nield_get_data(*mask);
 
     while (*p == '\r' || *p == '\n')
         p++;
@@ -763,7 +759,7 @@ ccsv_read_images(const CorningCSVHeader *header,
         }
         for (j = 0; j < xres; j++) {
             if (strncmp(line, "NaN", 3) == 0) {
-                m[i*xres + j] = 1.0;
+                m[i*xres + j] = 1;
                 line += 3;
             }
             else {
@@ -779,7 +775,7 @@ ccsv_read_images(const CorningCSVHeader *header,
         }
     }
 
-    gwy_field_laplace_solve(*dfield, *mask, -1, 1.0);
+    gwy_field_laplace_solve(*dfield, *mask, GWY_LAPLACE_MASKED, 1.0);
 
     return TRUE;
 }
