@@ -1,5 +1,5 @@
 /*
- *  $Id: win_stm.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: win_stm.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014 Jeffrey J. Schwartz.
  *  E-mail: schwartz@physics.ucla.edu
  *
@@ -192,9 +192,9 @@ load_file(const gchar *filename,
 
         gwy_file_pass_image(file, id, dfield);
         gwy_file_pass_title(file, GWY_FILE_IMAGE, id, gwy_convert_to_utf8(Title, -1, "ISO-8859-1"));
-        GwyContainer *meta = gwy_container_new_in_construction();
-        gwy_container_set_string_by_name(meta, "Bias", g_strdup_printf("%.3f V", stm.Bias));
-        gwy_container_set_string_by_name(meta, "Current Set Point", g_strdup_printf("%.3f pA", stm.Current));
+        GwyDict *meta = gwy_dict_new_in_construction();
+        gwy_dict_set_string_by_name(meta, "Bias", g_strdup_printf("%.3f V", stm.Bias));
+        gwy_dict_set_string_by_name(meta, "Current Set Point", g_strdup_printf("%.3f pA", stm.Current));
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, id, meta);
         gwy_log_add_import(file, GWY_FILE_IMAGE, id, NULL, filename);
     }
