@@ -1,5 +1,5 @@
 /*
- *  $Id: witfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: witfile.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -164,35 +164,35 @@ typedef struct {
     WITecImageOptions image_options;
 } WITecFile;
 
-static gboolean      module_register   (void);
-static gint          detect_file       (const GwyFileDetectInfo *fileinfo,
-                                        gboolean only_name);
-static GwyFile*      load_file         (const gchar *filename,
-                                        GwyRunModeFlags mode,
-                                        GError **error);
-static gboolean      read_file         (const guchar *buffer,
-                                        gsize len,
-                                        WITecFile *witfile,
-                                        GError **error);
-static GwyContainer* get_metadata      (WITecFile *witfile,
-                                        gint i);
-static GwyField*     image_to_field    (WITecFile *witfile,
-                                        guint i);
-static gboolean      read_scale        (const guchar **p,
-                                        gsize *len,
-                                        WITecScale *scale);
-static gboolean      read_header       (const guchar **p,
-                                        gsize *len,
-                                        WITecHeader *header);
-static gboolean      read_footer       (const guchar **p,
-                                        gsize *len,
-                                        WITecFooter *footer);
-static gboolean      read_range_options(const guchar **p,
-                                        gsize *len,
-                                        WITecRangeOptions *options);
-static gboolean      read_image_options(const guchar **p,
-                                        gsize *len,
-                                        WITecImageOptions *options);
+static gboolean  module_register   (void);
+static gint      detect_file       (const GwyFileDetectInfo *fileinfo,
+                                    gboolean only_name);
+static GwyFile*  load_file         (const gchar *filename,
+                                    GwyRunModeFlags mode,
+                                    GError **error);
+static gboolean  read_file         (const guchar *buffer,
+                                    gsize len,
+                                    WITecFile *witfile,
+                                    GError **error);
+static GwyDict*  get_metadata      (WITecFile *witfile,
+                                    gint i);
+static GwyField* image_to_field    (WITecFile *witfile,
+                                    guint i);
+static gboolean  read_scale        (const guchar **p,
+                                    gsize *len,
+                                    WITecScale *scale);
+static gboolean  read_header       (const guchar **p,
+                                    gsize *len,
+                                    WITecHeader *header);
+static gboolean  read_footer       (const guchar **p,
+                                    gsize *len,
+                                    WITecFooter *footer);
+static gboolean  read_range_options(const guchar **p,
+                                    gsize *len,
+                                    WITecRangeOptions *options);
+static gboolean  read_image_options(const guchar **p,
+                                    gsize *len,
+                                    WITecImageOptions *options);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -388,30 +388,30 @@ image_to_field(WITecFile *witfile, guint i)
 }
 
 /* FIXME: There seems to be no local metadata */
-static GwyContainer*
+static GwyDict*
 get_metadata(WITecFile *witfile, G_GNUC_UNUSED gint i)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     gdouble v;
 
     if (witfile->footer.title[0])
-        gwy_container_set_const_string_by_name(meta, "Title", witfile->footer.title);
+        gwy_dict_set_const_string_by_name(meta, "Title", witfile->footer.title);
     if (witfile->footer.comments[0])
-        gwy_container_set_const_string_by_name(meta, "Comments", witfile->footer.comments);
-    gwy_container_set_string_by_name(meta, "Date",
-                                     g_strdup_printf("%d-%02d-%02d %02d:%02d:%02d",
-                                                     witfile->footer.year,
-                                                     witfile->footer.month,
-                                                     witfile->footer.day,
-                                                     witfile->footer.hour,
-                                                     witfile->footer.minute,
-                                                     witfile->footer.second));
+        gwy_dict_set_const_string_by_name(meta, "Comments", witfile->footer.comments);
+    gwy_dict_set_string_by_name(meta, "Date",
+                                g_strdup_printf("%d-%02d-%02d %02d:%02d:%02d",
+                                                witfile->footer.year,
+                                                witfile->footer.month,
+                                                witfile->footer.day,
+                                                witfile->footer.hour,
+                                                witfile->footer.minute,
+                                                witfile->footer.second));
     if ((v = witfile->range_options.overscan_range))
-        gwy_container_set_string_by_name(meta, "Overscan range", g_strdup_printf("%g", v));
+        gwy_dict_set_string_by_name(meta, "Overscan range", g_strdup_printf("%g", v));
     if ((v = witfile->image_options.scan_time[WITEC_FORWARD]))
-        gwy_container_set_string_by_name(meta, "Scan time forward", g_strdup_printf("%g s", v));
+        gwy_dict_set_string_by_name(meta, "Scan time forward", g_strdup_printf("%g s", v));
     if ((v = witfile->image_options.scan_time[WITEC_BACKWARD]))
-        gwy_container_set_string_by_name(meta, "Scan time backward", g_strdup_printf("%g s", v));
+        gwy_dict_set_string_by_name(meta, "Scan time backward", g_strdup_printf("%g s", v));
 
     return meta;
 }
