@@ -1,5 +1,5 @@
 /*
- *  $Id: wrustfile.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: wrustfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -110,7 +110,7 @@ static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
     if (*(const guchar*)value)
-        gwy_container_set_const_string_by_name((GwyContainer*)user_data, key, value);
+        gwy_dict_set_const_string_by_name((GwyDict*)user_data, key, value);
 }
 
 static GwyFile*
@@ -119,7 +119,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyField *dfield = NULL;
     GwyUnit *xunit = NULL, *yunit = NULL, *actzunit = NULL, *amplzunit = NULL, *voltunit = NULL;
     gchar *line, *p, *s, *value, *key, *sens, *title, *buffer = NULL;
@@ -235,7 +235,7 @@ load_file(const gchar *filename,
     else
         gwy_image_title_fall_back(file, 0);
 
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, store_meta, meta);
     gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
 
