@@ -1,5 +1,5 @@
 /*
- *  $Id: wsffile.c 28789 2025-11-04 17:14:03Z yeti-dn $
+ *  $Id: wsffile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2011-2025 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -72,7 +72,7 @@ static gint          detect_file    (const GwyFileDetectInfo *fileinfo,
 static GwyFile*      load_file      (const gchar *filename,
                                      GwyRunModeFlags mode,
                                      GError **error);
-static GwyContainer* get_meta       (GHashTable *hash);
+static GwyDict* get_meta       (GHashTable *hash);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -118,7 +118,7 @@ load_file(const gchar *filename,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *dfield = NULL;
     gchar *line, *p, *header_end, *title, *header = NULL, *buffer = NULL;
     GwyTextHeaderParser parser;
@@ -257,18 +257,18 @@ add_meta(gpointer hkey, gpointer hvalue, gpointer user_data)
             g_free(p);
         }
 
-        gwy_container_set_string_by_name(GWY_CONTAINER(user_data), key, value);
+        gwy_dict_set_string_by_name(GWY_DICT(user_data), key, value);
     }
     g_free(key);
     /* value is either NULL or eaten by the container */
 }
 
-static GwyContainer*
+static GwyDict*
 get_meta(GHashTable *hash)
 {
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(hash, add_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         return meta;
 
     g_object_unref(meta);
