@@ -1,5 +1,5 @@
 /*
- *  $Id: wsxmfile.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: wsxmfile.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2005-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -462,9 +462,9 @@ wsxmcurve_load(const gchar *filename,
 static void
 store_meta(gpointer key, gpointer value, gpointer user_data)
 {
-    GwyContainer *meta = (GwyContainer*)user_data;
+    GwyDict *meta = (GwyDict*)user_data;
 
-    gwy_container_set_const_string_by_name(meta, key, value);
+    gwy_dict_set_const_string_by_name(meta, key, value);
 }
 
 static gboolean
@@ -534,7 +534,7 @@ process_metadata(GHashTable *wsxmmeta,
             gwy_field_multiply(dfield, p);
         }
         else {
-            gwy_field_get_min_max(dfield, &min, &max);
+            gwy_field_min_max(dfield, &min, &max);
             gwy_field_multiply(dfield, r*p/(max - min));
         }
 
@@ -563,9 +563,9 @@ process_metadata(GHashTable *wsxmmeta,
     for (i = 0; i < G_N_ELEMENTS(nometa); i++)
         g_hash_table_remove(wsxmmeta, nometa[i]);
 
-    GwyContainer *meta = gwy_container_new_in_construction();
+    GwyDict *meta = gwy_dict_new_in_construction();
     g_hash_table_foreach(wsxmmeta, store_meta, meta);
-    if (gwy_container_get_n_items(meta))
+    if (gwy_dict_get_n_items(meta))
         gwy_file_pass_meta(file, GWY_FILE_IMAGE, 0, meta);
     else
         g_object_unref(meta);
@@ -739,7 +739,7 @@ wsxmfile_export_double(GwyFile *data,
     d = gwy_field_get_data_const(dfield);
     xres = gwy_field_get_xres(dfield);
     yres = gwy_field_get_yres(dfield);
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
 
     xyunit = gwy_unit_get_string(gwy_field_get_unit_xy(dfield), GWY_UNIT_FORMAT_PLAIN);
     zunit = gwy_unit_get_string(gwy_field_get_unit_z(dfield), GWY_UNIT_FORMAT_PLAIN);
