@@ -1,5 +1,5 @@
 /*
- *  $Id: xyzexport.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: xyzexport.c 29246 2026-01-16 14:51:14Z yeti-dn $
  *  Copyright (C) 2015-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -60,8 +60,8 @@ static gboolean         export_file    (GwyFile *file,
                                         GError **error);
 static GwyDialogOutcome run_gui        (ModuleArgs *args,
                                         const gchar *title);
-static gboolean         export_field   (GwyField *dfield,
-                                        GwyField *mfield,
+static gboolean         export_field   (GwyField *field,
+                                        GwyNield *mask,
                                         FILE *fh,
                                         ModuleArgs *args);
 static gboolean         export_surface (GwySurface *surface,
@@ -123,7 +123,8 @@ export_file(GwyFile *file,
             GError **error)
 {
     ModuleArgs args;
-    GwyField *dfield, *mfield;
+    GwyField *field;
+    GwyNield *mask;
     GwySurface *surface;
     gint fid, sid;
     const gchar *title = NULL;
@@ -131,9 +132,9 @@ export_file(GwyFile *file,
     FILE *fh = NULL;
     gboolean ok = FALSE;
 
-    gwy_data_browser_get_current(GWY_APP_FIELD, &dfield,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
                                  GWY_APP_FIELD_ID, &fid,
-                                 GWY_APP_MASK_FIELD, &mfield,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_SURFACE, &surface,
                                  GWY_APP_SURFACE_ID, &sid,
                                  GWY_APP_DATA_KIND, &args.data_kind,
@@ -142,28 +143,28 @@ export_file(GwyFile *file,
     /* Ensure at most one is set.  We produce an error if no exportable data type is available or both types are
      * available but neither is active. When only one is available or one is active we assume that is what the user
      * wants to export. */
-    if (dfield && surface) {
+    if (field && surface) {
         if (args.data_kind != GWY_FILE_IMAGE)
-            dfield = NULL;
+            field = NULL;
         if (args.data_kind != GWY_FILE_XYZ)
             surface = NULL;
     }
-    if (!dfield && !surface) {
+    if (!field && !surface) {
         err_NO_CHANNEL_EXPORT(error);
         return FALSE;
     }
 
-    if (dfield) {
+    if (field) {
         args.data_kind = GWY_FILE_IMAGE;
     }
     if (surface) {
         args.data_kind = GWY_FILE_XYZ;
-        mfield = NULL;
+        mask = NULL;
     }
 
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    title = gwy_file_get_title(file, args.data_kind, dfield ? fid : sid);
+    title = gwy_file_get_title(file, args.data_kind, field ? fid : sid);
     if (!title)
         title = _("Untitled");
 
@@ -187,8 +188,8 @@ export_file(GwyFile *file,
 
         if (args.data_kind == GWY_FILE_IMAGE) {
             gwy_fprintf(fh, "# %s %s\n", _("Channel:"), title);
-            xyunit = gwy_field_get_unit_xy(dfield);
-            zunit = gwy_field_get_unit_z(dfield);
+            xyunit = gwy_field_get_unit_xy(field);
+            zunit = gwy_field_get_unit_z(field);
         }
         else if (args.data_kind == GWY_FILE_XYZ) {
             gwy_fprintf(fh, "# %s %s\n", _("XYZ data:"), title);
@@ -206,7 +207,7 @@ export_file(GwyFile *file,
     }
 
     if (args.data_kind == GWY_FILE_IMAGE) {
-        if (!export_field(dfield, mfield, fh, &args)) {
+        if (!export_field(field, mask, fh, &args)) {
             err_WRITE(error);
             goto fail;
         }
@@ -265,39 +266,37 @@ run_gui(ModuleArgs *args, const gchar *title)
     return gwy_dialog_run(dialog);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static gboolean
-export_field(GwyField *dfield, GwyField *mfield,
+export_field(GwyField *field, GwyNield *mask,
              FILE *fh, ModuleArgs *args)
 {
     gboolean decimal_dot = gwy_params_get_boolean(args->params, PARAM_DECIMAL_DOT);
     gint precision = gwy_params_get_int(args->params, PARAM_PRECISION);
-    GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mfield);
-    gdouble dx, dy, xoff, yoff;
-    const gdouble *d, *m;
-    gint xres, yres, i, j;
-    gdouble xyz[3];
-    GString *str;
+    GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble dx = gwy_field_get_dx(field), dy = gwy_field_get_dy(field);
+    gdouble xoff = gwy_field_get_xoffset(field), yoff = gwy_field_get_yoffset(field);
+    const gdouble *d = gwy_field_get_data_const(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
+    GString *str = g_string_new(NULL);
 
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    dx = gwy_field_get_dx(dfield);
-    dy = gwy_field_get_dy(dfield);
-    xoff = gwy_field_get_xoffset(dfield);
-    yoff = gwy_field_get_yoffset(dfield);
-
-    d = gwy_field_get_data_const(dfield);
-    m = mfield ? gwy_field_get_data_const(mfield) : NULL;
-
-    str = g_string_new(NULL);
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
+        gdouble xyz[3];
         xyz[1] = dy*(i + 0.5) + yoff;
-        for (j = 0; j < xres; j++) {
-            if (m) {
-                if (masking == GWY_MASK_EXCLUDE && m[i*xres + j] > 0.5)
-                    continue;
-                if (masking == GWY_MASK_INCLUDE && m[i*xres + j] < 0.5)
-                    continue;
-            }
+        for (gint j = 0; j < xres; j++) {
+            if (!nielded_included(m + i*xres + j, masking))
+                continue;
 
             xyz[0] = dx*(j + 0.5) + xoff;
             xyz[2] = d[i*xres + j];
