@@ -1,5 +1,5 @@
 /*
- *  $Id: zeisslsm.c 28803 2025-11-05 11:58:19Z yeti-dn $
+ *  $Id: zeisslsm.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2017-2025 David Necas (Yeti), Daniil Bratashov (dn2010).
  *  E-mail: dn2010@gwyddion.net.
  *
@@ -347,7 +347,7 @@ static LSMNamesColors*    read_names_colors(const GwyTIFF *tiff,
                                             guint32 offset,
                                             GError **error);
 static LSMEntryRecording* read_recording   (const GwyTIFF *tiff,
-                                            GwyContainer *meta,
+                                            GwyDict *meta,
                                             guint32 offset,
                                             GError **error);
 static LSMEntry*          read_entry       (const GwyTIFF *tiff,
@@ -450,7 +450,7 @@ load_tiff(const GwyTIFF *tiff,
           GError **error)
 {
     GwyFile *file = NULL;
-    GwyContainer *meta = NULL;
+    GwyDict *meta = NULL;
     GwyLine *line = NULL;
     GwyGraphCurveModel *gcmodel;
     GwyGraphModel *gmodel = NULL;
@@ -481,7 +481,7 @@ load_tiff(const GwyTIFF *tiff,
     }
 
     names_colors = read_names_colors(tiff, header_tag->offset_channel_colors_names, error);
-    meta = gwy_container_new_in_construction();
+    meta = gwy_dict_new_in_construction();
     recording = read_recording(tiff, meta, header_tag->offset_scan_information, error);
 
     ndirs = gwy_tiff_get_n_dirs(tiff);
@@ -626,8 +626,8 @@ load_tiff(const GwyTIFF *tiff,
             if (is_image) {
                 gwy_unit_set_from_string(gwy_field_get_unit_xy(dfield), "m");
                 gwy_file_pass_image(file, k, dfield);
-                if (gwy_container_get_n_items(meta)) {
-                    gwy_file_pass_meta(file, GWY_FILE_IMAGE, k, gwy_container_copy(meta));
+                if (gwy_dict_get_n_items(meta)) {
+                    gwy_file_pass_meta(file, GWY_FILE_IMAGE, k, gwy_dict_copy(meta));
                 }
                 gwy_log_add_import(file, GWY_FILE_IMAGE, k, NULL, filename);
 
@@ -667,8 +667,8 @@ load_tiff(const GwyTIFF *tiff,
                         g_array_insert_val(bricks_preview, j, brick);
 
                     gwy_file_pass_volume(file, volumes+1, brick);
-                    if (gwy_container_get_n_items(meta)) {
-                        gwy_file_pass_meta(file, GWY_FILE_VOLUME, volumes+1, gwy_container_copy(meta));
+                    if (gwy_dict_get_n_items(meta)) {
+                        gwy_file_pass_meta(file, GWY_FILE_VOLUME, volumes+1, gwy_dict_copy(meta));
                     }
                     gwy_log_add_import(file, GWY_FILE_VOLUME, volumes+1, NULL, filename);
 
@@ -864,37 +864,37 @@ read_names_colors(const GwyTIFF *tiff,
 }
 
 static gchar*
-set_meta_string(const LSMEntry *entry, const gchar *name, GwyContainer *meta)
+set_meta_string(const LSMEntry *entry, const gchar *name, GwyDict *meta)
 {
     gchar *s = gwy_convert_to_utf8(entry->data, entry->size, "ISO-8859-1");
 
-    gwy_container_set_string_by_name(meta, name, s);
+    gwy_dict_set_string_by_name(meta, name, s);
     return s;
 }
 
 static guint
-set_meta_int(const LSMEntry *entry, const gchar *name, GwyContainer *meta)
+set_meta_int(const LSMEntry *entry, const gchar *name, GwyDict *meta)
 {
     const guchar *p = entry->data;
     guint value = gwy_get_guint32_le(&p);
 
-    gwy_container_set_string_by_name(meta, name, g_strdup_printf("%d", value));
+    gwy_dict_set_string_by_name(meta, name, g_strdup_printf("%d", value));
     return value;
 }
 
 static gdouble
-set_meta_double(const LSMEntry *entry, const gchar *name, const gchar *unit, GwyContainer *meta)
+set_meta_double(const LSMEntry *entry, const gchar *name, const gchar *unit, GwyDict *meta)
 {
     const guchar *p = entry->data;
     gdouble value = gwy_get_gdouble_le(&p);
 
-    gwy_container_set_string_by_name(meta, name, g_strdup_printf("%g%s%s", value, unit ? " " : "", unit ? unit : ""));
+    gwy_dict_set_string_by_name(meta, name, g_strdup_printf("%g%s%s", value, unit ? " " : "", unit ? unit : ""));
     return value;
 }
 
 static LSMEntryRecording*
 read_recording(const GwyTIFF *tiff,
-               GwyContainer *meta,
+               GwyDict *meta,
                guint32 offset,
                G_GNUC_UNUSED GError **error)
 {
@@ -956,19 +956,19 @@ read_recording(const GwyTIFF *tiff,
         else if (entry->entry == LSM_RECORDING_ENTRY_SCAN_DIRECTION) {
             p = entry->data;
             recording->scan_direction = gwy_get_guint32_le(&p);
-            gwy_container_set_const_string_by_name(meta, "Scan direction",
-                                                   recording->scan_direction ? "Bidirectional" : "Unidirectional");
+            gwy_dict_set_const_string_by_name(meta, "Scan direction",
+                                              recording->scan_direction ? "Bidirectional" : "Unidirectional");
         }
         else if (entry->entry == LSM_RECORDING_ENTRY_TIME_SERIES) {
             p = entry->data;
             recording->time_series = gwy_get_guint32_le(&p);
-            gwy_container_set_const_string_by_name(meta, "Time series", recording->time_series ? "True" : "False");
+            gwy_dict_set_const_string_by_name(meta, "Time series", recording->time_series ? "True" : "False");
         }
         else if (entry->entry == LSM_RECORDING_ENTRY_ORIGINAL_SCAN_DATA) {
             p = entry->data;
             recording->original_scan_data = gwy_get_guint32_le(&p);
-            gwy_container_set_const_string_by_name(meta, "Original scan data",
-                                                   recording->original_scan_data ? "Original" : "Modified");
+            gwy_dict_set_const_string_by_name(meta, "Original scan data",
+                                              recording->original_scan_data ? "Original" : "Modified");
         }
         else if (entry->entry == LSM_RECORDING_ENTRY_ZOOM_X)
             recording->zoomx = set_meta_double(entry, "X zoom", NULL, meta);
@@ -1035,8 +1035,8 @@ read_recording(const GwyTIFF *tiff,
         else if (entry->entry == LSM_LASER_ENTRY_ACQUIRE) {
             p = entry->data;
             recording->laser_acquire = gwy_get_guint32_le(&p);
-            gwy_container_set_const_string_by_name(meta, "Laser acquire",
-                                                   recording->laser_acquire ? "Enabled" : "Disabled");
+            gwy_dict_set_const_string_by_name(meta, "Laser acquire",
+                                              recording->laser_acquire ? "Enabled" : "Disabled");
         }
         else if (entry->entry == LSM_LASER_ENTRY_POWER)
             recording->laser_power = set_meta_double(entry, "Laser power", "mW", meta);
