@@ -1,5 +1,5 @@
 /*
- *  $Id: zemax.c 28805 2025-11-05 12:28:20Z yeti-dn $
+ *  $Id: zemax.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2013-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net
  *
@@ -111,7 +111,7 @@ load_file(const gchar *filename,
 
     ZemaxFile zmxfile;
     GwyFile *file = NULL;
-    GwyContainer *meta;
+    GwyDict *meta;
     GwyField *fields[5];
     gdouble *field_data[5];
     gchar *p, *line, *end, *buffer = NULL;
@@ -182,9 +182,9 @@ load_file(const gchar *filename,
     if (is_empty(fields[1]) && is_empty(fields[2]) && is_empty(fields[3]))
         nchannels = 1;
 
-    meta = gwy_container_new_in_construction();
-    gwy_container_set_string_by_name(meta, "Decenter X", g_strdup_printf("%g m", q*zmxfile.xoff));
-    gwy_container_set_string_by_name(meta, "Decenter Y", g_strdup_printf("%g m", q*zmxfile.yoff));
+    meta = gwy_dict_new_in_construction();
+    gwy_dict_set_string_by_name(meta, "Decenter X", g_strdup_printf("%g m", q*zmxfile.xoff));
+    gwy_dict_set_string_by_name(meta, "Decenter Y", g_strdup_printf("%g m", q*zmxfile.yoff));
 
     file = gwy_file_new_in_construction();
     str = g_string_new(NULL);
@@ -192,9 +192,12 @@ load_file(const gchar *filename,
         gwy_unit_set_from_string(gwy_field_get_unit_z(fields[i]), units[i]);
         gwy_file_set_image(file, i, fields[i]);
         gwy_file_set_title(file, GWY_FILE_IMAGE, i, titles[i], FALSE);
-        if (havemask)
-            gwy_file_pass_image_mask(file, i, gwy_field_copy(fields[4]));
-        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_container_copy(meta));
+        if (havemask) {
+            GwyNield *mask = gwy_field_new_nield_alike(fields[4]);
+            gwy_nield_mark_by_threshold(mask, fields[4], 0.5, TRUE);
+            gwy_file_pass_image_mask(file, i, mask);
+        }
+        gwy_file_pass_meta(file, GWY_FILE_IMAGE, i, gwy_dict_copy(meta));
 
         gwy_log_add_import(file, GWY_FILE_IMAGE, i, NULL, filename);
     }
@@ -326,7 +329,7 @@ static gboolean
 is_empty(GwyField *field)
 {
     gdouble min, max;
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     return min == 0.0 && max == 0.0;
 }
 
