@@ -1,6 +1,6 @@
 /*
- *  $Id: zonfile.c 28789 2025-11-04 17:14:03Z yeti-dn $
- *  Copyright (C) 2023-2025 David Necas (Yeti).
+ *  $Id: zonfile.c 29534 2026-02-23 18:33:14Z yeti-dn $
+ *  Copyright (C) 2023-2026 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
  *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
@@ -40,9 +40,16 @@
 
 #include "err.h"
 #include "gwyzip.h"
+#ifdef HAVE_ZSTD
+#include "zstd.h"
+#endif
 
 #define MAGIC_PK "PK\x03\x04"
 #define MAGIC_PK_SIZE (sizeof(MAGIC_PK)-1)
+
+#define MAGIC_ZSTD "\x28\xb5\x2f\xfd"
+#define MAGIC_ZSTD_SIZE (sizeof(MAGIC_ZSTD)-1)
+
 #define BLOODY_UTF8_BOM "\xef\xbb\xbf"
 #define EXTENSION ".zon"
 
@@ -68,6 +75,9 @@ typedef struct {
     GString *path;
     GString *str;
     gboolean ignore;
+#ifdef HAVE_ZSTD
+    ZSTD_DCtx *zstd_context;
+#endif
 } ZONFile;
 
 static gboolean module_register(void);
@@ -80,13 +90,21 @@ static gboolean parse_one_file (GwyZipFile zipfile,
                                 ZONFile *zonfile,
                                 GError **error);
 static void     free_zonfile   (ZONFile *zonfile);
+#if HAVE_ZSTD
+static guchar*  decompress_zstd(ZSTD_DCtx *context,
+                                guchar *content,
+                                gsize compsize,
+                                gsize *decompsize,
+                                const gchar *filename,
+                                        GError **error);
+#endif
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Reads Keyence ZON files."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.2",
     "David Nečas (Yeti)",
     "2023",
 };
@@ -129,15 +147,17 @@ detect_file(const GwyFileDetectInfo *fileinfo, gboolean only_name)
 }
 
 static GwyZipFile
-open_contained_zip_file(const gchar *filename, gchar **zipfilename, GError **error)
+open_contained_zip_file(const gchar *filename, guchar **pbuffer, gsize *psize, GError **error)
 {
     GwyZipFile zipfile = NULL;
     GError *err = NULL;
     guchar *buffer = NULL;
-    const guchar *p;
+    const guchar *p, *zipstart;
     G_GNUC_UNUSED gsize headersize;
-    gsize bmpsize, size = 0;
+    gsize bmpsize, zipsize, size = 0;
 
+    *pbuffer = NULL;
+    *psize = 0;
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
         return NULL;
@@ -161,12 +181,31 @@ open_contained_zip_file(const gchar *filename, gchar **zipfilename, GError **err
         goto end;
     }
 
+    zipsize = size - ZON_PK_HEADER_SIZE - bmpsize;
+    zipstart = buffer + ZON_PK_HEADER_SIZE + bmpsize;
+    if (memcmp(zipstart, MAGIC_PK, MAGIC_PK_SIZE) != 0) {
+        gwy_debug("header size is wrong, trying to search forward for a PK ZIP signature");
+        const guchar *t = gwy_memmem(zipstart, MIN(zipsize, 1024), MAGIC_PK, MAGIC_PK_SIZE);
+        if (t) {
+            gwy_debug("found a PK ZIP signature %ld bytes after", (glong)(t - zipstart));
+            zipsize -= t - zipstart;
+            zipstart = t;
+        }
+        else {
+            gwy_debug("did not find a PK ZIP signature");
+        }
+    }
+
     gwy_debug("opening ZIP");
-    zipfile = gwyzip_make_temporary_archive(buffer + ZON_PK_HEADER_SIZE + bmpsize, size - ZON_PK_HEADER_SIZE - bmpsize,
-                                            "gwyddion-zonfile-XXXXXX.zip", zipfilename, error);
+    zipfile = gwyzip_make_temporary_archive(zipstart, zipsize, "gwyddion-zonfile-XXXXXX.zip", error);
 
 end:
-    gwy_file_abandon_contents(buffer, size, NULL);
+    if (zipfile) {
+        *pbuffer = buffer;
+        *psize = size;
+    }
+    else
+        gwy_file_abandon_contents(buffer, size, NULL);
 
     return zipfile;
 }
@@ -180,15 +219,17 @@ load_file(const gchar *filename,
     ZONFile zonfile;
     GwyZipFile zipfile = NULL;
     ZONData *zd;
-    gchar *zipfilename = NULL, *xml_filename;
+    gchar *xml_filename;
     const gchar *s;
-    GwyField *field, *mask;
+    guchar *buffer = NULL;
+    gsize size = 0;
+    GwyField *field;
     gdouble *d;
     gdouble dxy, q;
     guint i, j, id, mask_i = G_MAXUINT;
 
     gwy_clear1(zonfile);
-    if (!(zipfile = open_contained_zip_file(filename, &zipfilename, error)))
+    if (!(zipfile = open_contained_zip_file(filename, &buffer, &size, error)))
         goto fail;
 
     gwy_debug("OK");
@@ -245,36 +286,32 @@ load_file(const gchar *filename,
     }
     if (mask_i != G_MAXUINT) {
         zd = &g_array_index(zonfile.datafiles, ZONData, mask_i);
-        mask = gwy_field_new(zd->xres, zd->yres, zd->xres*dxy, zd->yres*dxy, FALSE);
-        gwy_unit_set_from_string(gwy_field_get_unit_xy(mask), "m");
-        d = gwy_field_get_data(mask);
-        for (j = 0; j < zd->yres; j++) {
-            gwy_convert_raw_data(zd->data + j*zd->rowstride, zd->xres, 1,
-                                 GWY_RAW_DATA_UINT8, GWY_BYTE_ORDER_LITTLE_ENDIAN, d + j*zd->xres, 1.0, 0.0);
+        GwyNield *mask = gwy_nield_new(zd->xres, zd->yres);
+        gint *m = gwy_nield_get_data(mask);
+        for (i = 0; i < zd->yres; i++) {
+            for (j = 0; j < zd->xres; j++)
+                m[i*zd->xres + j] = !!zd->data[i*zd->rowstride + j];
         }
-        gwy_field_threshold(mask, 0.5, 0.0, 1.0);
         for (i = 0; i < id; i++) {
             if (i == id-1)
                 gwy_file_set_image_mask(file, i, mask);
             else
-                gwy_file_pass_image_mask(file, i, gwy_field_copy(mask));
+                gwy_file_pass_image_mask(file, i, gwy_nield_copy(mask));
         }
         g_object_unref(mask);
     }
 
-    if (!gwy_container_get_n_items(GWY_CONTAINER(file))) {
+    if (!gwy_dict_get_n_items(GWY_DICT(file))) {
         g_clear_object(&file);
         err_NO_DATA(error);
         goto fail;
     }
 
 fail:
-    if (zipfilename) {
-        g_unlink(zipfilename);
-        g_free(zipfilename);
-    }
     if (zipfile)
         gwyzip_close(zipfile);
+    if (buffer)
+        gwy_file_abandon_contents(buffer, size, NULL);
     free_zonfile(&zonfile);
 
     return file;
@@ -412,6 +449,35 @@ parse_one_file(GwyZipFile zipfile, ZONFile *zonfile, GError **error)
     if (!(content = gwyzip_get_file_content(zipfile, &size, error)))
         return FALSE;
 
+    /* Sometimes the files inside the ZIP archive are also compressed individually using zstd. Because no matter how
+     * messy things are, someone always figures out a way to make them worse. Give an informative error message if
+     * this is not supported. */
+    if (size >= 4 && memcmp(content, MAGIC_ZSTD, MAGIC_ZSTD_SIZE) == 0) {
+#if HAVE_ZSTD
+        if (!zonfile->zstd_context)
+            zonfile->zstd_context = ZSTD_createDCtx();
+
+        gchar *filename = NULL;
+        if (!gwyzip_get_current_filename(zipfile, &filename, NULL))
+            filename = g_strdup("???");
+
+        /* It always eats the content passed to it, even on failure. */
+        gsize decompsize;
+        if (!(content = decompress_zstd(zonfile->zstd_context, content, size, &decompsize, filename, error))) {
+            g_free(filename);
+            return FALSE;
+        }
+        g_free(filename);
+        size = decompsize;
+#else
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_SPECIFIC,
+                    /* TRANSLATORS: %s is replaced by a software library name like zlib. */
+                    _("Cannot decompress compressed data.  Gwyddion was built without %s support."), "zstd");
+        g_free(content);
+        return FALSE;
+#endif
+    }
+
     if (g_str_has_prefix(content, "<"))
         s = gwy_strkill(content, "\r");
     else if (g_str_has_prefix(content, BLOODY_UTF8_BOM "<"))
@@ -419,8 +485,8 @@ parse_one_file(GwyZipFile zipfile, ZONFile *zonfile, GError **error)
     else if (size >= MAGIC_PK_SIZE && memcmp(content, MAGIC_PK, MAGIC_PK_SIZE) == 0) {
         gwy_debug("ignoring nested compressed file");
         g_free(content);
-        /* Just ignore nested compressed files. They probably contain other compressed files inside, which in turn
-         * contain stuff already present in the main archive… */
+        /* Just ignore nested ZIP files. They probably contain other ZIP files inside, which in turn contain stuff
+         * already present in the main archive. Or more nested ZIP files. */
         return TRUE;
     }
     else
@@ -441,6 +507,51 @@ parse_one_file(GwyZipFile zipfile, ZONFile *zonfile, GError **error)
     return ok;
 }
 
+#ifdef HAVE_ZSTD
+static guchar*
+decompress_zstd(ZSTD_DCtx *context,
+                guchar *content, gsize compsize, gsize *decompsize,
+                const gchar *filename, GError **error)
+{
+    // We must use the streaming API because they compress the files in a way which does not store the size.
+    // 4096 bytes should be enough for the various XML bits and pieces.
+    ZSTD_inBuffer input = { content, compsize, 0 };
+    ZSTD_outBuffer output = { NULL, 4096, 0 };
+
+    gwy_debug("trying to zstd-decompress file %s", filename);
+    output.dst = g_new(guchar, output.size);
+
+    while (TRUE) {
+        gsize status = ZSTD_decompressStream(context, &output, &input);
+        gwy_debug("input size=%zu, pos=%zu; output size=%zu, pos=%zu",
+                   input.size, input.pos, output.size, output.pos);
+        if (ZSTD_isError(status)) {
+            g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_SPECIFIC,
+                        _("Libzstd error while reading the zst file: %s."), filename);
+            g_free(content);
+            g_free(output.dst);
+            ZSTD_DCtx_reset(context, ZSTD_reset_session_only);
+            return NULL;
+        }
+        if (input.pos == input.size)
+            break;
+
+        output.size = 2*output.size;
+        output.dst = g_renew(guchar, output.dst, output.size);
+    }
+
+    g_free(content);
+    ZSTD_DCtx_reset(context, ZSTD_reset_session_only);
+
+    guchar *retval = output.dst;
+    if (output.pos == output.size)
+        retval = g_renew(guchar, retval, output.size+1);
+    retval[output.pos] = '\0';
+    *decompsize = output.pos;
+    return retval;
+}
+#endif
+
 static void
 free_zonfile(ZONFile *zonfile)
 {
@@ -460,6 +571,9 @@ free_zonfile(ZONFile *zonfile)
         }
         g_array_free(zonfile->datafiles, TRUE);
     }
+#ifdef HAVE_ZSTD
+    ZSTD_freeDCtx(zonfile->zstd_context);
+#endif
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
