@@ -1,5 +1,5 @@
 /*
- *  $Id: zyvex.c 28911 2025-11-24 18:27:42Z yeti-dn $
+ *  $Id: zyvex.c 29329 2026-01-23 16:22:18Z yeti-dn $
  *  ZyVector Scanz .zad file format import module
  *  Copyright (C) 2025 Zyvex Labs LLC.
  *  Author: Moutaz Haq.
@@ -1015,12 +1015,11 @@ load_file(const gchar *filename,
     for (i = 0; i < scan_data_num_scan_bufs(scan_data); i++) {
         ScanBuf *scan_buf = scan_data_get_scan_buf(scan_data, i);
         GwyField *field = create_field(system_data, scan_data, scan_buf, error);
-        GwyField *mask = NULL;
         if (!field) {
             g_clear_object(&file);
             goto finish;
         }
-        mask = gwy_app_channel_mask_of_nans(field, TRUE);
+        GwyNield *mask = gwy_mask_nans_in_field(field, TRUE);
         gwy_file_pass_image(file, i, field);
         gwy_file_set_title(file, GWY_FILE_IMAGE, i, (const guchar*)scan_buf->name, FALSE);
         if (mask)
