@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_align.c 28803 2025-11-05 11:58:19Z yeti-dn $
+ *  $Id: graph_align.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2015-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -104,10 +104,10 @@ module_main(GwyGraph *graph)
         return;
     }
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data,
                                  GWY_APP_GRAPH_MODEL_KEY, &quark,
                                  0);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_log_add(data, GWY_FILE_GRAPH, id, id);
 
     for (i = 0; i < ncurves; i++) {
@@ -332,7 +332,7 @@ regularise(const GwyXY *xydata, gint ndata, gdouble dx, gint *pn)
     if (nzero) {
         for (i = 0; i < n; i++)
             weight[i] = (weight[i] <= 0.0);
-        gwy_line_correct_laplace(dline, wline);
+        gwy_line_laplace_solve(dline, wline);
     }
     data = g_memdup(data, n*sizeof(gdouble));
 
