@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_cd.c 28734 2025-10-29 10:18:03Z yeti-dn $
+ *  $Id: graph_cd.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -134,7 +134,7 @@ module_main(GwyGraph *graph)
     gwy_clear1(args);
 
     GwyFile *file;
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &file, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &file, 0);
 
     args.params = gwy_params_new_from_settings(define_module_params());
     args.gmodel = gwy_graph_get_model(graph);
