@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_cut.c 28645 2025-10-13 17:19:42Z yeti-dn $
+ *  $Id: graph_cut.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2007-2023 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -101,7 +101,7 @@ module_main(GwyGraph *graph)
     GwyDialogOutcome outcome;
     ModuleArgs args;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     gwy_clear1(args);
     args.params = gwy_params_new_from_settings(define_module_params());
     args.gmodel = gwy_graph_get_model(graph);
