@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_dos_spectrum.c 28645 2025-10-13 17:19:42Z yeti-dn $
+ *  $Id: graph_dos_spectrum.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2025 David Necas (Yeti), Petr Klapetek, Daniil Bratashov
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -65,7 +65,7 @@ module_main(GwyGraph *graph)
     gchar *graphtitle, *newtitle;
     GwyUnit *siunitx, *siunity;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, NULL);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, NULL);
     gmodel = gwy_graph_get_model(GWY_GRAPH(graph));
     g_object_get(gmodel,
                  "title", &graphtitle,
