@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_fztofd.c 28645 2025-10-13 17:19:42Z yeti-dn $
+ *  $Id: graph_fztofd.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -169,7 +169,7 @@ module_main(GwyGraph *graph)
     execute(&args, TRUE);
 
     target_graph_id = gwy_params_get_data_id(args.params, PARAM_TARGET_GRAPH);
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     gwy_app_add_graph_or_curves(args.result, data, &target_graph_id, 1);
 
 end:
