@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_logscale.c 28645 2025-10-13 17:19:42Z yeti-dn $
+ *  $Id: graph_logscale.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -141,7 +141,7 @@ module_main(GwyGraph *graph)
     gdouble base;
     gchar *label, *llabel;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     gwy_clear1(args);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
