@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_measure_period.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: graph_measure_period.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -134,7 +134,7 @@ module_main(GwyGraph *graph)
     ModuleArgs args;
     gint id;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data,
                                  GWY_APP_GRAPH_MODEL_ID, &id,
                                  0);
     gwy_clear1(args);
@@ -330,7 +330,7 @@ regularise_curve(GwyGraphCurveModel *gcmodel, gint pos, gint npts)
             mdata[i] = 1.0;
     }
 
-    gwy_line_correct_laplace(line, mask);
+    gwy_line_laplace_solve(line, mask);
     g_object_unref(mask);
 
     return line;
@@ -1027,7 +1027,7 @@ fix_zero_line(GwyLine *line)
     /* For some gratings this is not very good, but it is a one-liner and the method based on peaks in height
      * distribution has its own problems. Do not use plain median. If the fill ratio is relatively far from 1/2,
      * mean becomes just somewhat off, whereas median can easily move to the top or bottom level. */
-    gwy_line_add(line, -gwy_line_avg(line));
+    gwy_line_add(line, -gwy_line_mean(line));
 }
 
 /* The way we do levelling makes a bit difficult to show it for the original curve. Try to reconstruct it at least
