@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_merge.c 28783 2025-11-04 17:09:52Z yeti-dn $
+ *  $Id: graph_merge.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2023 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net.
  *
@@ -90,10 +90,10 @@ merge_average_do(GwyGraph *graph, gdouble tightness)
     gint i, j, k, l, ncurves, ndata, nalldata;
     GQuark quark;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data,
                                  GWY_APP_GRAPH_MODEL_KEY, &quark,
                                  0);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     gmodel = gwy_graph_get_model(graph);
     ncurves = gwy_graph_model_get_n_curves(gmodel);
