@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_polylevel.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: graph_polylevel.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -126,7 +126,7 @@ module_main(GwyGraph *graph)
     GwyFile *data;
     ModuleArgs args;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     gwy_clear1(args);
     args.params = gwy_params_new_from_settings(define_module_params());
     args.gmodel = gwy_graph_get_model(graph);
@@ -209,7 +209,7 @@ run_gui(ModuleArgs *args, GwyFile *data)
     g_object_set(args->result, "label-visible", TRUE, NULL);
 
     target_graph_id = gwy_params_get_data_id(args->params, PARAM_TARGET_GRAPH);
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
     gwy_app_add_graph_or_curves(args->result, data, &target_graph_id, 1);
 
 end:
