@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_simplemech.c 28783 2025-11-04 17:09:52Z yeti-dn $
+ *  $Id: graph_simplemech.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -50,7 +50,7 @@ static gboolean         module_register     (void);
 static GwyParamDef*     define_module_params(void);
 static void             module_main         (GwyGraph *graph);
 static GwyDialogOutcome run_gui             (ModuleArgs *args,
-                                             GwyContainer *data);
+                                             GwyDict *data);
 static void             execute             (ModuleArgs *args,
                                              GwyResults *results);
 static void             param_changed       (ModuleGUI *gui,
@@ -116,12 +116,12 @@ static void
 module_main(G_GNUC_UNUSED GwyGraph *graph)
 {
     GwyDialogOutcome outcome;
-    GwyContainer *data;
+    GwyDict *data;
     ModuleArgs args;
     GwyAppDataId graph_id;
 
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data, 0);
-    gwy_data_browser_get_current(GWY_APP_CONTAINER_ID, &graph_id.datano,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data, 0);
+    gwy_data_browser_get_current(GWY_APP_FILE_ID, &graph_id.datano,
                                  GWY_APP_GRAPH_MODEL_ID, &graph_id.id,
                                  0);
 
@@ -146,7 +146,7 @@ end:
 }
 
 static GwyDialogOutcome
-run_gui(ModuleArgs *args, G_GNUC_UNUSED GwyContainer *data)
+run_gui(ModuleArgs *args, G_GNUC_UNUSED GwyDict *data)
 {
     GwyDialogOutcome outcome;
     GtkWidget *hbox, *graph;
