@@ -1,5 +1,5 @@
 /*
- *  $Id: graph_terraces.c 29059 2026-01-02 14:27:52Z yeti-dn $
+ *  $Id: graph_terraces.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -292,7 +292,7 @@ module_main(GwyGraph *graph)
     gwy_clear1(args);
     args.params = gwy_params_new_from_settings(define_module_params());
     args.gmodel = gwy_graph_get_model(graph);
-    gwy_data_browser_get_current(GWY_APP_CONTAINER, &data,
+    gwy_data_browser_get_current(GWY_APP_FILE, &data,
                                  GWY_APP_GRAPH_MODEL_ID, &id,
                                  0);
 
@@ -1107,15 +1107,13 @@ apply_gaussian_step_filter(const gdouble *xdata,
 {
     gint n = gwy_line_get_res(filtered);
     gdouble *d = gwy_line_get_data(filtered);
-    gint i;
 
     gwy_clear(d, n);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(d,xdata,ydata,n,dx,sigma) \
-            private(i)
+            shared(d,xdata,ydata,n,dx,sigma)
 #endif
-    for (i = 2; i < n-2; i++) {
+    for (gint i = 2; i < n-2; i++) {
         gdouble t, u, xorigin = xdata[i];
         gdouble x1, x2, y1, y2, zlimfw, zlimback, det;
         gdouble s1, sx, sxx, sy, sxy;
