@@ -1,6 +1,6 @@
 /*
- *  $Id: acf2d.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2007-2022 David Necas (Yeti).
+ *  $Id: acf2d.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2007-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -69,9 +69,9 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *acf;
-    GwyField *acfmask;
+    GwyNield *acfmask;
     GwySelection *selection;
     GwyGraphModel *gmodel;
 } ModuleArgs;
@@ -107,6 +107,8 @@ static void             preview                       (gpointer user_data);
 static void             calculate_zoomed_fields       (ModuleGUI *gui);
 static GwyField*        cut_field_to_zoom             (GwyField *field,
                                                        gint zoom);
+static GwyNield*        cut_nield_to_zoom             (GwyNield *field,
+                                                       gint zoom);
 static void             selection_changed             (ModuleGUI *gui,
                                                        gint hint);
 static void             update_sensitivity            (ModuleGUI *gui);
@@ -117,7 +119,8 @@ static void             add_line_selection_from_points(GwyFile *data,
                                                        gint id,
                                                        GwySelection *pointsel);
 static void             create_acf_mask               (ModuleArgs *args);
-static gboolean         find_decays                   (GwyField *mask,
+static gboolean         find_decays                   (GwyNield *mask,
+                                                       GwyField *acf,
                                                        gdouble *r1,
                                                        gdouble *r2,
                                                        gdouble *phi1,
@@ -130,7 +133,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates and analyzes two-dimensional autocorrelation function."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "3.2",
     "David Nečas (Yeti)",
     "2007",
 };
@@ -211,12 +214,12 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     args.params = gwy_params_new_from_settings(define_module_params());
     args.acf = gwy_field_new(17, 17, 1.0, 1.0, TRUE);
-    args.acfmask = gwy_field_new(17, 17, 1.0, 1.0, TRUE);
+    args.acfmask = gwy_nield_new(17, 17);
     // We need to set the units of args->gmodel immediately for target graph filtering.
     gwy_unit_assign(gwy_field_get_unit_xy(args.acf), gwy_field_get_unit_xy(args.field));
     gwy_unit_power(gwy_field_get_unit_z(args.field), 2, gwy_field_get_unit_z(args.acf));
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -232,10 +235,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (gwy_params_get_boolean(args.params, PARAM_CREATE_IMAGE)) {
         gboolean zoomed_image = gwy_params_get_boolean(args.params, PARAM_ZOOMED_IMAGE);
         guint zoom = (zoomed_image ? gwy_params_get_enum(args.params, PARAM_ZOOM) : 1);
-        GwyField *zoomed, *zoomedmask;
+        GwyField *zoomed;
+        GwyNield *zoomedmask;
 
         zoomed = cut_field_to_zoom(args.acf, zoom);
-        zoomedmask = cut_field_to_zoom(args.acfmask, zoom);
+        zoomedmask = cut_nield_to_zoom(args.acfmask, zoom);
         newid = gwy_file_add_image(data, zoomed);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_pass_image_mask(data, newid, zoomedmask);
@@ -494,7 +498,7 @@ preview(gpointer user_data)
         gdouble rmin, rmax, phimin, phimax;
 
         create_acf_mask(args);
-        if (find_decays(args->acfmask, &rmin, &rmax, &phimin, &phimax)) {
+        if (find_decays(args->acfmask, args->acf, &rmin, &rmax, &phimin, &phimax)) {
             gwy_results_fill_values(gui->results,
                                     "Sal", rmin, "tau2", rmax, "phi1", phimin, "phi2", phimax, "Str", rmin/rmax,
                                     NULL);
@@ -568,7 +572,7 @@ update_curve(ModuleGUI *gui, gint i)
     else
         lineres = resolution;
 
-    gwy_field_get_profile(acf, gui->line, xl0, yl0, xl1, yl1, lineres, thickness, interpolation);
+    gwy_field_profile(acf, gui->line, xl0, yl0, xl1, yl1, lineres, thickness, interpolation);
 
     n = gwy_graph_model_get_n_curves(args->gmodel);
     if (i < n)
@@ -594,44 +598,59 @@ calculate_zoomed_fields(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
     guint zoom = gwy_params_get_enum(args->params, PARAM_ZOOM);
-    GwyField *zoomed;
 
-    zoomed = cut_field_to_zoom(args->acf, zoom);
+    GwyField *zoomed = cut_field_to_zoom(args->acf, zoom);
     gwy_field_data_changed(zoomed);
     gwy_data_view_set_field(GWY_DATA_VIEW(gui->dataview), zoomed);
     g_object_unref(zoomed);
 
-    zoomed = cut_field_to_zoom(args->acfmask, zoom);
-    gwy_field_data_changed(zoomed);
-    gwy_data_view_set_mask(GWY_DATA_VIEW(gui->dataview), zoomed);
-    g_object_unref(zoomed);
+    GwyNield* zoomedmask = cut_nield_to_zoom(args->acfmask, zoom);
+    gwy_nield_data_changed(zoomedmask);
+    gwy_data_view_set_mask(GWY_DATA_VIEW(gui->dataview), zoomedmask);
+    g_object_unref(zoomedmask);
 }
 
-static GwyField*
-cut_field_to_zoom(GwyField *field, gint zoom)
+static gboolean
+calc_cut_to_zoom(gint xres, gint yres, gint zoom, gint *pwidth, gint *pheight)
 {
-    GwyField *zoomed;
-    guint xres, yres, width, height;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    width = (xres/zoom) | 1;
-    height = (yres/zoom) | 1;
+    gint width = (xres/zoom) | 1;
+    gint height = (yres/zoom) | 1;
     if (width < 17)
         width = MAX(width, MIN(17, xres));
     if (height < 17)
         height = MAX(height, MIN(17, yres));
 
-    if (width >= xres && height >= yres)
+    *pwidth = width;
+    *pheight = height;
+    return width >= xres && height >= yres;
+}
+
+static GwyField*
+cut_field_to_zoom(GwyField *field, gint zoom)
+{
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    guint width, height;
+
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
         return g_object_ref(field);
 
-    zoomed = gwy_field_area_extract(field, (xres - width)/2, (yres - height)/2, width, height);
+    GwyField *zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
     gwy_field_set_xoffset(zoomed, -0.5*gwy_field_get_xreal(zoomed));
     gwy_field_set_yoffset(zoomed, -0.5*gwy_field_get_yreal(zoomed));
-
     return zoomed;
 }
 
+static GwyNield*
+cut_nield_to_zoom(GwyNield *nield, gint zoom)
+{
+    gint xres = gwy_nield_get_xres(nield), yres = gwy_nield_get_yres(nield);
+    guint width, height;
+
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
+        return g_object_ref(nield);
+    return gwy_nield_area_extract(nield, (xres - width)/2, (yres - height)/2, width, height);
+}
+
 /* Convert points to lines from the origin, which is assumed to be in the centre. */
 static void
 add_line_selection_from_points(GwyFile *data,
@@ -662,7 +681,7 @@ add_line_selection_from_points(GwyFile *data,
     gwy_selection_set_data(linesel, nsel, seldata);
     g_free(seldata);
 
-    gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "line"), linesel);
+    gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_selection(id, "line"), linesel);
 }
 
 static void
@@ -670,82 +689,68 @@ execute(ModuleArgs *args)
 {
     GwyParams *params = args->params;
     LevellingType level = gwy_params_get_enum(params, PARAM_LEVEL);
-    GwyField *mask = args->mask, *field = args->field, *acf = args->acf, *acfmask = args->acfmask, *field_for_acf;
+    GwyField *field = args->field, *acf = args->acf, *field_for_acf;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint xres = gwy_field_get_xres(field);
     gint yres = gwy_field_get_yres(field);
     gdouble a, bx, by;
 
-    /* Reuse acfmask for the field because we do not need it for gwy_field_area_2dacf().  Reuse acf for the
-     * modified mask because we discard it immediately. */
     if (level == LEVELLING_MEAN_VALUE) {
-        gwy_field_resize(acfmask, xres, yres);
-        gwy_field_assign(acfmask, field);
-        a = gwy_field_area_get_avg(acfmask, mask, masking, 0, 0, xres, yres);
-        gwy_field_add(acfmask, -a);
-        field_for_acf = acfmask;
+        field_for_acf = gwy_field_copy(field);
+        a = gwy_field_area_mean(field_for_acf, mask, masking, 0, 0, xres, yres);
+        gwy_field_add(field_for_acf, -a);
     }
     else if (level == LEVELLING_MEAN_PLANE) {
-        gwy_field_resize(acfmask, xres, yres);
-        gwy_field_assign(acfmask, field);
-        gwy_field_area_fit_plane(acfmask, mask, masking, 0, 0, xres, yres, &a, &bx, &by);
-        gwy_field_plane_level(acfmask, a, bx, by);
-        field_for_acf = acfmask;
+        field_for_acf = gwy_field_copy(field);
+        gwy_field_area_fit_plane(field_for_acf, mask, masking, 0, 0, xres, yres, &a, &bx, &by);
+        gwy_field_plane_level(field_for_acf, a, bx, by);
     }
     else
-        field_for_acf = field;
+        field_for_acf = g_object_ref(field);
 
     gwy_field_area_acf_2d(field_for_acf, mask, masking, acf, 0, 0, xres, yres, 0, 0, NULL);
     create_acf_mask(args);
+    g_object_unref(field_for_acf);
 }
 
 static void
 create_acf_mask(ModuleArgs *args)
 {
     GwyField *acf = args->acf;
-    GwyField *acfmask = args->acfmask;
+    GwyNield *acfmask = args->acfmask;
     gdouble threshold = gwy_params_get_double(args->params, PARAM_THRESHOLD);
-    gint xres = gwy_field_get_xres(acf);
-    gint yres = gwy_field_get_yres(acf);
-    gdouble sigma2;
-
-    sigma2 = gwy_field_get_val(acf, xres/2, yres/2);
-    gwy_field_resize(acfmask, xres, yres);
-    gwy_field_assign(acfmask, acf);
-    gwy_field_threshold(acfmask, threshold*sigma2, 0.0, 1.0);
-    gwy_field_grains_extract_grain(acfmask, xres/2, yres/2);
-    gwy_unit_clear(gwy_field_get_unit_z(acfmask));
+    gint xres = gwy_field_get_xres(acf), yres = gwy_field_get_yres(acf);
+    gdouble sigma2 = gwy_field_get_val(acf, xres/2, yres/2);
+    gwy_nield_resize(acfmask, xres, yres);
+    gwy_nield_mark_by_threshold(acfmask, acf, threshold*sigma2, TRUE);
+    gwy_nield_isolate_at(acfmask, xres/2, yres/2, NULL);
 }
 
 /* XXX: This is not very efficient and probably does not do anything useful when the grain is highly non-convex. But
  * what exactly should be done in such case is anyone's guess... */
 static gboolean
-find_decays(GwyField *mask,
+find_decays(GwyNield *mask, GwyField *acf,
             gdouble *r1, gdouble *r2, gdouble *phi1, gdouble *phi2)
 {
-    const gdouble *data = gwy_field_get_data_const(mask);
-    guint xres = gwy_field_get_xres(mask);
-    guint yres = gwy_field_get_yres(mask);
-    gdouble dx = gwy_field_get_dx(mask);
-    gdouble dy = gwy_field_get_dy(mask);
+    const gint *data = gwy_nield_get_data_const(mask);
+    guint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
+    gdouble dx = gwy_field_get_dx(acf), dy = gwy_field_get_dy(acf);
     gdouble phimin = 0.0, r2min = G_MAXDOUBLE;
     gdouble phimax = 0.0, r2max = 0.0;
-    gdouble xc, yc;
-    guint i, j, k;
 
-    xc = 0.5*dx*xres;
-    yc = 0.5*dy*yres;
-    for (i = 0; i <= yres; i++) {
-        k = i*xres;
-        for (j = 0; j <= xres; j++, k++) {
+    gdouble xc = 0.5*dx*xres, yc = 0.5*dy*yres;
+    for (guint i = 0; i <= yres; i++) {
+        guint k = i*xres;
+        for (guint j = 0; j <= xres; j++, k++) {
             /*
              * 1 2
              * 3 4
              */
-            guint g0 = i && j && data[k - xres - 1] > 0.0;
-            guint g1 = i && j < xres && data[k - xres] > 0.0;
-            guint g2 = i < yres && j && data[k - 1] > 0.0;
-            guint g3 = i < yres && j < xres && data[k] > 0.0;
+            guint g0 = i && j && data[k - xres - 1] > 0;
+            guint g1 = i && j < xres && data[k - xres] > 0;
+            guint g2 = i < yres && j && data[k - 1] > 0;
+            guint g3 = i < yres && j < xres && data[k] > 0;
             guint g = g0 | (g1 << 1) | (g2 << 2) | (g3 << 3);
 
             if (g != 0 && g != 15) {
