@@ -1,5 +1,5 @@
 /*
- *  $Id: arc-revolve.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: arc-revolve.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -132,7 +132,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.bg = gwy_field_new_alike(args.field, TRUE);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -141,7 +141,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
@@ -338,7 +338,7 @@ arcrev_horizontal(GwyField *field, GwyField *bg, gdouble radius)
     yres = gwy_field_get_yres(bg);
     rdata = gwy_field_get_data(bg);
 
-    q = gwy_field_get_rms(field)/sqrt(2.0/3.0 - G_PI/16.0);
+    q = gwy_field_rms(field)/sqrt(2.0/3.0 - G_PI/16.0);
     arc = make_arc(radius, gwy_field_get_xres(field));
 
     /* Scale-freeing.
@@ -354,8 +354,7 @@ arcrev_horizontal(GwyField *field, GwyField *bg, gdouble radius)
     tmp = sum + 3*xres;
 
     /* Weights for RMS filter.  The fool-proof way is to sum 1's. */
-    for (j = 0; j < xres; j++)
-        weight[j] = 1.0;
+    gwy_math_fill(weight, xres, 1.0);
     moving_sums(xres, weight, sum, size);
     gwy_assign(weight, sum, xres);
 
