@@ -1,6 +1,6 @@
 /*
- *  $Id: arithmetic.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti).
+ *  $Id: arithmetic.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -76,7 +76,7 @@ typedef struct {
     GwyParams *params;
     GtkListStore *history;
     GwyField *result;
-    GwyField *mask;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -84,7 +84,6 @@ typedef struct {
     guint err;
     gchar *name[ARITHMETIC_NARGS];
     guint pos[ARITHMETIC_NARGS];
-    GPtrArray *ok_masks;
     GwyAppDataId first;
 } EvaluationData;
 
@@ -129,8 +128,6 @@ static void             make_mask_if_needed (ModuleArgs *args);
 static void             need_data           (const EvaluationData *evdata,
                                              gboolean *nd);
 static void             update_history      (ModuleArgs *args);
-static void             fix_mask_field      (GwyField *mask,
-                                             EvaluationData *evdata);
 static GwyField*        make_x              (GwyField *dfield);
 static GwyField*        make_y              (GwyField *dfield);
 static GwyField*        make_x_der          (GwyField *dfield);
@@ -144,7 +141,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Simple arithmetic operations with data fields."),
     "Yeti <yeti@gwyddion.net>",
-    "4.1",
+    "4.2",
     "David Nečas (Yeti)",
     "2004",
 };
@@ -203,7 +200,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear1(args);
     gwy_data_browser_get_current(GWY_APP_FIELD_ID, &dataid.id,
-                                 GWY_APP_CONTAINER_ID, &dataid.datano,
+                                 GWY_APP_FILE_ID, &dataid.datano,
                                  0);
     g_return_if_fail(gwy_app_data_id_verify_channel(&dataid));
     args.params = gwy_params_new_from_settings(define_module_params());
@@ -212,7 +209,6 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, 1.0, 1.0, TRUE);
     sanitise_params(&args);
 
-    evdata.ok_masks = g_ptr_array_new();
     evdata.expr = gwy_expr_new();
     gwy_expr_define_constant(evdata.expr, "pi", G_PI, NULL);
     gwy_expr_define_constant(evdata.expr, "π", G_PI, NULL);
@@ -239,6 +235,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Calculated"), TRUE);
     if (args.mask) {
+        gwy_nield_number_contiguous(args.mask);
         gwy_file_set_image_mask(data, newid, args.mask);
         gwy_file_sync_items(gwy_data_browser_get_file(evdata.first.datano), GWY_FILE_IMAGE, evdata.first.id,
                             data, GWY_FILE_IMAGE, newid,
@@ -251,7 +248,6 @@ end:
     g_clear_object(&args.mask);
     g_object_unref(args.params);
     g_object_unref(args.history);
-    g_ptr_array_free(evdata.ok_masks, TRUE);
     gwy_expr_free(evdata.expr);
     for (i = 0; i < ARITHMETIC_NARGS; i++)
         g_free(evdata.name[i]);
@@ -580,7 +576,8 @@ static void
 execute(ModuleArgs *args, EvaluationData *evdata)
 {
     static MakeFieldFunc derivers[ARITHMETIC_NVARS] = { NULL, NULL, make_x_der, make_y_der, };
-    GwyField **fields, *dfield, *mfield, *empty_mask = NULL; /* A zero filled mask. */
+    GwyField **fields, *field, *empty = NULL;
+    GwyNield *mask;
     const gdouble **d;
     gboolean nd[NARGS];
     gdouble *r = NULL;
@@ -597,40 +594,48 @@ execute(ModuleArgs *args, EvaluationData *evdata)
 
     /* First get all the data fields we directly have */
     for (i = 0; i < NARGS; i++) {
-        gwy_debug("dfield[%u]: %s", i, nd[i] ? "NEEDED" : "not needed");
+        gwy_debug("field[%u]: %s", i, nd[i] ? "NEEDED" : "not needed");
         if (!nd[i])
             continue;
 
-        dfield = fields[i] = gwy_params_get_image(args->params, PARAM_IMAGE + i);
-        d[evdata->pos[i]] = gwy_field_get_data_const(dfield);
+        field = fields[i] = gwy_params_get_image(args->params, PARAM_IMAGE + i);
+        d[evdata->pos[i]] = gwy_field_get_data_const(field);
         gwy_debug("d[%u] set to PRIMARY %u", evdata->pos[i], i);
         if (first) {
             first = FALSE;
-            update_field(dfield, args->result, &n, &r);
+            update_field(field, args->result, &n, &r);
             evdata->first = gwy_params_get_data_id(args->params, PARAM_IMAGE + i);
         }
     }
 
     /* Then the mask fields */
     for (i = NARGS*ARITHMETIC_MASK; i < NARGS*(ARITHMETIC_MASK + 1); i++) {
-        gwy_debug("mfield[%u]: %s", i, nd[i % NARGS] ? "NEEDED" : "not needed");
+        GwyField *mask_field;
+
+        gwy_debug("mask[%u]: %s", i, nd[i % NARGS] ? "NEEDED" : "not needed");
         if (!nd[i % NARGS])
             continue;
 
-        dfield = gwy_params_get_image(args->params, PARAM_IMAGE + i % NARGS);
+        field = gwy_params_get_image(args->params, PARAM_IMAGE + i % NARGS);
         if (first) {
             first = FALSE;
-            update_field(dfield, args->result, &n, &r);
+            update_field(field, args->result, &n, &r);
             evdata->first = gwy_params_get_data_id(args->params, PARAM_IMAGE + i);
         }
-        if (!(mfield = gwy_params_get_image_mask(args->params, PARAM_IMAGE + i % NARGS))) {
-            if (!empty_mask)
-                empty_mask = gwy_field_new_alike(dfield, TRUE);
-            mfield = empty_mask;
+
+        /* Expr evaluation requires arrays of doubles. We have to create a Field from the Nield. */
+        if (!(mask = gwy_params_get_image_mask(args->params, PARAM_IMAGE + i % NARGS))) {
+            if (!empty)
+                empty = gwy_field_new_alike(field, TRUE);
+            mask_field = empty;
         }
-        else
-            fix_mask_field(mfield, evdata);
-        d[evdata->pos[i]] = gwy_field_get_data_const(mfield);
+        else {
+            mask_field = fields[i] = gwy_field_new_alike(field, TRUE);
+            gwy_field_area_fill(mask_field, mask, GWY_MASK_INCLUDE,
+                                0, 0, gwy_field_get_xres(field), gwy_field_get_yres(field), 1.0);
+        }
+
+        d[evdata->pos[i]] = gwy_field_get_data_const(mask_field);
     }
 
     /* Derive derived fields */
@@ -639,24 +644,24 @@ execute(ModuleArgs *args, EvaluationData *evdata)
             continue;
 
         g_return_if_fail(fields[i % NARGS]);
-        dfield = derivers[i/NARGS](fields[i % NARGS]);
+        field = derivers[i/NARGS](fields[i % NARGS]);
         gwy_debug("d[%u] set to DERIVED %u (type %u)", evdata->pos[i], i/NARGS, i%NARGS);
-        fields[i] = dfield;
-        d[evdata->pos[i]] = gwy_field_get_data_const(dfield);
+        fields[i] = field;
+        d[evdata->pos[i]] = gwy_field_get_data_const(field);
     }
 
     i = NARGS*ARITHMETIC_NVARS + COMMON_COORD_X;
     if (evdata->pos[i]) {
-        dfield = make_x(fields[0]);
-        fields[i] = dfield;
-        d[evdata->pos[i]] = gwy_field_get_data_const(dfield);
+        field = make_x(fields[0]);
+        fields[i] = field;
+        d[evdata->pos[i]] = gwy_field_get_data_const(field);
     }
 
     i = NARGS*ARITHMETIC_NVARS + COMMON_COORD_Y;
     if (evdata->pos[i]) {
-        dfield = make_y(fields[0]);
-        fields[i] = dfield;
-        d[evdata->pos[i]] = gwy_field_get_data_const(dfield);
+        field = make_y(fields[0]);
+        fields[i] = field;
+        d[evdata->pos[i]] = gwy_field_get_data_const(field);
     }
 
     /* Execute */
@@ -673,11 +678,9 @@ execute(ModuleArgs *args, EvaluationData *evdata)
         gwy_field_copy_units(gwy_params_get_image(args->params, PARAM_IMAGE + dataunits), args->result);
 
     /* Free stuff */
-    g_clear_object(&empty_mask);
-    for (i = NARGS; i < ARITHMETIC_NARGS; i++) {
-        if (fields[i])
-            g_object_unref(fields[i]);
-    }
+    g_clear_object(&empty);
+    for (i = NARGS; i < ARITHMETIC_NARGS; i++)
+        g_clear_object(fields + i);
     g_free(fields);
     g_free(d);
 
@@ -687,9 +690,10 @@ execute(ModuleArgs *args, EvaluationData *evdata)
 static void
 make_mask_if_needed(ModuleArgs *args)
 {
-    GwyField *result = args->result, *mask;
+    GwyField *result = args->result;
+    GwyNield *mask;
 
-    args->mask = mask = gwy_app_channel_mask_of_nans(result, FALSE);
+    args->mask = mask = gwy_mask_nans_in_field(result, FALSE);
     if (!mask)
         return;
 
@@ -700,7 +704,7 @@ make_mask_if_needed(ModuleArgs *args)
         gwy_field_area_fill(result, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, filler_value);
     }
     else
-        gwy_field_laplace_solve(result, mask, -1, 0.25);
+        gwy_field_laplace_solve(result, mask, GWY_LAPLACE_MASKED, 0.25);
 }
 
 /* Find which data we need, for derivatives or otherwise */
@@ -725,27 +729,6 @@ need_data(const EvaluationData *evdata, gboolean *nd)
     }
 }
 
-static void
-fix_mask_field(GwyField *mask, EvaluationData *evdata)
-{
-    gdouble min, max;
-    guint i;
-
-    /* Do not process masks we have already processed. */
-    for (i = 0; i < evdata->ok_masks->len; i++) {
-        if (g_ptr_array_index(evdata->ok_masks, i) == (gpointer)mask)
-            return;
-    }
-
-    /* Silently normalise the mask values if they are outside [0, 1]. We do not actually like any value different from
-     * 0 and 1, but let them pass. */
-    gwy_field_get_min_max(mask, &min, &max);
-    if (min < 0.0 || max > 1.0)
-        gwy_field_clamp(mask, 0.0, 1.0);
-
-    g_ptr_array_add(evdata->ok_masks, mask);
-}
-
 static GwyField*
 make_x(GwyField *dfield)
 {
