@@ -1,6 +1,6 @@
 /*
- *  $Id: basicops.c 28848 2025-11-10 18:54:08Z yeti-dn $
- *  Copyright (C) 2003-2018 David Necas (Yeti), Petr Klapetek.
+ *  $Id: basicops.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -21,6 +21,13 @@
 
 #define RUN_MODES GWY_RUN_IMMEDIATE
 
+typedef struct {
+    GwyField *fields[2];
+    GwyNield *nields[1];
+    GQuark quarks[3];
+    gint id;
+} FieldsAndQuarks;
+
 static gboolean module_register           (void);
 static void     flip_horizontally         (GwyFile *data,
                                            GwyRunModeFlags mode);
@@ -46,7 +53,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Basic operations like flipping, value inversion, and rotation by multiples of 90 degrees."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "3.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -124,258 +131,217 @@ module_register(void)
 }
 
 static inline guint
-compress_quarks(GwyField **fields, GQuark *quarks, guint nitems)
+get_fields_and_quarks(FieldsAndQuarks *faq, gboolean masks_too)
 {
-    guint i, n;
+    gwy_clear(faq, 1);
+    gwy_data_browser_get_current(GWY_APP_FIELD, faq->fields + 0,
+                                 GWY_APP_SHOW_FIELD, faq->fields + 1,
+                                 GWY_APP_FIELD_KEY, faq->quarks + 0,
+                                 GWY_APP_SHOW_FIELD_KEY, faq->quarks + 1,
+                                 GWY_APP_FIELD_ID, &faq->id,
+                                 0);
+    gint have_show = !!faq->fields[1];
+    if (!masks_too)
+        return 1 + have_show;
 
-    for (i = n = 0; i < nitems; i++) {
-        if (fields[i]) {
-            fields[n] = fields[i];
-            quarks[n] = quarks[i];
-            n++;
-        }
-    }
-
-    return n;
+    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, faq->nields + 0,
+                                 GWY_APP_MASK_FIELD_KEY, faq->quarks + 1 + have_show,
+                                 0);
+    gint have_mask = !!faq->nields[0];
+    return 1 + have_show + have_mask;
 }
 
-static inline guint
-get_fields_and_quarks(GwyField **fields, GQuark *quarks, gint *id)
+static void
+flip(GwyFile *data, gboolean horizontally, gboolean vertically)
 {
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
-                                 GWY_APP_FIELD_KEY, quarks + 0,
-                                 GWY_APP_MASK_FIELD_KEY, quarks + 1,
-                                 GWY_APP_SHOW_FIELD_KEY, quarks + 2,
-                                 GWY_APP_FIELD_ID, id,
-                                 0);
-    return compress_quarks(fields, quarks, 3);
+    FieldsAndQuarks faq;
+    guint n = get_fields_and_quarks(&faq, TRUE);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), n, faq.quarks);
+    gwy_field_flip(faq.fields[0], horizontally, vertically);
+    gwy_field_data_changed(faq.fields[0]);
+    if (faq.fields[1]) {
+        gwy_field_flip(faq.fields[1], horizontally, vertically);
+        gwy_field_data_changed(faq.fields[1]);
+    }
+    if (faq.nields[0]) {
+        gwy_nield_flip(faq.nields[0], horizontally, vertically);
+        gwy_nield_data_changed(faq.nields[0]);
+    }
+    gwy_file_remove_selections(data, GWY_FILE_IMAGE, faq.id);
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, faq.id);
 }
 
 static void
 flip_horizontally(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfields[3];
-    GQuark quarks[3];
-    gint id, n, i;
-
     g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        gwy_field_flip(dfields[i], TRUE, FALSE);
-        gwy_field_data_changed(dfields[i]);
-    }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
+    flip(data, TRUE, FALSE);
 }
 
 static void
 flip_vertically(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfields[3];
-    GQuark quarks[3];
-    gint id, n, i;
-
     g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        gwy_field_flip(dfields[i], FALSE, TRUE);
-        gwy_field_data_changed(dfields[i]);
-    }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
-}
-
-static void
-flip_diagonally(GwyFile *data, GwyRunModeFlags mode)
-{
-    GwyField *dfields[3], *newfield;
-    GQuark quarks[3];
-    gint id, n, i;
-
-    g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        newfield = gwy_field_new_alike(dfields[i], FALSE);
-        gwy_field_transpose(dfields[i], newfield, FALSE);
-        gwy_container_pass_object(GWY_CONTAINER(data), quarks[i], newfield);
-    }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
-}
-
-static void
-invert_value(GwyFile *data, GwyRunModeFlags mode)
-{
-    GwyField *dfields[2];
-    GQuark quarks[2];
-    gint id, n, i;
-
-    g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, dfields + 0,
-                                 GWY_APP_SHOW_FIELD, dfields + 1,
-                                 GWY_APP_FIELD_KEY, quarks + 0,
-                                 GWY_APP_SHOW_FIELD_KEY, quarks + 1,
-                                 GWY_APP_FIELD_ID, &id,
-                                 0);
-    n = compress_quarks(dfields, quarks, G_N_ELEMENTS(dfields));
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        if (dfields[i]) {
-            gwy_field_invert_value(dfields[i]);
-            gwy_field_data_changed(dfields[i]);
-        }
-    }
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
-}
-
-static void
-rotate_clockwise_90(GwyFile *data, GwyRunModeFlags mode)
-{
-    GwyField *dfields[3], *newfield;
-    GQuark quarks[3];
-    gint id, n, i;
-
-    g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        newfield = gwy_field_new_rotated_90(dfields[i], TRUE);
-        gwy_container_pass_object(GWY_CONTAINER(data), quarks[i], newfield);
-    }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
-}
-
-static void
-rotate_counterclockwise_90(GwyFile *data, GwyRunModeFlags mode)
-{
-    GwyField *dfields[3], *newfield;
-    GQuark quarks[3];
-    gint id, n, i;
-
-    g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        newfield = gwy_field_new_rotated_90(dfields[i], FALSE);
-        gwy_container_pass_object(GWY_CONTAINER(data), quarks[i], newfield);
-    }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
+    flip(data, FALSE, TRUE);
 }
 
 static void
 rotate_180(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfields[3];
-    GQuark quarks[3];
-    gint id, n, i;
-
     g_return_if_fail(mode & RUN_MODES);
-    n = get_fields_and_quarks(dfields, quarks, &id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        gwy_field_flip(dfields[i], TRUE, TRUE);
-        gwy_field_data_changed(dfields[i]);
+    flip(data, TRUE, TRUE);
+}
+
+static void
+flip_diagonally(GwyFile *data, GwyRunModeFlags mode)
+{
+    g_return_if_fail(mode & RUN_MODES);
+
+    FieldsAndQuarks faq;
+    guint n = get_fields_and_quarks(&faq, TRUE);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), n, faq.quarks);
+    GwyField *newfield = gwy_field_new_alike(faq.fields[0], FALSE);
+    gwy_field_transpose(faq.fields[0], newfield, FALSE);
+    gwy_file_pass_image(data, faq.id, newfield);
+    if (faq.fields[1]) {
+        newfield = gwy_field_new_alike(faq.fields[1], FALSE);
+        gwy_field_transpose(faq.fields[1], newfield, FALSE);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(faq.id), newfield);
     }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
+    if (faq.nields[0]) {
+        GwyNield *newmask = gwy_nield_new_alike(faq.nields[0]);
+        gwy_nield_transpose(faq.nields[0], newmask, FALSE);
+        gwy_file_pass_image_mask(data, faq.id, newmask);
+    }
+    gwy_file_remove_selections(data, GWY_FILE_IMAGE, faq.id);
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, faq.id);
+}
+
+static void
+invert_value(GwyFile *data, GwyRunModeFlags mode)
+{
+    g_return_if_fail(mode & RUN_MODES);
+
+    FieldsAndQuarks faq;
+    guint n = get_fields_and_quarks(&faq, FALSE);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), n, faq.quarks);
+    for (guint i = 0; i < 2; i++) {
+        if (faq.fields[i]) {
+            gwy_field_invert_value(faq.fields[i]);
+            gwy_field_data_changed(faq.fields[i]);
+        }
+    }
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, faq.id);
+}
+
+static void
+rotate_90(GwyFile *data, gboolean cw)
+{
+    FieldsAndQuarks faq;
+    guint n = get_fields_and_quarks(&faq, TRUE);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), n, faq.quarks);
+    GwyField *newfield = gwy_field_new_rotated_90(faq.fields[0], cw);
+    gwy_file_pass_image(data, faq.id, newfield);
+    if (faq.fields[1]) {
+        newfield = gwy_field_new_rotated_90(faq.fields[1], cw);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(faq.id), newfield);
+    }
+    if (faq.nields[0]) {
+        GwyNield *newmask = gwy_nield_new_rotated_90(faq.nields[0], cw);
+        gwy_file_pass_image_mask(data, faq.id, newmask);
+    }
+    gwy_file_remove_selections(data, GWY_FILE_IMAGE, faq.id);
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, faq.id);
+}
+
+static void
+rotate_clockwise_90(GwyFile *data, GwyRunModeFlags mode)
+{
+    g_return_if_fail(mode & RUN_MODES);
+    rotate_90(data, TRUE);
+}
+
+static void
+rotate_counterclockwise_90(GwyFile *data, GwyRunModeFlags mode)
+{
+    g_return_if_fail(mode & RUN_MODES);
+    rotate_90(data, FALSE);
 }
 
 static void
 square_samples(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfield, *dfields[3];
-    gdouble xreal, yreal, qx, qy;
-    gint oldid, newid, xres, yres;
-
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, dfields + 0,
-                                 GWY_APP_MASK_FIELD, dfields + 1,
-                                 GWY_APP_SHOW_FIELD, dfields + 2,
-                                 GWY_APP_FIELD_ID, &oldid,
-                                 0);
-    dfield = dfields[0];
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    xreal = gwy_field_get_xreal(dfield);
-    yreal = gwy_field_get_yreal(dfield);
-    qx = xres/xreal;
-    qy = yres/yreal;
-    if (fabs(log(qx/qy)) > 1.0/hypot(xres, yres)) {
-        /* Resample */
-        if (qx < qy)
-            xres = MAX(GWY_ROUND(xreal*qy), 1);
-        else
-            yres = MAX(GWY_ROUND(yreal*qx), 1);
 
-        dfields[0] = gwy_field_new_resampled(dfields[0], xres, yres, GWY_INTERPOLATION_BSPLINE);
-        if (dfields[1])
-            dfields[1] = gwy_field_new_resampled(dfields[1], xres, yres, GWY_INTERPOLATION_ROUND);
-        if (dfields[2])
-            dfields[2] = gwy_field_new_resampled(dfields[2], xres, yres, GWY_INTERPOLATION_BSPLINE);
+    FieldsAndQuarks faq;
+    get_fields_and_quarks(&faq, TRUE);
+    GwyField *field = faq.fields[0];
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble xreal = gwy_field_get_xreal(field), yreal = gwy_field_get_yreal(field);
+    gdouble dx = gwy_field_get_dx(field), dy = gwy_field_get_dy(field);
+    if (fabs(log(dx/dy)) > 1.0/hypot(xres, yres)) {
+        /* Resample */
+        if (dx < dy)
+            xres = MAX(GWY_ROUND(xreal*dy), 1);
+        else
+            yres = MAX(GWY_ROUND(yreal*dx), 1);
+
+        faq.fields[0] = gwy_field_new_resampled(faq.fields[0], xres, yres, GWY_INTERPOLATION_BSPLINE);
+        if (faq.fields[1])
+            faq.fields[1] = gwy_field_new_resampled(faq.fields[1], xres, yres, GWY_INTERPOLATION_BSPLINE);
+        if (faq.nields[0])
+            faq.nields[0] = gwy_nield_new_resampled(faq.nields[0], xres, yres);
     }
     else {
         /* Ratios are equal, just duplicate */
-        dfields[0] = gwy_field_copy(dfields[0]);
-        if (dfields[1])
-            dfields[1] = gwy_field_copy(dfields[1]);
-        if (dfields[2])
-            dfields[2] = gwy_field_copy(dfields[2]);
+        faq.fields[0] = gwy_field_copy(faq.fields[0]);
+        if (faq.fields[1])
+            faq.fields[1] = gwy_field_copy(faq.fields[1]);
+        if (faq.nields[0])
+            faq.nields[0] = gwy_nield_copy(faq.nields[0]);
     }
 
-    newid = gwy_file_add_image(data, dfields[0]);
-
+    gint newid = gwy_file_add_image(data, faq.fields[0]);
+    g_object_unref(faq.fields[0]);
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
-    g_object_unref(dfields[0]);
-    gwy_file_sync_items(data, GWY_FILE_IMAGE, oldid,
+    gwy_file_sync_items(data, GWY_FILE_IMAGE, faq.id,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
 
-    if (dfields[1])
-        gwy_file_pass_image_mask(data, newid, dfields[1]);
-    if (dfields[2])
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), dfields[2]);
+    if (faq.fields[1])
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), faq.fields[1]);
+    if (faq.nields[0])
+        gwy_file_pass_image_mask(data, newid, faq.nields[0]);
 
-    gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, newid);
 }
 
 static void
 null_offsets(GwyFile *data,
              GwyRunModeFlags mode)
 {
-    GwyField *dfields[3];
-    GQuark quarks[3];
-    gint id, n, i;
-
     g_return_if_fail(mode & RUN_MODES);
-    get_fields_and_quarks(dfields, quarks, &id);
-    for (i = 0; i < G_N_ELEMENTS(dfields); i++) {
-        if (dfields[i]
-            && !gwy_field_get_xoffset(dfields[i])
-            && !gwy_field_get_yoffset(dfields[i])) {
-            quarks[i] = 0;
-            dfields[i] = NULL;
+
+    FieldsAndQuarks faq;
+    get_fields_and_quarks(&faq, FALSE);
+    guint nn = 0;
+    for (guint i = 0; i < 2; i++) {
+        if (faq.fields[i] && (gwy_field_get_xoffset(faq.fields[i]) || gwy_field_get_yoffset(faq.fields[i]))) {
+            faq.quarks[nn++] = faq.quarks[i];
+            faq.fields[nn++] = faq.fields[i];
         }
     }
-
-    n = compress_quarks(dfields, quarks, G_N_ELEMENTS(dfields));
-    if (!n)
+    if (!nn)
         return;
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
-    for (i = 0; i < n; i++) {
-        gwy_field_set_xoffset(dfields[i], 0.0);
-        gwy_field_set_yoffset(dfields[i], 0.0);
-        gwy_field_data_changed(dfields[i]);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), nn, faq.quarks);
+    for (guint i = 0; i < nn; i++) {
+        gwy_field_set_xoffset(faq.fields[i], 0.0);
+        gwy_field_set_yoffset(faq.fields[i], 0.0);
+        gwy_field_data_changed(faq.fields[i]);
     }
-    gwy_file_remove_selections(data, GWY_FILE_IMAGE, id);
-    gwy_log_add(data, GWY_FILE_IMAGE, id, id);
+    gwy_file_remove_selections(data, GWY_FILE_IMAGE, faq.id);
+    gwy_log_add(data, GWY_FILE_IMAGE, faq.id, faq.id);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
