@@ -1,6 +1,6 @@
 /*
- *  $Id: binning.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2017-2021 David Necas (Yeti).
+ *  $Id: binning.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2017-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -71,7 +71,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates a smaller image using binning."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.2",
     "David Nečas (Yeti)",
     "2017",
 };
@@ -117,63 +117,70 @@ define_module_params(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *fields[3];
-    GwyParams *params;
-    ModuleArgs args;
-    gint id, newid, binw, binh, trim_lowest, trim_highest, xoff, yoff;
-
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+
+    ModuleArgs args;
+    gwy_clear1(args);
+
+    GwyField *field, *show;
+    GwyNield *mask;
+    gint id;
+    gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_SHOW_FIELD, &show,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(fields[0]);
-    args.field = fields[0];
+    g_return_if_fail(args.field);
     args.xres = gwy_field_get_xres(args.field);
     args.yres = gwy_field_get_yres(args.field);
     args.max_binw = (args.xres-1)/2 + 1;
     args.max_binh = (args.yres-1)/2 + 1;
 
+    GwyParams *params;
     args.params = params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome != GWY_DIALOG_PROCEED)
             goto end;
     }
 
-    binw = gwy_params_get_int(params, PARAM_BINW);
-    binh = gwy_params_get_int(params, PARAM_BINH);
-    trim_lowest = gwy_params_get_int(params, PARAM_TRIM_LOWEST);
-    trim_highest = gwy_params_get_int(params, PARAM_TRIM_HIGHEST);
-    xoff = gwy_params_get_int(params, PARAM_XOFF);
-    yoff = gwy_params_get_int(params, PARAM_YOFF);
+    gint binw = gwy_params_get_int(params, PARAM_BINW);
+    gint binh = gwy_params_get_int(params, PARAM_BINH);
+    gint trim_lowest = gwy_params_get_int(params, PARAM_TRIM_LOWEST);
+    gint trim_highest = gwy_params_get_int(params, PARAM_TRIM_HIGHEST);
+    gint xoff = gwy_params_get_int(params, PARAM_XOFF);
+    gint yoff = gwy_params_get_int(params, PARAM_YOFF);
 
-    fields[0] = gwy_field_new_binned(fields[0], binw, binh, xoff, yoff, trim_lowest, trim_highest);
+    field = gwy_field_new_binned(args.field, binw, binh, xoff, yoff, trim_lowest, trim_highest);
     /* Only apply is_sum to data.  We do not want to sum mask, and it is pointless to do it with presentation. */
     if (gwy_params_get_boolean(params, PARAM_IS_SUM))
-        gwy_field_multiply(fields[0], binw*binh);
-    if (fields[1]) {
-        fields[1] = gwy_field_new_binned(fields[1], binw, binh, xoff, yoff, trim_lowest, trim_highest);
-        gwy_field_threshold(fields[1], 0.5, 0.0, 1.0);
+        gwy_field_multiply(field, binw*binh);
+    if (show)
+        show = gwy_field_new_binned(show, binw, binh, xoff, yoff, trim_lowest, trim_highest);
+    if (mask) {
+        GwyField *mask_field = gwy_field_new(args.xres, args.yres, args.xres, args.yres, FALSE);
+        gwy_field_fill_mask(mask_field, mask, 0.0, 1.0);
+        GwyField *new_mask_field = gwy_field_new_binned(mask_field, binw, binh, xoff, yoff, 0, 0);
+        g_object_unref(mask_field);
+        mask = gwy_field_new_nield_alike(new_mask_field);
+        gwy_nield_mark_by_threshold(mask, new_mask_field, 0.5, TRUE);
+        g_object_unref(new_mask_field);
     }
-    if (fields[2])
-        fields[2] = gwy_field_new_binned(fields[2], binw, binh, xoff, yoff, trim_lowest, trim_highest);
 
-    newid = gwy_file_add_image(data, fields[0]);
-    g_object_unref(fields[0]);
+    gint newid = gwy_file_add_image(data, field);
+    g_object_unref(field);
 
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-    if (fields[1])
-        gwy_file_pass_image_mask(data, newid, fields[1]);
-    if (fields[2])
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), fields[2]);
+    if (mask)
+        gwy_file_pass_image_mask(data, newid, mask);
+    if (show)
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
 
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Binned Data"), TRUE);
     gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
