@@ -1,6 +1,6 @@
 /*
- *  $Id: blockstep.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2003-2023 David Necas (Yeti), Petr Klapetek, Luke Somers.
+ *  $Id: blockstep.c 29543 2026-02-24 14:07:07Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek, Luke Somers.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, lsomers@sas.upenn.edu.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -62,7 +62,7 @@ typedef struct {
     GwyParams *params;
     GwyField *field;
     GwyField *result;
-    GwyField *mask;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -89,7 +89,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Corrects vertical steps in scan lines by block."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2023",
 };
@@ -155,8 +155,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(args.field && dquark);
 
     args.result = gwy_field_copy(args.field);
-    args.mask = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.mask));
+    args.mask = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     if (mode == GWY_RUN_INTERACTIVE) {
@@ -168,7 +167,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
     gwy_field_assign(args.field, args.result);
     gwy_field_data_changed(args.field);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
@@ -254,7 +253,7 @@ preview(gpointer user_data)
 
     n = execute(args);
     gwy_field_data_changed(args->result);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 
     s = g_strdup_printf("%u", n);
@@ -263,28 +262,31 @@ preview(gpointer user_data)
 }
 
 static LineSplit*
-mark_discontinuities(GwyField *field, GwyField *mask,
+mark_discontinuities(GwyField *field, GwyNield *mask,
                      gdouble threshold, ScanDirection scandir)
 {
     const gdouble *d = gwy_field_get_data_const(field);
-    gint i, xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
-    gint *imask;
-    LineSplit *ls;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gboolean set_mask = !!mask;
 
-    ls = g_new0(LineSplit, yres);
-    imask = g_new(gint, xres*yres);
-    gwy_clear(imask, xres);
+    LineSplit *ls = g_new0(LineSplit, yres);
+
+    if (mask)
+        gwy_nield_clear(mask);
+    else
+        mask = gwy_field_new_nield_alike(field);
+
+    gint *mdata = gwy_nield_get_data(mask);
 
     /* Mark locations of large jumps in the y direction. More precisely, mark the second row (after the jump). */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i) \
-            shared(d,imask,ls,xres,yres,threshold)
+            shared(d,mdata,ls,xres,yres,threshold)
 #endif
-    for (i = 1; i < yres; i++) {
+    for (gint i = 1; i < yres; i++) {
         const gdouble *row = d + i*xres;
         const gdouble *prev = row - xres;
-        gint *mrow = imask + i*xres;
+        gint *mrow = mdata + i*xres;
         gint j, c = 0;
 
         for (j = 0; j < xres; j++)
@@ -292,7 +294,7 @@ mark_discontinuities(GwyField *field, GwyField *mask,
         ls[i].totalsteps = c;
     }
 
-    for (i = 1; i < yres; i++) {
+    for (gint i = 1; i < yres; i++) {
         if (ls[i].totalsteps > xres/10) {
             gwy_debug("[%d] %d steps", i, ls[i].totalsteps);
         }
@@ -311,21 +313,20 @@ mark_discontinuities(GwyField *field, GwyField *mask,
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i) \
-            shared(imask,ls,xres,yres,scandir)
+            shared(mdata,ls,xres,yres,scandir)
 #endif
-    for (i = 1; i < yres; i++) {
-        gint *row = imask + i*xres;
+    for (gint i = 1; i < yres; i++) {
+        gint *row = mdata + i*xres;
         gint *prev = row - xres;
-        gint j, best = 0, bestpos = xres/2, nleft, nright, seenup = 0, seendown = 0, ntotal;
+        gint best = 0, bestpos = xres/2, nleft, nright, seenup = 0, seendown = 0;
 
         /* Try to find the best split to the upper (right) part and lower (left) segments.
          * For i == 1 the upper row is always empty, so the best will always be the entire lower row (pos = xres).
          *
          * If there are complete rows, we will find them twice, with pos = xres at index i and with pos = 0 at index
          * i+1. */
-        ntotal = ls[scandir == SCANDIR_LTR ? i-1 : i].totalsteps;
-        j = 0;
+        gint ntotal = ls[scandir == SCANDIR_LTR ? i-1 : i].totalsteps;
+        gint j = 0;
         while (TRUE) {
             if (scandir == SCANDIR_LTR) {
                 nleft = seendown;
@@ -352,21 +353,18 @@ mark_discontinuities(GwyField *field, GwyField *mask,
         ls[i].score = best;
     }
 
-    if (mask) {
-        gdouble *m = gwy_field_get_data(mask);
-
-        for (i = 0; i < xres*yres - xres; i++)
-            m[i] = fmax(imask[i], imask[i + xres]);
-        for (i = xres*yres - xres; i < xres*yres; i++)
-            m[i] = imask[i];
+    if (set_mask) {
+        for (gint k = 0; k < xres*yres - xres; k++)
+            mdata[k] = MAX(mdata[k], mdata[k + xres]);
     }
-    g_free(imask);
+    else
+        g_object_unref(mask);
 
     return ls;
 }
 
 static inline void
-process_one_step_segment(const gdouble *row, gdouble *mrow, gdouble *shifts,
+process_one_step_segment(const gdouble *row, gint *mrow, gdouble *shifts,
                          gint xres, gint from, gint len)
 {
     gint j;
@@ -378,18 +376,18 @@ process_one_step_segment(const gdouble *row, gdouble *mrow, gdouble *shifts,
     if (mrow) {
         mrow += from;
         for (j = 0; j < len; j++)
-            mrow[j + xres] = mrow[j] = 1.0;
+            mrow[j + xres] = mrow[j] = 1;
     }
 }
 
 static GArray*
-construct_blocks(GwyField *field, GwyField *mask,
+construct_blocks(GwyField *field, GwyNield *mask,
                  const LineSplit *ls, ScanDirection scandir)
 {
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     gint i, minlength = (gint)(3*xres/4);
     const gdouble *d = gwy_field_get_data_const(field);
-    gdouble *m = (mask ? gwy_field_get_data(mask) : NULL);
+    gint *m = (mask ? gwy_nield_get_data(mask) : NULL);
     GArray *blocksteps;
     gdouble *shifts;
     guint k;
@@ -440,12 +438,12 @@ construct_blocks(GwyField *field, GwyField *mask,
 
     shifts = g_new(gdouble, xres);
     if (mask)
-        gwy_field_clear(mask);
+        gwy_nield_clear(mask);
 
     for (k = 0; k < blocksteps->len; k++) {
         BlockStep *bs = &g_array_index(blocksteps, BlockStep, k);
         const gdouble *row = d + (bs->i - 1)*xres;
-        gdouble *mrow = m ? m + (bs->i - 1)*xres : NULL;
+        gint *mrow = m ? m + (bs->i - 1)*xres : NULL;
         gint fromleft = bs->fromleft;
 
         if (scandir == SCANDIR_LTR)
@@ -525,7 +523,8 @@ apply_correction(GwyField *field, const BlockStep *bs, ScanDirection scandir)
 static gint
 execute(ModuleArgs *args)
 {
-    GwyField *field = args->field, *result = args->result, *mask = args->mask;
+    GwyField *field = args->field, *result = args->result;
+    GwyNield *mask = args->mask;
     gdouble threshold = gwy_params_get_double(args->params, PARAM_THRESHOLD);
     ScanDirection scandir = gwy_params_get_enum(args->params, PARAM_SCANDIR);
     PreviewType display = gwy_params_get_enum(args->params, PARAM_DISPLAY);
@@ -537,8 +536,8 @@ execute(ModuleArgs *args)
 
     /* Get root square mean vertical difference (pixelwise, tan β₀ is in real units). */
     rmsline = gwy_line_new(1, 1, FALSE);
-    gwy_field_get_line_stats(field, rmsline, GWY_LINE_STAT_TAN_BETA0, GWY_ORIENTATION_VERTICAL);
-    rms = gwy_line_avg(rmsline) * gwy_field_get_dy(field);
+    gwy_field_line_stats(field, rmsline, GWY_LINE_STAT_TAN_BETA0, GWY_ORIENTATION_VERTICAL);
+    rms = gwy_line_mean(rmsline) * gwy_field_get_dy(field);
     g_object_unref(rmsline);
     threshold *= rms;
 
