@@ -1,6 +1,6 @@
 /*
- *  $Id: calibrate.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
+ *  $Id: calibrate.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -138,7 +138,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Recalibrates scan lateral dimensions or value range."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "4.2",
+    "4.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -309,42 +309,43 @@ calibrate_one_image(GwyField *field, GwyParams *params, gboolean calibrate_z)
 static void
 module_main_image(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *fields[3];
-    GQuark quarks[3];
-    gint n, i, oldid, newid;
+    GwyField *field, *show;
+    GwyNield *mask;
+    GQuark quarks[2];
+    gint oldid, newid;
     ModuleArgs args;
     GwyDialogOutcome outcome;
     GwyParams *params;
     gboolean new_channel;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+    gwy_clear1(args);
+
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_SHOW_FIELD, &show,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_KEY, quarks + 0,
-                                 GWY_APP_MASK_FIELD_KEY, quarks + 1,
-                                 GWY_APP_SHOW_FIELD_KEY, quarks + 2,
+                                 GWY_APP_SHOW_FIELD_KEY, quarks + 1,
                                  GWY_APP_FIELD_ID, &oldid,
                                  0);
-    g_return_if_fail(fields[0]);
+    g_return_if_fail(field);
 
-    gwy_clear1(args);
-    args.field = fields[0];
-    args.xres = gwy_field_get_xres(args.field);
-    args.yres = gwy_field_get_yres(args.field);
-    args.xreal = gwy_field_get_xreal(args.field);
-    args.yreal = gwy_field_get_yreal(args.field);
-    args.xoffset = gwy_field_get_xoffset(args.field);
-    args.yoffset = gwy_field_get_yoffset(args.field);
-    gwy_field_get_min_max(args.field, &args.zmin, &args.zmax);
-    args.xyunit = gwy_field_get_unit_xy(args.field);
-    args.zunit = gwy_field_get_unit_z(args.field);
+    args.field = field;
+    args.xres = gwy_field_get_xres(field);
+    args.yres = gwy_field_get_yres(field);
+    args.xreal = gwy_field_get_xreal(field);
+    args.yreal = gwy_field_get_yreal(field);
+    args.xoffset = gwy_field_get_xoffset(field);
+    args.yoffset = gwy_field_get_yoffset(field);
+    gwy_field_min_max(field, &args.zmin, &args.zmax);
+    args.xyunit = gwy_field_get_unit_xy(field);
+    args.zunit = gwy_field_get_unit_z(field);
     args.is_square = (fabs(log(args.yreal/args.yres * args.xres/args.xreal)) <= EPSILON);
     args.params = params = gwy_params_new_from_settings(define_image_params());
     init_xyparams_for_mode(&args);
     init_zparams_for_mode(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -353,43 +354,40 @@ module_main_image(GwyFile *data, GwyRunModeFlags mode)
 
     new_channel = gwy_params_get_boolean(params, PARAM_NEW_DATA);
     if (new_channel) {
-        for (i = 0; i < 3; i++) {
-            if (fields[i])
-                fields[i] = gwy_field_copy(fields[i]);
-        }
+        field = gwy_field_copy(field);
+        if (show)
+            show = gwy_field_copy(show);
+        if (mask)
+            mask = gwy_nield_copy(mask);
     }
     else {
-        for (i = n = 0; i < 3; i++) {
-            if (fields[i])
-                quarks[n++] = quarks[i];
-        }
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1 + !!show, quarks);
     }
 
-    for (i = 0; i < 3; i++) {
-        if (fields[i])
-            calibrate_one_image(fields[i], params, i == 0);
-    }
+    calibrate_one_image(field, params, TRUE);
+    if (show)
+        calibrate_one_image(show, params, FALSE);
+    /* There is nothing to calibrate in the mask. It is only needed when we create a new channel. */
 
     if (new_channel) {
-        newid = gwy_file_add_image(data, fields[0]);
-        g_object_unref(fields[0]);
+        newid = gwy_file_add_image(data, field);
+        g_object_unref(field);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_sync_items(data, GWY_FILE_IMAGE, oldid,
                             data, GWY_FILE_IMAGE, newid,
                             GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-        if (fields[1])
-            gwy_file_pass_image_mask(data, newid, fields[1]);
-        if (fields[2])
-            gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), fields[2]);
+        if (show)
+            gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
+        if (mask)
+            gwy_file_pass_image_mask(data, newid, mask);
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Recalibrated Data"), TRUE);
         gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
     }
     else {
-        for (i = 0; i < 3; i++) {
-            if (fields[i])
-                gwy_field_data_changed(fields[i]);
-        }
+        gwy_field_data_changed(field);
+        if (show)
+            gwy_field_data_changed(show);
+
         if (gwy_params_get_enum(params, PARAM_DIMS_MODE) != MODE_KEEP
             || gwy_params_get_enum(params, PARAM_OFFSETS_MODE) != MODE_KEEP)
             gwy_file_remove_selections(data, GWY_FILE_IMAGE, oldid);
@@ -447,18 +445,18 @@ module_main_xyz(GwyFile *data, GwyRunModeFlags mode)
 
     gwy_clear1(args);
     args.surface = surface;
-    gwy_surface_get_xrange(surface, &args.xoffset, &args.xreal);
+    gwy_surface_xrange(surface, &args.xoffset, &args.xreal);
     args.xreal -= args.xoffset;
-    gwy_surface_get_yrange(surface, &args.yoffset, &args.yreal);
+    gwy_surface_yrange(surface, &args.yoffset, &args.yreal);
     args.yreal -= args.yoffset;
-    gwy_surface_get_min_max(surface, &args.zmin, &args.zmax);
+    gwy_surface_min_max(surface, &args.zmin, &args.zmax);
     args.xyunit = gwy_surface_get_unit_xy(surface);
     args.zunit = gwy_surface_get_unit_z(surface);
     args.params = params = gwy_params_new_from_settings(define_xyz_params());
     init_xyparams_for_mode(&args);
     init_zparams_for_mode(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -469,7 +467,7 @@ module_main_xyz(GwyFile *data, GwyRunModeFlags mode)
     if (new_channel)
         surface = gwy_surface_copy(surface);
     else
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     calibrate_one_xyz(surface, &args);
 
@@ -539,7 +537,7 @@ module_main_cmap(GwyFile *data, GwyRunModeFlags mode)
     args.params = params = gwy_params_new_from_settings(define_cmap_params());
     init_xyparams_for_mode(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -550,11 +548,11 @@ module_main_cmap(GwyFile *data, GwyRunModeFlags mode)
     if (new_channel)
         lawn = gwy_lawn_copy(lawn);
     else
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     calibrate_one_cmap(lawn, params);
 
-    preview = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_cmap_picture(oldid));
+    preview = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_cmap_picture(oldid));
     if (new_channel) {
         preview = gwy_field_copy(preview);
         /* This relies on lateral parameter ids being the same for all data types! */
