@@ -1,6 +1,6 @@
 /*
- *  $Id: classify.c 29078 2026-01-05 16:55:04Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti).
+ *  $Id: classify.c 29478 2026-02-14 13:56:53Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -66,8 +66,8 @@ typedef struct {
     ClassifyQuantityType quantity[2*NCRITS];
     ClassifyScaleType scale[2*NCRITS];
     ClassifyDisplayType display;
-    GwyField *result_a;
-    GwyField *result_b;
+    GwyNield *result_a;
+    GwyNield *result_b;
 } ModuleArgs;
 
 typedef struct {
@@ -101,9 +101,9 @@ typedef struct {
 static gboolean         module_register             (void);
 static void             module_main                 (GwyFile *data,
                                                      GwyRunModeFlags mode);
-static void             load_args                   (GwyContainer *settings,
+static void             load_args                   (GwyDict *settings,
                                                      ModuleArgs *args);
-static void             save_args                   (GwyContainer *settings,
+static void             save_args                   (GwyDict *settings,
                                                      ModuleArgs *args);
 static GwyDialogOutcome run_gui                     (GwyFile *data,
                                                      gint id,
@@ -129,18 +129,18 @@ static void             run_classification          (ModuleGUI *gui);
 static void             classifier_train_full       (Classifier *cl,
                                                      GwyField **cldata,
                                                      gint ndata,
-                                                     GwyField *mask_a,
-                                                     GwyField *mask_b);
+                                                     GwyNield *mask_a,
+                                                     GwyNield *mask_b);
 static void             classifier_run              (Classifier *cl,
                                                      GwyField **cldata,
                                                      gint ndata,
-                                                     GwyField *result_a,
-                                                     GwyField *result_b);
+                                                     GwyNield *result_a,
+                                                     GwyNield *result_b);
 static void             ctree_run                   (CTree *ct,
                                                      GwyField **cldata,
                                                      gint ndata,
-                                                     GwyField *result_a,
-                                                     GwyField *result_b);
+                                                     GwyNield *result_a,
+                                                     GwyNield *result_b);
 
 static GwyAppDataId object_ids[NARGS];
 
@@ -149,7 +149,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Classify data sets using multiple data fields."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "1.2",
     "Petr Klapetek",
     "2020",
 };
@@ -180,14 +180,14 @@ static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     ModuleArgs args;
-    GwyContainer *settings;
+    GwyDict *settings;
     gint datano, id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear(&args, 1);
 
     gwy_data_browser_get_current(GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &datano,
+                                 GWY_APP_FILE_ID, &datano,
                                  0);
 
     args.objects[0].datano = datano;
@@ -199,7 +199,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GwyDialogOutcome outcome = run_gui(data, id, &args);
     if (outcome == GWY_DIALOG_PROCEED) {
         GQuark quark = gwy_file_key_image_mask(args.show.id);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
         if (args.result_b && args.display == CLASSIFY_DISPLAY_RESULT_B)
             gwy_file_set_image_mask(data, args.show.id, args.result_b);
@@ -240,7 +240,7 @@ run_gui(GwyFile *data,
     dfield = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, 1.0, 1.0, TRUE);
     gui.view = gwy_create_preview(dfield, NULL, PREVIEW_SIZE);
     /* XXX: This should go away with GwyParams. */
-    gwy_rgba_get_from_container(&color, gwy_app_settings_get(), "/mask");
+    gwy_rgba_get_from_dict(&color, gwy_app_settings_get(), "/mask");
     gwy_data_view_set_mask_color(GWY_DATA_VIEW(gui.view), &color);
     gwy_setup_data_view(GWY_DATA_VIEW(gui.view), data, GWY_FILE_IMAGE, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_MASK_COLOR | GWY_FILE_ITEM_REAL_SQUARE);
@@ -511,7 +511,8 @@ static void
 update_view(G_GNUC_UNUSED GtkComboBox *combo, ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
-    GwyField *result, *mask = NULL;
+    GwyField *result;
+    GwyNield *mask = NULL;
 
     args->display = gwy_enum_combo_box_get_active(GTK_COMBO_BOX(gui->display));
 
@@ -526,12 +527,12 @@ update_view(G_GNUC_UNUSED GtkComboBox *combo, ModuleGUI *gui)
            printf("getting mask A for %d\n", args->maska);
        //data = gwy_data_browser_get_file(args->objects[args->maska % NARGS].datano);
        //quark = gwy_file_key_image_mask(args->objects[args->maska % NARGS].id);
-       //if (!gwy_container_gis_object(data, quark, &mask)) printf("There is no mask A in channel %d\n", args->maska);
+       //if (!gwy_dict_gis_object(data, quark, &mask)) printf("There is no mask A in channel %d\n", args->maska);
     }
     else if (args->display == CLASSIFY_DISPLAY_MASK_B) {
        //data = gwy_data_browser_get_file(args->objects[args->maskb % NARGS].datano);
        //quark = gwy_file_key_image_mask(args->objects[args->maskb % NARGS].id);
-       //if (!gwy_container_gis_object(data, quark, &mask)) printf("There is no mask B in channel %d\n", args->maska);
+       //if (!gwy_dict_gis_object(data, quark, &mask)) printf("There is no mask B in channel %d\n", args->maska);
     }
     else if (args->display == CLASSIFY_DISPLAY_RESULT_A) {
         mask = args->result_a;
@@ -593,13 +594,13 @@ check_fields(ModuleArgs *args)
     data = gwy_data_browser_get_file(args->objects[first].datano);
     g_return_val_if_fail(data, NULL);
     quark = gwy_file_key_image(args->objects[first].id);
-    dfirst = GWY_FIELD(gwy_container_get_object(data, quark));
+    dfirst = GWY_FIELD(gwy_dict_get_object(data, quark));
     for (i = first+1; i < NARGS; i++) {
 
         data = gwy_data_browser_get_file(args->objects[i].datano);
         g_return_val_if_fail(data, NULL);
         quark = gwy_file_key_image(args->objects[i].id);
-        dfield = GWY_FIELD(gwy_container_get_object(data, quark));
+        dfield = GWY_FIELD(gwy_dict_get_object(data, quark));
 
         diff = gwy_field_is_incompatible
                                             (dfirst, dfield,
@@ -679,17 +680,14 @@ inclination_filter(GwyField *dfield)
     qx = gwy_field_get_dx(dfield);
     qy = gwy_field_get_dx(dfield);
 
-    size = gwy_field_get_circular_area_size(r);
+    size = gwy_circular_area_size(r);
     z = g_new(gdouble, size);
     xp = g_new(gint, 2*size);
     yp = xp + size;
     for (i = 0; i < yres; i++) {
         for (j = 0; j < xres; j++) {
+            gint n = gwy_field_circular_area_extract(dfield, j, i, r, z, xp, yp);
             gdouble bx, by;
-            gint n;
-
-            n = gwy_field_circular_area_extract_with_pos(dfield, j, i, r,
-                                                         z, xp, yp);
             fit_local_plane_by_pos(n, xp, yp, z, &bx, &by);
             bx /= qx;
             by /= qy;
@@ -706,7 +704,8 @@ inclination_filter(GwyField *dfield)
 static void
 run_classification(ModuleGUI *gui)
 {
-    GwyField *mask_a = NULL, *mask_b = NULL, *dfield;
+    GwyNield *mask_a = NULL, *mask_b = NULL;
+    GwyField *dfield;
     GwyField **cldata;
     ModuleArgs *args;
     GwyFile *data;
@@ -797,9 +796,9 @@ run_classification(ModuleGUI *gui)
 
     //run the classification, creating result_a and result_b
     if (!args->result_a)
-        args->result_a = gwy_field_copy(mask_b);
+        args->result_a = gwy_nield_copy(mask_b);
     if (!args->result_b)
-        args->result_b = gwy_field_copy(mask_a);
+        args->result_b = gwy_nield_copy(mask_a);
 
     classifier_run(&cl, cldata, ncriteria, args->result_a, args->result_b);
 
@@ -827,28 +826,29 @@ run_classification(ModuleGUI *gui)
 //a_purity: how much the A is really filled with As
 //b_purity: how much the B is really filled with Bs
 static gdouble
-get_score(GwyField *mask_a, GwyField *mask_b, GwyField *result_a, GwyField *result_b,
-          GwyField *selection, gdouble *a_purity, gdouble *b_purity, gdouble *sumsa, gdouble *sumsb)
+get_score(GwyNield *mask_a, GwyNield *mask_b, GwyNield *result_a, GwyNield *result_b,
+          GwyNield *selection, gdouble *a_purity, gdouble *b_purity, gdouble *sumsa, gdouble *sumsb)
 {
     gint i;
-    gint n = gwy_field_get_xres(mask_a)*gwy_field_get_yres(mask_a);
-    gdouble *ma, *mb, *ra, *rb, *s;
+    gint n = gwy_nield_get_xres(mask_a)*gwy_nield_get_yres(mask_a);
+    gint *ma, *mb, *ra, *rb, *s;
     gdouble sumainb, sumbina, nma, sumbinb, sumaina, nmb, paina, painb, pbina, pbinb;
     gboolean selall = 0;
     gdouble ginia, ginib;
 
-    ma = gwy_field_get_data(mask_a);
-    mb = gwy_field_get_data(mask_b);
-    ra = gwy_field_get_data(result_a);
-    rb = gwy_field_get_data(result_b);
+    ma = gwy_nield_get_data(mask_a);
+    mb = gwy_nield_get_data(mask_b);
+    ra = gwy_nield_get_data(result_a);
+    rb = gwy_nield_get_data(result_b);
 
-    if (selection==NULL) selall = 1;
-    else s = gwy_field_get_data(selection);
+    if (!selection)
+        selall = 1;
+    else
+        s = gwy_nield_get_data(selection);
 
     sumaina = sumbina = nma = 0;
     sumainb = sumbinb = nmb = 0;
-    for (i=0; i<n; i++)
-    {
+    for (i = 0; i < n; i++) {
         if (selall || s[i]) {
            sumaina += ma[i]*ra[i];
            sumbina += mb[i]*ra[i];
@@ -858,15 +858,19 @@ get_score(GwyField *mask_a, GwyField *mask_b, GwyField *result_a, GwyField *resu
            nmb += ma[i]*rb[i] + mb[i]*rb[i];
         }
     }
-    if ((sumaina+sumbina)>0) {
+    if (sumaina + sumbina > 0) {
        paina = sumaina/(sumaina + sumbina);
        pbina = sumbina/(sumaina + sumbina);
-    } else paina = pbina = 0;
+    }
+    else
+        paina = pbina = 0;
 
-    if ((sumainb+sumbinb)>0) {
+    if (sumainb + sumbinb > 0) {
        painb = sumainb/(sumainb + sumbinb);
        pbinb = sumbinb/(sumainb + sumbinb);
-    } else painb = pbinb = 0;
+    }
+    else
+        painb = pbinb = 0;
 
     ginia = paina*(1-paina) + pbina*(1-pbina);
     ginib = painb*(1-painb) + pbinb*(1-pbinb);
@@ -906,10 +910,10 @@ print_ct(CTree *ct)
 //last crit is the criterion that was used last time, to be skipped
 static gint
 get_next_split(GwyField **cldata, gint ndata,
-               GwyField *mask_a, GwyField *mask_b, GwyField *selection, gdouble *threshold,
+               GwyNield *mask_a, GwyNield *mask_b, GwyNield *selection, gdouble *threshold,
                gdouble *a_purity, gdouble *b_purity, gdouble *gini,
                gdouble *sumsa, gdouble *sumsb,
-               GwyField *result_a, GwyField *result_b,
+               GwyNield *result_a, GwyNield *result_b,
                gint lastcrit)
 {
    gint n, bestcrit;
@@ -937,8 +941,7 @@ get_next_split(GwyField **cldata, gint ndata,
 
        gint xres = gwy_field_get_xres(cldata[ct.rule_parameter[0]]);
        gint yres = gwy_field_get_yres(cldata[ct.rule_parameter[0]]);
-       min = gwy_field_area_get_min(cldata[ct.rule_parameter[0]], selection, GWY_MASK_INCLUDE, 0, 0, xres, yres);
-       max = gwy_field_area_get_max(cldata[ct.rule_parameter[0]], selection, GWY_MASK_INCLUDE, 0, 0, xres, yres);
+       gwy_field_area_min_max(cldata[ct.rule_parameter[0]], selection, GWY_MASK_INCLUDE, 0, 0, xres, yres, &min, &max);
        if (CDEBUG>1) printf("criterion %d min %g max %g\n", ct.rule_parameter[0], min, max);
        step = (max-min)/100;
 
@@ -991,6 +994,7 @@ get_next_split(GwyField **cldata, gint ndata,
    return bestcrit;
 }
 
+#if 0
 static void
 print_dfield(GwyField *df, gint index)
 {
@@ -1019,22 +1023,23 @@ print_dfield(GwyField *df, gint index)
 
     fclose(fw);
 }
+#endif
 
 static gint
-process_branch(CTree *ct, GwyField **cldata, GwyField *mask_a, GwyField *mask_b,
-               gint ndata, gint *n, GwyField *selection, gint lastcrit)
+process_branch(CTree *ct, GwyField **cldata, GwyNield *mask_a, GwyNield *mask_b,
+               gint ndata, gint *n, GwyNield *selection, gint lastcrit)
 {
-    GwyField *result_a = gwy_field_new_alike(cldata[0], TRUE);
-    GwyField *result_b = gwy_field_new_alike(cldata[0], TRUE);
-    GwyField *sel_a = gwy_field_new_alike(cldata[0], TRUE);
-    GwyField *sel_b = gwy_field_new_alike(cldata[0], TRUE);
+    GwyNield *result_a = gwy_field_new_nield_alike(cldata[0]);
+    GwyNield *result_b = gwy_field_new_nield_alike(cldata[0]);
+    GwyNield *sel_a = gwy_field_new_nield_alike(cldata[0]);
+    GwyNield *sel_b = gwy_field_new_nield_alike(cldata[0]);
     gdouble apur, bpur, gini, threshold, sumsa, sumsb, retval;
     gint thisn = *n;
     gint nextn, ret;
 
     if (CDEBUG) printf("Processing branch %d\n", thisn);
 
-    if (CDEBUG>1) print_dfield(selection, thisn);
+    //if (CDEBUG>1) print_dfield(selection, thisn);
 
     if (ndata==1) //special case when only one criterion exists, so we can't swap them
         ct->rule_parameter[thisn] = get_next_split(cldata, ndata,
@@ -1045,8 +1050,8 @@ process_branch(CTree *ct, GwyField **cldata, GwyField *mask_a, GwyField *mask_b,
                                                    mask_a, mask_b, selection, &threshold,
                                                    &apur, &bpur, &gini, &sumsa, &sumsb, result_a, result_b, lastcrit);
 
-    if (CDEBUG>1) print_dfield(result_a, 100+thisn);
-    if (CDEBUG>1) print_dfield(result_b, 200+thisn);
+    //if (CDEBUG>1) print_dfield(result_a, 100+thisn);
+    //if (CDEBUG>1) print_dfield(result_b, 200+thisn);
 
     ct->rule_threshold[thisn] = threshold;
     if (CDEBUG) printf("(%d) sugggested rule for split: crit %d  threshold %g, purities %g %g  sums %g %g\n", thisn, ct->rule_parameter[thisn], ct->rule_threshold[thisn], apur, bpur, sumsa, sumsb);
@@ -1074,12 +1079,11 @@ process_branch(CTree *ct, GwyField **cldata, GwyField *mask_a, GwyField *mask_b,
             if (CDEBUG) printf("(%d) step high: go to next branch at index %d\n", thisn, ct->rule_goto_high[thisn]);
 
             //create actual selection, combining the previous selection with last result_a
-            if (selection==NULL)
-                gwy_field_copy_data(result_a, sel_a);
-            else
-                gwy_field_multiply_fields(sel_a, selection, result_a);
+            gwy_nield_copy_data(result_a, sel_a);
+            if (selection)
+                gwy_nield_intersect(sel_a, selection);
 
-            if (CDEBUG) printf("(%d) selection for next process %d has %g points\n", thisn, nextn, gwy_field_get_sum(sel_a));
+            if (CDEBUG) printf("(%d) selection for next process %d has %d points\n", thisn, nextn, gwy_nield_count(sel_a));
             if (CDEBUG) printf("now will process branch A with number %d\n", nextn);
             if ((ret = process_branch(ct, cldata, mask_a, mask_b, ndata, n, sel_a, ct->rule_parameter[thisn]))!=0)
             {
@@ -1101,12 +1105,11 @@ process_branch(CTree *ct, GwyField **cldata, GwyField *mask_a, GwyField *mask_b,
             if (CDEBUG) printf("(%d) step low: go to next branch at index %d\n", thisn, ct->rule_goto_low[thisn]);
 
             //create actual selection, combining the previous selection with last result_a
-            if (selection==NULL)
-               gwy_field_copy_data(result_b, sel_b);
-            else
-               gwy_field_multiply_fields(sel_b, selection, result_b);
+            gwy_nield_copy_data(result_b, sel_b);
+            if (selection)
+               gwy_nield_intersect(sel_b, selection);
 
-            if (CDEBUG) printf("(%d) selection for next process %d has %g points\n", thisn, nextn, gwy_field_get_sum(sel_b));
+            if (CDEBUG) printf("(%d) selection for next process %d has %d points\n", thisn, nextn, gwy_nield_count(sel_b));
             if (CDEBUG) printf("now will process branch B with number %d\n", nextn);
 
             if ((ret = process_branch(ct, cldata, mask_a, mask_b, ndata, n, sel_b, ct->rule_parameter[thisn]))!=0) //we could not branch further, stop it
@@ -1131,8 +1134,8 @@ process_branch(CTree *ct, GwyField **cldata, GwyField *mask_a, GwyField *mask_b,
 
 static void
 train_tree(CTree *ct, GwyField **cldata,
-           gint ndata, GwyField *mask_a, GwyField *mask_b,
-           GwyField *selection)
+           gint ndata, GwyNield *mask_a, GwyNield *mask_b,
+           GwyNield *selection)
 {
     gint n = 0;
 
@@ -1143,7 +1146,7 @@ train_tree(CTree *ct, GwyField **cldata,
 //setup whole forest
 static void
 classifier_train_full(Classifier *cl, GwyField **cldata,
-                      gint ndata, GwyField *mask_a, GwyField *mask_b)
+                      gint ndata, GwyNield *mask_a, GwyNield *mask_b)
 {
     CTree *ct;
     if (CDEBUG) printf("Classifier train started on %d data sets\n", ndata);
@@ -1157,25 +1160,19 @@ classifier_train_full(Classifier *cl, GwyField **cldata,
 static gint
 run_ct(CTree *ct, GwyField **cldata, G_GNUC_UNUSED gint ndata, gint xpos, gint ypos)
 {
-    gint i, n;
+    gint n = 0;
 
-    n = 0;
-    for (i=0; i<1000; i++)
-    {
+    for (gint i = 0; i < 1000; i++) {
         //printf("rp at %d %d  n %d param %d\n", xpos, ypos, n, ct->rule_parameter[n]);
-        if (gwy_field_get_val(cldata[ct->rule_parameter[n]], xpos, ypos)>ct->rule_threshold[n])
-        {
-            if (ct->rule_goto_high[n]<0) {
+        // XXX: If you like it very slow, do things like this!
+        if (gwy_field_get_val(cldata[ct->rule_parameter[n]], xpos, ypos) > ct->rule_threshold[n]) {
+            if (ct->rule_goto_high[n] < 0)
                 return ct->rule_goto_high[n];
-            }
-            else n = ct->rule_goto_high[n];
+            n = ct->rule_goto_high[n];
         }
-        else
-        {
-            if (ct->rule_goto_low[n]<0) {
+        else {
+            if (ct->rule_goto_low[n] < 0)
                 return ct->rule_goto_low[n];
-            }
-
             n = ct->rule_goto_low[n];
         }
         //printf("next n: %d\n", n);
@@ -1187,24 +1184,22 @@ run_ct(CTree *ct, GwyField **cldata, G_GNUC_UNUSED gint ndata, gint xpos, gint y
 //run a single tree on whole image
 static void
 ctree_run(CTree *ct, GwyField **cldata,
-          gint ndata, GwyField *result_a, GwyField *result_b)
+          gint ndata, GwyNield *result_a, GwyNield *result_b)
 {
     gint i, j, result;
     gint xres = gwy_field_get_xres(cldata[0]);
     gint yres = gwy_field_get_yres(cldata[0]);
 
-    for (i=0; i<xres; i++) {
-        for (j=0; j<yres; j++) {
+    for (i = 0; i < xres; i++) {
+        for (j = 0; j < yres; j++) {
             result = run_ct(ct, cldata, ndata, i, j);
-            if (result == -1)
-            {
-                gwy_field_set_val(result_a, i, j, 1);
-                gwy_field_set_val(result_b, i, j, 0);
+            if (result == -1) {
+                gwy_nield_set_val(result_a, i, j, 1);
+                gwy_nield_set_val(result_b, i, j, 0);
             }
-            if (result == -2)
-            {
-                gwy_field_set_val(result_a, i, j, 0);
-                gwy_field_set_val(result_b, i, j, 1);
+            if (result == -2) {
+                gwy_nield_set_val(result_a, i, j, 0);
+                gwy_nield_set_val(result_b, i, j, 1);
             }
         }
     }
@@ -1214,7 +1209,7 @@ ctree_run(CTree *ct, GwyField **cldata,
 //run the forest on whole image
 static void
 classifier_run(Classifier *cl, GwyField **cldata,
-               gint ndata, GwyField *result_a, GwyField *result_b)
+               gint ndata, GwyNield *result_a, GwyNield *result_b)
 {
     ctree_run(cl->ct + 0, cldata, ndata, result_a, result_b);  //now just run the first tree
 }
@@ -1224,7 +1219,7 @@ static const gchar mask_b_key[]   = "/module/classify/mask_b";
 static const gchar display_key[]  = "/module/classify/display";
 
 static void
-load_args(GwyContainer *settings, ModuleArgs *args)
+load_args(GwyDict *settings, ModuleArgs *args)
 {
     guint i;
     gchar key[50];
@@ -1232,22 +1227,22 @@ load_args(GwyContainer *settings, ModuleArgs *args)
     args->maska = 1;
     args->maskb = 2;
     args->display = 0;
-    gwy_container_gis_int32_by_name(settings, mask_a_key, &args->maska);
-    gwy_container_gis_int32_by_name(settings, mask_b_key, &args->maskb);
-    gwy_container_gis_enum_by_name(settings, display_key, &args->display);
+    gwy_dict_gis_int32_by_name(settings, mask_a_key, &args->maska);
+    gwy_dict_gis_int32_by_name(settings, mask_b_key, &args->maskb);
+    gwy_dict_gis_enum_by_name(settings, display_key, &args->display);
 
-    for (i = 0; i < 2*NCRITS; i++) {
-        args->id[i] = args->scale[i] = args->quantity[i] = 0;
-    }
+    gwy_clear(args->id, 2*NCRITS);
+    gwy_clear(args->scale, 2*NCRITS);
+    gwy_clear(args->quantity, 2*NCRITS);
     for (i = 0; i < 2*NCRITS; i++) {
         g_snprintf(key, sizeof(key), "/module/classify/id%u", i);
-        gwy_container_gis_int32_by_name(settings, key, &(args->id[i]));
+        gwy_dict_gis_int32_by_name(settings, key, &(args->id[i]));
 
         g_snprintf(key, sizeof(key), "/module/classify/quantity%u", i);
-        gwy_container_gis_enum_by_name(settings, key, &(args->quantity[i]));
+        gwy_dict_gis_enum_by_name(settings, key, &(args->quantity[i]));
 
         g_snprintf(key, sizeof(key), "/module/classify/scale%u", i);
-        gwy_container_gis_enum_by_name(settings, key, &(args->scale[i]));
+        gwy_dict_gis_enum_by_name(settings, key, &(args->scale[i]));
      }
 
     args->show = object_ids[0]; //this should be done better, saving the last selection
@@ -1261,26 +1256,26 @@ load_args(GwyContainer *settings, ModuleArgs *args)
 }
 
 static void
-save_args(GwyContainer *settings, ModuleArgs *args)
+save_args(GwyDict *settings, ModuleArgs *args)
 {
     guint i;
     gchar key[50];
 
     gwy_assign(object_ids, args->objects, NARGS);
 
-    gwy_container_set_int32_by_name(settings, mask_a_key, args->maska);
-    gwy_container_set_int32_by_name(settings, mask_b_key, args->maskb);
-    gwy_container_set_enum_by_name(settings, display_key, args->display);
+    gwy_dict_set_int32_by_name(settings, mask_a_key, args->maska);
+    gwy_dict_set_int32_by_name(settings, mask_b_key, args->maskb);
+    gwy_dict_set_enum_by_name(settings, display_key, args->display);
 
     for (i = 0; i < 2*NCRITS; i++) {
         g_snprintf(key, sizeof(key), "/module/classify/id%u", i);
-        gwy_container_set_int32_by_name(settings, key, args->id[i]);
+        gwy_dict_set_int32_by_name(settings, key, args->id[i]);
 
         g_snprintf(key, sizeof(key), "/module/classify/quantity%u", i);
-        gwy_container_set_enum_by_name(settings, key, args->quantity[i]);
+        gwy_dict_set_enum_by_name(settings, key, args->quantity[i]);
 
         g_snprintf(key, sizeof(key), "/module/classify/scale%u", i);
-        gwy_container_set_enum_by_name(settings, key, args->scale[i]);
+        gwy_dict_set_enum_by_name(settings, key, args->scale[i]);
     }
 }
 
