@@ -1,5 +1,5 @@
 /*
- *  $Id: coerce.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: coerce.c 29425 2026-02-02 10:08:27Z yeti-dn $
  *  Copyright (C) 2016-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -196,7 +196,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new_alike(args.field, FALSE);
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -363,19 +363,19 @@ coerce_do_field(GwyField *field, GwyField *result,
     }
     else if (distribution == COERCE_DISTRIBUTION_UNIFORM) {
         gdouble min, max;
-        gwy_field_get_min_max(field, &min, &max);
+        gwy_field_min_max(field, &min, &max);
         build_values_uniform(z, n, min, max);
     }
     else if (distribution == COERCE_DISTRIBUTION_GAUSSIAN) {
         gdouble avg, rms;
-        avg = gwy_field_get_avg(field);
-        rms = gwy_field_get_rms(field);
+        avg = gwy_field_mean(field);
+        rms = gwy_field_rms(field);
         build_values_gaussian(z, n, avg, rms);
     }
     else if (distribution == COERCE_DISTRIBUTION_SKEW_NORMAL) {
         gdouble avg, rms;
-        avg = gwy_field_get_avg(field);
-        rms = gwy_field_get_rms(field);
+        avg = gwy_field_mean(field);
+        rms = gwy_field_rms(field);
         build_values_skew_normal(z, n, avg, rms, gwy_params_get_double(params, PARAM_SKEW));
     }
     else {
@@ -394,25 +394,24 @@ static void
 coerce_do_field_levels(GwyField *field, GwyField *result,
                        GwyParams *params)
 {
-    guint n = gwy_field_get_xres(field)*gwy_field_get_yres(field);
+    gsize n = gwy_field_get_xres(field)*gwy_field_get_yres(field);
     const gdouble *d = gwy_field_get_data_const(field);
     gdouble *dr = gwy_field_get_data(result);
-    gdouble min, max, q;
-    gint k, nlevels = gwy_params_get_int(params, PARAM_NLEVELS);
+    gint nlevels = gwy_params_get_int(params, PARAM_NLEVELS);
 
-    gwy_field_get_min_max(field, &min, &max);
+    gdouble min, max;
+    gwy_field_min_max(field, &min, &max);
     if (max <= min) {
         gwy_field_fill(result, 0.5*(min + max));
         return;
     }
 
-    q = (max - min)/nlevels;
+    gdouble q = (max - min)/nlevels;
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(k) \
             shared(d,dr,n,nlevels,q,min)
 #endif
-    for (k = 0; k < n; k++) {
+    for (gsize k = 0; k < n; k++) {
         gint v = (gint)floor((d[k] - min)/q);
         v = CLAMP(v, 0, nlevels-1);
         dr[k] = (v + 0.5)*q + min;
@@ -436,7 +435,7 @@ coerce_do_rows(GwyField *field, GwyField *result,
     if (distribution == COERCE_DISTRIBUTION_LEVELS) {
         GwyField *tmp = gwy_field_copy(field);
         gdouble min, max;
-        gwy_field_get_min_max(field, &min, &max);
+        gwy_field_min_max(field, &min, &max);
         for (i = 0; i < yres; i++)
             gwy_field_area_renormalize(tmp, 0, i, xres, 1, max-min, min);
         coerce_do_field(tmp, result, params);
@@ -454,19 +453,19 @@ coerce_do_rows(GwyField *field, GwyField *result,
     }
     else if (distribution == COERCE_DISTRIBUTION_UNIFORM) {
         gdouble min, max;
-        gwy_field_get_min_max(field, &min, &max);
+        gwy_field_min_max(field, &min, &max);
         build_values_uniform(z, xres, min, max);
     }
     else if (distribution == COERCE_DISTRIBUTION_GAUSSIAN) {
         gdouble avg, rms;
-        avg = gwy_field_get_avg(field);
-        rms = gwy_field_get_rms(field);
+        avg = gwy_field_mean(field);
+        rms = gwy_field_rms(field);
         build_values_gaussian(z, xres, avg, rms);
     }
     else if (distribution == COERCE_DISTRIBUTION_SKEW_NORMAL) {
         gdouble avg, rms;
-        avg = gwy_field_get_avg(field);
-        rms = gwy_field_get_rms(field);
+        avg = gwy_field_mean(field);
+        rms = gwy_field_rms(field);
         build_values_skew_normal(z, xres, avg, rms, gwy_params_get_double(params, PARAM_SKEW));
     }
     else {
@@ -509,9 +508,7 @@ build_values_levels(const ValuePos *vpos, gdouble *z, guint n, guint nlevels)
             for (j = blockstart; j <= i; j++)
                 v += vpos[j].z;
 
-            v /= (i+1 - blockstart);
-            for (j = blockstart; j <= i; j++)
-                z[j] = v;
+            gwy_math_fill(z + blockstart, j+1 - blockstart, v/(i+1 - blockstart));
 
             counter -= n;
             blockstart = i+1;
@@ -580,17 +577,13 @@ gwy_inverf(gdouble y)
 static void
 build_values_gaussian(gdouble *z, guint n, gdouble mean, gdouble rms)
 {
-    gdouble x;
-    guint i;
-
     rms *= sqrt(2.0);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,x) \
             shared(z,n,mean,rms)
 #endif
-    for (i = 0; i < n; i++) {
-        x = (2.0*i + 1.0)/n - 1.0;
+    for (guint i = 0; i < n; i++) {
+        gdouble x = (2.0*i + 1.0)/n - 1.0;
         z[i] = mean + rms*gwy_inverf(x);
     }
 }
@@ -696,9 +689,9 @@ static void
 build_values_skew_normal(gdouble *z, guint n,
                          gdouble mean, gdouble rms, gdouble skew)
 {
-    guint i, npdf = 2*n;
+    guint npdf = 2*n;
     gdouble *pdf = g_new(gdouble, npdf);
-    gdouble x, s, m, alpha;
+    gdouble alpha;
 
     if (fabs(skew) > 0.995)
         alpha = 100.0;
@@ -708,30 +701,28 @@ build_values_skew_normal(gdouble *z, guint n,
     if (skew < 0.0)
         alpha = -alpha;
 
-    s = 0.0;
+    gdouble s = 0.0;
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(+:s) \
-            private(i,x) \
             shared(pdf,npdf,alpha)
 #endif
-    for (i = 0; i < npdf; i++) {
-        x = 20.0*i/(npdf - 1.0) - 10.0;
+    for (guint i = 0; i < npdf; i++) {
+        gdouble x = 20.0*i/(npdf - 1.0) - 10.0;
         pdf[i] = exp(-0.5*x*x) * (erf(alpha*x) + 1.0);
         s += pdf[i];
     }
 
-    /* Ensure given mean and rms: This is actually generic and we assume
-     * interval [-1,1]. */
-    m = 0.0;
-    for (i = 0; i < npdf; i++) {
-        x = 2.0*i/(npdf - 1.0) - 1.0;
+    /* Ensure given mean and rms: This is actually generic and we assume interval [-1,1]. */
+    gdouble m = 0.0;
+    for (guint i = 0; i < npdf; i++) {
+        gdouble x = 2.0*i/(npdf - 1.0) - 1.0;
         pdf[i] /= s;
         m += x*pdf[i];
     }
     s = 0.0;
-    for (i = 0; i < npdf; i++) {
-        x = 2.0*i/(npdf - 1.0) - 1.0 - m;
+    for (guint i = 0; i < npdf; i++) {
+        gdouble x = 2.0*i/(npdf - 1.0) - 1.0 - m;
         s += x*x*pdf[i];
     }
     s = sqrt(s);
