@@ -1,5 +1,5 @@
 /*
- *  $Id: convolution_filter.c 29078 2026-01-05 16:55:04Z yeti-dn $
+ *  $Id: convolution_filter.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -226,7 +226,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
