@@ -1,5 +1,5 @@
 /*
- *  $Id: convolve.c 24441 2021-10-29 15:30:17Z yeti-dn $
+ *  $Id: convolve.c 28858 2025-11-13 14:32:56Z yeti-dn $
  *  Copyright (C) 2018-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -16,16 +16,9 @@
  */
 
 #include "config.h"
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include <libgwyddion/gwymacros.h>
-#include <libprocess/arithmetic.h>
-#include <libprocess/stats.h>
-#include <libprocess/correlation.h>
-#include <libprocess/filters.h>
-#include <libgwydgets/gwystock.h>
-#include <libgwymodule/gwymodule-process.h>
-#include <app/gwymoduleutils.h>
-#include <app/gwyapp.h>
+#include <gwy.h>
 
 #define RUN_MODES GWY_RUN_INTERACTIVE
 
@@ -44,8 +37,8 @@ enum {
 
 typedef struct {
     GwyParams *params;
-    GwyDataField *field;
-    GwyDataField *result;
+    GwyField *field;
+    GwyField *result;
 } ModuleArgs;
 
 typedef struct {
@@ -56,13 +49,13 @@ typedef struct {
 
 static gboolean         module_register     (void);
 static GwyParamDef*     define_module_params(void);
-static void             convolve            (GwyContainer *data,
-                                             GwyRunType runtype);
+static void             module_main         (GwyFile *data,
+                                             GwyRunModeFlags mode);
 static void             execute             (ModuleArgs *args);
 static GwyDialogOutcome run_gui             (ModuleArgs *args);
 static void             param_changed       (ModuleGUI *gui,
                                              gint id);
-static gboolean         kernel_filter       (GwyContainer *data,
+static gboolean         kernel_filter       (GwyFile *data,
                                              gint id,
                                              gpointer user_data);
 
@@ -82,11 +75,11 @@ static gboolean
 module_register(void)
 {
     gwy_process_func_register("convolve",
-                              (GwyProcessFunc)&convolve,
+                              module_main,
                               N_("/M_ultidata/_Convolve..."),
-                              GWY_STOCK_CONVOLVE,
+                              GWY_ICON_CONVOLVE,
                               RUN_MODES,
-                              GWY_MENU_FLAG_DATA,
+                              GWY_MENU_FLAG_IMAGE,
                               N_("Convolve two images"));
 
     return TRUE;
@@ -97,10 +90,10 @@ define_module_params(void)
 {
     static const GwyEnum exteriors[] = {
         { N_("Zero"),              GWY_EXTERIOR_FIXED_VALUE,   },
-        { N_("exterior|Border"),   GWY_EXTERIOR_BORDER_EXTEND, },
-        { N_("exterior|Mirror"),   GWY_EXTERIOR_MIRROR_EXTEND, },
-        { N_("exterior|Periodic"), GWY_EXTERIOR_PERIODIC,      },
-        { N_("exterior|Laplace"),  GWY_EXTERIOR_LAPLACE,       },
+        { gwy_NC("exterior", "Border"),   GWY_EXTERIOR_BORDER, },
+        { gwy_NC("exterior", "Mirror"),   GWY_EXTERIOR_MIRROR, },
+        { gwy_NC("exterior", "Periodic"), GWY_EXTERIOR_PERIODIC,      },
+        { gwy_NC("exterior", "Laplace"),  GWY_EXTERIOR_LAPLACE,       },
     };
     static const GwyEnum outsizes[] = {
         { N_("Crop to interior"),    CONVOLVE_SIZE_CROP,   },
@@ -124,17 +117,17 @@ define_module_params(void)
 }
 
 static void
-convolve(GwyContainer *data, GwyRunType runtype)
+module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     ModuleArgs args;
     GwyDialogOutcome outcome;
     gint newid, id;
 
-    gwy_clear(&args, 1);
-    g_return_if_fail(runtype & RUN_MODES);
-    gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &args.field,
-                                     GWY_APP_DATA_FIELD_ID, &id,
-                                     0);
+    gwy_clear1(args);
+    g_return_if_fail(mode & RUN_MODES);
+    gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
+                                 GWY_APP_FIELD_ID, &id,
+                                 0);
     g_return_if_fail(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
@@ -145,17 +138,18 @@ convolve(GwyContainer *data, GwyRunType runtype)
 
     execute(&args);
 
-    newid = gwy_app_data_browser_add_data_field(args.result, data, TRUE);
-    gwy_app_sync_data_items(data, data, id, newid, FALSE,
-                            GWY_DATA_ITEM_GRADIENT,
-                            GWY_DATA_ITEM_REAL_SQUARE,
-                            0);
-    gwy_app_set_data_field_title(data, newid, _("Convolved"));
-    gwy_app_channel_log_add_proc(data, id, newid);
+    newid = gwy_file_add_image(data, args.result);
+
+    gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
+    gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
+                        data, GWY_FILE_IMAGE, newid,
+                        GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE, FALSE);
+    gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Convolved"), TRUE);
+    gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
 
 end:
     g_object_unref(args.params);
-    GWY_OBJECT_UNREF(args.result);
+    g_clear_object(&args.result);
 }
 
 static GwyDialogOutcome
@@ -202,22 +196,21 @@ param_changed(ModuleGUI *gui, gint id)
 }
 
 static gboolean
-kernel_filter(GwyContainer *data, gint id, gpointer user_data)
+kernel_filter(GwyFile *data, gint id, gpointer user_data)
 {
     ModuleArgs *args = (ModuleArgs*)user_data;
-    GwyDataField *kernel, *field = args->field;
+    GwyField *kernel, *field = args->field;
     gint xres, yres, kxres, kyres;
 
-    if (!gwy_container_gis_object(data, gwy_app_get_data_key_for_id(id), &kernel))
+    if (!(kernel = gwy_file_get_image(data, id)))
         return FALSE;
-    if (gwy_data_field_check_compatibility(kernel, field,
-                                           GWY_DATA_COMPATIBILITY_LATERAL | GWY_DATA_COMPATIBILITY_MEASURE))
+    if (gwy_field_is_incompatible(kernel, field, GWY_DATA_MISMATCH_LATERAL | GWY_DATA_MISMATCH_MEASURE))
         return FALSE;
 
-    kxres = gwy_data_field_get_xres(kernel);
-    kyres = gwy_data_field_get_yres(kernel);
-    xres = gwy_data_field_get_xres(field);
-    yres = gwy_data_field_get_yres(field);
+    kxres = gwy_field_get_xres(kernel);
+    kyres = gwy_field_get_yres(kernel);
+    xres = gwy_field_get_xres(field);
+    yres = gwy_field_get_yres(field);
 
     /* For non-empty result with CONVOLVE_SIZE_CROP we need a sharp inequality. */
     if (gwy_params_get_enum(args->params, PARAM_OUTSIZE) == CONVOLVE_SIZE_CROP)
@@ -231,34 +224,34 @@ execute(ModuleArgs *args)
     ConvolveSizeType outsize = gwy_params_get_enum(args->params, PARAM_OUTSIZE);
     GwyExteriorType exterior = gwy_params_get_enum(args->params, PARAM_EXTERIOR);
     gboolean as_integral = gwy_params_get_boolean(args->params, PARAM_AS_INTEGRAL);
-    GwyDataField *field = args->field, *kernel = gwy_params_get_image(args->params, PARAM_KERNEL);
-    GwyDataField *extfield, *result;
+    GwyField *field = args->field, *kernel = gwy_params_get_image(args->params, PARAM_KERNEL);
+    GwyField *extfield, *result;
     gint xres, yres, kxres, kyres;
 
-    kxres = gwy_data_field_get_xres(kernel);
-    kyres = gwy_data_field_get_yres(kernel);
-    xres = gwy_data_field_get_xres(field);
-    yres = gwy_data_field_get_yres(field);
+    kxres = gwy_field_get_xres(kernel);
+    kyres = gwy_field_get_yres(kernel);
+    xres = gwy_field_get_xres(field);
+    yres = gwy_field_get_yres(field);
 
     if (outsize == CONVOLVE_SIZE_EXTEND) {
-        /* XXX: This way we extend the field twice.  The extension in gwy_data_field_area_ext_convolve() then just
+        /* XXX: This way we extend the field twice.  The extension in gwy_field_area_ext_convolve() then just
          * messes things up, for instance for periodic exterior.  So extend it all the way here, use zero-filled
          * exterior and crop. */
-        extfield = gwy_data_field_extend(field, kxres, kxres, kyres, kyres, exterior, 0.0, FALSE);
-        result = args->result = gwy_data_field_new_alike(extfield, FALSE);
-        gwy_data_field_area_ext_convolve(extfield, 0, 0, xres + 2*kxres, yres + 2*kyres,
-                                         result, kernel,
-                                         GWY_EXTERIOR_FIXED_VALUE, 0.0, as_integral);
+        extfield = gwy_field_extend(field, kxres, kxres, kyres, kyres, exterior, 0.0, FALSE);
+        result = args->result = gwy_field_new_alike(extfield, FALSE);
+        gwy_field_area_ext_convolve(extfield, 0, 0, xres + 2*kxres, yres + 2*kyres,
+                                    result, kernel,
+                                    GWY_EXTERIOR_FIXED_VALUE, 0.0, as_integral);
         g_object_unref(extfield);
-        gwy_data_field_resize(result, kxres/2, kyres/2, xres + 2*kxres - kxres/2, yres + 2*kyres - kyres/2);
+        gwy_field_crop(result, kxres/2, kyres/2, xres + 2*kxres - 2*(kxres/2), yres + 2*kyres - 2*(kyres/2));
     }
     else {
-        result = args->result = gwy_data_field_new_alike(field, FALSE);
-        gwy_data_field_area_ext_convolve(field, 0, 0, xres, yres,
-                                         result, kernel,
-                                         exterior, 0.0, as_integral);
+        result = args->result = gwy_field_new_alike(field, FALSE);
+        gwy_field_area_ext_convolve(field, 0, 0, xres, yres,
+                                    result, kernel,
+                                    exterior, 0.0, as_integral);
         if (outsize == CONVOLVE_SIZE_CROP)
-            gwy_data_field_resize(result, kxres/2, kyres/2, xres + kxres/2 - kxres, yres + kyres/2 - kyres);
+            gwy_field_crop(result, kxres/2, kyres/2, xres - kxres, yres - kyres);
     }
 }
 
