@@ -1,5 +1,5 @@
 /*
- *  $Id: correct_affine.c 29084 2026-01-05 18:02:33Z yeti-dn $
+ *  $Id: correct_affine.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2013-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -246,7 +246,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &datano,
+                                 GWY_APP_FILE_ID, &datano,
                                  0);
     g_return_if_fail(args.field);
     /* Init the image we use for ACF to the current image. If someone wants to use a different image she will
@@ -299,7 +299,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         /* FIXME: We might want an option for that. */
         GwySelection *selection = gwy_selection_lattice_new();
         gwy_selection_set_data(selection, 1, a1a2_corr);
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_selection(corrid, "lattice"), selection);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_selection(corrid, "lattice"), selection);
 
         gchar *s = gwy_file_get_display_title(data, GWY_FILE_IMAGE, oldid);
         gchar *t = g_strconcat(s, " ", _("Corrected"), NULL);
@@ -384,7 +384,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     GObject *selection;
     GQuark selection_key = gwy_file_key_image_selection(id, "lattice");
-    if (gwy_container_gis_object(GWY_CONTAINER(data), selection_key, &selection)
+    if (gwy_dict_gis_object(GWY_DICT(data), selection_key, &selection)
         && gwy_selection_get_data(GWY_SELECTION(selection), NULL) == 1)
         gwy_selection_assign(args->selection, GWY_SELECTION(selection));
     else
@@ -397,7 +397,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     GwyDialogOutcome outcome = gwy_dialog_run(dialog);
 
-    gwy_container_pass_object(GWY_CONTAINER(data), selection_key, gwy_selection_copy(args->selection));
+    gwy_dict_pass_object(GWY_DICT(data), selection_key, gwy_selection_copy(args->selection));
     gwy_value_format_free(gui.vf);
     gwy_value_format_free(gui.vfphi);
     g_object_unref(gui.acf);
@@ -729,7 +729,7 @@ calculate_acf_field(ModuleGUI *gui)
     gui->acf_calculated_for = field;
     field = gwy_field_copy(field);
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
-    gwy_field_add(field, -gwy_field_get_avg(field));
+    gwy_field_add(field, -gwy_field_mean(field));
     gint acfwidth = MIN(MAX(xres/4, 64), xres/2);
     gint acfheight = MIN(MAX(yres/4, 64), yres/2);
     gwy_field_area_acf_2d(field, NULL, GWY_MASK_IGNORE, gui->acf, 0, 0, xres, yres, acfwidth, acfheight, NULL);
@@ -743,10 +743,10 @@ calculate_acf_field(ModuleGUI *gui)
 
     /* Remember interpolated middle row. */
     GwyField *mid = gwy_field_area_extract(gui->acf, 0, acfheight/2-1, acfwidth, 3);
-    GwyField *mask = gwy_field_new(acfwidth, 3, acfwidth, 3, TRUE);
-    gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 1, acfwidth, 1, 1.0);
-    gwy_field_set_val(mask, acfwidth/2, 1, 0.0);
-    gwy_field_laplace_solve(mid, mask, -1, 1.0);
+    GwyNield *mask = gwy_nield_new(acfwidth, 3);
+    gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 1, acfwidth, 1, 1);
+    gwy_nield_set_val(mask, acfwidth/2, 1, 0);
+    gwy_field_laplace_solve(mid, mask, GWY_LAPLACE_MASKED, 1.0);
     gwy_field_get_row(mid, gui->hacf_fixed, 1);
     g_object_unref(mask);
     g_object_unref(mid);
@@ -948,7 +948,7 @@ create_corrected_field(GwyField *field,
 
     corrected = gwy_field_new(1, 1, 1.0, 1.0, FALSE);
     gwy_field_affine_prepare(field, corrected, a1a2, a1a2_corr, invtrans, scaling, TRUE, 1.0);
-    gwy_field_affine(field, corrected, invtrans, interp, GWY_EXTERIOR_FIXED_VALUE, gwy_field_get_avg(field));
+    gwy_field_affine(field, corrected, invtrans, interp, GWY_EXTERIOR_FIXED_VALUE, gwy_field_mean(field));
 
     return corrected;
 }
