@@ -1,5 +1,5 @@
 /*
- *  $Id: correct_perspective.c 29084 2026-01-05 18:02:33Z yeti-dn $
+ *  $Id: correct_perspective.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2021-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -60,7 +60,7 @@ static gboolean         module_register                (void);
 static GwyParamDef*     define_module_params           (void);
 static void             module_main                    (GwyFile *data,
                                                         GwyRunModeFlags mode);
-static void             gather_quarks_for_one_image    (GwyContainer *data,
+static void             gather_quarks_for_one_image    (GwyDict *data,
                                                         gint id,
                                                         GArray *quarks);
 static void             apply_correction_to_one_image  (ModuleArgs *args,
@@ -99,7 +99,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Corrects or applies perspective distortion of images."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti)",
     "2021",
 };
@@ -171,7 +171,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = params = gwy_params_new_from_settings(define_module_params());
     init_coordinates(field, args.xy);
     GQuark selection_key = gwy_file_key_image_selection(id, "projective");
-    if (gwy_container_gis_object(GWY_CONTAINER(data), selection_key, &selection)
+    if (gwy_dict_gis_object(GWY_DICT(data), selection_key, &selection)
         && gwy_selection_get_data(GWY_SELECTION(selection), NULL))
         gwy_selection_get_object(GWY_SELECTION(selection), 0, args.xy);
 
@@ -180,7 +180,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     selection = gwy_selection_quad_new();
     gwy_selection_set_object(GWY_SELECTION(selection), 0, args.xy);
-    gwy_container_pass_object(GWY_CONTAINER(data), selection_key, selection);
+    gwy_dict_pass_object(GWY_DICT(data), selection_key, selection);
 
     if (outcome != GWY_DIALOG_PROCEED)
         goto end;
@@ -190,8 +190,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (!distribute) {
         if (!new_image) {
             undo_quarks = g_array_new(FALSE, FALSE, sizeof(GQuark));
-            gather_quarks_for_one_image(GWY_CONTAINER(data), id, undo_quarks);
-            gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), undo_quarks->len, (GQuark*)undo_quarks->data);
+            gather_quarks_for_one_image(GWY_DICT(data), id, undo_quarks);
+            gwy_app_undo_qcheckpointv(GWY_DICT(data), undo_quarks->len, (GQuark*)undo_quarks->data);
             g_array_free(undo_quarks, TRUE);
         }
         apply_correction_to_one_image(&args, data, id);
@@ -205,9 +205,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         for (i = 0; image_ids[i] != -1; i++) {
             GwyField *otherfield = gwy_file_get_image(data, image_ids[i]);
             if (!gwy_field_is_incompatible(field, otherfield, compat_flags))
-                gather_quarks_for_one_image(GWY_CONTAINER(data), image_ids[i], undo_quarks);
+                gather_quarks_for_one_image(GWY_DICT(data), image_ids[i], undo_quarks);
         }
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), undo_quarks->len, (GQuark*)undo_quarks->data);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), undo_quarks->len, (GQuark*)undo_quarks->data);
         g_array_free(undo_quarks, TRUE);
     }
     for (i = 0; image_ids[i] != -1; i++) {
@@ -225,22 +225,22 @@ end:
 }
 
 static void
-gather_quarks_for_one_image(GwyContainer *data, gint id, GArray *quarks)
+gather_quarks_for_one_image(GwyDict *data, gint id, GArray *quarks)
 {
     GObject *object;
     GQuark quark;
 
     quark = gwy_file_key_image(id);
-    object = gwy_container_get_object(data, quark);
+    object = gwy_dict_get_object(data, quark);
     g_assert(GWY_IS_FIELD(object));
     g_array_append_val(quarks, quark);
 
     quark = gwy_file_key_image_mask(id);
-    if (gwy_container_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
+    if (gwy_dict_gis_object(data, quark, &object) && GWY_IS_NIELD(object))
         g_array_append_val(quarks, quark);
 
     quark = gwy_file_key_image_picture(id);
-    if (gwy_container_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
+    if (gwy_dict_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
         g_array_append_val(quarks, quark);
 }
 
@@ -254,13 +254,14 @@ apply_correction_to_one_image(ModuleArgs *args, GwyFile *data, gint id)
     gboolean fixres = gwy_params_get_boolean(params, PARAM_FIXRES);
     gint xres = (fixres ? gwy_params_get_int(params, PARAM_XRES) : 0);
     gint yres = (fixres ? gwy_params_get_int(params, PARAM_YRES) : 0);
-    GwyField *field = gwy_file_get_image(data, id), *mask = NULL, *show = NULL;
+    GwyField *field = gwy_file_get_image(data, id), *show = NULL;
+    GwyNield *mask = gwy_file_get_image_mask(data, id);
     gchar *title, *newtitle;
     gint newid;
 
     g_assert(GWY_IS_FIELD(field));
-    mask = gwy_file_get_image_mask(data, id);
-    gwy_container_gis_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), &show);
+
+    gwy_dict_gis_object(GWY_DICT(data), gwy_file_key_image_picture(id), &show);
 
     field = create_corrected_field(field, args->xy, xres, yres, interpolation);
     if (!new_image) {
@@ -280,12 +281,20 @@ apply_correction_to_one_image(ModuleArgs *args, GwyFile *data, gint id)
     g_object_unref(field);
 
     if (mask) {
-        mask = create_corrected_field(mask, args->xy, xres, yres, GWY_INTERPOLATION_ROUND);
+        /* Mask transformation is hard. Just transform it as a Field and threshold to 0 and 1. */
+        gint origxres = gwy_nield_get_xres(mask), origyres = gwy_nield_get_yres(mask);
+        GwyField *mask_field = gwy_field_new(origxres, origyres, origxres, origyres, FALSE);
+        gwy_field_fill_mask(mask_field, mask, 0.0, 1.0);
+        field = create_corrected_field(mask_field, args->xy, xres, yres, GWY_INTERPOLATION_ROUND);
+        g_object_unref(mask_field);
+        mask = gwy_field_new_nield_alike(field);
+        gwy_nield_mark_by_threshold(mask, mask_field, 0.5, TRUE);
+        g_object_unref(mask_field);
         gwy_file_pass_image_mask(data, newid, mask);
     }
     if (show) {
         show = create_corrected_field(show, args->xy, xres, yres, interpolation);
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), show);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
     }
 
     if (!new_image) {
