@@ -1,6 +1,6 @@
 /*
- *  $Id: crosscor.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: crosscor.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -60,7 +60,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result[OUTPUT_NTYPES];
 } ModuleArgs;
 
@@ -108,7 +108,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates cross-correlation of two data fields."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -197,7 +197,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                             GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE, FALSE);
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _(gwy_enum_to_string(1 << i, outputs, OUTPUT_NTYPES)), TRUE);
         if (args.mask)
-            gwy_file_pass_image_mask(data, newid, gwy_field_copy(args.mask));
+            gwy_file_pass_image_mask(data, newid, gwy_nield_copy(args.mask));
         gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
     }
 
@@ -433,9 +433,9 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 {
     GwyParams *params = args->params;
     GwyField *field1 = args->field,
-                 *field2 = gwy_params_get_image(params, PARAM_OTHER_IMAGE),
-                 *field3 = gwy_params_get_image(params, PARAM_SECOND_SOURCE),
-                 *field4 = gwy_params_get_image(params, PARAM_SECOND_OTHER);
+             *field2 = gwy_params_get_image(params, PARAM_OTHER_IMAGE),
+             *field3 = gwy_params_get_image(params, PARAM_SECOND_SOURCE),
+             *field4 = gwy_params_get_image(params, PARAM_SECOND_OTHER);
     GwyField *fieldx, *fieldy, *score;
     GwyField *field2b = NULL, *field4b = NULL, *fieldx2 = NULL, *fieldy2 = NULL, *score2 = NULL;
     gboolean multiple = gwy_params_get_boolean(params, PARAM_MULTIPLE);
@@ -472,13 +472,13 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     /* If a shift is requested, make a copy and shift it. */
     if (xoffset || yoffset) {
         field2b = gwy_field_new_alike(field2, FALSE);
-        gwy_field_fill(field2b, gwy_field_get_avg(field2));
+        gwy_field_fill(field2b, gwy_field_mean(field2));
         gwy_field_area_copy(field2, field2b, 0, 0, -1, -1, xoffset, yoffset);
         field2 = field2b;
 
         if (multiple) {
             field4b = gwy_field_new_alike(field4, FALSE);
-            gwy_field_fill(field4b, gwy_field_get_avg(field4));
+            gwy_field_fill(field4b, gwy_field_mean(field4));
             gwy_field_area_copy(field4, field4b, 0, 0, -1, -1, xoffset, yoffset);
             field4 = field4b;
         }
@@ -529,21 +529,22 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         gwy_field_add(fieldy, gwy_field_itor(fieldx, yoffset));
 
     if (gwy_params_get_boolean(params, PARAM_EXTEND)) {
-        GwyField *mask = gwy_field_new_alike(fieldx, TRUE);
-        gint leftadd, rightadd, topadd, bottomadd;
+        GwyNield *mask = gwy_field_new_nield_alike(fieldx);
 
         // Crop data if there was a global shift.
-        leftadd = (xoffset < 0) ? 0 : xoffset;
-        rightadd = (xoffset < 0) ? -xoffset : 0;
-        topadd = (yoffset < 0) ? 0 : yoffset;
-        bottomadd = (yoffset < 0) ? -yoffset : 0;
+        gint leftadd = (xoffset < 0) ? 0 : xoffset;
+        gint rightadd = (xoffset < 0) ? -xoffset : 0;
+        gint topadd = (yoffset < 0) ? 0 : yoffset;
+        gint bottomadd = (yoffset < 0) ? -yoffset : 0;
 
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, window_x/2 + 2 + leftadd, yres, 1.0);
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, xres, window_y/2 + 2 + topadd, 1.0);
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, xres - window_x/2 - 2 - rightadd, 0, window_x/2 + 2 + rightadd, yres, 1.0);
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, yres - window_y/2 - 2 - bottomadd, xres, window_y/2 + 2 + bottomadd, 1.0);
-        gwy_field_laplace_solve(fieldx, mask, -1, 0.8);
-        gwy_field_laplace_solve(fieldy, mask, -1, 0.8);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, window_x/2 + 2 + leftadd, yres, 1);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, xres, window_y/2 + 2 + topadd, 1);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE,
+                            xres - window_x/2 - 2 - rightadd, 0, window_x/2 + 2 + rightadd, yres, 1);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE,
+                            0, yres - window_y/2 - 2 - bottomadd, xres, window_y/2 + 2 + bottomadd, 1);
+        gwy_field_laplace_solve(fieldx, mask, GWY_LAPLACE_MASKED, 0.8);
+        gwy_field_laplace_solve(fieldy, mask, GWY_LAPLACE_MASKED, 0.8);
         g_object_unref(mask);
     }
 
@@ -585,8 +586,8 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     if (output & (1 << OUTPUT_SCORE))
         args->result[OUTPUT_SCORE] = g_object_ref(score);
     if (gwy_params_get_boolean(params, PARAM_GAUSSIAN)) {
-        args->mask = gwy_field_copy(score);
-        gwy_field_threshold(args->mask, gwy_params_get_double(params, PARAM_GAUSSIAN_WIDTH), 1.0, 0.0);
+        args->mask = gwy_field_new_nield_alike(score);
+        gwy_nield_mark_by_threshold(args->mask, score, gwy_params_get_double(params, PARAM_GAUSSIAN_WIDTH), TRUE);
     }
 
     ok = TRUE;
