@@ -1,6 +1,6 @@
 /*
- *  $Id: curvature.c 28861 2025-11-14 13:02:11Z yeti-dn $
- *  Copyright (C) 2009-2022 David Necas (Yeti).
+ *  $Id: curvature.c 29520 2026-02-23 09:32:20Z yeti-dn $
+ *  Copyright (C) 2009-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -53,7 +53,7 @@ typedef struct {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGraphModel *gmodel;
     GwySelection *selection;
     gdouble results[RESULT_NRESULTS];
@@ -88,7 +88,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates overall curvature."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "3.2",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -153,7 +153,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_selection_set_max_objects(args.selection, 2);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -163,7 +163,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         execute(&args);
 
     if (gwy_params_get_boolean(params, PARAM_SET_SELECTION)) {
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "line"), args.selection);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_selection(id, "line"), args.selection);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
     if (gwy_params_get_boolean(params, PARAM_PLOT_GRAPH)) {
@@ -249,7 +249,7 @@ intersect_with_boundary(gdouble x_0, gdouble y_0, gdouble phi, gdouble w, gdoubl
 
 /* Does not include x and y offsets of the data field */
 static gboolean
-curvature_calculate(GwyField *field, GwyField *mask, GwyMaskingType masking,
+curvature_calculate(GwyField *field, GwyNield *mask, GwyMaskingType masking,
                     gdouble *r, Intersection *i1, Intersection *i2)
 {
     enum { DEGREE = 2 };
@@ -303,7 +303,7 @@ curvature_calculate(GwyField *field, GwyField *mask, GwyMaskingType masking,
 
     ok = TRUE;
     for (i = 0; i < 2; i++)
-        ok &= intersect_with_boundary(r[RESULT_X0], r[RESULT_Y0], -r[RESULT_PHI1 + i], xreal, yreal, i1 + i, i2 + i);
+        ok &= intersect_with_boundary(r[RESULT_X0], r[RESULT_Y0], r[RESULT_PHI1 + i], xreal, yreal, i1 + i, i2 + i);
 
     r[RESULT_X0] += gwy_field_get_xoffset(field);
     r[RESULT_Y0] += gwy_field_get_yoffset(field);
@@ -372,11 +372,11 @@ curvature_plot_graph(GwyField *field,
         gint col2 = gwy_field_rtoj(field, i2[i].x);
         gint row2 = gwy_field_rtoi(field, i2[i].y);
 
-        /* FIXME: We should use gwy_field_get_profile_mask() here. */
-        gwy_field_get_profile(field, dline,
-                              CLAMP(col1, 0, xres-1), CLAMP(row1, 0, yres-1),
-                              CLAMP(col2, 0, xres-1), CLAMP(row2, 0, yres-1),
-                              -1, 1, GWY_INTERPOLATION_LINEAR);
+        /* FIXME: We should use gwy_field_profile_mask() here. */
+        gwy_field_profile(field, dline,
+                          CLAMP(col1, 0, xres-1), CLAMP(row1, 0, yres-1),
+                          CLAMP(col2, 0, xres-1), CLAMP(row2, 0, yres-1),
+                          -1, 1, GWY_INTERPOLATION_LINEAR);
         gwy_line_set_offset(dline, i1[i].t/(i2[i].t - i1[i].t)*gwy_line_get_real(dline));
         gcmodel = gwy_graph_model_get_curve(gmodel, i);
         gwy_graph_curve_model_set_data_from_line(gcmodel, dline, 0, 0);
@@ -513,7 +513,8 @@ create_results(ModuleArgs *args, GwyFile *data, gint id)
 static gboolean
 execute(ModuleArgs *args)
 {
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     Intersection i1[2], i2[2];
 
@@ -533,7 +534,7 @@ preview(gpointer user_data)
 {
     ModuleGUI *gui = (ModuleGUI*)user_data;
     ModuleArgs *args = gui->args;
-    GwyField *mask = args->mask;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     GwyResults *results = gui->results;
     gdouble *r = args->results;
