@@ -1,5 +1,5 @@
 /*
- *  $Id: deconvolve.c 28858 2025-11-13 14:32:56Z yeti-dn $
+ *  $Id: deconvolve.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2018-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -573,7 +573,7 @@ calculate_lcurve(ModuleGUI *gui)
     deconv = gwy_field_new_alike(field, TRUE);
     difference = gwy_field_new_alike(field, TRUE);
     gwy_field_assign(lfield, field);
-    gwy_field_add(lfield, -gwy_field_get_avg(field));
+    gwy_field_add(lfield, -gwy_field_mean(field));
 
     for (i = 0; i < nsteps; i++) {
         if (!gwy_app_wait_set_fraction((gdouble)i/nsteps)) {
@@ -588,8 +588,8 @@ calculate_lcurve(ModuleGUI *gui)
 
         deconvolve_with_kernel(lfield, kernel, deconv, difference, sigma);
 
-        lcurvedata[nsteps*LCURVE_DATA_DIFFERENCE + i] = sqrt(gwy_field_get_mean_square(difference));
-        lcurvedata[nsteps*LCURVE_DATA_RMS + i] = gwy_field_get_rms(deconv);
+        lcurvedata[nsteps*LCURVE_DATA_DIFFERENCE + i] = sqrt(gwy_field_mean_square(difference));
+        lcurvedata[nsteps*LCURVE_DATA_RMS + i] = gwy_field_rms(deconv);
         if (!lcurvedata[nsteps*LCURVE_DATA_RMS + i] || !lcurvedata[nsteps*LCURVE_DATA_DIFFERENCE + i]) {
             clear_lcurve(gui);
             goto end;
