@@ -1,6 +1,6 @@
 /*
- *  $Id: displfield.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2019-2021 David Necas (Yeti).
+ *  $Id: displfield.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2019-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -98,7 +98,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Distorts image or individual scan lines in plane using a displacement field."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -174,7 +174,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -394,18 +394,17 @@ execute(ModuleArgs *args)
 }
 
 static gboolean
-collides_with_another_tear(const gdouble *m,
+collides_with_another_tear(const gint *m,
                            gint xres, gint yres,
                            gint col, gint row, gint len)
 {
     gint ifrom = MAX(row-1, 0), ito = MIN(row+2+1, yres);
     gint jfrom = MAX(col-len/2-1, 0), jto = MIN(col+len/2+2, xres);
-    gint i, j;
 
-    for (i = ifrom; i < ito; i++) {
-        const gdouble *mrow = m + i*xres;
-        for (j = jfrom; j < jto; j++) {
-            if (mrow[j] != 0.0)
+    for (gint i = ifrom; i < ito; i++) {
+        const gint *mrow = m + i*xres;
+        for (gint j = jfrom; j < jto; j++) {
+            if (mrow[j] > 0)
                 return TRUE;
         }
     }
@@ -414,30 +413,29 @@ collides_with_another_tear(const gdouble *m,
 }
 
 static void
-fill_tear(gdouble *d, gdouble *m,
+fill_tear(gdouble *d, gint *m,
           gint xres, gint yres,
           gint col, gint row, gint len,
           gdouble value)
 {
     gint jfrom = MAX(col-len/2, 0), jto = MIN(col+len/2+1, xres);
-    gint j;
 
     if (row >= 0) {
         gdouble *drow = d + row*xres;
-        gdouble *mrow = m + row*xres;
-        for (j = jfrom; j < jto; j++) {
+        gint *mrow = m + row*xres;
+        for (gint j = jfrom; j < jto; j++) {
             gdouble t = (j - col)/(gdouble)(len/2), tp = 1.0 + t, tm = 1.0 - t;
             drow[j] = value*tm*tm*tp*tp;
-            mrow[j] = 1.0;
+            mrow[j] = 1;
         }
     }
     if (row < yres-1) {
         gdouble *drow = d + (row + 1)*xres;
-        gdouble *mrow = m + (row + 1)*xres;
-        for (j = jfrom; j < jto; j++) {
+        gint *mrow = m + (row + 1)*xres;
+        for (gint j = jfrom; j < jto; j++) {
             gdouble t = (j - col)/(gdouble)(len/2), tp = 1.0 + t, tm = 1.0 - t;
             drow[j] = -value*tm*tm*tp*tp;
-            mrow[j] = 1.0;
+            mrow[j] = 1;
         }
     }
 }
@@ -457,20 +455,17 @@ make_tear_map(guint xres, guint yres,
               gdouble sigma, gdouble density, gdouble length,
               GRand *rng)
 {
-    GwyField *field, *mask;
-    gdouble *d, *m;
-    guint n, k;
+    GwyField *field = gwy_field_new(xres, yres, 1.0, 1.0, TRUE);
+    gdouble *d = gwy_field_get_data(field);
 
-    field = gwy_field_new(xres, yres, 1.0, 1.0, TRUE);
-    n = GWY_ROUND(0.5*xres*yres*density/length);
+    guint n = GWY_ROUND(0.5*xres*yres*density/length);
     if (!n)
         return field;
 
-    mask = gwy_field_new(xres, yres, 1.0, 1.0, TRUE);
-    d = gwy_field_get_data(field);
-    m = gwy_field_get_data(mask);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
+    gint *m = gwy_nield_get_data(mask);
 
-    for (k = 0; k < n; k++) {
+    for (guint k = 0; k < n; k++) {
         gint col, row, len, count = 0;
         gdouble value;
 
@@ -492,7 +487,7 @@ make_tear_map(guint xres, guint yres,
         fill_tear(d, m, xres, yres, col, row, len, value);
     }
 
-    gwy_field_laplace_solve(field, mask, 0, 0.5);
+    gwy_field_laplace_solve(field, mask, GWY_LAPLACE_UNMASKED, 0.5);
     g_object_unref(mask);
 
     return field;
