@@ -1,6 +1,6 @@
 /*
- *  $Id: drift.c 29023 2025-12-19 13:06:16Z yeti-dn $
- *  Copyright (C) 2007-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: drift.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2007-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  ‘Distribute’ and ‘Replace’ options were originally added by Sameer Grover  (sameer.grover.1@gmail.com)
@@ -48,7 +48,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyLine *drift;
 } ModuleArgs;
@@ -67,7 +67,7 @@ static gboolean         module_register              (void);
 static GwyParamDef*     define_module_params         (void);
 static void             module_main                  (GwyFile *data,
                                                       GwyRunModeFlags mode);
-static void             gather_quarks_for_one_image  (GwyContainer *data,
+static void             gather_quarks_for_one_image  (GwyDict *data,
                                                       gint id,
                                                       GArray *quarks);
 static void             apply_correction_to_one_image(ModuleArgs *args,
@@ -80,7 +80,7 @@ static GwyDialogOutcome run_gui                      (ModuleArgs *args,
 static void             param_changed                (ModuleGUI *gui,
                                                       gint id);
 static void             preview                      (gpointer user_data);
-static void             mask_process                 (GwyField *maskfield,
+static void             mask_process                 (GwyNield *maskfield,
                                                       GwyLine *drift);
 static void             gwy_field_normalize_rows     (GwyField *field);
 static void             match_line                   (gint res,
@@ -109,7 +109,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Evaluates and/or correct thermal drift in fast scan axis."),
     "Petr Klapetek <petr@klapetek.cz>, Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2007",
 };
@@ -166,7 +166,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GwyDialogOutcome outcome = GWY_DIALOG_PROCEED;
     ModuleArgs args;
     GwyParams *params;
-    GwyField *field, *mask, *sfield;
+    GwyField *field, *sfield;
     gboolean do_plot, do_correct, new_image, distribute;
     GArray *undo_quarks;
     gint *image_ids;
@@ -174,20 +174,18 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_SHOW_FIELD, &sfield,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     g_return_if_fail(field);
 
     args.field = field;
-    args.mask = gwy_field_new_alike(field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.mask));
+    args.mask = gwy_field_new_nield_alike(field);
     args.result = gwy_field_new_alike(field, TRUE);
     args.drift = gwy_line_new(gwy_field_get_yres(field), gwy_field_get_yreal(field), TRUE);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -228,8 +226,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (!distribute) {
         if (!new_image) {
             undo_quarks = g_array_new(FALSE, FALSE, sizeof(GQuark));
-            gather_quarks_for_one_image(GWY_CONTAINER(data), id, undo_quarks);
-            gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), undo_quarks->len, (GQuark*)undo_quarks->data);
+            gather_quarks_for_one_image(GWY_DICT(data), id, undo_quarks);
+            gwy_app_undo_qcheckpointv(GWY_DICT(data), undo_quarks->len, (GQuark*)undo_quarks->data);
             g_array_free(undo_quarks, TRUE);
         }
         apply_correction_to_one_image(&args, data, id);
@@ -242,9 +240,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         for (i = 0; image_ids[i] != -1; i++) {
             GwyField *otherfield = gwy_file_get_image(data, image_ids[i]);
             if (!gwy_field_is_incompatible(field, otherfield, compat_flags))
-                gather_quarks_for_one_image(GWY_CONTAINER(data), image_ids[i], undo_quarks);
+                gather_quarks_for_one_image(GWY_DICT(data), image_ids[i], undo_quarks);
         }
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), undo_quarks->len, (GQuark*)undo_quarks->data);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), undo_quarks->len, (GQuark*)undo_quarks->data);
         g_array_free(undo_quarks, TRUE);
     }
     for (i = 0; image_ids[i] != -1; i++) {
@@ -264,22 +262,22 @@ end:
 }
 
 static void
-gather_quarks_for_one_image(GwyContainer *data, gint id, GArray *quarks)
+gather_quarks_for_one_image(GwyDict *data, gint id, GArray *quarks)
 {
     GObject *object;
     GQuark quark;
 
     quark = gwy_file_key_image(id);
-    object = gwy_container_get_object(data, quark);
+    object = gwy_dict_get_object(data, quark);
     g_assert(GWY_IS_FIELD(object));
     g_array_append_val(quarks, quark);
 
     quark = gwy_file_key_image_mask(id);
-    if (gwy_container_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
+    if (gwy_dict_gis_object(data, quark, &object) && GWY_IS_NIELD(object))
         g_array_append_val(quarks, quark);
 
     quark = gwy_file_key_image_picture(id);
-    if (gwy_container_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
+    if (gwy_dict_gis_object(data, quark, &object) && GWY_IS_FIELD(object))
         g_array_append_val(quarks, quark);
 }
 
@@ -289,20 +287,25 @@ apply_correction_to_one_image(ModuleArgs *args, GwyFile *data, gint id)
     GwyInterpolationType interp = gwy_params_get_enum(args->params, PARAM_INTERP);
     gboolean new_image = gwy_params_get_boolean(args->params, PARAM_NEW_IMAGE);
     gboolean distribute = gwy_params_get_boolean(args->params, PARAM_DISTRIBUTE);
-    GwyField *field = gwy_file_get_image(data, id), *mask = NULL, *show = NULL;
+    GwyField *field = gwy_file_get_image(data, id), *show = NULL;
+    GwyNield *mask = gwy_file_get_image_mask(data, id);
     gchar *title, *newtitle;
     gint newid;
 
     g_assert(GWY_IS_FIELD(field));
-    mask = gwy_file_get_image_mask(data, id);
-    gwy_container_gis_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), &show);
+    gwy_dict_gis_object(GWY_DICT(data), gwy_file_key_image_picture(id), &show);
 
     if (!new_image) {
         apply_drift(field, args->drift, interp);
         gwy_field_data_changed(field);
         if (mask) {
-            apply_drift(mask, args->drift, GWY_INTERPOLATION_ROUND);
-            gwy_field_data_changed(mask);
+            gint origxres = gwy_nield_get_xres(mask), origyres = gwy_nield_get_yres(mask);
+            GwyField *mask_field = gwy_field_new(origxres, origyres, origxres, origyres, FALSE);
+            gwy_field_fill_mask(mask_field, mask, 0.0, 1.0);
+            apply_drift(mask_field, args->drift, GWY_INTERPOLATION_ROUND);
+            gwy_nield_mark_by_threshold(mask, mask_field, 0.5, TRUE);
+            g_object_unref(mask_field);
+            gwy_nield_data_changed(mask);
         }
         if (show) {
             apply_drift(show, args->drift, interp);
@@ -331,14 +334,19 @@ apply_correction_to_one_image(ModuleArgs *args, GwyFile *data, gint id)
     gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
 
     if (mask) {
-        mask = gwy_field_copy(mask);
-        apply_drift(mask, args->drift, GWY_INTERPOLATION_ROUND);
+        gint origxres = gwy_nield_get_xres(mask), origyres = gwy_nield_get_yres(mask);
+        GwyField *mask_field = gwy_field_new(origxres, origyres, origxres, origyres, FALSE);
+        gwy_field_fill_mask(mask_field, mask, 0.0, 1.0);
+        apply_drift(mask_field, args->drift, GWY_INTERPOLATION_ROUND);
+        mask = gwy_field_new_nield_alike(mask_field);
+        gwy_nield_mark_by_threshold(mask, mask_field, 0.5, TRUE);
+        g_object_unref(mask_field);
         gwy_file_pass_image_mask(data, newid, mask);
     }
     if (show) {
         show = gwy_field_copy(show);
         apply_drift(show, args->drift, interp);
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), show);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
     }
 }
 
@@ -438,32 +446,28 @@ preview(gpointer user_data)
     execute(args);
     mask_process(args->mask, args->drift);
     gwy_field_data_changed(args->result);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
 static void
-mask_process(GwyField *maskfield, GwyLine *drift)
+mask_process(GwyNield *maskfield, GwyLine *drift)
 {
-    gint i, j, k, step, pos, xres, yres, w, from, to;
-    gdouble *mdata, *rdata;
+    gwy_nield_clear(maskfield);
 
-    gwy_field_clear(maskfield);
-    xres = gwy_field_get_xres(maskfield);
-    yres = gwy_field_get_yres(maskfield);
-
-    step = xres/10;
-    w = (xres + 3*PREVIEW_SIZE/4)/PREVIEW_SIZE;
+    gint xres = gwy_nield_get_xres(maskfield), yres = gwy_nield_get_yres(maskfield);
+    gint step = xres/10;
+    gint w = (xres + 3*PREVIEW_SIZE/4)/PREVIEW_SIZE;
     w = MAX(w, 1);
-    rdata = gwy_line_get_data(drift);
-    mdata = gwy_field_get_data(maskfield);
-    for (i = 0; i < yres; i++) {
-        for (j = -2*step - step/2; j <= xres + 2*step + step/2; j += step) {
-            pos = j + GWY_ROUND(gwy_line_rtoi(drift, rdata[i]));
-            from = MAX(0, pos - w/2);
-            to = MIN(pos + (w - w/2) - 1, xres-1);
-            for (k = from; k <= to; k++)
-                mdata[i*xres + k] = 1.0;
+    const gdouble *rdata = gwy_line_get_data_const(drift);
+    gint *mdata = gwy_nield_get_data(maskfield);
+    for (gint i = 0; i < yres; i++) {
+        for (gint j = -2*step - step/2; j <= xres + 2*step + step/2; j += step) {
+            gint pos = j + GWY_ROUND(gwy_line_rtoi(drift, rdata[i]));
+            gint from = MAX(0, pos - w/2);
+            gint to = MIN(pos + (w - w/2) - 1, xres-1);
+            for (gint k = from; k <= to; k++)
+                mdata[i*xres + k] = 1;
         }
     }
 }
@@ -567,40 +571,30 @@ calculate_correlation_scores(GwyField *field,
                              GwyField *scores,
                              GwyField *offsets)
 {
-    GwyField *dsuper;
-    GwyUnit *siunit;
-    gint xres, yres, rangeres;
-    gint maxoff, i, ii;
-    const gdouble *ds;
-    gdouble *sdata, *odata;
-    gdouble dx;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint maxoff = (gint)ceil(supersample*maxoffset);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    maxoff = (gint)ceil(supersample*maxoffset);
     xres *= supersample;
-    dsuper = gwy_field_new_resampled(field, xres, yres, interp);
+    GwyField *dsuper = gwy_field_new_resampled(field, xres, yres, interp);
     gwy_field_normalize_rows(dsuper);
 
-    rangeres = 2*range + 1;
-    ds = gwy_field_get_data_const(dsuper);
-    sdata = gwy_field_get_data(scores);
-    odata = gwy_field_get_data(offsets);
-    dx = gwy_field_get_dx(dsuper);
+    gint rangeres = 2*range + 1;
+    const gdouble *ds = gwy_field_get_data_const(dsuper);
+    gdouble *sdata = gwy_field_get_data(scores);
+    gdouble *odata = gwy_field_get_data(offsets);
+    gdouble dx = gwy_field_get_dx(dsuper);
 #ifdef _OPENMP
 #pragma omp parallel if (gwy_threads_are_enabled()) default(none) \
-            private(i,ii) \
             shared(odata,sdata,dsuper,range,rangeres,xres,yres,maxoff,ds,dx)
 #endif
     {
         gint ifrom = gwy_omp_chunk_start(yres), ito = gwy_omp_chunk_end(yres);
         gdouble *tmp = g_new(gdouble, 2*maxoff + 1);
 
-        for (i = ifrom; i < ito; i++) {
+        for (gint i = ifrom; i < ito; i++) {
             odata[i*rangeres + range] = 0.0;
             sdata[i*rangeres + range] = 1.0;
-            for (ii = i+1; ii <= i+range; ii++) {
+            for (gint ii = i+1; ii <= i+range; ii++) {
                 gdouble offset, score;
 
                 if (ii < yres)
@@ -621,8 +615,8 @@ calculate_correlation_scores(GwyField *field,
      * Delta_{i,j} = -Delta_{j,i}
      * w_{i,j} = w_{j,i}
      */
-    for (i = 0; i < yres; i++) {
-        for (ii = i-range; ii < i; ii++) {
+    for (gint i = 0; i < yres; i++) {
+        for (gint ii = i-range; ii < i; ii++) {
             gdouble offset, score;
 
             if (ii >= 0) {
@@ -645,7 +639,7 @@ calculate_correlation_scores(GwyField *field,
     gwy_field_set_xreal(offsets, gwy_field_itor(field, rangeres));
     gwy_field_set_xoffset(offsets, gwy_field_itor(field, -range - 0.5));
 
-    siunit = gwy_field_get_unit_xy(field);
+    GwyUnit *siunit = gwy_field_get_unit_xy(field);
     gwy_unit_assign(gwy_field_get_unit_xy(scores), siunit);
     gwy_unit_assign(gwy_field_get_unit_xy(offsets), siunit);
     gwy_unit_assign(gwy_field_get_unit_z(offsets), siunit);
