@@ -1,5 +1,5 @@
 /*
- *  $Id: dwt.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: dwt.c 29406 2026-01-29 22:51:34Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -116,7 +116,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         args.goodsize <<= 1;
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -188,7 +188,7 @@ execute(ModuleArgs *args)
 
     result = args->result = gwy_field_new_resampled(field, args->goodsize, args->goodsize, interp);
     if (!is_inverse)
-        gwy_field_add(result, -gwy_field_get_avg(result));
+        gwy_field_add(result, -gwy_field_mean(result));
 
     wtcoefs = gwy_line_new(1, 1.0, TRUE);
     wtcoefs = gwy_dwt_set_coefficients(wtcoefs, wavelet);
