@@ -1,6 +1,6 @@
 /*
- *  $Id: dwtanisotropy.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: dwtanisotropy.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *result;
+    GwyNield *result;
     /* Cached input image properties. */
     gint goodsize;
 } ModuleArgs;
@@ -55,7 +55,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("2D DWT anisotropy detection based on X/Y components ratio."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -119,7 +119,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         args.goodsize <<= 1;
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -127,11 +127,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
     execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -187,22 +185,19 @@ execute(ModuleArgs *args)
     gdouble ratio = gwy_params_get_double(args->params, PARAM_RATIO);
     gint limit = gwy_params_get_int(args->params, PARAM_LOWLIMIT);
     gint xres = gwy_field_get_xres(args->field);
-    GwyField *resampled, *mask;
-    GwyLine *wtcoefs;
 
-    resampled = gwy_field_new_resampled(args->field, args->goodsize, args->goodsize, interp);
-    gwy_field_add(resampled, -gwy_field_get_avg(resampled));
+    GwyField *resampled = gwy_field_new_resampled(args->field, args->goodsize, args->goodsize, interp);
+    gwy_field_add(resampled, -gwy_field_mean(resampled));
 
-    mask = args->result = gwy_field_new_alike(resampled, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
-
-    wtcoefs = gwy_line_new(1, 1.0, TRUE);
+    GwyNield *resmask = gwy_field_new_nield_alike(resampled);
+    GwyLine *wtcoefs = gwy_line_new(1, 1.0, TRUE);
     wtcoefs = gwy_dwt_set_coefficients(wtcoefs, wavelet);
-    gwy_field_dwt_mark_anisotropy(resampled, mask, wtcoefs, ratio, (1u << limit));
+    gwy_field_dwt_mark_anisotropy(resampled, resmask, wtcoefs, ratio, (1u << limit));
     g_object_unref(wtcoefs);
     g_object_unref(resampled);
 
-    gwy_field_resample(mask, xres, xres, GWY_INTERPOLATION_ROUND);
+    args->result = gwy_nield_new_resampled(resmask, xres, xres);
+    g_object_unref(resmask);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
