@@ -1,5 +1,5 @@
 /*
- *  $Id: edge.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: edge.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -194,11 +194,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(dfield && dquark && squark);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
     if (!showfield) {
         showfield = gwy_field_new_alike(dfield, FALSE);
         gwy_unit_clear(gwy_field_get_unit_z(showfield));
-        gwy_container_pass_object(GWY_CONTAINER(data), squark, showfield);
+        gwy_dict_pass_object(GWY_DICT(data), squark, showfield);
     }
 
     for (i = 0; i < G_N_ELEMENTS(functions); i++) {
@@ -326,16 +326,14 @@ nonlinearity_do(GwyField *dfield, GwyField *show)
     qx = gwy_field_get_dx(dfield);
     qy = gwy_field_get_dx(dfield);
 
-    size = gwy_field_get_circular_area_size(r);
+    size = gwy_circular_area_size(r);
     z = g_new(gdouble, size);
     xp = g_new(gint, 2*size);
     yp = xp + size;
     for (i = 0; i < yres; i++) {
         for (j = 0; j < xres; j++) {
+            gint n = gwy_field_circular_area_extract(dfield, j, i, r, z, xp, yp);
             gdouble bx, by, s0r;
-            gint n;
-
-            n = gwy_field_circular_area_extract_with_pos(dfield, j, i, r, z, xp, yp);
             s0r = fit_local_plane_by_pos(n, xp, yp, z, &bx, &by);
             bx /= qx;
             by /= qy;
@@ -361,16 +359,14 @@ inclination_do(GwyField *dfield, GwyField *show)
     qx = gwy_field_get_dx(dfield);
     qy = gwy_field_get_dx(dfield);
 
-    size = gwy_field_get_circular_area_size(r);
+    size = gwy_circular_area_size(r);
     z = g_new(gdouble, size);
     xp = g_new(gint, 2*size);
     yp = xp + size;
     for (i = 0; i < yres; i++) {
         for (j = 0; j < xres; j++) {
+            gint n = gwy_field_circular_area_extract(dfield, j, i, r, z, xp, yp);
             gdouble bx, by;
-            gint n;
-
-            n = gwy_field_circular_area_extract_with_pos(dfield, j, i, r, z, xp, yp);
             fit_local_plane_by_pos(n, xp, yp, z, &bx, &by);
             bx /= qx;
             by /= qy;
@@ -392,13 +388,11 @@ step_do(GwyField *dfield, GwyField *show)
     yres = gwy_field_get_yres(dfield);
     d = gwy_field_get_data(show);
 
-    size = gwy_field_get_circular_area_size(r);
+    size = gwy_circular_area_size(r);
     z = g_new(gdouble, size);
     for (i = 0; i < yres; i++) {
         for (j = 0; j < xres; j++) {
-            gint n;
-
-            n = gwy_field_circular_area_extract(dfield, j, i, r, z);
+            gint n = gwy_field_circular_area_extract(dfield, j, i, r, z, NULL, NULL);
             gwy_math_sort(z, n);
             d[i*xres + j] = sqrt(z[n-1 - n/3] - z[n/3]);
         }
