@@ -1,5 +1,5 @@
 /*
- *  $Id: extend.c 28844 2025-11-10 16:07:51Z yeti-dn $
+ *  $Id: extend.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -76,7 +76,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extends image by adding borders."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2012",
 };
@@ -101,9 +101,9 @@ static GwyParamDef*
 define_module_params(void)
 {
     static const GwyEnum exteriors[] = {
-        { N_("Mean"),              GWY_EXTERIOR_FIXED_VALUE,   },
-        { gwy_NC("exterior", "Border"),   GWY_EXTERIOR_BORDER, },
-        { gwy_NC("exterior", "Mirror"),   GWY_EXTERIOR_MIRROR, },
+        { N_("Mean"),                     GWY_EXTERIOR_FIXED_VALUE,   },
+        { gwy_NC("exterior", "Border"),   GWY_EXTERIOR_BORDER,        },
+        { gwy_NC("exterior", "Mirror"),   GWY_EXTERIOR_MIRROR,        },
         { gwy_NC("exterior", "Periodic"), GWY_EXTERIOR_PERIODIC,      },
         { gwy_NC("exterior", "Laplace"),  GWY_EXTERIOR_LAPLACE,       },
     };
@@ -131,33 +131,33 @@ define_module_params(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *fields[3], *result;
+    GwyField *field, *show, *result;
+    GwyNield *mask;
     GQuark quarks[3];
     GwyParams *params;
     ModuleArgs args;
     GwyDialogOutcome outcome = GWY_DIALOG_PROCEED;
-    gint n, id, newid, up, down, left, right, exterior;
-    gboolean new_channel, keep_offsets;
+    gint n, id, newid;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear1(args);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_SHOW_FIELD, &show,
                                  GWY_APP_FIELD_KEY, quarks + 0,
                                  GWY_APP_MASK_FIELD_KEY, quarks + 1,
                                  GWY_APP_SHOW_FIELD_KEY, quarks + 2,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(fields[0]);
+    g_return_if_fail(field);
 
-    args.field = fields[0];
+    args.field = field;
     args.xres = gwy_field_get_xres(args.field);
     args.yres = gwy_field_get_yres(args.field);
     args.params = params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         args.result = gwy_field_copy(args.field);
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
@@ -165,41 +165,31 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             goto end;
     }
 
-    up = gwy_params_get_int(params, PARAM_UP);
-    down = gwy_params_get_int(params, PARAM_DOWN);
-    left = gwy_params_get_int(params, PARAM_LEFT);
-    right = gwy_params_get_int(params, PARAM_RIGHT);
-    exterior = gwy_params_get_int(params, PARAM_EXTERIOR);
-    new_channel = gwy_params_get_boolean(params, PARAM_NEW_CHANNEL);
-    keep_offsets = gwy_params_get_boolean(params, PARAM_KEEP_OFFSETS);
+    gint up = gwy_params_get_int(params, PARAM_UP);
+    gint down = gwy_params_get_int(params, PARAM_DOWN);
+    gint left = gwy_params_get_int(params, PARAM_LEFT);
+    gint right = gwy_params_get_int(params, PARAM_RIGHT);
+    gint exterior = gwy_params_get_int(params, PARAM_EXTERIOR);
+    gboolean new_channel = gwy_params_get_boolean(params, PARAM_NEW_CHANNEL);
+    gboolean keep_offsets = gwy_params_get_boolean(params, PARAM_KEEP_OFFSETS);
 
     if (!new_channel) {
-        n = 1;
-        if (fields[1]) {
-            n++;
-            if (fields[2])
-                n++;
-        }
-        else if (fields[2]) {
-            quarks[1] = quarks[2];
-            quarks[2] = 0;
-            n++;
-        }
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), n, quarks);
+        quarks[1] *= !!mask;
+        quarks[2] *= !!show;
+        n = gwy_compactify_quarks(quarks, 3);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), n, quarks);
     }
 
     if (outcome == GWY_DIALOG_HAVE_RESULT) {
         result = args.result;
         args.result = NULL;
     }
-    else {
-        result = gwy_field_extend(fields[0], left, right, up, down, exterior, gwy_field_get_avg(fields[0]),
-                                  keep_offsets);
-    }
+    else
+        result = gwy_field_extend(field, left, right, up, down, exterior, gwy_field_mean(field), keep_offsets);
 
     if (!new_channel) {
-        gwy_field_assign(fields[0], result);
-        gwy_field_data_changed(fields[0]);
+        gwy_field_assign(field, result);
+        gwy_field_data_changed(field);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
     else {
@@ -215,41 +205,29 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
     g_object_unref(result);
 
-    if (fields[1]) {
+    if (mask) {
         /* Do not apply Laplace interpolation to masks, it makes no sense. */
-        GwyExteriorType mask_exterior = (exterior == GWY_EXTERIOR_LAPLACE ? GWY_EXTERIOR_FIXED_VALUE : exterior);
-        gdouble fill_value = 0.0;
+        gint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
+        GwyExteriorType mask_exterior = exterior;
+        if (exterior == GWY_EXTERIOR_LAPLACE || exterior == GWY_EXTERIOR_CONNECT)
+            mask_exterior = GWY_EXTERIOR_FIXED_VALUE;
 
         /* Set fill_value to 1 for fields that are mostly masked, 0 for fields that are mostly unmasked. */
-        if (mask_exterior == GWY_EXTERIOR_FIXED_VALUE) {
-            guint n_unmasked, xres, yres;
+        gdouble fill_value = (mask_exterior == GWY_EXTERIOR_FIXED_VALUE ? gwy_nield_count(mask) > 0.5*xres*yres : 0);
 
-            xres = gwy_field_get_xres(fields[1]);
-            yres = gwy_field_get_yres(fields[1]);
-            gwy_field_area_count_in_range(fields[1], NULL, GWY_MASK_IGNORE,
-                                          0, 0, xres, yres, 0.0, 0.0, &n_unmasked, NULL);
-            fill_value = (n_unmasked > 0.5*xres*yres);
-        }
-        result = gwy_field_extend(fields[1], left, right, up, down, mask_exterior, fill_value, keep_offsets);
-        if (!new_channel) {
-            gwy_field_assign(fields[1], result);
-            gwy_field_data_changed(fields[1]);
-        }
-        else {
-            gwy_file_set_image_mask(data, newid, result);
-        }
-        g_object_unref(result);
+        mask = gwy_nield_extend(mask, left, right, up, down, mask_exterior, fill_value);
+        gwy_nield_number_contiguous(mask);
+        gwy_file_pass_image_mask(data, new_channel ? newid : id, mask);
     }
 
-    if (fields[2]) {
-        result = gwy_field_extend(fields[2], left, right, up, down, exterior, gwy_field_get_avg(fields[2]),
-                                  keep_offsets);
+    if (show) {
+        result = gwy_field_extend(show, left, right, up, down, exterior, gwy_field_mean(show), keep_offsets);
         if (!new_channel) {
-            gwy_field_assign(fields[2], result);
-            gwy_field_data_changed(fields[2]);
+            gwy_field_assign(show, result);
+            gwy_field_data_changed(show);
         }
         else {
-            gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), result);
+            gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_picture(newid), result);
         }
         g_object_unref(result);
     }
@@ -370,7 +348,7 @@ preview(gpointer user_data)
     GwyExteriorType exterior = gwy_params_get_int(params, PARAM_EXTERIOR);
     gboolean keep_offsets = gwy_params_get_boolean(params, PARAM_KEEP_OFFSETS);
 
-    result = gwy_field_extend(field, left, right, up, down, exterior, gwy_field_get_avg(field), keep_offsets);
+    result = gwy_field_extend(field, left, right, up, down, exterior, gwy_field_mean(field), keep_offsets);
     gwy_field_assign(args->result, result);
     g_object_unref(result);
     gwy_field_data_changed(args->result);
