@@ -1,5 +1,5 @@
 /*
- *  $Id: extract_path.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: extract_path.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -116,10 +116,10 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    gwy_container_gis_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "path"), &args.selection);
-    gwy_container_gis_boolean(GWY_CONTAINER(data), gwy_file_key_image_real_square(id), &args.realsquare);
+    gwy_dict_gis_object(GWY_DICT(data), gwy_file_key_image_selection(id, "path"), &args.selection);
+    gwy_dict_gis_boolean(GWY_DICT(data), gwy_file_key_image_real_square(id), &args.realsquare);
 
-    if (mode ==GWY_RUN_IMMEDIATE) {
+    if (mode == GWY_RUN_IMMEDIATE) {
         if (!args.selection)
             goto end;
     }
