@@ -1,6 +1,6 @@
 /*
- *  $Id: facet-level.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: facet-level.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
 } ModuleArgs;
 
@@ -47,7 +47,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Automatic facet-orientation based leveling. Levels data to make facets point up."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -111,7 +111,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (!execute(&args, gwy_data_browser_get_window_for_data(data, GWY_FILE_IMAGE, id)))
         goto end;
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_field_copy_data(args.result, args.field);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     gwy_field_data_changed(args.field);
@@ -140,7 +140,8 @@ run_gui(ModuleArgs *args)
 static gboolean
 execute(ModuleArgs *args, GtkWindow *window)
 {
-    GwyField *mask = args->mask, *result = args->result;
+    GwyField *result = args->result;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     gboolean ok;
 
