@@ -1,6 +1,6 @@
 /*
- *  $Id: facet_analysis.c 29089 2026-01-06 15:19:51Z yeti-dn $
- *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
+ *  $Id: facet_analysis.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -111,10 +111,10 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *theta;
     GwyField *phi;
-    GwyField *result;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -124,7 +124,7 @@ typedef struct {
     GtkWidget *view;
     GtkWidget *fview;
     GwyField *dist;
-    GwyField *mask;
+    GwyNield *mask;
     GwyNullStore *store;
     GwyParamTable *table_list;
     GwyParamTable *table_facets;
@@ -221,7 +221,7 @@ static void             gwy_field_mark_facets         (GwyField *dtheta,
                                                        gdouble theta0,
                                                        gdouble phi0,
                                                        gdouble tolerance,
-                                                       GwyField *mask);
+                                                       GwyNield *mask);
 static void             calculate_average_angle       (GwyField *dtheta,
                                                        GwyField *dphi,
                                                        gdouble theta0,
@@ -231,7 +231,7 @@ static void             calculate_average_angle       (GwyField *dtheta,
                                                        gdouble *phi);
 static gdouble          calc_facet_distribution       (ModuleArgs *args,
                                                        GwyField *dist);
-static void             mark_fdata                    (GwyField *mask,
+static void             mark_fdata                    (GwyNield *mask,
                                                        gdouble q,
                                                        gdouble theta0,
                                                        gdouble phi0,
@@ -267,7 +267,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Visualizes, marks and measures facet orientation."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "4.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
@@ -361,10 +361,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (!gwy_require_image_same_units(args.field, data, id, _("Facet Analysis")))
         return;
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
-    args.theta = gwy_field_new_alike(args.result, FALSE);
-    args.phi = gwy_field_new_alike(args.result, FALSE);
+    args.result = gwy_field_new_nield_alike(args.field);
+    args.theta = gwy_field_new_alike(args.field, FALSE);
+    args.phi = gwy_field_new_alike(args.field, FALSE);
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
@@ -383,11 +382,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             execute(&args);
     }
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
     gwy_params_save_to_settings(args.params);
@@ -458,7 +455,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 4);
 
     gui.dist = make_fdist_field(args->field);
-    gui.mask = gwy_field_new_alike(gui.dist, TRUE);
+    gui.mask = gwy_field_new_nield_alike(gui.dist);
     gui.fview = gwy_create_preview(gui.dist, gui.mask, FACETVIEW_SIZE);
     gwy_data_view_set_gradient(GWY_DATA_VIEW(gui.fview), gwy_gradients_get_gradient(FVIEW_GRADIENT));
     gwy_data_view_set_mask_color(GWY_DATA_VIEW(gui.fview), &facet_mask_color);
@@ -509,15 +506,11 @@ execute(ModuleArgs *args)
     gdouble tolerance = gwy_params_get_double(params, PARAM_TOLERANCE);
     gboolean combine = gwy_params_get_boolean(params, PARAM_COMBINE);
     GwyMergeType combine_type = gwy_params_get_enum(params, PARAM_COMBINE_TYPE);
-    GwyField *result = args->result, *mask = args->mask;
+    GwyNield *result = args->result, *mask = args->mask;
 
     gwy_field_mark_facets(args->theta, args->phi, theta0, phi0, tolerance, result);
-    if (mask && combine) {
-        if (combine_type == GWY_MERGE_UNION)
-            gwy_field_grains_add(result, mask);
-        else if (combine_type == GWY_MERGE_INTERSECTION)
-            gwy_field_grains_intersect(result, mask);
-    }
+    if (combine)
+        gwy_nield_merge(result, mask, combine_type);
 }
 
 static GtkWidget*
@@ -778,7 +771,7 @@ param_changed(ModuleGUI *gui, gint id)
         gdouble xy[2];
 
         gui->did_init = TRUE;
-        if (gwy_container_gis_object(GWY_CONTAINER(data), gui->selkey, &sel)
+        if (gwy_dict_gis_object(GWY_DICT(data), gui->selkey, &sel)
             && gwy_selection_get_object(sel, 0, xy) > 0)
             slopes_to_angles(xy[0], xy[1], &theta, &phi);
         /* XXX: recursion? */
@@ -833,7 +826,7 @@ save_facet_selection(ModuleGUI *gui)
     gdouble theta, phi, xy[2];
 
     if (!gwy_selection_get_data(gui->fselection, NULL)) {
-        gwy_container_remove(GWY_CONTAINER(gui->args_data), gui->selkey);
+        gwy_dict_remove(GWY_DICT(gui->args_data), gui->selkey);
         return;
     }
 
@@ -844,7 +837,7 @@ save_facet_selection(ModuleGUI *gui)
     selection = gwy_selection_point_new();
     gwy_selection_set_max_objects(selection, 1);
     gwy_selection_set_data(selection, 1, xy);
-    gwy_container_pass_object(GWY_CONTAINER(gui->args_data), gui->selkey, selection);
+    gwy_dict_pass_object(GWY_DICT(gui->args_data), gui->selkey, selection);
 }
 
 static void
@@ -1037,7 +1030,7 @@ mark_facet(ModuleGUI *gui)
     gwy_params_set_double(args->params, PARAM_PHI0, phi);
 
     execute(args);
-    gwy_field_data_changed(args->result);
+    gwy_nield_data_changed(args->result);
     mark_fdata(gui->mask, gui->q, theta, phi, tolerance);
     update_average_angle(gui, FALSE);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
@@ -1107,8 +1100,8 @@ recalculate_distribution(ModuleGUI *gui)
         gwy_app_wait_cursor_start(GTK_WINDOW(gui->dialog));
     gui->q = calc_facet_distribution(args, gui->dist);
 
-    gwy_field_clear(gui->mask);
-    gwy_field_data_changed(gui->mask);
+    gwy_nield_clear(gui->mask);
+    gwy_nield_data_changed(gui->mask);
     gwy_field_data_changed(gui->dist);
     update_theta_range(gui);
 
@@ -1249,27 +1242,20 @@ gwy_field_mark_facets(GwyField *dtheta,
                       gdouble theta0,
                       gdouble phi0,
                       gdouble tolerance,
-                      GwyField *mask)
+                      GwyNield *mask)
 {
-    gdouble cr, cth0, sth0;
-    const gdouble *td, *fd;
-    gdouble *md;
-    guint i, n;
-
-    cr = cos(tolerance);
-    cth0 = cos(theta0);
-    sth0 = sin(theta0);
-
-    td = gwy_field_get_data_const(dtheta);
-    fd = gwy_field_get_data_const(dphi);
-    md = gwy_field_get_data(mask);
-    n = gwy_field_get_xres(dtheta)*gwy_field_get_yres(dtheta);
+    gdouble cr = cos(tolerance);
+    gdouble cth0 = cos(theta0);
+    gdouble sth0 = sin(theta0);
+    const gdouble *td = gwy_field_get_data_const(dtheta);
+    const gdouble *fd = gwy_field_get_data_const(dphi);
+    gint *md = gwy_nield_get_data(mask);
+    gsize n = gwy_field_get_xres(dtheta)*gwy_field_get_yres(dtheta);
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(td,fd,md,n,cth0,sth0,phi0,cr)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gsize i = 0; i < n; i++) {
         gdouble cro = cth0*cos(td[i]) + sth0*sin(td[i])*cos(fd[i] - phi0);
         md[i] = (cro >= cr);
     }
@@ -1280,28 +1266,21 @@ calculate_average_angle(GwyField *dtheta, GwyField *dphi,
                         gdouble theta0, gdouble phi0, gdouble tolerance,
                         gdouble *theta, gdouble *phi)
 {
-    gdouble sx, sy, sz, cth0, sth0, ctol;
-    const gdouble *td, *pd;
-    gint i, n, count;
-    GwyXYZ s;
-
-    cth0 = cos(theta0);
-    sth0 = sin(theta0);
-    ctol = cos(tolerance);
-
-    td = gwy_field_get_data_const(dtheta);
-    pd = gwy_field_get_data_const(dphi);
-    n = gwy_field_get_xres(dtheta)*gwy_field_get_yres(dtheta);
-    count = 0;
-    sx = sy = sz = 0.0;
+    gdouble ctol = cos(tolerance);
+    gdouble cth0 = cos(theta0);
+    gdouble sth0 = sin(theta0);
+    const gdouble *td = gwy_field_get_data_const(dtheta);
+    const gdouble *pd = gwy_field_get_data_const(dphi);
+    gsize n = gwy_field_get_xres(dtheta)*gwy_field_get_yres(dtheta);
+    gsize count = 0;
+    gdouble sx = 0.0, sy = 0.0, sz = 0.0;
 
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
             reduction(+:count,sx,sy,sz) \
-            private(i) \
             shared(td,pd,n,cth0,sth0,phi0,ctol)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gsize i = 0; i < n; i++) {
         gdouble cro = cth0*cos(td[i]) + sth0*sin(td[i]) * cos(pd[i] - phi0);
         if (cro >= ctol) {
             GwyXYZ v;
@@ -1313,33 +1292,28 @@ calculate_average_angle(GwyField *dtheta, GwyField *dphi,
             count++;
         }
     }
-    s.x = sx;
-    s.y = sy;
-    s.z = sz;
 
-    if (!count)
-        *theta = *phi = 0.0;
+    if (count)
+        vector_angles(&(GwyXYZ){ sx, sy, sz }, theta, phi);
     else
-        vector_angles(&s, theta, phi);
+        *theta = *phi = 0.0;
 }
 
 static gdouble
 calc_facet_distribution(ModuleArgs *args, GwyField *dist)
 {
     gint kernel_size = gwy_params_get_int(args->params, PARAM_KERNEL_SIZE);
-    gint i, fres = gwy_field_get_xres(dist);
-    gdouble *d;
+    gint fres = gwy_field_get_xres(dist);
 
     gwy_field_facet_distribution(args->field, dist, (fres - 1)/2, 2*kernel_size+1, args->theta, args->phi);
 
     /* Transform values for visualisation. */
-    d = gwy_field_get_data(dist);
+    gdouble *d = gwy_field_get_data(dist);
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(d,fres)
 #endif
-    for (i = 0; i < fres*fres; i++)
+    for (gint i = 0; i < fres*fres; i++)
         d[i] = cbrt(d[i]);
 
     return 0.5*gwy_field_get_xreal(dist);
@@ -1523,31 +1497,26 @@ reset_rotation(ModuleGUI *gui)
 }
 
 static void
-mark_fdata(GwyField *mask, gdouble q, gdouble theta0, gdouble phi0, gdouble tolerance)
+mark_fdata(GwyNield *mask, gdouble q, gdouble theta0, gdouble phi0, gdouble tolerance)
 {
-    gdouble r, r2, cr, cro, cth0, sth0, cphi0, sphi0;
-    gint fres, hres, i, j;
-    gdouble *m;
-
-    cr = cos(tolerance);
-    cth0 = cos(theta0);
-    sth0 = sin(theta0);
-    cphi0 = cos(phi0);
-    sphi0 = sin(phi0);
-    fres = gwy_field_get_xres(mask);
-    g_assert(gwy_field_get_yres(mask) == fres);
-    hres = (fres - 1)/2;
-    m = gwy_field_get_data(mask);
+    gdouble cr = cos(tolerance);
+    gdouble cth0 = cos(theta0);
+    gdouble sth0 = sin(theta0);
+    gdouble cphi0 = cos(phi0);
+    gdouble sphi0 = sin(phi0);
+    gint fres = gwy_nield_get_xres(mask);
+    g_assert(gwy_nield_get_yres(mask) == fres);
+    gint hres = (fres - 1)/2;
+    gint *m = gwy_nield_get_data(mask);
 
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i,j,r2,r,cro) \
             shared(m,fres,hres,cth0,sth0,cphi0,sphi0,q,cr)
 #endif
-    for (i = 0; i < fres; i++) {
+    for (gint i = 0; i < fres; i++) {
         gdouble y = -q*(i/(gdouble)hres - 1.0);
 
-        for (j = 0; j < fres; j++) {
+        for (gint j = 0; j < fres; j++) {
             gdouble x = q*(j/(gdouble)hres - 1.0);
 
             /**
@@ -1558,9 +1527,9 @@ mark_fdata(GwyField *mask, gdouble q, gdouble theta0, gdouble phi0, gdouble tole
              * sin(phi) = y/r
              * where r = hypot(x, y)
              **/
-            r2 = x*x + y*y;
-            r = sqrt(r2);
-            cro = cth0*(1.0 - r2) + sth0*G_SQRT2*r*sqrt(1.0 - r2/2.0)*(x/r*cphi0 + y/r*sphi0);
+            gdouble r2 = x*x + y*y;
+            gdouble r = sqrt(r2);
+            gdouble cro = cth0*(1.0 - r2) + sth0*G_SQRT2*r*sqrt(1.0 - r2/2.0)*(x/r*cphi0 + y/r*sphi0);
             m[i*fres + j] = (cro >= cr);
         }
     }
