@@ -1,5 +1,5 @@
 /*
- *  $Id: fft.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: fft.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -143,7 +143,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     gwy_data_browser_get_current(GWY_APP_FIELD, &field,
                                  GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &datano,
+                                 GWY_APP_FILE_ID, &datano,
                                  0);
     g_return_if_fail(field);
 
@@ -151,7 +151,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -231,28 +231,22 @@ create_output(GwyFile *data, gint id, GwyField *field, const gchar *output_name,
     /* make fft more visible by choosing a good gradient and using auto range */
     gwy_file_set_palette(data, GWY_FILE_IMAGE, newid, "DFit");
     if (!is_phase)
-        gwy_container_set_enum(GWY_CONTAINER(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_AUTO);
+        gwy_dict_set_enum(GWY_DICT(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_AUTO);
 }
 
 static GwyField*
 make_modulus(GwyField *re, GwyField *im)
 {
-    GwyField *modulus;
-    const gdouble *datare, *dataim;
-    gdouble *data;
-    guint n, i;
-
-    modulus = gwy_field_new_alike(re, FALSE);
-    n = gwy_field_get_xres(re)*gwy_field_get_yres(re);
-    datare = gwy_field_get_data_const(re);
-    dataim = gwy_field_get_data_const(im);
-    data = gwy_field_get_data(modulus);
+    GwyField *modulus = gwy_field_new_alike(re, FALSE);
+    gsize n = gwy_field_get_xres(re)*gwy_field_get_yres(re);
+    const gdouble *datare = gwy_field_get_data_const(re);
+    const gdouble *dataim = gwy_field_get_data_const(im);
+    gdouble *data = gwy_field_get_data(modulus);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(data,datare,dataim,n) \
-            private(i)
+            shared(data,datare,dataim,n)
 #endif
-    for (i = 0; i < n; i++)
+    for (gsize i = 0; i < n; i++)
         data[i] = sqrt(datare[i]*datare[i] + dataim[i]*dataim[i]);
 
     return modulus;
@@ -261,22 +255,17 @@ make_modulus(GwyField *re, GwyField *im)
 static GwyField*
 make_phase(GwyField *re, GwyField *im)
 {
-    GwyField *phase;
-    const gdouble *datare, *dataim;
-    gdouble *data;
-    guint n, i;
-
-    phase = gwy_field_new_alike(re, FALSE);
+    GwyField *phase = gwy_field_new_alike(re, FALSE);
     gwy_unit_clear(gwy_field_get_unit_z(phase));
-    n = gwy_field_get_xres(re)*gwy_field_get_yres(re);
-    datare = gwy_field_get_data_const(re);
-    dataim = gwy_field_get_data_const(im);
-    data = gwy_field_get_data(phase);
+    gsize n = gwy_field_get_xres(re)*gwy_field_get_yres(re);
+    const gdouble *datare = gwy_field_get_data_const(re);
+    const gdouble *dataim = gwy_field_get_data_const(im);
+    gdouble *data = gwy_field_get_data(phase);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(data,datare,dataim,n) private(i)
+            shared(data,datare,dataim,n)
 #endif
-    for (i = 0; i < n; i++)
+    for (gsize i = 0; i < n; i++)
         data[i] = atan2(dataim[i], datare[i]);
 
     return phase;
