@@ -1,8 +1,8 @@
 /*
- *  $Id: fft_filter_2d.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: fft_filter_2d.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2005 Christopher Anderson, Molecular Imaging Corp.
  *  E-mail: Chris Anderson (sidewinder.asu@gmail.com)
- *  Copyright (C) 2011-2025 David Necas (Yeti).
+ *  Copyright (C) 2011-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -72,7 +72,7 @@ typedef enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyField *diff;
     GwyField *filtered_modulus;
@@ -81,7 +81,7 @@ typedef struct {
 typedef struct {
     ModuleArgs *args;
     GwyField *modulus;
-    GwyField *prev_mask;
+    GwyNield *prev_mask;
     gboolean has_undo;
 
     GwyFile *data;
@@ -117,6 +117,8 @@ static void             switch_layer           (ModuleGUI *gui);
 static void             calculate_zoomed_fields(ModuleGUI *gui);
 static GwyField*        cut_field_to_zoom      (GwyField *field,
                                                 gint zoom);
+static GwyNield*        cut_nield_to_zoom      (GwyNield *field,
+                                                gint zoom);
 static void             calculate_modulus      (GwyField *field,
                                                 GwyField *fftmod);
 static gint             add_output_field       (GwyFile *data,
@@ -129,7 +131,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("2D FFT Filtering"),
     "Chris Anderson <sidewinder.asu@gmail.com>",
-    "2.0",
+    "2.1",
     "Chris Anderson, Molecular Imaging Corp.",
     "2005",
 };
@@ -211,8 +213,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new_alike(args.field, FALSE);
     args.diff = gwy_field_new_alike(args.field, FALSE);
     args.filtered_modulus = gwy_field_new_alike(args.field, FALSE);
-    args.mask = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.mask));
+    args.mask = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     GwyDialogOutcome outcome = run_gui(&args, data, id);
@@ -435,9 +436,9 @@ static void
 record_undo(ModuleGUI *gui)
 {
     if (!gui->prev_mask)
-        gui->prev_mask = gwy_field_copy(gui->args->mask);
+        gui->prev_mask = gwy_nield_copy(gui->args->mask);
     else
-        gwy_field_copy_data(gui->args->mask, gui->prev_mask);
+        gwy_nield_copy_data(gui->args->mask, gui->prev_mask);
     gui->has_undo = TRUE;
 }
 
@@ -450,7 +451,8 @@ selection_finished(GwySelection *selection, ModuleGUI *gui)
 
     ModuleArgs *args = gui->args;
     GwyDataView *dataview = GWY_DATA_VIEW(gui->view);
-    GwyField *modulus = gui->modulus, *mask = args->mask;
+    GwyField *modulus = gui->modulus;
+    GwyNield *mask = args->mask;
     GwyField *zoomed = gwy_data_view_get_field(dataview);
     EditType mode = gwy_params_get_enum(args->params, PARAM_EDIT_MODE);
     gboolean snap = gwy_params_get_boolean(args->params, PARAM_SNAP);
@@ -493,19 +495,19 @@ selection_finished(GwySelection *selection, ModuleGUI *gui)
     mirror[2] -= mirror[0];
     mirror[3] -= mirror[1];
 
-    gdouble value = 1.0;
+    gdouble value = 1;
     if (mode == FFT_RECTANGLE_SUB || mode == FFT_ELLIPSE_SUB)
-        value = 0.0;
+        value = 0;
 
     /* Apply change to mask and queue recomputation. */
     record_undo(gui);
     if (mode == FFT_ELLIPSE_ADD || mode == FFT_ELLIPSE_SUB) {
-        gwy_field_elliptic_area_fill(mask, isel[0], isel[1], isel[2], isel[3], value);
-        gwy_field_elliptic_area_fill(mask, mirror[0], mirror[1], mirror[2], mirror[3], value);
+        gwy_nield_elliptic_area_fill(mask, isel[0], isel[1], isel[2], isel[3], value);
+        gwy_nield_elliptic_area_fill(mask, mirror[0], mirror[1], mirror[2], mirror[3], value);
     }
     else {
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, isel[0], isel[1], isel[2], isel[3], value);
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, mirror[0], mirror[1], mirror[2], mirror[3], value);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, isel[0], isel[1], isel[2], isel[3], value);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, mirror[0], mirror[1], mirror[2], mirror[3], value);
     }
     gwy_selection_clear(selection);
 
@@ -521,8 +523,8 @@ dialog_response(ModuleGUI *gui, gint response)
 
     if (response == RESPONSE_UNDO) {
         if (gui->has_undo) {
-            gwy_field_copy_data(gui->prev_mask, args->mask);
-            gwy_field_data_changed(args->mask);
+            gwy_nield_copy_data(gui->prev_mask, args->mask);
+            gwy_nield_data_changed(args->mask);
             gui->has_undo = FALSE;
             if (gwy_params_get_enum(gui->args->params, PARAM_DISPLAY) == PREVIEW_FFT)
                 calculate_zoomed_fields(gui);
@@ -535,12 +537,12 @@ dialog_response(ModuleGUI *gui, gint response)
         record_undo(gui);
         /* Compute the results trivially here. No need to queue FFT. */
         if (response == GWY_RESPONSE_CLEAR) {
-            gwy_field_clear(args->mask);
+            gwy_nield_clear(args->mask);
             gwy_field_assign(args->result, args->field);
             gwy_field_clear(args->diff);
         }
         else {
-            gwy_field_fill(args->mask, 1.0);
+            gwy_nield_fill(args->mask, 1);
             gwy_field_clear(args->result);
             gwy_field_assign(args->diff, args->field);
         }
@@ -557,6 +559,7 @@ execute(ModuleArgs *args)
     GwyField *r_in = args->result;
     GwyField *r_out = gwy_field_new_alike(r_in, FALSE);
     GwyField *i_out = gwy_field_new_alike(r_in, FALSE);
+    gint xres = gwy_field_get_xres(r_in), yres = gwy_field_get_yres(r_in);
     gwy_field_assign(r_in, args->field);
 
     gwy_field_fft_2d_raw(r_in, NULL, r_out, i_out, GWY_TRANSFORM_DIRECTION_FORWARD);
@@ -564,14 +567,15 @@ execute(ModuleArgs *args)
     /* Remember the filtered modulus in case someone wants it as an output. */
     gwy_field_hypot_of_fields(args->filtered_modulus, r_out, i_out);
     gwy_field_fft_postprocess(args->filtered_modulus, TRUE);
-    gwy_field_multiply_fields(args->filtered_modulus, args->filtered_modulus, args->mask);
+    gwy_field_area_fill(args->filtered_modulus, args->mask, GWY_MASK_EXCLUDE, 0, 0, xres, yres, 0.0);
 
-    /* Apply mask to the fft */
+    /* Apply mask to the fft. Filling unmasked with zero is a slightly involved way of saying ‘clear pixels which are
+     * not marked‘. */
     gwy_field_fft_2d_center(r_out);
     gwy_field_fft_2d_center(i_out);
 
-    gwy_field_multiply_fields(r_out, r_out, args->mask);
-    gwy_field_multiply_fields(i_out, i_out, args->mask);
+    gwy_field_area_fill(r_out, args->mask, GWY_MASK_EXCLUDE, 0, 0, xres, yres, 0.0);
+    gwy_field_area_fill(i_out, args->mask, GWY_MASK_EXCLUDE, 0, 0, xres, yres, 0.0);
 
     /* Run the inverse FFT */
     GwyField *i_in = gwy_field_new_alike(r_in, TRUE);
@@ -593,46 +597,62 @@ calculate_zoomed_fields(ModuleGUI *gui)
     ModuleArgs *args = gui->args;
     guint zoom = gwy_params_get_enum(args->params, PARAM_ZOOM);
     GwyDataView *dataview = GWY_DATA_VIEW(gui->view);
-    GwyField *zoomed;
 
-    zoomed = cut_field_to_zoom(gui->modulus, zoom);
+    GwyField *zoomed = cut_field_to_zoom(gui->modulus, zoom);
     gwy_field_data_changed(zoomed);
     gwy_data_view_set_field(dataview, zoomed);
     g_object_unref(zoomed);
 
-    zoomed = cut_field_to_zoom(args->mask, zoom);
-    gwy_field_data_changed(zoomed);
-    gwy_data_view_set_mask(dataview, zoomed);
-    g_object_unref(zoomed);
+    GwyNield* zoomedmask = cut_nield_to_zoom(args->mask, zoom);
+    gwy_nield_data_changed(zoomedmask);
+    gwy_data_view_set_mask(dataview, zoomedmask);
+    g_object_unref(zoomedmask);
 
     gwy_set_data_preview_size(dataview, PREVIEW_SIZE);
 }
 
-static GwyField*
-cut_field_to_zoom(GwyField *field, gint zoom)
+static gboolean
+calc_cut_to_zoom(gint xres, gint yres, gint zoom, gint *pwidth, gint *pheight)
 {
-    GwyField *zoomed;
-    guint xres, yres, width, height;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    width = (xres/zoom) | 1;
-    height = (yres/zoom) | 1;
+    gint width = (xres/zoom) | 1;
+    gint height = (yres/zoom) | 1;
     if (width < 17)
         width = MAX(width, MIN(17, xres));
     if (height < 17)
         height = MAX(height, MIN(17, yres));
 
-    if (width >= xres && height >= yres)
+    *pwidth = width;
+    *pheight = height;
+    return width >= xres && height >= yres;
+}
+
+static GwyField*
+cut_field_to_zoom(GwyField *field, gint zoom)
+{
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    guint width, height;
+
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
         return g_object_ref(field);
 
-    zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
+    GwyField *zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
     gwy_field_set_xoffset(zoomed, -0.5*gwy_field_get_xreal(zoomed));
     gwy_field_set_yoffset(zoomed, -0.5*gwy_field_get_yreal(zoomed));
 
     return zoomed;
 }
 
+static GwyNield*
+cut_nield_to_zoom(GwyNield *nield, gint zoom)
+{
+    gint xres = gwy_nield_get_xres(nield), yres = gwy_nield_get_yres(nield);
+    guint width, height;
+
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
+        return g_object_ref(nield);
+    return gwy_nield_area_extract(nield, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
+}
+
 /* This is the modulus we show in GUI (with windowing, etc.) */
 static void
 calculate_modulus(GwyField *field, GwyField *fftmod)
