@@ -1,6 +1,6 @@
 /*
- *  $Id: fit-shape.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2016-2025 David Necas (Yeti).
+ *  $Id: fit-shape.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2016-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -78,7 +78,7 @@ typedef struct {
     /* These are always what we display – when run with XYZ data they are just imge previews.  Conversely, a surface
      * is created for fitting even if the input is images. */
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyField *diff;
     GwySurface *surface;
@@ -189,7 +189,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fits predefined geometrical shapes to data."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti)",
     "2016",
 };
@@ -941,7 +941,8 @@ static void
 update_fields(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
-    GwyField *field = args->field, *result = args->result, *diff = args->diff, *mask = args->mask;
+    GwyField *field = args->field, *result = args->result, *diff = args->diff;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     gboolean diff_excluded = gwy_params_get_boolean(args->params, PARAM_DIFF_EXCLUDED);
     GwySurface *surface;
@@ -992,20 +993,20 @@ static void
 update_diff_gradient(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
-    GwyField *mask = args->mask, *diff = args->diff;
+    GwyNield *mask = args->mask;
+    GwyField *diff = args->diff;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     gboolean diff_excluded = gwy_params_get_boolean(args->params, PARAM_DIFF_EXCLUDED);
     gdouble min, max, dispmin, dispmax;
 
     if (!diff_excluded && mask) {
-        gint xres = gwy_field_get_xres(mask);
-        gint yres = gwy_field_get_yres(mask);
-        gwy_field_area_get_min_max(diff, mask, masking, 0, 0, xres, yres, &min, &max);
-        gwy_field_area_get_autorange(diff, mask, masking, 0, 0, xres, yres, &dispmin, &dispmax);
+        gint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
+        gwy_field_area_min_max(diff, mask, masking, 0, 0, xres, yres, &min, &max);
+        gwy_field_area_autorange(diff, mask, masking, 0, 0, xres, yres, &dispmin, &dispmax);
     }
     else {
-        gwy_field_get_min_max(diff, &min, &max);
-        gwy_field_get_autorange(diff, &dispmin, &dispmax);
+        gwy_field_min_max(diff, &min, &max);
+        gwy_field_autorange(diff, &dispmin, &dispmax);
     }
 
     gwy_set_gradient_for_residuals(gui->diff_gradient, min, max, &dispmin, &dispmax);
@@ -1086,12 +1087,14 @@ static void
 update_context_data(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
-    GwyField *mask = args->mask;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     FitShapeContext *ctx = gui->ctx;
 
-    if (args->data_kind == GWY_FILE_IMAGE)
-        gwy_surface_set_from_field_mask(args->surface, args->field, mask, masking);
+    if (args->data_kind == GWY_FILE_IMAGE) {
+        gwy_surface_set_from_field_area(args->surface, args->field, mask, masking,
+                                        0, 0, gwy_field_get_xres(args->field), gwy_field_get_yres(args->field));
+    }
 
     ctx->n = gwy_surface_get_npoints(args->surface);
     args->f = g_renew(gdouble, args->f, ctx->n);
@@ -1125,7 +1128,7 @@ calculate_field(GwyShapeFitPreset *preset, const gdouble *params,
 {
     GwySurface *surface = gwy_surface_new();
 
-    gwy_surface_set_from_field_mask(surface, field, NULL, GWY_MASK_IGNORE);
+    gwy_surface_set_from_field(surface, field);
     gwy_shape_fit_preset_calculate_z(preset,
                                      gwy_surface_get_data_const(surface),
                                      gwy_field_get_data(field),
