@@ -1,6 +1,6 @@
 /*
- *  $Id: fraccor.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  $Id: fraccor.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Removes data under mask using fractal interpolation."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.3",
+    "1.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -46,8 +46,7 @@ module_register(void)
                               GWY_ICON_FRACTAL_CORRECTION,
                               RUN_MODES,
                               GWY_MENU_FLAG_IMAGE_MASK | GWY_MENU_FLAG_IMAGE,
-                              N_("Interpolate data under mask with fractal "
-                                 "interpolation"));
+                              N_("Interpolate data under mask with fractal interpolation"));
 
     return TRUE;
 }
@@ -55,21 +54,22 @@ module_register(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfield, *mfield;
+    GwyField *field;
+    GwyNield *mask;
     GQuark dquark;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD_KEY, &dquark,
-                                 GWY_APP_FIELD, &dfield,
-                                 GWY_APP_MASK_FIELD, &mfield,
+                                 GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(dfield && dquark && mfield);
+    g_return_if_fail(field && dquark && mask);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
-    gwy_field_fractal_correction(dfield, mfield, GWY_INTERPOLATION_LINEAR);
-    gwy_field_data_changed(dfield);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
+    gwy_field_fractal_correction(field, mask, GWY_INTERPOLATION_LINEAR);
+    gwy_field_data_changed(field);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
