@@ -1,5 +1,5 @@
 /*
- *  $Id: freq_split.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: freq_split.c 29406 2026-01-29 22:51:34Z yeti-dn $
  *  Copyright (C) 2018-2024 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -177,7 +177,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.lowpass = gwy_field_new_alike(args.field, TRUE);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -411,7 +411,7 @@ extend_field_smconn(GwyField *field)
     if (extxres >= 3*xres || extyres >= 3*extyres) {
         /* This is a silly case.  We just do not want to hit the assertion in extend_one_row(). */
         return gwy_field_extend(field, 0, 0, extxres - xres, extyres - yres,
-                                GWY_EXTERIOR_FIXED_VALUE, gwy_field_get_avg(field), FALSE);
+                                GWY_EXTERIOR_FIXED_VALUE, gwy_field_mean(field), FALSE);
     }
 
     extfield = gwy_field_new(extxres, extyres, extxres*dx, extyres*dy, FALSE);
@@ -524,16 +524,14 @@ filter_frequencies(GwyField *refield, GwyField *imfield,
     gint yres = gwy_field_get_yres(refield);
     gdouble *re = gwy_field_get_data(refield);
     gdouble *im = gwy_field_get_data(imfield);
-    gint i, j;
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(re,im,xres,yres,cutoff,width)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gdouble fy = 2.0*MIN(i, yres-i)/yres;
-        for (j = 0; j < xres; j++) {
+        for (gint j = 0; j < xres; j++) {
             gdouble fx = 2.0*MIN(j, xres-j)/xres;
             gdouble q, f = sqrt(fx*fx + fy*fy);
 
