@@ -1,6 +1,6 @@
 /*
- *  $Id: good_profile.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2020-2021 David Necas (Yeti).
+ *  $Id: good_profile.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2020-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -48,7 +48,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGraphModel *gmodel;
 } ModuleArgs;
 
@@ -83,7 +83,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates good average row from one or multiple images of repeated scanning of the same feature."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "3.0",
     "David Nečas (Yeti)",
     "2020",
 };
@@ -147,6 +147,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
+    gwy_clear1(args);
     gwy_data_browser_get_current(GWY_APP_FIELD, &field,
                                  GWY_APP_FIELD_ID, &id,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
@@ -154,18 +155,15 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(field);
 
     args.field = field;
-    args.mask = NULL;
     args.gmodel = gwy_graph_model_new();
     gwy_graph_model_set_units_from_field(args.gmodel, field, 1, 0, 0, 1);
     args.params = params = gwy_params_new_from_settings(define_module_params());
     /* Avoid Laplace interpolation in execute() if we do not need it. */
-    if (mode ==GWY_RUN_INTERACTIVE || gwy_params_get_boolean(params, PARAM_CREATE_MASK)) {
-        args.mask = gwy_field_new_alike(field, TRUE);
-        gwy_unit_clear(gwy_field_get_unit_z(args.mask));
-    }
+    if (mode == GWY_RUN_INTERACTIVE || gwy_params_get_boolean(params, PARAM_CREATE_MASK))
+        args.mask = gwy_field_new_nield_alike(field);
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -179,6 +177,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_app_add_graph_or_curves(args.gmodel, data, &target_graph_id, 1);
 
     if (gwy_params_get_boolean(params, PARAM_CREATE_MASK)) {
+        gwy_nield_number_contiguous(args.mask);
         /* This is convoluted because the images may come from different files – and we have to create two separate
          * undo checkpoints then, one in each file. */
         if (gwy_params_get_enum(params, PARAM_MODE) == GOOD_PROF_MULTIPLE) {
@@ -187,19 +186,19 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             GQuark quarks[2] = { mquark, gwy_file_key_image_mask(other_image_id.id) };
 
             if (otherdata == data)
-                gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 2, quarks);
+                gwy_app_undo_qcheckpointv(GWY_DICT(data), 2, quarks);
             else {
-                gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, quarks);
-                gwy_app_undo_qcheckpointv(GWY_CONTAINER(otherdata), 1, quarks+1);
+                gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, quarks);
+                gwy_app_undo_qcheckpointv(GWY_DICT(otherdata), 1, quarks+1);
                 /* XXX: We should sync the mask colour, but only if the user has changed it.  Otherwise the second
                  * channel must be left alone. */
             }
-            field = gwy_field_copy(args.mask);
+            GwyNield *nield = gwy_nield_copy(args.mask);
             gwy_file_set_image_mask(data, id, args.mask);
-            gwy_file_pass_image(otherdata, other_image_id.id, field);
+            gwy_file_pass_image_mask(otherdata, other_image_id.id, nield);
         }
         else {
-            gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
+            gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
             gwy_file_set_image_mask(data, id, args.mask);
         }
     }
@@ -281,7 +280,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     if (outcome != GWY_DIALOG_CANCEL && gwy_params_get_boolean(args->params, PARAM_CREATE_MASK)) {
         GwyRGBA color = gwy_params_get_color(args->params, PARAM_MASK_COLOR);
-        gwy_container_set_boxed(GWY_CONTAINER(data), GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
+        gwy_dict_set_boxed(GWY_DICT(data), GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
     }
 
     gwy_value_format_free(gui.varvf);
@@ -349,36 +348,38 @@ preview(gpointer user_data)
     gchar *s;
 
     execute(args, &variation);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
     s = g_strdup_printf("%.*f", vf->precision, variation/vf->magnitude);
     gwy_param_table_info_set_valuestr(gui->table, INFO_VARIATION, s);
     g_free(s);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
-static void
-good_profile_do_single(GwyLine *profile, ModuleArgs *args)
+static GwyLine*
+good_profile_do_single(ModuleArgs *args)
 {
-    GwyField *ffield, *fmask = NULL, *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask, *fmask = NULL;
     gdouble trim_fraction = gwy_params_get_double(args->params, PARAM_TRIM_FRACTION);
     const gdouble *ddata, *drow;
-    gdouble *data, *mdata = NULL, *row, *mrow, *ldata, *low = NULL, *high = NULL;
-    gint xres, yres, ntrim, i, j, k[2];
+    gdouble *data, *row, *low = NULL, *high = NULL;
+    gint *mdata = NULL, *mrow;
+    gint ntrim, i, j, k[2];
     gdouble v[2];
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    ldata = gwy_line_get_data(profile);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    GwyLine *profile = gwy_line_new(xres, gwy_field_get_xreal(field), TRUE);
+    gdouble *ldata = gwy_line_get_data(profile);
 
-    /* Work with a flipped field because we process it by column.  Note
-     * that this means xres and yres have swapped meaning! */
-    ffield = gwy_field_new_alike(field, FALSE);
+    /* Work with a flipped field because we process it by column.  Note that this means xres and yres have swapped
+     * meaning! */
+    GwyField *ffield = gwy_field_new_alike(field, FALSE);
     gwy_field_transpose(field, ffield, FALSE);
     data = gwy_field_get_data(ffield);
     if (mask) {
-        fmask = gwy_field_new_alike(mask, FALSE);
-        gwy_field_transpose(mask, fmask, FALSE);
-        mdata = gwy_field_get_data(fmask);
+        fmask = gwy_nield_new_alike(mask);
+        gwy_nield_transpose(mask, fmask, FALSE);
+        mdata = gwy_nield_get_data(fmask);
         low = g_new(gdouble, xres);
         high = g_new(gdouble, xres);
     }
@@ -394,7 +395,6 @@ good_profile_do_single(GwyLine *profile, ModuleArgs *args)
         row = data + i*yres;
         ldata[i] = gwy_math_trimmed_mean(row, yres, ntrim, ntrim);
         if (mdata) {
-            mrow = mdata + i*yres;
             gwy_math_kth_ranks(row, yres, k, 2, v);
             low[i] = v[0];
             high[i] = v[1];
@@ -405,7 +405,7 @@ good_profile_do_single(GwyLine *profile, ModuleArgs *args)
     if (fmask) {
         g_object_unref(fmask);
         ddata = gwy_field_get_data_const(field);
-        mdata = gwy_field_get_data(mask);
+        mdata = gwy_nield_get_data(mask);
         for (i = 0; i < yres; i++) {
             drow = ddata + i*xres;
             mrow = mdata + i*xres;
@@ -415,53 +415,52 @@ good_profile_do_single(GwyLine *profile, ModuleArgs *args)
         g_free(low);
         g_free(high);
     }
+
+    return profile;
 }
 
-static void
-good_profile_do_multiple(GwyLine *profile, GwyLine *weights, ModuleArgs *args)
+static GwyLine*
+good_profile_do_multiple(GwyLine *weights, ModuleArgs *args)
 {
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     gdouble trim_fraction = gwy_params_get_double(args->params, PARAM_TRIM_FRACTION);
     GwyField *field2 = gwy_params_get_image(args->params, PARAM_OTHER_IMAGE);
-    GwyField *buf;
-    const gdouble *d1, *d2;
-    gdouble *b, *m;
-    gdouble p, threshold;
-    gint xres, yres, n, i;
 
-    d1 = gwy_field_get_data_const(field);
-    d2 = gwy_field_get_data_const(field2);
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    n = xres*yres;
+    const gdouble *d1 = gwy_field_get_data_const(field);
+    const gdouble *d2 = gwy_field_get_data_const(field2);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gsize n = (gsize)xres * (gsize)yres;
 
-    buf = gwy_field_new_alike(field, FALSE);
-    b = gwy_field_get_data(buf);
+    GwyField *buf = gwy_field_new_alike(field, FALSE);
+    gdouble *b = gwy_field_get_data(buf);
 
-    if (!mask) {
-        mask = gwy_field_new_alike(field, FALSE);
-        gwy_unit_clear(gwy_field_get_unit_z(mask));
-    }
+    for (gsize i = 0; i < n; i++)
+        b[i] = fabs(d1[i] - d2[i]);
+
+    gdouble p = 100.0*(1.0 - trim_fraction), threshold;
+    gdouble *b2 = g_memdup(gwy_field_get_data_const(buf), n*sizeof(gdouble));
+    gwy_math_percentiles(b2, n, GWY_PERCENTILE_INTERPOLATION_MIDPOINT, &p, 1, &threshold);
+    g_free(b2);
+
+    if (!mask)
+        mask = gwy_field_new_nield_alike(field);
     else
         g_object_ref(mask);
-    m = gwy_field_get_data(mask);
 
-    /* Use m[] temporarily for the difference we pass to gwy_math_percentiles() and they get shuffled. */
-    for (i = 0; i < n; i++)
-        b[i] = m[i] = fabs(d1[i] - d2[i]);
+    gint *m = gwy_nield_get_data(mask);
 
-    p = 100.0*(1.0 - trim_fraction);
-    gwy_math_percentiles(m, n, GWY_PERCENTILE_INTERPOLATION_MIDPOINT, &p, 1, &threshold);
-
-    for (i = 0; i < n; i++) {
+    for (gsize i = 0; i < n; i++) {
         m[i] = (b[i] > threshold);
         b[i] = 0.5*(d1[i] + d2[i]);
     }
-    gwy_field_area_get_line_stats(buf, mask, GWY_MASK_EXCLUDE, profile, weights, 0, 0, xres, yres,
-                                  GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL);
+    GwyLine *profile = gwy_field_area_line_stats(buf, mask, GWY_MASK_EXCLUDE, 0, 0, xres, yres,
+                                                 GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL, weights);
 
     g_object_unref(mask);
     g_object_unref(buf);
+
+    return profile;
 }
 
 static void
@@ -470,25 +469,24 @@ execute(ModuleArgs *args, gdouble *variation)
     GoodProfMode mode = gwy_params_get_enum(args->params, PARAM_MODE);
     GwyGraphCurveModel *gcmodel;
     GwyField *field = args->field;
-    GwyLine *profile, *weights = NULL;
+    GwyLine *profile = NULL, *weights = NULL;
     gdouble dx, xoff;
     gint xres, i, n;
     gdouble *d, *w;
     GwyXY *xy;
 
     xres = gwy_field_get_xres(field);
-    profile = gwy_line_new(xres, gwy_field_get_xreal(field), TRUE);
-    gwy_field_copy_units_to_line(field, profile);
 
     if (mode == GOOD_PROF_SINGLE)
-        good_profile_do_single(profile, args);
+        profile = good_profile_do_single(args);
     else if (mode == GOOD_PROF_MULTIPLE) {
-        weights = gwy_line_new_alike(profile, FALSE);
-        good_profile_do_multiple(profile, weights, args);
+        weights = gwy_line_new(xres, gwy_field_get_xreal(field), TRUE);
+        profile = good_profile_do_multiple(weights, args);
     }
     else {
         g_assert_not_reached();
     }
+    gwy_field_copy_units_to_line(field, profile);
 
     g_object_set(args->gmodel, "title", _("Mean profile"), NULL);
     if (gwy_graph_model_get_n_curves(args->gmodel))
@@ -525,7 +523,7 @@ execute(ModuleArgs *args, gdouble *variation)
         if (variation) {
             for (i = 0; i < xres; i++)
                 w[i] = (w[i] <= 0.0);
-            gwy_line_correct_laplace(profile, weights);
+            gwy_line_laplace_solve(profile, weights);
         }
     }
 
