@@ -1,6 +1,6 @@
 /*
- *  $Id: grain_cross.c 28978 2025-12-11 10:41:31Z yeti-dn $
- *  Copyright (C) 2007-2025 David Necas (Yeti).
+ *  $Id: grain_cross.c 29281 2026-01-17 20:54:31Z yeti-dn $
+ *  Copyright (C) 2007-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -140,7 +140,7 @@ check_same_units(GwyParams *params, gint idvalue, gint idexpanded,
         return TRUE;
 
     /* Non-interactively, we complain.  But interactively we just reset to valid values. */
-    if (mode ==GWY_RUN_IMMEDIATE) {
+    if (mode == GWY_RUN_IMMEDIATE) {
         gwy_require_image_same_units(field, data, id, _("Grain Correlations"));
         return FALSE;
     }
@@ -163,7 +163,6 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear1(args);
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
-                                 /* TODO Nield */
                                  GWY_APP_MASK_FIELD, &args.grains,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
@@ -179,7 +178,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.gmodel = gwy_graph_model_new();
     set_graph_model_units(&args);
     args.ngrains = gwy_nield_max(args.grains);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -391,11 +390,11 @@ execute(ModuleArgs *args)
     rdata[1] = ydata = bothdata + 3*ngrains + 1;
 
     if (ordfield != absfield) {
-        gwy_grain_values_calculate(gvalues + 0, rdata + 0, 1, absfield, args->grains);
-        gwy_grain_values_calculate(gvalues + 1, rdata + 1, 1, ordfield, args->grains);
+        gwy_nield_grain_values(args->grains, absfield, gvalues + 0, 1, rdata + 0);
+        gwy_nield_grain_values(args->grains, ordfield, gvalues + 1, 1, rdata + 1);
     }
     else
-        gwy_grain_values_calculate(gvalues, rdata, 2, absfield, args->grains);
+        gwy_nield_grain_values(args->grains, absfield, gvalues, 2, rdata);
 
     for (i = 0; i < ngrains; i++) {
         bothdata[2*i + 0] = xdata[i+1];
