@@ -1,5 +1,5 @@
 /*
- *  $Id: grain_dist.c 28978 2025-12-11 10:41:31Z yeti-dn $
+ *  $Id: grain_dist.c 29281 2026-01-17 20:54:31Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
@@ -157,7 +157,6 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
-                                 /* TODO Nield */
                                  GWY_APP_MASK_FIELD, &args.grains,
                                  0);
     g_return_if_fail(args.field && args.grains);
@@ -167,7 +166,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.ngrains = gwy_nield_max(args.grains);
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -335,7 +334,7 @@ preview(gpointer user_data)
     dline = gwy_line_new(args->ngrains+1, 1.0, FALSE);
     d = gwy_line_get_data(dline);
     expdata.rawvalues = &dline;
-    gwy_grain_values_calculate(expdata.gvalues, &d, 1, args->field, args->grains);
+    gwy_nield_grain_values(args->grains, args->field, expdata.gvalues, 1, &d);
     add_one_distribution(gui->gmodel, &expdata, 0);
     g_object_unref(dline);
 }
@@ -414,7 +413,7 @@ execute(ModuleArgs *args, GwyFile *data)
     expdata.nvalues = nvalues;
     g_strfreev(selected_quantities);
 
-    gwy_grain_values_calculate(expdata.gvalues, results, nvalues, args->field, args->grains);
+    gwy_nield_grain_values(args->grains, args->field, expdata.gvalues, nvalues, results);
     g_free(results);
 
     if (mode == MODE_GRAPH) {
