@@ -1,6 +1,6 @@
 /*
- *  $Id: grain_edge.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2011-2021 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
+ *  $Id: grain_edge.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2011-2026 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -34,8 +34,8 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -61,7 +61,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks grains by edge detection method."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.6",
+    "0.7",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2011",
 };
@@ -116,11 +116,10 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field && mquark);
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.result = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -129,11 +128,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -196,7 +193,7 @@ preview(gpointer user_data)
     ModuleArgs *args = gui->args;
 
     execute(args);
-    gwy_field_data_changed(args->result);
+    gwy_nield_data_changed(args->result);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
@@ -207,19 +204,21 @@ execute(ModuleArgs *args)
     gboolean combine = gwy_params_get_boolean(params, PARAM_COMBINE);
     GwyMergeType combine_type = gwy_params_get_enum(params, PARAM_COMBINE_TYPE);
     gdouble threshold_laplacian = gwy_params_get_double(params, PARAM_THRESHOLD_LAPLACIAN);
-    GwyField *temp_field, *mask = args->mask;
+    GwyNield *mask = args->mask;
+    GwyField *temp_field = gwy_field_copy(args->field);
 
-    temp_field = gwy_field_copy(args->field);
     gwy_field_filter_laplacian_of_gaussians(temp_field);
-    gwy_field_grains_mark_height(temp_field, args->result, 100.0*threshold_laplacian, TRUE);
+
+    /* Recompute old-style percentage threshold to the absolute value. */
+    gdouble min, max;
+    gwy_field_min_max(temp_field, &min, &max);
+    gdouble threshold = min + threshold_laplacian*(max - min);
+
+    gwy_nield_mark_by_threshold(args->result, temp_field, threshold, FALSE);
     g_object_unref(temp_field);
 
-    if (mask && combine) {
-        if (combine_type == GWY_MERGE_UNION)
-            gwy_field_grains_add(args->result, mask);
-        else if (combine_type == GWY_MERGE_INTERSECTION)
-            gwy_field_grains_intersect(args->result, mask);
-    }
+    if (combine)
+        gwy_nield_merge(args->result, mask, combine_type);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
