@@ -1,6 +1,6 @@
 /*
- *  $Id: grain_filter.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2014-2025 David Necas (Yeti).
+ *  $Id: grain_filter.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2014-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -231,7 +231,6 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GQuark mquark;
     gint id;
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
-                                 /* TODO Nield */
                                  GWY_APP_MASK_FIELD, &args.grains,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
                                  GWY_APP_FIELD_ID, &id,
@@ -281,8 +280,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_dict_set_object(GWY_DICT(data), mquark, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -559,7 +558,7 @@ ensure_grain_values(ModuleArgs *args, guint i)
     guint ngrains = args->ngrains;
     GwyGrainValue *gvalue = gwy_inventory_get_nth_item(gwy_grain_values(), i);
     gdouble *valdata = g_ptr_array_index(args->valuedata, i) = g_new(gdouble, ngrains + 1);
-    gwy_grain_values_calculate(&gvalue, &valdata, 1, args->field, args->grains);
+    gwy_nield_grain_values(args->grains, args->field, &gvalue, 1, &valdata);
 
     /* +1 to avoid the zeroth non-grain */
     gdouble *sorted = g_ptr_array_index(args->sortedvaluedata, i) = g_memdup(valdata + 1, ngrains*sizeof(gdouble));
