@@ -1,6 +1,6 @@
 /*
- *  $Id: grain_makesel.c 28873 2025-11-18 14:59:29Z yeti-dn $
- *  Copyright (C) 2014-2021 David Necas (Yeti), Petr Klapetek, Sven Neumann.
+ *  $Id: grain_makesel.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2014-2026 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates selections visualizing grains."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "2.0",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -59,7 +59,7 @@ module_register(void)
     gwy_process_func_register("grain_circumscribe_circles",
                               &grain_circumscribe_circles,
                               N_("/_Grains/Select _Circumscribed Circles"),
-                              GWY_ICON_GRAIN_EXSCRIBED_CIRCLE,
+                              GWY_ICON_GRAIN_CIRCUMCIRCLE,
                               RUN_MODES,
                               GWY_MENU_FLAG_IMAGE | GWY_MENU_FLAG_IMAGE_MASK,
                               N_("Create a selection visualizing grain circumcircles"));
@@ -103,15 +103,37 @@ make_circles(GwyFile *data, gint id, GwyField *field, gdouble **rxydata, guint n
 {
     gdouble xoffset = gwy_field_get_xoffset(field), yoffset = gwy_field_get_yoffset(field);
     GwySelection *selection;
-    guint i;
 
     selection = create_selection(GWY_TYPE_SELECTION_ELLIPSE, &ngrains);
-    for (i = 1; i <= ngrains; i++) {
+    for (guint i = 1; i <= ngrains; i++) {
         gdouble r = rxydata[0][i], x = rxydata[1][i] - xoffset, y = rxydata[2][i] - yoffset;
         gdouble xy[4] = { x - r, y - r, x + r, y + r };
         gwy_selection_set_object(selection, i-1, xy);
     }
-    gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "ellipse"), selection);
+    gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_selection(id, "ellipse"), selection);
+}
+
+static void
+exinscribe_discs(GwyFile *data, const GwyGrainQuantity *quantities)
+{
+    GwyField *field;
+    GwyNield *mask;
+    gint id;
+
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_FIELD_ID, &id,
+                                 0);
+
+    guint ngrains = gwy_nield_max(mask);
+    gdouble *circles = g_new(gdouble, 3*(ngrains + 1));
+    gdouble *values[3];
+    for (guint i = 0; i < 3; i++)
+        values[i] = circles + i*(ngrains + 1);
+
+    gwy_nield_grain_quantities(mask, field, quantities, 3, values);
+    make_circles(data, id, field, values, ngrains);
+    g_free(circles);
 }
 
 /* FIXME: It would be nice to have something like that also for minimum and maximum bounding dimensions. */
@@ -122,30 +144,8 @@ grain_inscribe_discs(GwyFile *data, GwyRunModeFlags mode)
         GWY_GRAIN_INSCRIBED_DISC_R, GWY_GRAIN_INSCRIBED_DISC_X, GWY_GRAIN_INSCRIBED_DISC_Y,
     };
 
-    GwyField *field, *mfield;
-    guint ngrains, i;
-    gint *grains;
-    gdouble *inscd;
-    gdouble *values[3];
-    gint id;
-
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mfield,
-                                 GWY_APP_FIELD_ID, &id,
-                                 0);
-
-    grains = g_new0(gint, mfield->xres * mfield->yres);
-    ngrains = gwy_field_number_grains(mfield, grains);
-    inscd = g_new(gdouble, 3*(ngrains + 1));
-    for (i = 0; i < 3; i++)
-        values[i] = inscd + i*(ngrains + 1);
-
-    gwy_field_grains_get_quantities(field, values, quantities, 3, ngrains, grains);
-    g_free(grains);
-
-    make_circles(data, id, field, values, ngrains);
-    g_free(inscd);
+    exinscribe_discs(data, quantities);
 }
 
 static void
@@ -155,30 +155,8 @@ grain_circumscribe_circles(GwyFile *data, GwyRunModeFlags mode)
         GWY_GRAIN_CIRCUMCIRCLE_R, GWY_GRAIN_CIRCUMCIRCLE_X, GWY_GRAIN_CIRCUMCIRCLE_Y,
     };
 
-    GwyField *field, *mfield;
-    guint ngrains, i;
-    gint *grains;
-    gdouble *circc;
-    gdouble *values[3];
-    gint id;
-
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mfield,
-                                 GWY_APP_FIELD_ID, &id,
-                                 0);
-
-    grains = g_new0(gint, mfield->xres * mfield->yres);
-    ngrains = gwy_field_number_grains(mfield, grains);
-    circc = g_new(gdouble, 3*(ngrains + 1));
-    for (i = 0; i < 3; i++)
-        values[i] = circc + i*(ngrains + 1);
-
-    gwy_field_grains_get_quantities(field, values, quantities, 3, ngrains, grains);
-    g_free(grains);
-
-    make_circles(data, id, field, values, ngrains);
-    g_free(circc);
+    exinscribe_discs(data, quantities);
 }
 
 static void
@@ -186,66 +164,55 @@ make_boxes(GwyFile *data, gint id, GwyField *field, const gint *boxes, guint ngr
 {
     gdouble dx = gwy_field_get_dx(field), dy = gwy_field_get_dy(field);
     GwySelection *selection;
-    guint i;
 
     selection = create_selection(GWY_TYPE_SELECTION_RECTANGLE, &ngrains);
-    for (i = 1; i <= ngrains; i++) {
+    for (guint i = 1; i <= ngrains; i++) {
         const gint *bb = boxes + 4*i;
         gdouble x = dx*bb[0], y = dy*bb[1], w = dx*bb[2], h = dy*bb[3];
         gdouble xy[4] = { x, y, x + w, y + h };
         gwy_selection_set_object(selection, i-1, xy);
     }
-    gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "rectangle"), selection);
+    gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_selection(id, "rectangle"), selection);
 }
 
 static void
 grain_inscribe_rects(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *field, *mfield;
-    guint ngrains;
-    gint *grains, *iboxes;
+    GwyField *field;
+    GwyNield *mask;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mfield,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
+    g_return_if_fail(field && mask);
 
-    grains = g_new0(gint, mfield->xres * mfield->yres);
-    ngrains = gwy_field_number_grains(mfield, grains);
-    iboxes = g_new(gint, 4*(ngrains + 1));
-
-    gwy_field_get_grain_inscribed_boxes(mfield, ngrains, grains, iboxes);
-    g_free(grains);
-
-    make_boxes(data, id, field, iboxes, ngrains);
-    g_free(iboxes);
+    guint ngrains;
+    gint *boxes = gwy_nield_inscribed_boxes(mask, &ngrains);
+    make_boxes(data, id, field, boxes, ngrains);
+    g_free(boxes);
 }
 
 static void
 grain_circumscribe_bboxes(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *field, *mfield;
-    guint ngrains;
-    gint *grains, *bboxes;
+    GwyField *field;
+    GwyNield *mask;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mfield,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
+    g_return_if_fail(field && mask);
 
-    grains = g_new0(gint, mfield->xres * mfield->yres);
-    ngrains = gwy_field_number_grains(mfield, grains);
-    bboxes = g_new(gint, 4*(ngrains + 1));
-
-    gwy_field_get_grain_bounding_boxes(mfield, ngrains, grains, bboxes);
-    g_free(grains);
-
-    make_boxes(data, id, field, bboxes, ngrains);
-    g_free(bboxes);
+    guint ngrains;
+    gint *boxes = gwy_nield_bounding_boxes(mask, &ngrains);
+    make_boxes(data, id, field, boxes, ngrains);
+    g_free(boxes);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
