@@ -1,5 +1,5 @@
 /*
- *  $Id: grain_stat.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: grain_stat.c 29281 2026-01-17 20:54:31Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
@@ -137,7 +137,6 @@ module_main(G_GNUC_UNUSED GwyFile *data, GwyRunModeFlags mode)
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
-                                 /* TODO Nield */
                                  GWY_APP_MASK_FIELD, &args.grains,
                                  0);
     g_return_if_fail(args.field && args.grains);
@@ -311,7 +310,7 @@ calculate_stats(GwyField *field, GwyNield *grains)
         values[i] = g_new(gdouble, ngrains + 1);
     }
 
-    gwy_grain_values_calculate(gvalues, values, n, field, grains);
+    gwy_nield_grain_values(grains, field, gvalues, n, values);
 
     stats = g_new(GrainQuantityStats, n);
     p[0] = 25.0;
