@@ -1,5 +1,5 @@
 /*
- *  $Id: grain_summary.c 28873 2025-11-18 14:59:29Z yeti-dn $
+ *  $Id: grain_summary.c 29476 2026-02-14 12:57:32Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
@@ -32,7 +32,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -54,14 +54,14 @@ static GwyResults*      create_results      (ModuleArgs *args,
                                              gint id);
 static void             fill_results        (GwyResults *results,
                                              GwyField *field,
-                                             GwyField *mask);
+                                             GwyNield *mask);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Displays overall grain statistics."),
     "Petr Klapetek <petr@klapetek.cz>, Sven Neumann <neumann@jpk.com>, Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek & Sven Neumann",
     "2015",
 };
@@ -171,7 +171,7 @@ create_results(ModuleArgs *args, GwyFile *data, gint id)
     gwy_results_add_value(results, "meanarea", N_("Mean grain area"),
                           "power-x", 1, "power-y", 1,
                           NULL);
-    gwy_results_add_value_x(results, "meansize", N_("Mean grain size"));
+    gwy_results_add_value_x(results, "meansize", N_("Mean grain radius"));
     gwy_results_add_value(results, "vol_0", N_("Total grain volume (zero)"),
                           "power-x", 1, "power-y", 1, "power-z", 1,
                           NULL);
@@ -194,42 +194,28 @@ create_results(ModuleArgs *args, GwyFile *data, gint id)
 }
 
 static gdouble
-grains_get_total_value(GwyField *field,
-                       gint ngrains, const gint *grains,
-                       gdouble **values, GwyGrainQuantity quantity)
+grains_get_total_value(GwyField *field, GwyNield *mask, GwyGrainQuantity quantity)
 {
-    gint i;
-    gdouble sum;
-
-    *values = gwy_field_grains_get_values(field, *values, ngrains, grains, quantity);
-    sum = 0.0;
-    for (i = 1; i <= ngrains; i++)
-        sum += (*values)[i];
+    guint ngrains;
+    gdouble *values = gwy_nield_grain_quantity(mask, field, quantity, &ngrains);
+    gdouble sum = 0.0;
+    for (gint i = 1; i <= ngrains; i++)
+        sum += values[i];
 
     return sum;
 }
 
 static void
-fill_results(GwyResults *results, GwyField *field, GwyField *mask)
+fill_results(GwyResults *results, GwyField *field, GwyNield *mask)
 {
-    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     gdouble xreal = gwy_field_get_xreal(field), yreal = gwy_field_get_yreal(field);
-    gdouble area, size, vol_0, vol_min, vol_laplace, bound_len;
-    gdouble *values;
-    gint *grains;
-    gint ngrains;
-
-    grains = g_new0(gint, xres*yres);
-    ngrains = gwy_field_number_grains(mask, grains);
-    values = NULL;
-    area = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_PROJECTED_AREA);
-    size = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_EQUIV_SQUARE_SIDE);
-    vol_0 = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_VOLUME_0);
-    vol_min = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_VOLUME_MIN);
-    vol_laplace = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_VOLUME_LAPLACE);
-    bound_len = grains_get_total_value(field, ngrains, grains, &values, GWY_GRAIN_FLAT_BOUNDARY_LENGTH);
-    g_free(values);
-    g_free(grains);
+    gint ngrains = gwy_nield_max(mask);
+    gdouble area = grains_get_total_value(field, mask, GWY_GRAIN_PROJECTED_AREA);
+    gdouble size = grains_get_total_value(field, mask, GWY_GRAIN_EQUIV_DISC_RADIUS);
+    gdouble vol_0 = grains_get_total_value(field, mask, GWY_GRAIN_VOLUME_0);
+    gdouble vol_min = grains_get_total_value(field, mask, GWY_GRAIN_VOLUME_MIN);
+    gdouble vol_laplace = grains_get_total_value(field, mask, GWY_GRAIN_VOLUME_LAPLACE);
+    gdouble bound_len = grains_get_total_value(field, mask, GWY_GRAIN_PERIMETER);
 
     gwy_results_fill_values(results,
                             "ngrains", ngrains,
