@@ -1,6 +1,6 @@
 /*
- *  $Id: grain_wshed.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: grain_wshed.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -38,8 +38,8 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -66,7 +66,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks grains by watershed algorithm."),
     "Petr Klapetek <petr@klapetek.cz>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -125,8 +125,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field && mquark);
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.result = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     if (mode == GWY_RUN_INTERACTIVE) {
@@ -140,11 +139,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             goto end;
     }
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -221,11 +218,11 @@ preview(gpointer user_data)
     ModuleArgs *args = gui->args;
 
     if (execute(args, GTK_WINDOW(gui->dialog))) {
-        gwy_field_data_changed(args->result);
+        gwy_nield_data_changed(args->result);
         gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
     }
     else
-        gwy_field_clear(args->result);
+        gwy_nield_clear(args->result);
 }
 
 static gboolean
@@ -240,25 +237,23 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     gint wshed_steps = gwy_params_get_int(params, PARAM_WSHED_STEPS);
     gdouble wshed_dropsize = gwy_params_get_double(params, PARAM_WSHED_DROPSIZE);
     gboolean inverted = gwy_params_get_boolean(params, PARAM_INVERTED);
-    GwyField *newmask, *mask = args->mask;
-    gdouble max, min, q;
-    GwyComputationState *state;
+    GwyNield *mask = args->mask;
     GwyWatershedStateType oldstate = -1;
-    gboolean ok = FALSE;
 
-    max = gwy_field_get_max(args->field);
-    min = gwy_field_get_min(args->field);
-    q = (max - min)/5000.0 * 100.0;
+    gdouble max, min;
+    gwy_field_min_max(args->field, &min, &max);
+    gdouble q = (max - min)/5000.0 * 100.0;
 
-    newmask = gwy_field_new_alike(args->result, FALSE);
-    state = gwy_field_grains_watershed_init(args->field, newmask,
-                                            locate_steps, locate_thresh, locate_dropsize*q,
-                                            wshed_steps, wshed_dropsize*q,
-                                            FALSE, inverted);
+    GwyNield *newmask = gwy_nield_new_alike(args->result);
+    GwyComputationState *state = gwy_field_watershed_init(args->field, newmask,
+                                                          locate_steps, locate_thresh, locate_dropsize*q,
+                                                          wshed_steps, wshed_dropsize*q,
+                                                          FALSE, inverted);
     gwy_app_wait_start(wait_window, _("Initializing..."));
 
+    gboolean ok = FALSE;
     do {
-        gwy_field_grains_watershed_iteration(state);
+        gwy_field_watershed_iteration(state);
         if (oldstate != state->state) {
             if (state->state == GWY_WATERSHED_STATE_MIN)
                 ok = gwy_app_wait_set_message(_("Finding minima..."));
@@ -278,17 +273,12 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     ok = (state->state == GWY_WATERSHED_STATE_FINISHED);
 
     gwy_app_wait_finish();
-    gwy_field_grains_watershed_finalize(state);
+    gwy_field_watershed_finalize(state);
 
     if (ok) {
-        if (mask && combine) {
-            if (combine_type == GWY_MERGE_UNION)
-                gwy_field_grains_add(newmask, mask);
-            else if (combine_type == GWY_MERGE_INTERSECTION)
-                gwy_field_grains_intersect(newmask, mask);
-        }
-        gwy_field_threshold(newmask, 0.5, 0.0, 1.0);
-        gwy_field_copy_data(newmask, args->result);
+        if (combine)
+            gwy_nield_merge(newmask, mask, combine_type);
+        gwy_nield_copy_data(newmask, args->result);
     }
     g_object_unref(newmask);
 
