@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: hertz.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2017-2021 Anna Charvatova Campbell
+ *  @(#) $Id: hertz.c 29292 2026-01-19 17:09:59Z yeti-dn $
+ *  Copyright (C) 2017-2026 Anna Charvatova Campbell
  *  E-mail: acampbellova@cmi.cz
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -45,7 +45,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result[PREVIEW_NTYPES];
 } ModuleArgs;
 
@@ -159,11 +159,10 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         s = gwy_enum_to_string(i, result_units, G_N_ELEMENTS(result_units));
         gwy_unit_set_from_string(gwy_field_get_unit_z(args.result[i]), s);
     }
-    args.mask = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.mask));
+    args.mask = gwy_field_new_nield_alike(args.field);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -178,7 +177,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
         newid = gwy_file_add_image(data, args.result[i]);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(args.mask));
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(args.mask));
         s = gwy_enum_to_string(i, outputs, G_N_ELEMENTS(outputs));
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _(s), TRUE);
         gwy_log_add_full(data, GWY_FILE_IMAGE, id, newid, "proc::hertz_modulus",
@@ -287,7 +286,7 @@ preview(gpointer user_data)
     execute(args);
     for (i = 0; i < PREVIEW_NTYPES; i++)
         gwy_field_data_changed(args->result[i]);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_data_changed(args->mask);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
@@ -301,18 +300,17 @@ execute(ModuleArgs *args)
     GwyField *gausscurv = args->result[PREVIEW_GAUSSCURV];
     GwyField *modulus = args->result[PREVIEW_MODULUS];
     GwyField *dz = args->result[PREVIEW_DEFORMATION];
-    GwyField *mask = args->mask, *field = args->field;
-    GwyField *dxfield, *dyfield;
+    GwyNield *mask = args->mask;
+    GwyField *field = args->field;
+    GwyField *dxfield, *dyfield, *tmp;
     GwyField *dxxfield, *dxyfield, *dyyfield;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gsize n = (gsize)xres * (gsize)yres;
     gdouble *px, *py, *pxx, *pyy, *pxy;
-    gdouble *pc, *pg, *pE, *m, *pz;
-    gint i, xres, yres, n;
+    gdouble *pc, *pg, *pE, *pz;
+    gint *m;
     gdouble coeff;
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    n = xres*yres;
-
     /* Recycle modulus and dz as the first derivative fiels. */
     dxfield = modulus;
     dyfield = dz;
@@ -321,10 +319,10 @@ execute(ModuleArgs *args)
     dxxfield = gwy_field_new_alike(field, FALSE);
     dyyfield = gwy_field_new_alike(field, FALSE);
     dxyfield = gwy_field_new_alike(field, FALSE);
+    tmp = gwy_field_new_alike(field, FALSE);
     gwy_field_filter_slope(dxfield, dxxfield, dxyfield);
-    /* Recycle mask as temporary dyxfield and then average. */
-    gwy_field_filter_slope(dyfield, mask, dyyfield);
-    gwy_field_linear_combination(dxyfield, 0.5, dxyfield, 0.5, mask, 0.0);
+    gwy_field_filter_slope(dyfield, tmp, dyyfield);
+    gwy_field_linear_combination(dxyfield, 0.5, dxyfield, 0.5, tmp, 0.0);
 
     px = gwy_field_get_data(dxfield);
     py = gwy_field_get_data(dyfield);
@@ -336,10 +334,9 @@ execute(ModuleArgs *args)
     pg = gwy_field_get_data(gausscurv);
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(px,py,pxx,pxy,pyy,pc,pg,n)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gsize i = 0; i < n; i++) {
         gdouble dx2 = px[i]*px[i], dy2 = py[i]*py[i], dxdy = px[i]*py[i];
         gdouble w = 1.0 + dx2 + dy2;
         pc[i] = 0.5*((1.0 + dx2)*pyy[i] + (1.0 + dy2)*pxx[i] - 2.0*pxy[i]*dxdy)/(w*sqrt(w));
@@ -349,21 +346,21 @@ execute(ModuleArgs *args)
     g_object_unref(dxxfield);
     g_object_unref(dxyfield);
     g_object_unref(dyyfield);
+    g_object_unref(tmp);
 
-    gwy_field_clear(mask);
+    gwy_nield_clear(mask);
     pE = gwy_field_get_data(modulus);
     pz = gwy_field_get_data(dz);
-    m = gwy_field_get_data(mask);
+    m = gwy_nield_get_data(mask);
     coeff = cbrt(9.0/16.0*F*F/R);
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(m,pE,pz,pc,pg,R,E,coeff,n)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gsize i = 0; i < n; i++) {
         gdouble d = 1.0 - 2.0*pc[i]*R + R*R*pg[i];
         if (d <= 0.0) {
-            m[i] = 1.0;
+            m[i] = 1;
             pE[i] = -1.0;
             pz[i] = -1e-9;
         }
