@@ -1,5 +1,5 @@
 /*
- *  $Id: immerse.c 28844 2025-11-10 16:07:51Z yeti-dn $
+ *  $Id: immerse.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -347,14 +347,14 @@ immerse_update_detail(ModuleGUI *gui)
     if (gwy_params_get_boolean(args->params, PARAM_ADAPT_COLOR_RANGE)) {
         GwyColorMappingType range_type;
         gdouble min, max;
-        gwy_container_gis_enum(GWY_CONTAINER(file), gwy_file_key_image_color_mapping(id), &range_type);
+        gwy_dict_gis_enum(GWY_DICT(file), gwy_file_key_image_color_mapping(id), &range_type);
         if (range_type == GWY_COLOR_MAPPING_AUTO)
-            gwy_field_get_autorange(field, &min, &max);
+            gwy_field_autorange(field, &min, &max);
         else {
-            gwy_field_get_min_max(field, &min, &max);
+            gwy_field_min_max(field, &min, &max);
             if (range_type == GWY_COLOR_MAPPING_FIXED) {
-                gwy_container_gis_double(GWY_CONTAINER(file), gwy_file_key_image_range_min(id), &min);
-                gwy_container_gis_double(GWY_CONTAINER(file), gwy_file_key_image_range_max(id), &max);
+                gwy_dict_gis_double(GWY_DICT(file), gwy_file_key_image_range_min(id), &min);
+                gwy_dict_gis_double(GWY_DICT(file), gwy_file_key_image_range_max(id), &max);
             }
             /* FIXME: Adaptive mapping using the distribution of different data field is currently not possible. */
         }
@@ -550,7 +550,7 @@ execute(ModuleArgs *args)
     gint x, y, w, h;
     gdouble iavg, davg;
 
-    davg = gwy_field_get_avg(detail);
+    davg = gwy_field_mean(detail);
     kxres = gwy_field_get_xres(detail);
     kyres = gwy_field_get_yres(detail);
 
@@ -565,7 +565,7 @@ execute(ModuleArgs *args)
         gwy_debug("w: %d, h: %d", w, h);
         resampled = gwy_field_new_resampled(detail, w, h, GWY_INTERPOLATION_LINEAR);
         if (levelling == GWY_IMMERSE_LEVEL_MEAN) {
-            iavg = gwy_field_area_get_avg(result, NULL, GWY_MASK_IGNORE, x, y, w, h);
+            iavg = gwy_field_area_mean(result, NULL, GWY_MASK_IGNORE, x, y, w, h);
             gwy_field_add(resampled, iavg - davg);
         }
         gwy_field_area_copy(resampled, result, 0, 0, w, h, x, y);
@@ -579,7 +579,7 @@ execute(ModuleArgs *args)
         x = gwy_field_rtoj(result, xpos);
         y = gwy_field_rtoi(result, ypos);
         if (levelling == GWY_IMMERSE_LEVEL_MEAN) {
-            iavg = gwy_field_area_get_avg(result, NULL, GWY_MASK_IGNORE, x, y, kxres, kyres);
+            iavg = gwy_field_area_mean(result, NULL, GWY_MASK_IGNORE, x, y, kxres, kyres);
             gwy_field_area_copy(detail, result, 0, 0, kxres, kyres, x, y);
             gwy_field_area_add(result, x, y, kxres, kyres, iavg - davg);
         }
