@@ -1,6 +1,6 @@
 /*
- *  $Id: indent_analyze.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2006-2022 Lukas Chvatal, David Necas (Yeti), Petr Klapetek.
+ *  $Id: indent_analyze.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2006-2026 Lukas Chvatal, David Necas (Yeti), Petr Klapetek.
  *  E-mail: chvatal@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -97,7 +97,7 @@ typedef struct {
     GwyField *adjusted;
     GwyField *xder;
     GwyField *yder;
-    GwyField *result[RESULT_NTYPES];
+    GwyNield *result[RESULT_NTYPES];
     GwySelection *selection;
     ImprintParameters imp;
 } ModuleArgs;
@@ -126,7 +126,7 @@ static void             param_changed           (ModuleGUI *gui,
                                                  gint id);
 static void             preview                 (gpointer user_data);
 static void             level_using_exterior    (GwyField *field,
-                                                 GwyField *mask,
+                                                 GwyNield *mask,
                                                  gdouble wfrac,
                                                  gboolean do_level);
 static void             compute_slopes          (GwyField *field,
@@ -135,7 +135,7 @@ static void             compute_slopes          (GwyField *field,
                                                  GwyField *yder,
                                                  GwyField *atanfield);
 static gdouble          find_prevalent_phi      (GwyField *field,
-                                                 GwyField *exclmask,
+                                                 GwyNield *exclmask,
                                                  GwyField *xder,
                                                  GwyField *yder,
                                                  GwyField *atanfield);
@@ -152,15 +152,15 @@ static void             calc_mean_normal        (GwyField *xder,
                                                  GwyXYZ *v);
 static void             mark_facet              (GwyField *xder,
                                                  GwyField *yder,
-                                                 GwyField *mask,
+                                                 GwyNield *mask,
                                                  gdouble theta0,
                                                  gdouble phi0,
                                                  gdouble tolerance);
-static void             mark_pileup             (GwyField *above,
-                                                 GwyField *imprint,
-                                                 GwyField *pileup);
+static void             mark_pileup             (GwyNield *above,
+                                                 GwyNield *imprint,
+                                                 GwyNield *pileup);
 static void             calc_surface_and_volume (GwyField *field,
-                                                 GwyField *mask,
+                                                 GwyNield *mask,
                                                  gdouble *Aproj,
                                                  gdouble *Asurf,
                                                  gdouble *V);
@@ -170,7 +170,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Analyses nanoindentation structure (volumes, surfaces, ...)."),
     "Lukáš Chvátal <chvatal@physics.muni.cz> & Yeti <yeti@physics.muni.cz>",
-    "1.0",
+    "2.0",
     "Lukáš Chvátal",
     "2005",
 };
@@ -241,7 +241,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gboolean set_mask;
     ModuleArgs args;
     GQuark mquark;
-    gint id, i;
+    gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear1(args);
@@ -255,10 +255,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         return;
 
     args.adjusted = gwy_field_copy(args.field);
-    for (i = 1; i < RESULT_NTYPES; i++) {
-        args.result[i] = gwy_field_new_alike(args.field, TRUE);
-        gwy_unit_clear(gwy_field_get_unit_z(args.result[i]));
-    }
+    for (guint i = 1; i < RESULT_NTYPES; i++)
+        args.result[i] = gwy_field_new_nield_alike(args.field);
     args.xder = gwy_field_new_alike(args.field, TRUE);
     args.yder = gwy_field_new_alike(args.field, TRUE);
     args.params = gwy_params_new_from_settings(define_module_params());
@@ -273,16 +271,15 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (set_mask && display != RESULT_NOTHING) {
         if (outcome != GWY_DIALOG_HAVE_RESULT)
             execute(&args);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-        if (gwy_field_get_max(args.result[display]) > 0.0)
-            gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result[display]);
-        else
-            gwy_container_remove(GWY_CONTAINER(data), mquark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+        GwyNield *result = args.result[display];
+        gboolean nonempty = gwy_nield_flatten(result);
+        gwy_file_set_image_mask(data, id, nonempty ? result : NULL);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
 
 end:
-    for (i = 1; i < RESULT_NTYPES; i++)
+    for (guint i = 1; i < RESULT_NTYPES; i++)
         g_object_unref(args.result[i]);
     g_object_unref(args.params);
     g_object_unref(args.adjusted);
@@ -442,12 +439,11 @@ preview(gpointer user_data)
     ModuleGUI *gui = (ModuleGUI*)user_data;
     ModuleArgs *args = gui->args;
     ImprintParameters *imp = &args->imp;
-    gint i;
 
     execute(args);
     gwy_field_data_changed(args->adjusted);
-    for (i = 1; i < RESULT_NTYPES; i++)
-        gwy_field_data_changed(args->result[i]);
+    for (guint i = 1; i < RESULT_NTYPES; i++)
+        gwy_nield_data_changed(args->result[i]);
     gwy_results_fill_values(gui->results,
                             "x0", imp->x0, "y0", imp->y0, "zmin", imp->zmin, "zmax", imp->zmax,
                             "Aproj_imp", imp->Aproj_imp, "Asurf_imp", imp->Asurf_imp, "Acontact", imp->Acontact,
@@ -465,47 +461,47 @@ execute(ModuleArgs *args)
 {
     GwyParams *params = args->params;
     ImprintParameters *imp = &args->imp;
-    GwyField *adjusted = args->adjusted, *xder = args->xder, *yder = args->yder, *buf, *atanfield, *kernel;
-    GwyField *imprint = args->result[RESULT_IMPRINT];
-    GwyField *above = args->result[RESULT_ABOVE];
-    GwyField *below = args->result[RESULT_BELOW];
-    GwyField *impfaces = args->result[RESULT_IMPRINT_FACES];
-    GwyField *facesborder = args->result[RESULT_FACES_BORDER];
-    GwyField *pileup = args->result[RESULT_PILEUP];
+    GwyField *adjusted = args->adjusted, *xder = args->xder, *yder = args->yder;
+    GwyNield *imprint = args->result[RESULT_IMPRINT];
+    GwyNield *above = args->result[RESULT_ABOVE];
+    GwyNield *below = args->result[RESULT_BELOW];
+    GwyNield *impfaces = args->result[RESULT_IMPRINT_FACES];
+    GwyNield *facesborder = args->result[RESULT_FACES_BORDER];
+    GwyNield *pileup = args->result[RESULT_PILEUP];
+    GwyNield *innerpileup = args->result[RESULT_INNER_PILEUP];
+    GwyNield *outerpileup = args->result[RESULT_OUTER_PILEUP];
     gboolean do_level = gwy_params_get_boolean(params, PARAM_DO_LEVEL);
     gdouble exterior = gwy_params_get_double(params, PARAM_EXTERIOR);
     gdouble plane_tol = gwy_params_get_double(params, PARAM_PLANE_TOL);
     gdouble phi_tol = gwy_params_get_double(params, PARAM_PHI_TOL);
     GwyIndenterType indenter = gwy_params_get_enum(params, PARAM_INDENTER);
     gint xres = gwy_field_get_xres(args->field), yres = gwy_field_get_yres(args->field);
-    gint i, ksize, nsides = indenter;
+    gint nsides = indenter;
     gdouble points[2*5];
-    gdouble search_to_z, dx, dy;
+    gdouble dx = gwy_field_get_dx(adjusted), dy = gwy_field_get_dy(adjusted);
 
     /* Level (if requested) using exterior and find the base plane and its rms. */
     gwy_field_copy_data(args->field, adjusted);
-    dx = gwy_field_get_dx(adjusted);
-    dy = gwy_field_get_dy(adjusted);
     level_using_exterior(adjusted, args->result[RESULT_EXTERIOR], exterior/100.0, do_level);
     if (!gwy_field_get_local_minima_list(adjusted, &imp->x0, &imp->y0, &imp->zmin, 1, 0, G_MAXDOUBLE, TRUE)) {
         g_printerr("cannot find any minimum! fixme to handle this!\n");
         return;
     }
-    imp->zmax = gwy_field_get_max(adjusted);
-    imp->rms_base = gwy_field_area_get_rms(adjusted, args->result[RESULT_EXTERIOR], GWY_MASK_INCLUDE, 0, 0, xres, yres);
+    imp->zmax = gwy_field_max(adjusted);
+    imp->rms_base = gwy_field_area_rms(adjusted, args->result[RESULT_EXTERIOR], GWY_MASK_INCLUDE, 0, 0, xres, yres);
     plane_tol *= imp->rms_base;
 
-    /* Calculate slopes and find the imprint face. */
-    /* use FACES_BORDER and OUTER_PILEUP as temporary buffers */
-    atanfield = args->result[RESULT_OUTER_PILEUP];
-    buf = args->result[RESULT_FACES_BORDER];
+    /* Calculate slopes and find the imprint face.
+     * Use the FACES_BORDER mask as a temporary buffer. */
+    GwyField *atanfield = gwy_field_new_alike(args->field, FALSE);
+    GwyNield *maskbuf = facesborder;
     compute_slopes(adjusted, 5, xder, yder, atanfield);
-    gwy_field_clear(impfaces);
+    gwy_nield_clear(impfaces);
     imp->phi = find_prevalent_phi(adjusted, impfaces, xder, yder, atanfield);
-    search_to_z = imp->zmin - 0.3*imp->zmin;
+    gdouble search_to_z = imp->zmin - 0.3*imp->zmin;
     gwy_debug("search side from to %g within [%g..0.0]", search_to_z, imp->zmin);
     if (nsides) {
-        for (i = 0; i < nsides; i++) {
+        for (gint i = 0; i < nsides; i++) {
             gdouble phi = gwy_canonicalize_angle(imp->phi + 2.0*G_PI/nsides*i, TRUE, TRUE);
             gdouble xc = imp->x0, yc = imp->y0, theta0, phi0;
             GwyXYZ v;
@@ -517,48 +513,49 @@ execute(ModuleArgs *args)
             phi0 = atan2(v.y, v.x);
             theta0 = atan(hypot(v.x, v.y));
             gwy_debug("mean normal phi0=%g, theta0=%g", gwy_rad2deg(phi0), gwy_rad2deg(theta0));
-            mark_facet(xder, yder, buf, theta0, phi0, phi_tol);
-            gwy_field_grains_extract_grain(buf, (gint)floor(xc), (gint)floor(yc));
-            gwy_field_fill_voids(buf, TRUE);
-            gwy_field_max_of_fields(impfaces, buf, impfaces);
+            mark_facet(xder, yder, maskbuf, theta0, phi0, phi_tol);
+            gwy_nield_isolate_at(maskbuf, (gint)floor(xc), (gint)floor(yc), NULL);
+            gwy_nield_fill_voids(maskbuf, TRUE);
+            gwy_nield_union(impfaces, maskbuf);
         }
     }
+    g_object_unref(atanfield);
 
     /* Mark various derived regions. */
-    gwy_field_copy_data(adjusted, above);
-    gwy_field_copy_data(adjusted, below);
-    gwy_field_threshold(above, plane_tol, 0.0, 1.0);
-    gwy_field_threshold(below, -plane_tol, 1.0, 0.0);
-    gwy_field_max_of_fields(args->result[RESULT_PLANE], above, below);
-    gwy_field_threshold(args->result[RESULT_PLANE], 0.5, 1.0, 0.0);
+    gwy_nield_mark_by_threshold(above, adjusted, plane_tol, TRUE);
+    gwy_nield_mark_by_threshold(below, adjusted, -plane_tol, FALSE);
+    gwy_nield_copy_data(above, args->result[RESULT_PLANE]);
+    gwy_nield_union(args->result[RESULT_PLANE], below);
+    gwy_nield_invert(args->result[RESULT_PLANE]);
 
-    gwy_field_copy_data(below, imprint);
-    gwy_field_grains_extract_grain(imprint, (gint)floor(imp->x0), (gint)floor(imp->y0));
-    gwy_field_fill_voids(imprint, TRUE);
+    gwy_nield_copy_data(below, imprint);
+    gwy_nield_isolate_at(imprint, (gint)floor(imp->x0), (gint)floor(imp->y0), NULL);
+    gwy_nield_fill_voids(imprint, TRUE);
     /* FIXME */
     if (!nsides)
-        gwy_field_copy_data(imprint, impfaces);
+        gwy_nield_copy_data(imprint, impfaces);
 
     mark_pileup(above, imprint, pileup);
-    gwy_field_min_of_fields(args->result[RESULT_INNER_PILEUP], pileup, impfaces);
-    gwy_field_subtract_fields(args->result[RESULT_OUTER_PILEUP], pileup, impfaces);
-    gwy_field_threshold(args->result[RESULT_INNER_PILEUP], 0.5, 0.0, 1.0);
+    gwy_nield_copy_data(pileup, innerpileup);
+    gwy_nield_intersect(innerpileup, impfaces);
+    gwy_nield_copy_data(pileup, outerpileup);
+    gwy_nield_merge(outerpileup, impfaces, GWY_MERGE_SUBTRACT);
 
-    ksize = GWY_ROUND(sqrt(xres*yres)/150.0);
+    gint ksize = GWY_ROUND(sqrt(xres*yres)/150.0);
     ksize = MAX(ksize, 2);
-    kernel = gwy_field_new(ksize, ksize, 1.0, 1.0, TRUE);
-    gwy_field_elliptic_area_fill(kernel, 0, 0, ksize, ksize, 1.0);
-    gwy_field_copy_data(impfaces, args->result[RESULT_CONTACT_AREA]);
-    gwy_field_area_filter_min_max(args->result[RESULT_CONTACT_AREA], kernel, GWY_MIN_MAX_FILTER_CLOSING,
-                                  0, 0, xres, yres);
+    GwyNield *kernel = gwy_nield_new(ksize, ksize);
+    gwy_nield_elliptic_fill(kernel);
+    GwyField *contact = gwy_field_new(xres, yres, xres, yres, FALSE);
+    gwy_field_fill_mask(contact, impfaces, 0.0, 1.0);
+    gwy_field_filter_min_max(contact, kernel, GWY_MIN_MAX_FILTER_CLOSING);
     g_object_unref(kernel);
-    gwy_field_fill_voids(args->result[RESULT_CONTACT_AREA], TRUE);
+    gwy_nield_mark_by_threshold(args->result[RESULT_CONTACT_AREA], contact, 0.5, TRUE);
+    gwy_nield_fill_voids(args->result[RESULT_CONTACT_AREA], TRUE);
+    g_object_unref(contact);
 
-    gwy_field_copy_data(impfaces, facesborder);
-    gwy_field_grains_grow(facesborder, 1.0, GWY_DISTANCE_TRANSFORM_CHESS, FALSE);
-    gwy_field_threshold(facesborder, 0.5, 0.0, 1.0);
-    gwy_field_subtract_fields(facesborder, facesborder, impfaces);
-    gwy_field_threshold(facesborder, 0.5, 0.0, 1.0);
+    gwy_nield_copy_data(impfaces, facesborder);
+    gwy_nield_grow(facesborder, 1.0, GWY_DISTANCE_TRANSFORM_CHESS, FALSE);
+    gwy_nield_merge(facesborder, impfaces, GWY_MERGE_SUBTRACT);
 
     /* Calculate surfaces and volumes. */
     calc_surface_and_volume(adjusted, impfaces, &imp->Aproj_imp, &imp->Asurf_imp, &imp->Vimp);
@@ -581,24 +578,24 @@ execute(ModuleArgs *args)
 
 /* Always make average height over the exterior zero.  Plane-level only if requested. */
 static void
-level_using_exterior(GwyField *field, GwyField *mask, gdouble wfrac, gboolean do_level)
+level_using_exterior(GwyField *field, GwyNield *mask, gdouble wfrac, gboolean do_level)
 {
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     gint wx = MAX(GWY_ROUND(xres*wfrac), 1);
     gint wy = MAX(GWY_ROUND(yres*wfrac), 1);
     gdouble a, bx, by;
 
-    gwy_field_clear(mask);
-    gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, xres, wy, 1.0);
-    gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, wx, yres, 1.0);
-    gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, yres-wy, xres, wy, 1.0);
-    gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, xres-wx, 0, wx, yres, 1.0);
+    gwy_nield_clear(mask);
+    gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, xres, wy, 1);
+    gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 0, wx, yres, 1);
+    gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, yres-wy, xres, wy, 1);
+    gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, xres-wx, 0, wx, yres, 1);
     if (do_level) {
         gwy_field_area_fit_plane(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, &a, &bx, &by);
         gwy_debug("fitted plane bx=%g, by=%g", bx, by);
         gwy_field_plane_level(field, a, bx, by);
     }
-    a = gwy_field_area_get_avg(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
+    a = gwy_field_area_mean(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
     gwy_field_add(field, -a);
 }
 
@@ -609,9 +606,7 @@ compute_slopes(GwyField *field, gint kernel_size,
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     GwyPlaneFitQuantity quantites[2] = { GWY_PLANE_FIT_BX, GWY_PLANE_FIT_BY };
     GwyField *fields[2] = { xder, yder };
-    const gdouble *xd, *yd;
-    gdouble *a;
-    gint i, n = xres*yres;
+    gint n = xres*yres;
 
     if (!kernel_size)
         gwy_field_filter_slope(field, xder, yder);
@@ -621,58 +616,54 @@ compute_slopes(GwyField *field, gint kernel_size,
         gwy_field_multiply(yder, 1.0/gwy_field_get_dy(field));
     }
 
-    xd = gwy_field_get_data_const(xder);
-    yd = gwy_field_get_data_const(yder);
-    a = gwy_field_get_data(atanfield);
+    const gdouble *xd = gwy_field_get_data_const(xder);
+    const gdouble *yd = gwy_field_get_data_const(yder);
+    gdouble *a = gwy_field_get_data(atanfield);
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(a,xd,yd,n)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gint i = 0; i < n; i++) {
         a[i] = gwy_canonicalize_angle(atan2(-yd[i], xd[i]), TRUE, TRUE);
     }
 }
 
 static gdouble
-find_prevalent_phi(GwyField *field, GwyField *exclmask,
+find_prevalent_phi(GwyField *field, GwyNield *exclmask,
                    GwyField *xder, GwyField *yder, GwyField *atanfield)
 {
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     const gdouble *xd = gwy_field_get_data_const(xder);
     const gdouble *yd = gwy_field_get_data_const(yder);
-    const gdouble *m = gwy_field_get_data_const(exclmask);
+    const gint *m = gwy_nield_get_data_const(exclmask);
     const gdouble *a = gwy_field_get_data_const(atanfield);
-    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
-    GwyLine *phidist;
-    gdouble *data;
-    gdouble d, phi, x, y[3];
-    gint n, i, iphi, size;
 
-    n = xres*yres;
-    gwy_field_area_count_in_range(exclmask, NULL, GWY_MASK_IGNORE, 0, 0, xres, yres, 0.5, 0.5, &size, NULL);
+    gint n = xres*yres;
+    gint size = n - gwy_nield_count(exclmask);
     size = (gint)floor(5.49*cbrt(size) + 0.5);
     size = MAX(size, 24);
     gwy_debug("phi dist size %d", size);
 
-    phidist = gwy_line_new(size, 2.0*G_PI, TRUE);
-    data = gwy_line_get_data(phidist);
-    for (i = 0; i < n; i++) {
-        if (m[i] <= 0.0) {
-            d = xd[i]*xd[i] + yd[i]*yd[i];
-            iphi = floor(size*a[i]/(2.0*G_PI));
+    GwyLine *phidist = gwy_line_new(size, 2.0*G_PI, TRUE);
+    gdouble *data = gwy_line_get_data(phidist);
+    for (gint i = 0; i < n; i++) {
+        if (m[i] <= 0) {
+            gdouble d = xd[i]*xd[i] + yd[i]*yd[i];
+            gint iphi = floor(size*a[i]/(2.0*G_PI));
             iphi = CLAMP(iphi, 0, size-1);
             data[iphi] += sqrt(d);
         }
     }
-    i = (gint)gwy_line_max_pos_i(phidist);
+    gint i = (gint)gwy_line_max_pos_i(phidist);
 
     gwy_debug("phi maximum at %d (%g deg)", i, 360.0*(i + 0.5)/size);
+    gdouble y[3];
     y[0] = gwy_line_get_val(phidist, (i + size-1) % size);
     y[1] = gwy_line_get_val(phidist, i);
     y[2] = gwy_line_get_val(phidist, (i+1) % size);
-    x = 0.0;
+    gdouble x = 0.0;
     gwy_math_refine_maximum_1d(y, &x);
-    phi = gwy_line_get_dx(phidist)*(i + 0.5 + x);
+    gdouble phi = gwy_line_get_dx(phidist)*(i + 0.5 + x);
     gwy_debug("refined phi to %g deg", gwy_rad2deg(phi));
 
     g_object_unref(phidist);
@@ -750,21 +741,20 @@ calc_mean_normal(GwyField *xder, GwyField *yder, gdouble x, gdouble y, gdouble r
 }
 
 static void
-mark_facet(GwyField *xder, GwyField *yder, GwyField *mask,
+mark_facet(GwyField *xder, GwyField *yder, GwyNield *mask,
            gdouble theta0, gdouble phi0, gdouble tolerance)
 {
     gdouble ctol = cos(tolerance), cth0 = cos(theta0), sth0 = sin(theta0), cphi0 = cos(phi0), sphi0 = sin(phi0);
     const gdouble *xd = gwy_field_get_data_const(xder);
     const gdouble *yd = gwy_field_get_data_const(yder);
-    gdouble *md = gwy_field_get_data(mask);
-    guint i, n = gwy_field_get_xres(xder)*gwy_field_get_yres(xder);
+    gint *md = gwy_nield_get_data(mask);
+    guint n = gwy_field_get_xres(xder)*gwy_field_get_yres(xder);
 
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(xd,yd,md,n,cth0,sth0,cphi0,sphi0,ctol)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gint i = 0; i < n; i++) {
         gdouble stheta2 = xd[i]*xd[i] + yd[i]*yd[i];
         gdouble stheta = sqrt(stheta2);
         gdouble ctheta = sqrt(1.0 - fmin(stheta2, 1.0));
@@ -840,48 +830,48 @@ end:
 
 /* Keep connected components not too far from imprint in pileup. */
 static void
-mark_pileup(GwyField *above, GwyField *imprint, GwyField *pileup)
+mark_pileup(GwyNield *above, GwyNield *imprint, GwyNield *pileup)
 {
-    gint xres = gwy_field_get_xres(imprint), yres = gwy_field_get_yres(imprint);
-    gint ngrains, i, n = xres*yres;
-    gint *grains, *keep;
-    gdouble *d;
-    gdouble maxdist;
+    gint xres = gwy_nield_get_xres(imprint), yres = gwy_nield_get_yres(imprint);
+    gint n = xres*yres;
 
-    maxdist = fmax(0.02*sqrt(gwy_field_get_sum(imprint)), 2.1);
+    gdouble maxdist = fmax(0.02*sqrt(gwy_nield_count(imprint)), 2.1);
     gwy_debug("using maxdist %g", maxdist);
 
-    gwy_field_copy_data(imprint, pileup);
-    gwy_field_grains_invert(pileup);
-    gwy_field_grain_simple_dist_trans(pileup, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
-    d = gwy_field_get_data(pileup);
+    gwy_nield_copy_data(imprint, pileup);
+    gwy_nield_invert(pileup);
+    GwyField *distances = gwy_field_new(xres, yres, xres, yres, FALSE);
+    gwy_nield_distance_transform(pileup, distances, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
+    const gdouble *d = gwy_field_get_data(distances);
 
-    grains = g_new0(gint, n);
-    ngrains = gwy_field_number_grains(above, grains);
-    keep = g_new0(gint, ngrains+1);
-    for (i = 0; i < n; i++)
+    gint ngrains = gwy_nield_number_contiguous(above);
+    gint *grains = gwy_nield_get_data(above);
+    gint *keep = g_new0(gint, ngrains+1);
+    for (gint i = 0; i < n; i++)
         keep[grains[i]] |= (d[i] > 0.0 && d[i] < maxdist);
     keep[0] = 0;
-    for (i = 0; i < n; i++)
-        d[i] = keep[grains[i]];
+    g_object_unref(distances);
+
+    gint *m = gwy_nield_get_data(pileup);
+    for (gint i = 0; i < n; i++)
+        m[i] = keep[grains[i]];
 
     g_free(keep);
-    g_free(grains);
 }
 
 static void
-calc_surface_and_volume(GwyField *field, GwyField *mask,
+calc_surface_and_volume(GwyField *field, GwyNield *mask,
                         gdouble *Aproj, gdouble *Asurf, gdouble *V)
 {
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     gdouble dA = gwy_field_get_dx(field)*gwy_field_get_dy(field);
 
     if (Aproj)
-        *Aproj = dA*gwy_field_get_sum(mask);
+        *Aproj = dA*gwy_nield_count(mask);
     if (Asurf)
-        *Asurf = gwy_field_area_get_surface_area(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
+        *Asurf = gwy_field_area_surface_area(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
     if (V)
-        *V = gwy_field_area_get_volume(field, NULL, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres);
+        *V = gwy_field_area_volume(field, mask, GWY_MASK_INCLUDE, GWY_FIELD_VOLUME_DEFAULT, 0, 0, xres, yres);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
