@@ -1,6 +1,6 @@
 /*
- *  $Id: laplace.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  $Id: laplace.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Removes data under mask, interpolating them with Laplace equation solution."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -63,29 +63,30 @@ static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     const gchar *name = gwy_process_func_current();
-    GwyField *dfield, *mfield;
+    GwyField *field;
+    GwyNield *mask;
     GQuark dquark;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD_KEY, &dquark,
-                                 GWY_APP_FIELD, &dfield,
-                                 GWY_APP_MASK_FIELD, &mfield,
+                                 GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(dfield && dquark && mfield);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
+    g_return_if_fail(field && dquark && mask);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
     if (gwy_strequal(name, "laplace"))
-        gwy_field_laplace_solve(dfield, mfield, -1, 1.0);
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 1.0);
     else if (gwy_strequal(name, "zeromasked")) {
-        gint xres = gwy_field_get_xres(dfield);
-        gint yres = gwy_field_get_yres(dfield);
-        gwy_field_area_fill(dfield, mfield, GWY_MASK_INCLUDE, 0, 0, xres, yres, 0.0);
+        gint xres = gwy_field_get_xres(field);
+        gint yres = gwy_field_get_yres(field);
+        gwy_field_area_fill(field, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, 0.0);
     }
     else {
         g_assert_not_reached();
     }
-    gwy_field_data_changed(dfield);
+    gwy_field_data_changed(field);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
