@@ -1,6 +1,6 @@
 /*
- *  $Id: level.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: level.c 29510 2026-02-20 15:22:39Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Levels data by simple plane subtraction or by rotation, and fixes minimal or mean value to zero."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "3.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -108,7 +108,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GwyDialogOutcome outcome = GWY_DIALOG_PROCEED;
     GwyMaskingType masking;
     GwyParams *params;
-    GwyField *dfield, *mask;
+    GwyField *dfield;
+    GwyNield *mask;
     gdouble c, bx, by;
     gint xres, yres;
     GQuark quark;
@@ -136,7 +137,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     xres = gwy_field_get_xres(dfield);
     yres = gwy_field_get_yres(dfield);
 
-    gwy_app_undo_qcheckpoint(GWY_CONTAINER(data), quark, NULL);
+    gwy_app_undo_qcheckpoint(GWY_DICT(data), quark, NULL);
 
     if (gwy_stramong(funcname, "level", "level_rotate", NULL)) {
         gwy_field_area_fit_plane(dfield, mask, masking, 0, 0, xres, yres, &c, &bx, &by);
@@ -153,25 +154,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         }
     }
     else if (gwy_strequal(funcname, "fix_zero")) {
-        if (mask)
-            gwy_field_area_get_min_max(dfield, mask, masking, 0, 0, xres, yres, &c, NULL);
-        else
-            c = gwy_field_get_min(dfield);
-        gwy_field_add(dfield, -c);
+        gwy_field_add(dfield, -gwy_field_area_min(dfield, mask, masking, 0, 0, xres, yres));
     }
     else if (gwy_strequal(funcname, "zero_mean")) {
-        if (mask)
-            c = gwy_field_area_get_avg(dfield, mask, masking, 0, 0, xres, yres);
-        else
-            c = gwy_field_get_avg(dfield);
-        gwy_field_add(dfield, -c);
+        gwy_field_add(dfield, -gwy_field_area_mean(dfield, mask, masking, 0, 0, xres, yres));
     }
     else if (gwy_strequal(funcname, "zero_max")) {
-        if (mask)
-            gwy_field_area_get_min_max(dfield, mask, masking, 0, 0, xres, yres, NULL, &c);
-        else
-            c = gwy_field_get_max(dfield);
-        gwy_field_add(dfield, -c);
+        gwy_field_add(dfield, -gwy_field_area_max(dfield, mask, masking, 0, 0, xres, yres));
     }
     else {
         g_assert_not_reached();
