@@ -1,6 +1,6 @@
 /*
- *  $Id: level_grains.c 28873 2025-11-18 14:59:29Z yeti-dn $
- *  Copyright (C) 2011-2021 David Necas (Yeti).
+ *  $Id: level_grains.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2011-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyField *bg;
 } ModuleArgs;
@@ -53,7 +53,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Levels individual grains, interpolating the shifts between using Laplacian interpolation."),
     "David Nečas <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2011",
 };
@@ -125,13 +125,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.bg = gwy_field_new_alike(args.field, FALSE);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome != GWY_DIALOG_PROCEED)
             goto end;
     }
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     execute(&args);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     gwy_field_data_changed(args.field);
@@ -180,34 +180,27 @@ run_gui(ModuleArgs *args)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *invmask, *background = args->bg, *mask = args->mask;
+    GwyField *background = args->bg;
+    GwyNield *mask = args->mask;
+    gint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
     GwyGrainQuantity base = gwy_params_get_enum(args->params, PARAM_BASE);
-    gdouble *heights, *bgdata;
-    gint *grains;
-    gint i, xres, yres, ngrains;
+    guint ngrains = gwy_nield_max(mask);
 
-    xres = gwy_field_get_xres(mask);
-    yres = gwy_field_get_yres(mask);
-    grains = g_new0(gint, xres*yres);
-    ngrains = gwy_field_number_grains(mask, grains);
-    if (!ngrains) {
-        g_free(grains);
+    if (!ngrains)
         return;
-    }
 
-    heights = g_new(gdouble, ngrains+1);
-    gwy_field_grains_get_values(args->field, heights, ngrains, grains, base);
+    gdouble *heights = gwy_nield_grain_quantity(mask, args->field, base, &ngrains);
     heights[0] = 0.0;
 
-    bgdata = gwy_field_get_data(background);
-    for (i = 0; i < xres*yres; i++)
+    const gint *grains = gwy_nield_get_data_const(mask);
+    gdouble *bgdata = gwy_field_get_data(background);
+    for (gint i = 0; i < xres*yres; i++)
         bgdata[i] = -heights[grains[i]];
-    g_free(grains);
     g_free(heights);
 
-    invmask = gwy_field_copy(mask);
-    gwy_field_grains_invert(invmask);
-    gwy_field_laplace_solve(background, invmask, -1, 0.8);
+    GwyNield *invmask = gwy_nield_copy(mask);
+    gwy_nield_invert(invmask);
+    gwy_field_laplace_solve(background, invmask, GWY_LAPLACE_MASKED, 0.8);
     g_object_unref(invmask);
 
     gwy_field_invert_value(background);
