@@ -1,6 +1,6 @@
 /*
- *  $Id: linecorrect.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2003-2023 David Necas (Yeti), Petr Klapetek, Luke Somers.
+ *  $Id: linecorrect.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek, Luke Somers.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, lsomers@sas.upenn.edu.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Corrects line defects (mostly experimental algorithms)."),
     "Yeti <yeti@gwyddion.net>, Luke Somers <lsomers@sas.upenn.edu>",
-    "1.12",
+    "2.0",
     "David Nečas (Yeti) & Petr Klapetek & Luke Somers",
     "2004",
 };
@@ -69,117 +69,107 @@ module_register(void)
 
 static void
 calculate_segment_correction(const gdouble *drow,
-                             gdouble *mrow,
+                             gdouble *output,
                              gint xres,
                              gint len)
 {
     const gint min_len = 4;
-    gdouble corr;
-    gint j;
 
     if (len >= min_len) {
-        corr = 0.0;
-        for (j = 0; j < len; j++)
+        gdouble corr = 0.0;
+        for (gint j = 0; j < len; j++)
             corr += (drow[j] + drow[2*xres + j])/2.0 - drow[xres + j];
         corr /= len;
-        for (j = 0; j < len; j++)
-            mrow[j] = (3*corr + (drow[j] + drow[2*xres + j])/2.0 - drow[xres + j])/4.0;
-    }
-    else {
-        for (j = 0; j < len; j++)
-            mrow[j] = 0.0;
+        for (gint j = 0; j < len; j++)
+            output[j] = (3*corr + (drow[j] + drow[2*xres + j])/2.0 - drow[xres + j])/4.0;
     }
+    /* output is expected to be zero-initialised. */
 }
 
 static void
-line_correct_step_iter(GwyField *dfield,
-                       GwyField *mask)
+line_correct_step_iter(GwyField *field,
+                       GwyField *tmp)
 {
     const gdouble threshold = 3.0;
-    gint xres, yres, i, j, len;
-    gdouble u, v, w;
-    const gdouble *d, *drow;
-    gdouble *m, *mrow;
 
-    yres = gwy_field_get_yres(dfield);
-    xres = gwy_field_get_xres(dfield);
-    d = gwy_field_get_data_const(dfield);
-    m = gwy_field_get_data(mask);
+    gwy_field_clear(tmp);
+    gint yres = gwy_field_get_yres(field), xres = gwy_field_get_xres(field);
+    const gdouble *d = gwy_field_get_data_const(field);
+    gdouble *b = gwy_field_get_data(tmp);
 
-    w = 0.0;
-    for (i = 0; i < yres-1; i++) {
-        drow = d + i*xres;
-        for (j = 0; j < xres; j++) {
-            v = drow[j + xres] - drow[j];
+    gdouble w = 0.0;
+    for (gint i = 0; i < yres-1; i++) {
+        const gdouble *drow = d + i*xres;
+        for (gint j = 0; j < xres; j++) {
+            gdouble v = drow[j + xres] - drow[j];
             w += v*v;
         }
     }
     w = w/(yres-1)/xres;
 
-    for (i = 0; i < yres-2; i++) {
-        drow = d + i*xres;
-        mrow = m + (i + 1)*xres;
+    gint *mrow = g_new(gint, xres);
+    for (gint i = 0; i < yres-2; i++) {
+        const gdouble *drow = d + i*xres;
+        gdouble *brow = b + i*xres;
+        gwy_clear(mrow, xres);
 
-        for (j = 0; j < xres; j++) {
-            u = drow[xres + j];
-            v = (u - drow[j])*(u - drow[j + 2*xres]);
+        for (gint j = 0; j < xres; j++) {
+            gdouble u = drow[xres + j];
+            gdouble v = (u - drow[j])*(u - drow[j + 2*xres]);
             if (G_UNLIKELY(v > threshold*w)) {
                 if (2*u - drow[j] - drow[j + 2*xres] > 0)
-                    mrow[j] = 1.0;
+                    mrow[j] = 1;
                 else
-                    mrow[j] = -1.0;
+                    mrow[j] = -1;
             }
         }
 
-        len = 1;
+        gint len = 1, j;
         for (j = 1; j < xres; j++) {
             if (mrow[j] == mrow[j-1])
                 len++;
             else {
                 if (mrow[j-1])
-                    calculate_segment_correction(drow + j-len, mrow + j-len, xres, len);
+                    calculate_segment_correction(drow + j-len, brow + j-len, xres, len);
                 len = 1;
             }
         }
         if (mrow[j-1])
-            calculate_segment_correction(drow + j-len, mrow + j-len, xres, len);
+            calculate_segment_correction(drow + j-len, brow + j-len, xres, len);
     }
 
-    gwy_field_sum_fields(dfield, dfield, mask);
+    gwy_field_sum_fields(field, field, tmp);
 }
 
 static void
 line_correct_step(GwyFile *data,
                   GwyRunModeFlags mode)
 {
-    GwyField *dfield, *mask;
-    GwyLine *shifts;
+    GwyField *field;
     GQuark dquark;
-    gdouble avg;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, &dfield,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
                                  GWY_APP_FIELD_KEY, &dquark,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(dfield && dquark);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
+    g_return_if_fail(field && dquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
 
-    avg = gwy_field_get_avg(dfield);
-    shifts = gwy_field_find_row_shifts_trimmed_mean(dfield, NULL, GWY_MASK_IGNORE, 0.5, 0);
-    gwy_field_subtract_row_shifts(dfield, shifts);
+    gdouble avg = gwy_field_mean(field);
+    GwyLine *shifts = gwy_field_find_row_shifts_trimmed_mean(field, NULL, GWY_MASK_IGNORE, 0.5, 0);
+    gwy_field_subtract_row_shifts(field, shifts);
     g_object_unref(shifts);
 
-    mask = gwy_field_new_alike(dfield, TRUE);
-    line_correct_step_iter(dfield, mask);
-    gwy_field_clear(mask);
-    line_correct_step_iter(dfield, mask);
-    g_object_unref(mask);
+    GwyField *tmp = gwy_field_new_alike(field, FALSE);
+    line_correct_step_iter(field, tmp);
+    line_correct_step_iter(field, tmp);
+    g_object_unref(tmp);
 
-    gwy_field_filter_conservative(dfield, 5);
-    gwy_field_add(dfield, avg - gwy_field_get_avg(dfield));
-    gwy_field_data_changed(dfield);
+    gwy_field_filter_conservative(field, 5);
+    gwy_field_add(field, avg - gwy_field_mean(field));
+    gwy_field_data_changed(field);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
@@ -202,42 +192,37 @@ static void
 mark_inverted_lines(GwyFile *data,
                     GwyRunModeFlags mode)
 {
-    GwyField *dfield, *existing_mask, *mask;
-    GwyLine *avgline, *rmsline;
+    GwyField *field;
+    GwyNield *existing_mask;
     GQuark mquark;
-    gdouble *weight;
-    const gdouble *avg, *rms;
-    gint xres, yres, i, from, j, id;
-    gdouble total_rms, s, wmax;
-    gboolean have_negative = FALSE, inverted;
-    const gdouble *d;
+    gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, &dfield,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
                                  GWY_APP_MASK_FIELD, &existing_mask,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(dfield && mquark);
+    g_return_if_fail(field && mquark);
 
-    total_rms = gwy_field_get_rms(dfield);
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
+    gdouble total_rms = gwy_field_rms(field);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     if (total_rms <= 0.0 || yres < 3 || xres < 3)
         return;
 
-    avgline = gwy_line_new(yres, yres, FALSE);
-    gwy_field_get_line_stats(dfield, avgline, GWY_LINE_STAT_MEAN, GWY_ORIENTATION_HORIZONTAL);
-    avg = gwy_line_get_data(avgline);
+    GwyLine *avgline = gwy_line_new(yres, yres, FALSE);
+    gwy_field_line_stats(field, avgline, GWY_LINE_STAT_MEAN, GWY_ORIENTATION_HORIZONTAL);
+    gdouble *avg = gwy_line_get_data(avgline);
 
-    rmsline = gwy_line_new(yres, yres, FALSE);
-    gwy_field_get_line_stats(dfield, rmsline, GWY_LINE_STAT_RMS, GWY_ORIENTATION_HORIZONTAL);
-    rms = gwy_line_get_data(rmsline);
+    GwyLine *rmsline = gwy_line_new(yres, yres, FALSE);
+    gwy_field_line_stats(field, rmsline, GWY_LINE_STAT_RMS, GWY_ORIENTATION_HORIZONTAL);
+    gdouble *rms = gwy_line_get_data(rmsline);
 
-    d = gwy_field_get_data_const(dfield);
+    gboolean have_negative = FALSE;
+    const gdouble *d = gwy_field_get_data_const(field);
     /* Calculate neighbour row correlations. */
-    weight = g_new0(gdouble, yres-1);
-    for (i = 0; i < yres-1; i++) {
+    gdouble *weight = g_new0(gdouble, yres-1);
+    for (gint i = 0; i < yres-1; i++) {
         weight[i] = row_correlation(d + i*xres, avg[i], rms[i],
                                     d + (i+1)*xres, avg[i+1], rms[i+1],
                                     xres, total_rms);
@@ -252,26 +237,25 @@ mark_inverted_lines(GwyFile *data,
     }
 
     /* Find the most positively correlated block. */
-    from = 0;
-    for (i = 0; i < yres-2; i++) {
+    gint from = 0;
+    for (gint i = 0; i < yres-2; i++) {
         if (weight[i]*weight[i+1] < 0.0) {
-            s = 0.0;
-            for (j = from; j <= i; j++)
+            gdouble s = 0.0;
+            for (gint j = from; j <= i; j++)
                 s += weight[j];
-            for (j = from; j <= i; j++)
-                weight[j] = s;
+            gwy_math_fill(weight + from, i+1 - from, s);
             from = i+1;
         }
     }
-    s = 0.0;
-    for (j = from; j < yres-1; j++)
+    gdouble s = 0.0;
+    for (gint j = from; j < yres-1; j++)
         s += weight[j];
-    for (j = from; j < yres-1; j++)
+    for (gint j = from; j < yres-1; j++)
         weight[j] = s;
 
-    wmax = 0.0;
+    gdouble wmax = 0.0;
     from = 0;
-    for (i = 0; i < yres-1; i++) {
+    for (gint i = 0; i < yres-1; i++) {
         if (weight[i] > wmax) {
             wmax = weight[i];
             from = i;
@@ -281,44 +265,36 @@ mark_inverted_lines(GwyFile *data,
     g_object_unref(avgline);
     g_object_unref(rmsline);
 
-    mask = gwy_field_new_alike(dfield, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
+    GwyNield *mask = gwy_field_new_nield_alike(field);
 
     /* Extend the sign of this block downwards.  Note weight[i] represents the sign between rows i and i+1. */
-    inverted = FALSE;
-    for (i = from; i < yres-1; i++) {
+    gboolean inverted = FALSE;
+    for (gint i = from; i < yres-1; i++) {
         if (weight[i] < 0.0)
             inverted = !inverted;
         if (inverted)
-            gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, i+1, xres, 1, 1.0);
+            gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, i+1, xres, 1, 1);
     }
 
     /* Extend the sign of this block upwards.  Note weight[i] represents the sign between rows i and i+1. */
     inverted = FALSE;
-    for (i = j = from; i >= 0; i--) {
+    for (gint i = from; i >= 0; i--) {
         if (weight[i] < 0.0)
             inverted = !inverted;
         if (inverted)
-            gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, i, xres, 1, 1.0);
+            gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, i, xres, 1, 1);
     }
 
     g_free(weight);
 
-    if (!existing_mask && gwy_field_get_max(mask) <= 0.0) {
+    gint nonempty = gwy_nield_count(mask);
+    if (!existing_mask && !nonempty) {
         g_object_unref(mask);
         return;
     }
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-
-    if (existing_mask) {
-        gwy_field_copy_data(mask, existing_mask);
-        gwy_field_data_changed(existing_mask);
-    }
-    else {
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, mask);
-    }
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_file_set_image_mask(data, id, nonempty ? mask : NULL);
     g_object_unref(mask);
-
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
