@@ -1,6 +1,6 @@
 /*
- *  $Id: linematch.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2015-2024 David Necas (Yeti).
+ *  $Id: linematch.c 29543 2026-02-24 14:07:07Z yeti-dn $
+ *  Copyright (C) 2015-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -57,7 +57,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyField *bg;
     GwyLine *shifts;
@@ -82,25 +82,25 @@ static void             param_changed            (ModuleGUI *gui,
                                                   gint id);
 static void             preview                  (gpointer user_data);
 static void             linematch_do_trimmed_mean(GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking,
                                                   gdouble trim_fraction);
 static void             linematch_do_trimmed_diff(GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking,
                                                   gdouble trim_fraction);
 static void             linematch_do_modus       (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             linematch_do_match       (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             linematch_do_facet_tilt  (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             zero_level_row_shifts    (GwyLine *shifts);
@@ -121,7 +121,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Aligns rows by various methods."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -168,7 +168,7 @@ define_module_params(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *field, *mask;
+    GwyField *field;
     GQuark quark;
     GwyParams *params;
     ModuleArgs args;
@@ -179,28 +179,27 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD_KEY, &quark,
                                  GWY_APP_FIELD, &field,
-                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_MASK_FIELD, &args.mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     g_return_if_fail(field && quark);
 
     args.field = field;
-    args.mask = mask;
     args.bg = gwy_field_new_alike(field, FALSE);
     args.shifts = gwy_line_new(field->yres, field->yreal, FALSE);
     gwy_field_copy_units_to_line(field, args.shifts);
     args.params = params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(params);
         if (outcome != GWY_DIALOG_HAVE_RESULT)
             goto end;
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         gwy_field_copy_data(args.result, field);
     }
     else {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         args.result = g_object_ref(field);
         execute(&args);
     }
@@ -327,9 +326,9 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *rowfield = args->result, *field = args->field;
+    GwyNield *rowmask = args->mask, *mask = args->mask;
     GwyLine *shifts = args->shifts;
-    GwyField *myfield, *mymask;
     LineMatchMethod method = gwy_params_get_enum(args->params, PARAM_METHOD);
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     GwyOrientation direction = gwy_params_get_enum(args->params, PARAM_DIRECTION);
@@ -340,50 +339,48 @@ execute(ModuleArgs *args)
     gwy_field_assign(args->bg, field);
 
     /* Transpose the fields if necessary. */
-    mymask = mask;
-    myfield = args->result;
     if (direction == GWY_ORIENTATION_VERTICAL) {
-        myfield = gwy_field_new_alike(args->result, FALSE);
-        gwy_field_transpose(args->result, myfield, FALSE);
+        rowfield = gwy_field_new_alike(args->result, FALSE);
+        gwy_field_transpose(args->result, rowfield, FALSE);
         if (mask) {
-            mymask = gwy_field_new_alike(mask, FALSE);
-            gwy_field_transpose(mask, mymask, FALSE);
+            rowmask = gwy_nield_new_alike(mask);
+            gwy_nield_transpose(mask, rowmask, FALSE);
         }
     }
 
-    gwy_line_resize(shifts, gwy_field_get_yres(myfield));
-    gwy_line_set_real(shifts, gwy_field_get_yreal(myfield));
+    gwy_line_resize(shifts, gwy_field_get_yres(rowfield));
+    gwy_line_set_real(shifts, gwy_field_get_yreal(rowfield));
 
     /* Perform the correction. */
     if (method == LINE_MATCH_POLY) {
         if (max_degree == 0)
-            linematch_do_trimmed_mean(myfield, mymask, shifts, masking, 0.0);
+            linematch_do_trimmed_mean(rowfield, rowmask, shifts, masking, 0.0);
         else
-            gwy_field_row_level_poly(myfield, mymask, masking, max_degree, shifts);
+            gwy_field_row_level_poly(rowfield, rowmask, masking, max_degree, shifts);
     }
     else if (method == LINE_MATCH_MEDIAN)
-        linematch_do_trimmed_mean(myfield, mymask, shifts, masking, 0.5);
+        linematch_do_trimmed_mean(rowfield, rowmask, shifts, masking, 0.5);
     else if (method == LINE_MATCH_MEDIAN_DIFF)
-        linematch_do_trimmed_diff(myfield, mymask, shifts, masking, 0.5);
+        linematch_do_trimmed_diff(rowfield, rowmask, shifts, masking, 0.5);
     else if (method == LINE_MATCH_MODUS)
-        linematch_do_modus(myfield, mymask, shifts, masking);
+        linematch_do_modus(rowfield, rowmask, shifts, masking);
     else if (method == LINE_MATCH_MATCH)
-        linematch_do_match(myfield, mymask, shifts, masking);
+        linematch_do_match(rowfield, rowmask, shifts, masking);
     else if (method == LINE_MATCH_FACET_TILT)
-        linematch_do_facet_tilt(myfield, mymask, shifts, masking);
+        linematch_do_facet_tilt(rowfield, rowmask, shifts, masking);
     else if (method == LINE_MATCH_TRIMMED_MEAN)
-        linematch_do_trimmed_mean(myfield, mymask, shifts, masking, trim_fraction);
+        linematch_do_trimmed_mean(rowfield, rowmask, shifts, masking, trim_fraction);
     else if (method == LINE_MATCH_TMEAN_DIFF)
-        linematch_do_trimmed_diff(myfield, mymask, shifts, masking, trim_fraction);
+        linematch_do_trimmed_diff(rowfield, rowmask, shifts, masking, trim_fraction);
     else {
         g_assert_not_reached();
     }
 
     /* Transpose back if necessary. */
     if (direction == GWY_ORIENTATION_VERTICAL) {
-        g_clear_object(&mymask);
-        gwy_field_transpose(myfield, args->result, FALSE);
-        g_object_unref(myfield);
+        g_clear_object(&rowmask);
+        gwy_field_transpose(rowfield, args->result, FALSE);
+        g_object_unref(rowfield);
     }
     gwy_field_subtract_fields(args->bg, args->bg, args->result);
 }
@@ -420,43 +417,44 @@ preview(gpointer user_data)
 }
 
 static void
-linematch_do_trimmed_mean(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_trimmed_mean(GwyField *field, GwyNield *mask, GwyLine *shifts,
                           GwyMaskingType masking, gdouble trimfrac)
 {
-    GwyLine *myshifts;
-
-    myshifts = gwy_field_find_row_shifts_trimmed_mean(field, mask, masking, trimfrac, 0);
+    GwyLine *myshifts = gwy_field_find_row_shifts_trimmed_mean(field, mask, masking, trimfrac, 0);
     gwy_field_subtract_row_shifts(field, myshifts);
     gwy_line_assign(shifts, myshifts);
     g_object_unref(myshifts);
 }
 
 static void
-linematch_do_trimmed_diff(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_trimmed_diff(GwyField *field, GwyNield *mask, GwyLine *shifts,
                           GwyMaskingType masking, gdouble trimfrac)
 {
-    GwyLine *myshifts;
-
-    myshifts = gwy_field_find_row_shifts_trimmed_diff(field, mask, masking, trimfrac, 0);
+    GwyLine *myshifts = gwy_field_find_row_shifts_trimmed_diff(field, mask, masking, trimfrac, 0);
     gwy_field_subtract_row_shifts(field, myshifts);
     gwy_line_assign(shifts, myshifts);
     g_object_unref(myshifts);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static void
-linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
+linematch_do_modus(GwyField *field, GwyNield *mask, GwyLine *modi,
                    GwyMaskingType masking)
 {
-    gint xres, yres;
-    const gdouble *d, *m;
-    gdouble total_median;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    total_median = gwy_field_area_get_median(field, mask, masking, 0, 0, xres, yres);
-
-    d = gwy_field_get_data(field);
-    m = mask ? gwy_field_get_data_const(mask) : NULL;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble total_median = gwy_field_area_median(field, mask, masking, 0, 0, xres, yres);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -466,22 +464,18 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
         GwyLine *line = gwy_line_new(xres, 1.0, FALSE);
         gdouble *buf = gwy_line_get_data(line);
         gint ifrom = gwy_omp_chunk_start(yres), ito = gwy_omp_chunk_end(yres);
-        gint i;
 
-        for (i = ifrom; i < ito; i++) {
+        for (gint i = ifrom; i < ito; i++) {
             const gdouble *row = d + i*xres;
-            const gdouble *mrow = m ? m + i*xres : NULL;
-            gdouble modus;
-            gint count = 0, j;
+            const gint *mrow = m ? m + i*xres : NULL;
+            gint count = 0;
 
-            for (j = 0; j < xres; j++) {
-                if ((masking == GWY_MASK_INCLUDE && mrow[j] <= 0.0)
-                    || (masking == GWY_MASK_EXCLUDE && mrow[j] >= 1.0))
-                    continue;
-
-                buf[count++] = row[j];
+            for (gint j = 0; j < xres; j++) {
+                if (nielded_included(mrow + j, masking))
+                    buf[count++] = row[j];
             }
 
+            gdouble modus;
             if (!count)
                 modus = total_median;
             else if (count < 9)
@@ -491,7 +485,7 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
                 gdouble diff, bestdiff = G_MAXDOUBLE;
 
                 gwy_math_sort(buf, count);
-                for (j = 0; j + seglen-1 < count; j++) {
+                for (gint j = 0; j + seglen-1 < count; j++) {
                     diff = buf[j + seglen-1] - buf[j];
                     if (diff < bestdiff) {
                         bestdiff = diff;
@@ -500,7 +494,7 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
                 }
                 modus = 0.0;
                 count = 0;
-                for (j = seglen/3; j < seglen - seglen/3; j++, count++)
+                for (gint j = seglen/3; j < seglen - seglen/3; j++, count++)
                     modus += buf[bestj + j];
                 modus /= count;
             }
@@ -516,18 +510,13 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
 }
 
 static void
-linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_match(GwyField *field, GwyNield *mask, GwyLine *shifts,
                    GwyMaskingType masking)
 {
-    gint xres, yres, k;
-    const gdouble *d, *m;
-    gdouble *s;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    d = gwy_field_get_data(field);
-    m = mask ? gwy_field_get_data_const(mask) : NULL;
-    s = gwy_line_get_data(shifts);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
+    gdouble *s = gwy_line_get_data(shifts);
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -537,54 +526,46 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
         gint ifrom = gwy_omp_chunk_start(yres-1) + 1;
         gint ito = gwy_omp_chunk_end(yres-1) + 1;
         gdouble *w = g_new(gdouble, xres-1);
-        const gdouble *a, *b, *ma, *mb;
-        gdouble q, wsum, lambda, x;
-        gint i, j;
 
-        for (i = ifrom; i < ito; i++) {
-            a = d + xres*(i - 1);
-            b = d + xres*i;
-            ma = m + xres*(i - 1);
-            mb = m + xres*i;
+        for (gint i = ifrom; i < ito; i++) {
+            const gdouble *a = d + xres*(i - 1);
+            const gdouble *b = d + xres*i;
+            const gint *ma = m + xres*(i - 1);
+            const gint *mb = m + xres*i;
 
             /* Diffnorm */
-            wsum = 0.0;
-            for (j = 0; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0)))
-                    continue;
-
-                x = a[j+1] - a[j] - b[j+1] + b[j];
-                wsum += fabs(x);
+            gdouble wsum = 0.0;
+            for (gint j = 0; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking)) {
+                    gdouble x = a[j+1] - a[j] - b[j+1] + b[j];
+                    wsum += fabs(x);
+                }
             }
             if (wsum == 0) {
                 s[i] = 0.0;
                 continue;
             }
-            q = wsum/(xres-1);
+            gdouble q = wsum/(xres-1);
 
             /* Weights */
             wsum = 0.0;
-            for (j = 0; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0))) {
+            for (gint j = 0; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking)) {
+                    gdouble x = a[j+1] - a[j] - b[j+1] + b[j];
+                    w[j] = exp(-(x*x/(2.0*q)));
+                    wsum += w[j];
+                }
+                else {
                     w[j] = 0.0;
                     continue;
                 }
-
-                x = a[j+1] - a[j] - b[j+1] + b[j];
-                w[j] = exp(-(x*x/(2.0*q)));
-                wsum += w[j];
             }
 
             /* Correction */
-            lambda = (a[0] - b[0])*w[0];
-            for (j = 1; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0)))
-                    continue;
-
-                lambda += (a[j] - b[j])*(w[j-1] + w[j]);
+            gdouble lambda = (a[0] - b[0])*w[0];
+            for (gint j = 1; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking))
+                    lambda += (a[j] - b[j])*(w[j-1] + w[j]);
             }
             lambda += (a[xres-1] - b[xres-1])*w[xres-2];
             lambda /= 2.0*wsum;
@@ -598,7 +579,7 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
     }
 
     s[0] = 0.0;
-    for (k = 1; k < yres; k++)
+    for (gint k = 1; k < yres; k++)
         s[k] += s[k-1];
 
     zero_level_row_shifts(shifts);
@@ -607,39 +588,27 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
 
 static gdouble
 row_fit_facet_tilt(const gdouble *drow,
-                   const gdouble *mrow,
+                   const gint *mrow,
                    GwyMaskingType masking,
                    guint res, gdouble dx,
                    guint mincount)
 {
     const gdouble c = 1.0/200.0;
 
-    gdouble vx, q, sumvx, sumvz, sigma2;
-    guint i, n;
-
-    sigma2 = 0.0;
-    n = 0;
-    if (mrow && masking == GWY_MASK_INCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] >= 1.0 && mrow[i+1] >= 1.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                sigma2 += vx*vx;
-                n++;
-            }
-        }
-    }
-    else if (mrow && masking == GWY_MASK_EXCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] <= 0.0 && mrow[i+1] <= 0.0) {
-                vx = (drow[i+1] - drow[i])/dx;
+    gdouble sigma2 = 0.0;
+    gint n = 0;
+    if (mrow) {
+        for (gint i = 0; i < res-1; i++) {
+            if (nielded_included(mrow + i, masking) && nielded_included(mrow + i+1, masking)) {
+                gdouble vx = (drow[i+1] - drow[i])/dx;
                 sigma2 += vx*vx;
                 n++;
             }
         }
     }
     else {
-        for (i = 0; i < res-1; i++) {
-            vx = (drow[i+1] - drow[i])/dx;
+        for (gint i = 0; i < res-1; i++) {
+            gdouble vx = (drow[i+1] - drow[i])/dx;
             sigma2 += vx*vx;
         }
         n = res-1;
@@ -651,31 +620,21 @@ row_fit_facet_tilt(const gdouble *drow,
 
     sigma2 = c*sigma2/n;
 
-    sumvx = sumvz = 0.0;
-    if (mrow && masking == GWY_MASK_INCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] >= 1.0 && mrow[i+1] >= 1.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                q = exp(vx*vx/sigma2);
-                sumvx += vx/q;
-                sumvz += 1.0/q;
-            }
-        }
-    }
-    else if (mrow && masking == GWY_MASK_EXCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] <= 0.0 && mrow[i+1] <= 0.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                q = exp(vx*vx/sigma2);
+    gdouble sumvx = 0.0, sumvz = 0.0;
+    if (mrow) {
+        for (gint i = 0; i < res-1; i++) {
+            if (nielded_included(mrow + i, masking) && nielded_included(mrow + i+1, masking)) {
+                gdouble vx = (drow[i+1] - drow[i])/dx;
+                gdouble q = exp(vx*vx/sigma2);
                 sumvx += vx/q;
                 sumvz += 1.0/q;
             }
         }
     }
     else {
-        for (i = 0; i < res-1; i++) {
-            vx = (drow[i+1] - drow[i])/dx;
-            q = exp(vx*vx/sigma2);
+        for (gint i = 0; i < res-1; i++) {
+            gdouble vx = (drow[i+1] - drow[i])/dx;
+            gdouble q = exp(vx*vx/sigma2);
             sumvx += vx/q;
             sumvz += 1.0/q;
         }
@@ -700,41 +659,35 @@ untilt_row(gdouble *drow, guint res, gdouble bx)
 }
 
 static void
-linematch_do_facet_tilt(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_facet_tilt(GwyField *field, GwyNield *mask, GwyLine *shifts,
                         GwyMaskingType masking)
 {
-    guint xres, yres, i, j, mincount;
-    const gdouble *mdata, *mrow;
-    gdouble *data, *drow;
-    gdouble dx, tilt;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble dx = gwy_field_get_dx(field);
+    gint mincount = GWY_ROUND(log(xres) + 1);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    dx = gwy_field_get_dx(field);
-    mincount = GWY_ROUND(log(xres) + 1);
-
-    data = gwy_field_get_data(field);
-    mdata = mask ? gwy_field_get_data_const(mask) : NULL;
-    for (i = 0; i < yres; i++) {
-        drow = data + i*xres;
-        mrow = mdata ? mdata + i*xres : NULL;
-        for (j = 0; j < 30; j++) {
-            tilt = row_fit_facet_tilt(drow, mrow, masking, xres, dx, mincount);
+    gdouble *data = gwy_field_get_data(field);
+    const gint *mdata = mask ? gwy_nield_get_data_const(mask) : NULL;
+    for (gint i = 0; i < yres; i++) {
+        gdouble *drow = data + i*xres;
+        const gint *mrow = mdata ? mdata + i*xres : NULL;
+        for (gint j = 0; j < 30; j++) {
+            gdouble tilt = row_fit_facet_tilt(drow, mrow, masking, xres, dx, mincount);
             untilt_row(drow, xres, tilt);
             if (fabs(tilt/dx) < 1e-6)
                 break;
         }
     }
 
-    /* FIXME: Should we put the tilts there to confuse the user?  We need to
-     * make sure all functions set the units correctly in such case. */
+    /* FIXME: Should we put the tilts there to confuse the user?  We need to make sure all functions set the units
+     * correctly in such case. */
     gwy_line_clear(shifts);
 }
 
 static void
 zero_level_row_shifts(GwyLine *shifts)
 {
-    gwy_line_add(shifts, -gwy_line_avg(shifts));
+    gwy_line_add(shifts, -gwy_line_mean(shifts));
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
