@@ -1,6 +1,6 @@
 /*
- *  $Id: local_contrast.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: local_contrast.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -46,7 +46,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Maximizes local contrast."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
@@ -100,7 +100,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = NULL;  /* Create it here once we have a GUI. */
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome != GWY_DIALOG_PROCEED)
@@ -112,8 +112,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     execute(&args);
 
     gwy_field_normalize(args.result);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
-    gwy_container_set_object(GWY_CONTAINER(data), squark, args.result);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
+    gwy_dict_set_object(GWY_DICT(data), squark, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -146,49 +146,42 @@ run_gui(ModuleArgs *args)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *field = args->field, *result = args->result, *minfield, *maxfield;
+    GwyField *field = args->field, *result = args->result;
     gint size = gwy_params_get_int(args->params, PARAM_SIZE);
     gint depth = gwy_params_get_int(args->params, PARAM_DEPTH);
     gdouble weight = gwy_params_get_double(args->params, PARAM_WEIGHT);
-    const gdouble *dat, *min, *max;
-    gdouble *show, *weights;
-    gdouble sum, gmin, gmax;
-    gint xres, yres, i, j;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    gmin = gwy_field_get_min(field);
-    gmax = gwy_field_get_max(field);
+    gdouble gmin = gwy_field_min(field), gmax = gwy_field_max(field);
     if (gmax == gmin) {
         gwy_field_clear(result);
         return;
     }
 
-    minfield = gwy_field_copy(field);
+    GwyField *minfield = gwy_field_copy(field);
     gwy_field_filter_minimum(minfield, size);
 
-    maxfield = gwy_field_copy(field);
+    GwyField *maxfield = gwy_field_copy(field);
     gwy_field_filter_maximum(maxfield, size);
 
-    dat = gwy_field_get_data_const(field);
-    min = gwy_field_get_data_const(minfield);
-    max = gwy_field_get_data_const(maxfield);
-    show = gwy_field_get_data(result);
+    const gdouble *dat = gwy_field_get_data_const(field);
+    const gdouble *min = gwy_field_get_data_const(minfield);
+    const gdouble *max = gwy_field_get_data_const(maxfield);
+    gdouble *show = gwy_field_get_data(result);
 
-    weights = g_new(gdouble, depth);
-    sum = 0.0;
-    for (i = 0; i < depth; i++) {
+    gdouble *weights = g_new(gdouble, depth);
+    gdouble sum = 0.0;
+    for (gint i = 0; i < depth; i++) {
         weights[i] = exp(-log(depth - 1.0)*i/(depth - 1.0));
         sum += weights[i];
     }
 
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(dat,show,min,max,weights,xres,yres,depth,size,weight,gmin,gmax,sum)
 #endif
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
+    for (gint i = 0; i < yres; i++) {
+        for (gint j = 0; j < xres; j++) {
             gdouble minv = dat[i*xres + j], maxv = dat[i*xres + j];
             gdouble mins = minv*weights[0];
             gdouble maxs = maxv*weights[0];
