@@ -1,6 +1,6 @@
 /*
- *  $Id: logistic.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2016-2021 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
+ *  $Id: logistic.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2016-2026 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gwyddion.net
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -53,8 +53,8 @@ typedef struct {
     GwyParams *params;
     GwyLine *thetas;
     GwyField *field;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -75,19 +75,19 @@ static void             param_changed          (ModuleGUI *gui,
 static GwyBrick*        create_feature_vector  (GwyField *field,
                                                 ModuleArgs *args);
 static gdouble          cost_function          (GwyBrick *brick,
-                                                GwyField *mask,
+                                                GwyNield *mask,
                                                 gdouble *thetas,
                                                 gdouble *grad,
                                                 gdouble lambda);
 static void             train_logistic         (GwyFile *container,
                                                 gint id,
                                                 GwyBrick *features,
-                                                GwyField *mask,
+                                                GwyNield *mask,
                                                 gdouble *thetas,
                                                 gdouble lambda);
 static void             predict_mask           (GwyBrick *brick,
                                                 gdouble *thetas,
-                                                GwyField *mask);
+                                                GwyNield *mask);
 static void             logistic_filter_hessian(GwyField *field,
                                                 LogisticHessianFilter filter_type);
 static gint             logistic_nfeatures     (ModuleArgs *args);
@@ -99,7 +99,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Trains logistic regression to mark grains."),
     "Daniil Bratashov <dn2010@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2016",
 };
@@ -148,7 +148,6 @@ define_module_params(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *field, *mask;
     GwyDialogOutcome outcome;
     ModuleArgs args;
     GwyBrick *features;
@@ -156,16 +155,14 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GQuark quark;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_MASK_FIELD, &args.mask,
                                  GWY_APP_MASK_FIELD_KEY, &quark,
                                  0);
+    g_assert(args.field);
 
-    args.field = field;
-    args.mask = mask;
-    args.result = gwy_field_new_alike(field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.result = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
     load_thetas(&args);
 
@@ -175,20 +172,20 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         goto end;
 
     nfeatures = logistic_nfeatures(&args);
-    features = create_feature_vector(field, &args);
+    features = create_feature_vector(args.field, &args);
 
     if (gwy_params_get_enum(args.params, PARAM_MODE) == LOGISTIC_MODE_TRAIN) {
         /* XXX: We should not let the user think training is done when there is no mask. */
-        if (mask) {
+        if (args.mask) {
             gdouble lambda = gwy_params_get_double(args.params, PARAM_LAMBDA);
 
             gwy_line_resize(args.thetas, nfeatures);
-            train_logistic(data, id, features, mask, gwy_line_get_data(args.thetas), lambda);
+            train_logistic(data, id, features, args.mask, gwy_line_get_data(args.thetas), lambda);
             save_thetas(&args);
         }
     }
     else {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         predict_mask(features, gwy_line_get_data(args.thetas), args.result);
         gwy_file_set_image_mask(data, id, args.result);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
@@ -279,7 +276,7 @@ static void
 assign_feature(GwyField *feature, GwyBrick *brick, gint *z)
 {
     gwy_field_normalize(feature);
-    gwy_field_add(feature, -gwy_field_get_avg(feature));
+    gwy_field_add(feature, -gwy_field_mean(feature));
     gwy_brick_set_xy_plane(brick, feature, *z);
     (*z)++;
 }
@@ -374,7 +371,7 @@ sigmoid(gdouble z)
 
 static void
 train_logistic(GwyFile *container, gint id,
-               GwyBrick *features, GwyField *mask, gdouble *thetas, gdouble lambda)
+               GwyBrick *features, GwyNield *mask, gdouble *thetas, gdouble lambda)
 {
     gdouble *grad, *oldgrad;
     gdouble epsilon, alpha, sum;
@@ -428,57 +425,52 @@ train_logistic(GwyFile *container, gint id,
 }
 
 static gdouble
-cost_function(GwyBrick *brick, GwyField *mask,
+cost_function(GwyBrick *brick, GwyNield *mask,
               gdouble *thetas, gdouble *grad, gdouble lambda)
 {
-    gint i, j, m, xres, yres, fres;
-    gdouble ksum, jsum;
-    const gdouble *fdata, *mdata;
+    gint fres = gwy_brick_get_xres(brick);
+    gint xres = gwy_brick_get_yres(brick), yres = gwy_brick_get_zres(brick);
+    g_assert(xres == gwy_nield_get_xres(mask));
+    g_assert(yres == gwy_nield_get_yres(mask));
 
-    fres = gwy_brick_get_xres(brick);
-    xres = gwy_brick_get_yres(brick);
-    yres = gwy_brick_get_zres(brick);
-    fdata = gwy_brick_get_data_const(brick);
-    g_assert(xres == gwy_field_get_xres(mask));
-    g_assert(yres == gwy_field_get_yres(mask));
-    m = xres*yres;
-    mdata = gwy_field_get_data_const(mask);
+    const gdouble *fdata = gwy_brick_get_data_const(brick);
+    gint m = xres*yres;
+    const gint *mdata = gwy_nield_get_data_const(mask);
 
-    jsum = 0;
+    gdouble jsum = 0.0;
     gwy_clear(grad, fres);
 
 #ifdef _OPENMP
 #pragma omp parallel if (gwy_threads_are_enabled()) default(none) \
             reduction(+:jsum) \
-            private(i,j) \
             shared(xres,yres,fres,m,fdata,mdata,thetas,grad)
 #endif
     {
         gdouble *tgrad = gwy_omp_if_threads_new0(grad, fres);
         gint ifrom = gwy_omp_chunk_start(yres), ito = gwy_omp_chunk_end(yres);
 
-        for (i = ifrom; i < ito; i++) {
-            for (j = 0; j < xres; j++) {
+        for (gint i = ifrom; i < ito; i++) {
+            for (gint j = 0; j < xres; j++) {
                 const gdouble *fblock = fdata + (i*xres + j)*fres;
-                gdouble h, y = mdata[i*xres + j], sum = 0.0;
-                gint k;
+                gint y = mdata[i*xres + j];
+                gdouble sum = 0.0;
 
-                for (k = 0; k < fres; k++)
+                for (gint k = 0; k < fres; k++)
                     sum += fblock[k] * thetas[k];
-                h = sigmoid(sum);
+                gdouble h = sigmoid(sum);
                 jsum += -log(h)*y - log(1-h)*(1-y);
-                for (k = 0; k < fres; k++)
+                for (gint k = 0; k < fres; k++)
                     tgrad[k] += fblock[k] * (h - y)/m;
             }
         }
         gwy_omp_if_threads_sum_double(grad, tgrad, fres);
     }
-    for (i = 1; i < fres; i++)
+    for (gint i = 1; i < fres; i++)
         grad[i] += thetas[i] * lambda/m;
     jsum /= m;
 
-    ksum = 0.0;
-    for (i = 1; i < fres; i++)
+    gdouble ksum = 0.0;
+    for (gint i = 1; i < fres; i++)
         ksum += thetas[i] * thetas[i];
     jsum += ksum * 0.5*lambda/m;
 
@@ -486,34 +478,27 @@ cost_function(GwyBrick *brick, GwyField *mask,
 }
 
 static void
-predict_mask(GwyBrick *brick, gdouble *thetas, GwyField *mask)
+predict_mask(GwyBrick *brick, gdouble *thetas, GwyNield *mask)
 {
-    gint i, j, xres, yres, fres;
-    const gdouble *fdata;
-    gdouble *mdata;
-
-    fres = gwy_brick_get_xres(brick);
-    xres = gwy_brick_get_yres(brick);
-    yres = gwy_brick_get_zres(brick);
-    fdata = gwy_brick_get_data_const(brick);
-    mdata = gwy_field_get_data(mask);
-    g_assert(xres == gwy_field_get_xres(mask));
-    g_assert(yres == gwy_field_get_yres(mask));
+    gint fres = gwy_brick_get_xres(brick);
+    gint xres = gwy_brick_get_yres(brick), yres = gwy_brick_get_zres(brick);
+    g_assert(xres == gwy_nield_get_xres(mask));
+    g_assert(yres == gwy_nield_get_yres(mask));
+    const gdouble *fdata = gwy_brick_get_data_const(brick);
+    gint *mdata = gwy_nield_get_data(mask);
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(xres,yres,fres,fdata,mdata,thetas)
 #endif
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
+    for (gint i = 0; i < yres; i++) {
+        for (gint j = 0; j < xres; j++) {
             const gdouble *fblock = fdata + (i*xres + j)*fres;
             gdouble sum = 0.0;
-            gint k;
 
-            for (k = 0; k < fres; k++)
+            for (gint k = 0; k < fres; k++)
                 sum += fblock[k]*thetas[k];
-            mdata[i*xres + j] = (sigmoid(sum) > 0.5) ? 1.0 : 0.0;
+            mdata[i*xres + j] = (sigmoid(sum) > 0.5);
         }
     }
 }
