@@ -1,5 +1,5 @@
 /*
- *  $Id: mark_disconn.c 29073 2026-01-02 17:26:12Z yeti-dn $
+ *  $Id: mark_disconn.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2015-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -35,8 +35,8 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -63,7 +63,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates mask of values disconnected to the rest."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "3.0",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -125,8 +125,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field && mquark);
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.result = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     if (mode == GWY_RUN_INTERACTIVE) {
@@ -140,11 +139,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             goto end;
     }
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -213,35 +210,31 @@ preview(gpointer user_data)
     ModuleArgs *args = gui->args;
 
     if (execute(args, GTK_WINDOW(gui->dialog))) {
-        gwy_field_data_changed(args->result);
+        gwy_nield_data_changed(args->result);
         gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
     }
     else
-        gwy_field_clear(args->result);
+        gwy_nield_clear(args->result);
 }
 
-/* Remove from mask pixels with values that do not belong to the largest contiguous block of values in the height
+/* Unmask pixels with image values that do not belong to the largest contiguous block of values in the height
  * distribution. */
 static guint
-unmark_disconnected_values(GwyField *dfield, GwyField *inclmask,
+unmark_disconnected_values(GwyField *field, GwyNield *inclmask,
                            guint n, gdouble threshold)
 {
-    guint xres = gwy_field_get_xres(dfield);
-    guint yres = gwy_field_get_yres(dfield);
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
     guint lineres = (guint)floor(2.5*cbrt(xres*yres - n) + 0.5);
     GwyLine *dline = gwy_line_new(lineres, lineres, FALSE);
-    const gdouble *d;
-    gdouble *m;
-    guint nn, i, blockstart = 0, bestblockstart = 0, bestblocklen = 0;
-    gdouble blocksum = 0.0, bestblocksum = 0.0;
-    gdouble real, off, min, max, rho_zero;
 
-    gwy_field_area_dh(dfield, inclmask, GWY_MASK_INCLUDE, dline, 0, 0, xres, yres, lineres);
-    rho_zero = gwy_line_max(dline)/sqrt(xres*yres - n)*threshold;
-    d = gwy_line_get_data_const(dline);
+    gwy_field_area_height_dist(field, inclmask, GWY_MASK_INCLUDE, dline, 0, 0, xres, yres, lineres);
+    gdouble rho_zero = gwy_line_max(dline)/sqrt(xres*yres - n)*threshold;
+    const gdouble *d = gwy_line_get_data_const(dline);
     lineres = gwy_line_get_res(dline);
 
-    for (i = 0; i <= lineres; i++) {
+    guint blockstart = 0, bestblockstart = 0, bestblocklen = 0;
+    gdouble blocksum = 0.0, bestblocksum = 0.0;
+    for (gint i = 0; i <= lineres; i++) {
         if (i == lineres || (i && d[i] + d[i-1] < rho_zero)) {
             if (blocksum > bestblocksum) {
                 bestblocksum = blocksum;
@@ -260,16 +253,16 @@ unmark_disconnected_values(GwyField *dfield, GwyField *inclmask,
         return 0;
     }
 
-    real = gwy_line_get_real(dline);
-    off = gwy_line_get_offset(dline);
-    min = off + real/lineres*bestblockstart;
-    max = off + real/lineres*(bestblockstart + bestblocklen + 1);
-    m = gwy_field_get_data(inclmask);
-    d = gwy_field_get_data_const(dfield);
-    nn = 0;
-    for (i = 0; i < xres*yres; i++) {
-        if (m[i] > 0.0 && (d[i] < min || d[i] > max)) {
-            m[i] = 0.0;
+    gdouble real = gwy_line_get_real(dline);
+    gdouble off = gwy_line_get_offset(dline);
+    gdouble min = off + real/lineres*bestblockstart;
+    gdouble max = off + real/lineres*(bestblockstart + bestblocklen + 1);
+    gint *m = gwy_nield_get_data(inclmask);
+    d = gwy_field_get_data_const(field);
+    gint nn = 0;
+    for (gint i = 0; i < xres*yres; i++) {
+        if (m[i] > 0 && (d[i] < min || d[i] > max)) {
+            m[i] = 0;
             nn++;
         }
     }
@@ -287,8 +280,9 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     gint size = 2*gwy_params_get_int(params, PARAM_RADIUS) + 1;
     gdouble threshold = gwy_params_get_double(params, PARAM_THRESHOLD);
     GwySignFlags type = gwy_params_get_enum(params, PARAM_TYPE);
-    GwyField *field = args->field, *mask = args->mask, *result = args->result;
-    GwyField *difffield = NULL, *buffer = NULL, *kernel = NULL;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask, *result = args->result, *maskbuf = NULL, *kernel = NULL;
+    GwyField *difffield = NULL, *buffer = NULL;
     gint xres = gwy_field_get_xres(field);
     gint yres = gwy_field_get_yres(field);
     guint n, nn;
@@ -296,13 +290,12 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 
     gwy_app_wait_start(wait_window, _("Initializing..."));
     /* Remove the positive, negative (or both) defects using a filter.  This produces a defect-free field. */
-    buffer = gwy_field_new_alike(result, FALSE);
-    gwy_field_copy_data(field, buffer);
+    buffer = gwy_field_copy(field);
     if (!gwy_app_wait_set_message(_("Filtering...")))
         goto finish;
 
-    kernel = gwy_field_new(size, size, size, size, TRUE);
-    n = gwy_field_elliptic_area_fill(kernel, 0, 0, size, size, 1.0);
+    kernel = gwy_nield_new(size, size);
+    n = gwy_nield_elliptic_fill(kernel);
     if (type == GWY_SIGN_POSITIVE || type == GWY_SIGN_NEGATIVE) {
         GwyMinMaxFilterType filtertpe = (type == GWY_SIGN_POSITIVE
                                          ? GWY_MIN_MAX_FILTER_OPENING
@@ -317,29 +310,28 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     /* Then find look at the difference and mark any outliers in it because these must be defects. */
     difffield = gwy_field_new_alike(field, FALSE);
     gwy_field_subtract_fields(difffield, field, buffer);
-    gwy_field_fill(buffer, 1.0);
+
+    maskbuf = gwy_field_new_nield_alike(field);
+    gwy_nield_fill(maskbuf, 1);
 
     if (!gwy_app_wait_set_message(_("Marking outliers...")))
         goto finish;
 
     n = 0;
-    while ((nn = unmark_disconnected_values(difffield, buffer, n, 4.0*threshold)))
+    while ((nn = unmark_disconnected_values(difffield, maskbuf, n, 4.0*threshold)))
         n += nn;
 
-    gwy_field_grains_invert(buffer);
-    if (mask && combine) {
-        if (combine_type == GWY_MERGE_UNION)
-            gwy_field_grains_add(buffer, mask);
-        else if (combine_type == GWY_MERGE_INTERSECTION)
-            gwy_field_grains_intersect(buffer, mask);
-    }
-    gwy_field_copy_data(buffer, result);
+    gwy_nield_invert(maskbuf);
+    if (combine)
+        gwy_nield_merge(maskbuf, mask, combine_type);
+    gwy_nield_copy_data(maskbuf, result);
     ok = TRUE;
 
 finish:
     gwy_app_wait_finish();
     g_clear_object(&kernel);
     g_clear_object(&buffer);
+    g_clear_object(&maskbuf);
     g_clear_object(&difffield);
     return ok;
 }
