@@ -1,6 +1,6 @@
 /*
- *  $Id: mark_with.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2009-2021 David Necas (Yeti).
+ *  $Id: mark_with.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2009-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -23,20 +23,6 @@
 
 #define RUN_MODES GWY_RUN_INTERACTIVE
 
-typedef enum {
-    MARK_WITH_MASK = 0,
-    MARK_WITH_IMAGE = 1,
-    MARK_WITH_SHOW = 2,
-} MarkWithWhat;
-
-/* Copied from the mask editor tool, might make sense to use the same enum. */
-typedef enum {
-    MASK_EDIT_SET       = 0,
-    MASK_EDIT_ADD       = 1,
-    MASK_EDIT_REMOVE    = 2,
-    MASK_EDIT_INTERSECT = 3
-} MaskEditMode;
-
 enum {
     PARAM_MARK_WITH,
     PARAM_OPERATION,
@@ -51,12 +37,18 @@ enum {
     LABEL_RANGE,
 };
 
+typedef enum {
+    MARK_WITH_MASK  = 0,
+    MARK_WITH_IMAGE = 1,
+    MARK_WITH_SHOW  = 2,
+} MarkWithWhat;
+
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    GwyField *source;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *source;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -68,6 +60,7 @@ typedef struct {
     GtkWidget *operand[3];
     gboolean has_any[3];
     GtkSizeGroup *sizegroup;
+    GwyField *empty;
 } ModuleGUI;
 
 static gboolean         module_register                (void);
@@ -81,18 +74,13 @@ static void             execute                        (ModuleArgs *args);
 static void             param_changed                  (ModuleGUI *gui,
                                                         gint id);
 static void             preview                        (gpointer user_data);
-static GwyField*        get_other_field                (GwyParams *params,
+static GObject*         get_other_field                (GwyParams *params,
                                                         GwyFile **pdata,
-                                                        gint *id,
-                                                        gboolean base_field);
+                                                        gint *id);
 static void             dialog_response                (GwyDialog *dialog,
                                                         gint response,
                                                         ModuleGUI *gui);
 static void             ensure_something_is_selected   (ModuleGUI *gui);
-static void             gwy_field_threshold_to         (GwyField *source,
-                                                        GwyField *dest,
-                                                        gdouble min,
-                                                        gdouble max);
 static GtkWidget*       create_operand_row_mask        (gpointer user_data);
 static GtkWidget*       create_operand_row_image       (gpointer user_data);
 static GtkWidget*       create_operand_row_presentation(gpointer user_data);
@@ -121,7 +109,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates or modifies a mask using other channels."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "3.0",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -145,10 +133,10 @@ static GwyParamDef*
 define_module_params(void)
 {
     static const GwyEnum operations[] = {
-        { N_("Se_t mask"),        MASK_EDIT_SET,       },
-        { N_("_Add mask"),        MASK_EDIT_ADD,       },
-        { N_("_Subtract mask"),   MASK_EDIT_REMOVE,    },
-        { N_("_Intersect masks"), MASK_EDIT_INTERSECT, },
+        { N_("Se_t mask"),        GWY_MERGE_COPY,         },
+        { N_("_Add mask"),        GWY_MERGE_UNION,        },
+        { N_("_Subtract mask"),   GWY_MERGE_SUBTRACT,     },
+        { N_("_Intersect masks"), GWY_MERGE_INTERSECTION, },
     };
 
     static GwyParamDef *paramdef = NULL;
@@ -161,7 +149,7 @@ define_module_params(void)
     gwy_param_def_add_gwyenum(paramdef, PARAM_MARK_WITH, "mark_with", _("Mark with"),
                               withwhats, G_N_ELEMENTS(withwhats), MARK_WITH_MASK);
     gwy_param_def_add_gwyenum(paramdef, PARAM_OPERATION, "operation", _("Operation"),
-                              operations, G_N_ELEMENTS(operations), MASK_EDIT_SET);
+                              operations, G_N_ELEMENTS(operations), GWY_MERGE_COPY);
     gwy_param_def_add_percentage(paramdef, PARAM_MIN, "min", _("_Minimum"), 0.0);
     gwy_param_def_add_percentage(paramdef, PARAM_MAX, "max", _("M_aximum"), 1.0);
     gwy_param_def_add_image_id(paramdef, PARAM_OPERAND_MASK, "operand_mask", NULL);
@@ -189,10 +177,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field && mquark);
 
-    args.source = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.source));
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.source = gwy_field_new_nield_alike(args.field);
+    args.result = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     outcome = run_gui(&args, data, id);
@@ -201,8 +187,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome == GWY_DIALOG_PROCEED)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_dict_set_object(GWY_DICT(data), mquark, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -223,6 +209,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     gwy_clear1(gui);
     gui.args = args;
+    gui.empty = gwy_field_new_alike(args->field, TRUE);
 
     gui.dialog = gwy_dialog_new(_("Mark With"));
     dialog = GWY_DIALOG(gui.dialog);
@@ -302,56 +289,45 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gwy_dialog_set_preview_func(dialog, GWY_PREVIEW_IMMEDIATE, preview, &gui, NULL);
     ensure_something_is_selected(&gui);
 
-    return gwy_dialog_run(dialog);
+    GwyDialogOutcome outcome = gwy_dialog_run(dialog);
+
+    g_object_unref(gui.empty);
+
+    return outcome;
 }
 
 static void
 execute(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    MaskEditMode operation = gwy_params_get_enum(params, PARAM_OPERATION);
+    GwyMergeType operation = gwy_params_get_enum(params, PARAM_OPERATION);
     MarkWithWhat withwhat = gwy_params_get_enum(params, PARAM_MARK_WITH);
     gdouble min = gwy_params_get_double(params, PARAM_MIN);
     gdouble max = gwy_params_get_double(params, PARAM_MAX);
     gdouble data_min, data_max, d;
-    GwyField *otherfield;
+    GObject *otherfield;
 
     /* XXX: This does not have to be done when just the operation changes.  But well… */
-    otherfield = get_other_field(params, NULL, NULL, FALSE);
+    otherfield = get_other_field(params, NULL, NULL);
     if (withwhat == MARK_WITH_MASK)
-        gwy_field_copy_data(otherfield, args->source);
+        gwy_nield_copy_data(GWY_NIELD(otherfield), args->source);
     else {
-        gwy_field_get_min_max(otherfield, &data_min, &data_max);
+        gwy_field_min_max(GWY_FIELD(otherfield), &data_min, &data_max);
         d = data_max - data_min;
-        gwy_field_threshold_to(otherfield, args->source, data_min + d*min, data_min + d*max);
+        gwy_nield_mark_range(args->source, GWY_FIELD(otherfield), data_min + d*min, data_min + d*max);
     }
 
     /* Simple cases. */
-    if (!args->mask || operation == MASK_EDIT_SET) {
-        if (operation == MASK_EDIT_SET || operation == MASK_EDIT_ADD)
-            gwy_field_copy_data(args->source, args->result);
+    if (!args->mask || operation == GWY_MERGE_COPY) {
+        if (operation == GWY_MERGE_COPY || operation == GWY_MERGE_UNION)
+            gwy_nield_copy_data(args->source, args->result);
         else
-            gwy_field_clear(args->result);
+            gwy_nield_clear(args->result);
         return;
     }
 
-    /* Not so simple cases. */
-    if (operation == MASK_EDIT_ADD)
-        gwy_field_max_of_fields(args->result, args->mask, args->source);
-    else if (operation == MASK_EDIT_INTERSECT)
-        gwy_field_min_of_fields(args->result, args->mask, args->source);
-    else if (operation == MASK_EDIT_REMOVE) {
-        const gdouble *sdata, *odata;
-        gdouble *mdata;
-        gint i, n;
-
-        n = gwy_field_get_xres(args->source) * gwy_field_get_yres(args->source);
-        mdata = gwy_field_get_data(args->result);
-        odata = gwy_field_get_data_const(args->mask);
-        sdata = gwy_field_get_data_const(args->source);
-        for (i = 0; i < n; i++)
-            mdata[i] = MIN(odata[i], 1.0 - sdata[i]);
-    }
+    gwy_nield_copy_data(args->mask, args->result);
+    gwy_nield_merge(args->result, args->source, operation);
 }
 
 static void
@@ -383,23 +359,32 @@ preview(gpointer user_data)
     ModuleArgs *args = gui->args;
     GwyParams *params = args->params;
     GwyFile *data;
-    GwyField *otherfield;
+    GObject *otherfield;
     gint id;
 
-    if (!(otherfield = get_other_field(params, &data, &id, TRUE)))
+    if (!(otherfield = get_other_field(params, &data, &id)))
         return;
     execute(args);
-    gwy_field_data_changed(args->source);
-    gwy_field_data_changed(args->result);
-    gwy_data_view_set_field(GWY_DATA_VIEW(gui->srcview), otherfield);
+    gwy_nield_data_changed(args->source);
+    gwy_nield_data_changed(args->result);
+    if (GWY_IS_NIELD(otherfield)) {
+        gwy_data_view_set_field(GWY_DATA_VIEW(gui->srcview), gui->empty);
+        gwy_data_view_set_mask(GWY_DATA_VIEW(gui->srcview), GWY_NIELD(otherfield));
+    }
+    else if (GWY_IS_FIELD(otherfield)) {
+        gwy_data_view_set_field(GWY_DATA_VIEW(gui->srcview), GWY_FIELD(otherfield));
+        gwy_data_view_set_mask(GWY_DATA_VIEW(gui->srcview), NULL);
+    }
+    else {
+        g_assert_not_reached();
+    }
     gwy_setup_data_view(GWY_DATA_VIEW(gui->srcview), data, GWY_FILE_IMAGE, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_MASK_COLOR | GWY_FILE_ITEM_RANGE);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
-static GwyField*
-get_other_field(GwyParams *params, GwyFile **pdata, gint *id,
-                gboolean base_field)
+static GObject*
+get_other_field(GwyParams *params, GwyFile **pdata, gint *id)
 {
     MarkWithWhat withwhat = gwy_params_get_enum(params, PARAM_MARK_WITH);
     GwyAppDataId dataid;
@@ -410,7 +395,7 @@ get_other_field(GwyParams *params, GwyFile **pdata, gint *id,
         if (gwy_params_data_id_is_none(params, PARAM_OPERAND_MASK))
             return NULL;
         dataid = gwy_params_get_data_id(params, PARAM_OPERAND_MASK);
-        quark = base_field ? gwy_file_key_image(dataid.id) : gwy_file_key_image_mask(dataid.id);
+        quark = gwy_file_key_image_mask(dataid.id);
     }
     else if (withwhat == MARK_WITH_SHOW) {
         if (gwy_params_data_id_is_none(params, PARAM_OPERAND_SHOW))
@@ -430,7 +415,7 @@ get_other_field(GwyParams *params, GwyFile **pdata, gint *id,
     if (id)
         *id = dataid.id;
 
-    return gwy_container_get_object(GWY_CONTAINER(data), quark);
+    return gwy_dict_get_object(GWY_DICT(data), quark);
 }
 
 static void
@@ -443,33 +428,10 @@ dialog_response(G_GNUC_UNUSED GwyDialog *dialog, gint response, ModuleGUI *gui)
 static void
 ensure_something_is_selected(ModuleGUI *gui)
 {
-    if (!get_other_field(gui->args->params, NULL, NULL, FALSE))
+    if (!get_other_field(gui->args->params, NULL, NULL))
         gwy_radio_buttons_set_current(gui->withwhat, MARK_WITH_IMAGE);
 }
 
-/* Use gwy_nield_mark_by_threshold(). */
-static void
-gwy_field_threshold_to(GwyField *source, GwyField *dest,
-                       gdouble min, gdouble max)
-{
-    const gdouble *dsrc;
-    gdouble *ddst;
-    gint i, n;
-
-    n = gwy_field_get_xres(source) * gwy_field_get_yres(source);
-    dsrc = gwy_field_get_data_const(source);
-    ddst = gwy_field_get_data(dest);
-
-    if (min <= max) {
-        for (i = 0; i < n; i++)
-            ddst[i] = (dsrc[i] >= min && dsrc[i] <= max);
-    }
-    else {
-        for (i = 0; i < n; i++)
-            ddst[i] = (dsrc[i] >= min || dsrc[i] <= max);
-    }
-}
-
 static GtkWidget*
 create_operand_row(ModuleGUI *gui, gint i, gint param_id)
 {
@@ -532,34 +494,29 @@ create_operand_row_presentation(gpointer user_data)
 }
 
 static gboolean
-operand_filter(GwyFile *source, GQuark quark, ModuleGUI *gui)
+operand_filter_image(GwyFile *source, gint id, gpointer user_data)
 {
-    GwyField *target_field = gui->args->field;
-    GwyField *source_field;
+    ModuleGUI *gui = (ModuleGUI*)user_data;
+    GwyField *field = gwy_file_get_image(source, id);
+    return !gwy_field_is_incompatible(field, gui->args->field,
+                                      GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL | GWY_DATA_MISMATCH_LATERAL);
+}
 
-    if (!gwy_container_gis_object(GWY_CONTAINER(source), quark, &source_field))
-        return FALSE;
-
-    return !gwy_field_is_incompatible(source_field, target_field,
+static gboolean
+operand_filter_presentation(GwyFile *source, gint id, gpointer user_data)
+{
+    ModuleGUI *gui = (ModuleGUI*)user_data;
+    GwyField *field = gwy_dict_get_object(GWY_DICT(source), gwy_file_key_image_picture(id));
+    return !gwy_field_is_incompatible(field, gui->args->field,
                                       GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL | GWY_DATA_MISMATCH_LATERAL);
 }
 
 static gboolean
 operand_filter_mask(GwyFile *source, gint id, gpointer user_data)
 {
-    return operand_filter(source, gwy_file_key_image_mask(id), (ModuleGUI*)user_data);
-}
-
-static gboolean
-operand_filter_image(GwyFile *source, gint id, gpointer user_data)
-{
-    return operand_filter(source, gwy_file_key_image(id), (ModuleGUI*)user_data);
-}
-
-static gboolean
-operand_filter_presentation(GwyFile *source, gint id, gpointer user_data)
-{
-    return operand_filter(source, gwy_file_key_image_picture(id), (ModuleGUI*)user_data);
+    ModuleGUI *gui = (ModuleGUI*)user_data;
+    GwyNield *nield = gwy_file_get_image_mask(source, id);
+    return !gwy_nield_is_incompatible_with_field(nield, gui->args->field, GWY_DATA_MISMATCH_RES);
 }
 
 static void
