@@ -1,6 +1,6 @@
 /*
- *  $Id: mask_distribute.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: mask_distribute.c 29520 2026-02-23 09:32:20Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -34,7 +34,8 @@ enum {
 
 typedef struct {
     GwyParams *params;
-    GwyField *mask;
+    GwyField *field;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -63,7 +64,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Distributes masks to other channels."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -113,12 +114,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &args.mask,
+                                 GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     g_return_if_fail(args.mask && id >= 0);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode !=GWY_RUN_IMMEDIATE) {
+    if (mode != GWY_RUN_IMMEDIATE) {
         GwyDialogOutcome outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome != GWY_DIALOG_PROCEED)
@@ -169,30 +171,31 @@ static void
 distribute_in_one(GwyFile *file, gpointer user_data)
 {
     MaskDistribData *distdata = (MaskDistribData*)user_data;
-    GwyField *field, *mask;
     GwyDataMismatchFlags flags = GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL;
     gboolean keep_existing = gwy_params_get_boolean(distdata->args->params, PARAM_KEEP_EXISTING);
     GArray *undo_quarks = distdata->undo_quarks;
-    GQuark quark;
-    gint *ids;
-    guint i;
+    GwyNield *srcmask = distdata->args->mask;
+    GwyField *srcfield = distdata->args->field;
 
     g_array_set_size(undo_quarks, 0);
-    ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
+    gint *ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
 
-    for (i = 0; ids[i] >= 0; i++) {
+    for (guint i = 0; ids[i] >= 0; i++) {
         if (file == distdata->file && ids[i] == distdata->id)
             continue;
 
-        field = gwy_file_get_image(file, ids[i]);
+        GwyField *field = gwy_file_get_image(file, ids[i]);
         g_return_if_fail(field);
-        mask = gwy_file_get_image_mask(file, ids[i]);
+        GwyNield *mask = gwy_file_get_image_mask(file, ids[i]);
 
         if (mask && keep_existing)
             continue;
-        if (gwy_field_is_incompatible(distdata->args->mask, field, flags))
+        /* Check the fields for real dimensions. We may add an option to simply put the mask on anything with matching
+         * pixel dimensions. Would it be useful? */
+        if (gwy_field_is_incompatible(srcfield, field, flags))
             continue;
 
+        GQuark quark = gwy_file_key_image_mask(ids[i]);
         g_array_append_val(undo_quarks, quark);
         gwy_log_add(file, GWY_FILE_IMAGE, -1, ids[i]);
     }
@@ -201,11 +204,10 @@ distribute_in_one(GwyFile *file, gpointer user_data)
     if (!undo_quarks->len)
         return;
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(file), undo_quarks->len, (GQuark*)undo_quarks->data);
-    for (i = 0; i < undo_quarks->len; i++) {
-        quark = g_array_index(undo_quarks, GQuark, i);
-        mask = gwy_field_copy(distdata->args->mask);
-        gwy_container_pass_object(GWY_CONTAINER(file), quark, mask);
+    gwy_app_undo_qcheckpointv(GWY_DICT(file), undo_quarks->len, (GQuark*)undo_quarks->data);
+    for (guint i = 0; i < undo_quarks->len; i++) {
+        GQuark quark = g_array_index(undo_quarks, GQuark, i);
+        gwy_dict_pass_object(GWY_DICT(file), quark, gwy_nield_copy(srcmask));
     }
 }
 
