@@ -1,6 +1,6 @@
 /*
- *  $Id: mask_edt.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2014-2021 David Necas (Yeti).
+ *  $Id: mask_edt.c 29447 2026-02-07 12:14:37Z yeti-dn $
+ *  Copyright (C) 2014-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -23,12 +23,6 @@
 
 #define RUN_MODES (GWY_RUN_IMMEDIATE | GWY_RUN_INTERACTIVE)
 
-typedef enum {
-    MASKEDT_INTERIOR = 0,
-    MASKEDT_EXTERIOR = 1,
-    MASKEDT_SIGNED   = 2,
-} MaskEdtType;
-
 enum {
     PARAM_DIST_TYPE,
     PARAM_OUTPUT,
@@ -36,10 +30,16 @@ enum {
     PARAM_UPDATE,
 };
 
+typedef enum {
+    MASKEDT_INTERIOR = 0,
+    MASKEDT_EXTERIOR = 1,
+    MASKEDT_SIGNED   = 2,
+} MaskEdtType;
+
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
 } ModuleArgs;
 
@@ -66,7 +66,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Performs simple and true Euclidean distance transforms of masks."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti)",
     "2014",
 };
@@ -128,7 +128,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new_alike(args.field, TRUE);
     args.params = gwy_params_new_from_settings(define_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -205,27 +205,27 @@ preview(gpointer user_data)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *mask = args->mask, *field = args->field, *result = args->result;
+    GwyField *field = args->field, *result = args->result;
+    GwyNield *mask = args->mask;
     GwyDistanceTransformType dtype = gwy_params_get_enum(args->params, PARAM_DIST_TYPE);
     gboolean from_border = gwy_params_get_boolean(args->params, PARAM_FROM_BORDER);
     MaskEdtType output = gwy_params_get_enum(args->params, PARAM_OUTPUT);
 
-    gwy_field_copy_data(mask, result);
     if (output == MASKEDT_INTERIOR) {
-        gwy_field_grain_simple_dist_trans(result, dtype, from_border);
+        gwy_nield_distance_transform(mask, result, dtype, TRUE, from_border);
     }
-    else if (output == MASKEDT_EXTERIOR) {
-        gwy_field_grains_invert(result);
-        gwy_field_grain_simple_dist_trans(result, dtype, from_border);
-    }
-    else if (output == MASKEDT_SIGNED) {
-        GwyField *tmp = gwy_field_copy(result);
+    else if (output == MASKEDT_EXTERIOR || output == MASKEDT_SIGNED) {
+        GwyNield *invmask = gwy_nield_copy(mask);
+        gwy_nield_invert(invmask);
+        gwy_nield_distance_transform(invmask, result, dtype, TRUE, from_border);
+        g_object_unref(invmask);
 
-        gwy_field_grain_simple_dist_trans(result, dtype, from_border);
-        gwy_field_grains_invert(tmp);
-        gwy_field_grain_simple_dist_trans(tmp, dtype, from_border);
-        gwy_field_subtract_fields(result, result, tmp);
-        g_object_unref(tmp);
+        if (output == MASKEDT_SIGNED) {
+            GwyField *tmp = gwy_field_copy(result);
+            gwy_nield_distance_transform(mask, tmp, dtype, TRUE, from_border);
+            gwy_field_subtract_fields(result, result, tmp);
+            g_object_unref(tmp);
+        }
     }
 
     gwy_field_multiply(result, sqrt(gwy_field_get_dx(field)*gwy_field_get_dy(field)));
