@@ -1,6 +1,6 @@
 /*
- *  $Id: mask_morph.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2015-2021 David Necas (Yeti).
+ *  $Id: mask_morph.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2015-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -52,8 +52,8 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -83,7 +83,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Performs basic morphological operations with masks."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -108,12 +108,12 @@ static GwyParamDef*
 define_module_params(void)
 {
     static const GwyEnum operations[] = {
-        { N_("Erosion"),        MASKMORPH_EROSION,     },
-        { N_("Dilation"),       MASKMORPH_DILATION,    },
+        { N_("Erosion"),               MASKMORPH_EROSION,     },
+        { N_("Dilation"),              MASKMORPH_DILATION,    },
         { gwy_NC("filter", "Opening"), MASKMORPH_OPENING,     },
         { gwy_NC("filter", "Closing"), MASKMORPH_CLOSING,     },
-        { N_("ASF Opening"),    MASKMORPH_ASF_OPENING, },
-        { N_("ASF Closing"),    MASKMORPH_ASF_CLOSING, },
+        { N_("ASF Opening"),           MASKMORPH_ASF_OPENING, },
+        { N_("ASF Closing"),           MASKMORPH_ASF_CLOSING, },
     };
     static const GwyEnum shapes[] = {
         { N_("Disc"),         MASKMORPH_DISC,        },
@@ -156,7 +156,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.mask);
 
-    args.result = gwy_field_new_alike(args.mask, TRUE);
+    args.result = gwy_nield_new_alike(args.mask);
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
     if (mode == GWY_RUN_INTERACTIVE) {
@@ -168,11 +168,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0)
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -257,35 +255,31 @@ preview(gpointer user_data)
     ModuleGUI *gui = (ModuleGUI*)user_data;
 
     execute(gui->args);
-    gwy_field_data_changed(gui->args->result);
+    gwy_nield_data_changed(gui->args->result);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
-static GwyField*
+static GwyNield*
 create_kernel(MaskMorphShapeType shape, gint radius)
 {
-    GwyField *kernel;
-    gint i, j, res;
-    gdouble *d;
-
-    res = 2*radius + 1;
-    kernel = gwy_field_new(res, res, res, res, TRUE);
+    gint res = 2*radius + 1;
+    GwyNield *kernel = gwy_nield_new(res, res);
     if (shape == MASKMORPH_DISC)
-        gwy_field_elliptic_area_fill(kernel, 0, 0, res, res, 1.0);
+        gwy_nield_elliptic_area_fill(kernel, 0, 0, res, res, 1);
     else if (shape == MASKMORPH_OCTAGON || shape == MASKMORPH_DIAMOND) {
         gint rlim = (shape == MASKMORPH_OCTAGON ? GWY_ROUND(res/G_SQRT2) : radius);
-        d = gwy_field_get_data(kernel);
-        for (i = 0; i < res; i++) {
+        gint *d = gwy_nield_get_data(kernel);
+        for (gint i = 0; i < res; i++) {
             gint ii = ABS(i - radius);
-            for (j = 0; j < res; j++) {
+            for (gint j = 0; j < res; j++) {
                 gint jj = ABS(j - radius);
                 if (ii + jj <= rlim)
-                    d[i*res + j] = 1.0;
+                    d[i*res + j] = 1;
             }
         }
     }
     else if (shape == MASKMORPH_SQUARE)
-        gwy_field_fill(kernel, 1.0);
+        gwy_nield_fill(kernel, 1);
     else {
         g_assert_not_reached();
     }
@@ -307,33 +301,38 @@ execute(ModuleArgs *args)
         { GWY_MIN_MAX_FILTER_CLOSING,  MASKMORPH_CLOSING,  },
     };
 
-    GwyField *kernel, *mask = args->result;
     GwyParams *params = args->params;
     MaskMorphOperation operation = gwy_params_get_enum(params, PARAM_MODE);
     MaskMorphShapeType shape = gwy_params_get_enum(params, PARAM_SHAPE);
     guint radius = gwy_params_get_int(params, PARAM_RADIUS);
     gboolean crop_kernel = gwy_params_get_boolean(params, PARAM_CROP_KERNEL);
     GwyMinMaxFilterType filtertype1, filtertype2;
-    guint i, xres, yres;
+    guint xres = gwy_nield_get_xres(args->mask), yres = gwy_nield_get_yres(args->mask);
+    GwyNield *result = args->result;
 
-    xres = gwy_field_get_xres(mask);
-    yres = gwy_field_get_yres(mask);
-    gwy_field_copy_data(args->mask, mask);
-    for (i = 0; i < G_N_ELEMENTS(operation_map); i++) {
+    gwy_nield_copy_data(args->mask, result);
+    gwy_nield_flatten(result);
+
+    for (guint i = 0; i < G_N_ELEMENTS(operation_map); i++) {
         if (operation_map[i].operation != operation)
             continue;
 
+        GwyNield *kernel;
         if (shape == MASKMORPH_USER_KERNEL) {
             if (!(kernel = gwy_params_get_image_mask(params, PARAM_KERNEL)))
                 continue;
-            kernel = gwy_field_copy(kernel);
-            if (crop_kernel)
-                gwy_field_grains_autocrop(kernel, FALSE, NULL, NULL, NULL, NULL);
+
+            if (crop_kernel) {
+                kernel = gwy_nield_copy(kernel);
+                gwy_nield_autocrop(kernel, FALSE, NULL, NULL, NULL, NULL);
+            }
+            else
+                g_object_ref(kernel);
         }
         else
             kernel = create_kernel(shape, radius);
 
-        gwy_field_area_filter_min_max(mask, kernel, operation_map[i].filtertype, 0, 0, xres, yres);
+        gwy_nield_area_filter_min_max(result, kernel, operation_map[i].filtertype, 0, 0, xres, yres);
         g_object_unref(kernel);
         return;
     }
@@ -345,7 +344,7 @@ execute(ModuleArgs *args)
         return;
 
     if (shape == MASKMORPH_DISC) {
-        gwy_field_area_filter_disc_asf(mask, radius, operation == MASKMORPH_ASF_CLOSING, 0, 0, xres, yres);
+        gwy_nield_area_filter_disc_asf(result, radius, operation == MASKMORPH_ASF_CLOSING, 0, 0, xres, yres);
         return;
     }
 
@@ -358,10 +357,10 @@ execute(ModuleArgs *args)
         filtertype2 = GWY_MIN_MAX_FILTER_OPENING;
     }
 
-    for (i = 1; i <= radius; i++) {
-        kernel = create_kernel(shape, i);
-        gwy_field_area_filter_min_max(mask, kernel, filtertype1, 0, 0, xres, yres);
-        gwy_field_area_filter_min_max(mask, kernel, filtertype2, 0, 0, xres, yres);
+    for (guint i = 1; i <= radius; i++) {
+        GwyNield *kernel = create_kernel(shape, i);
+        gwy_nield_area_filter_min_max(result, kernel, filtertype1, 0, 0, xres, yres);
+        gwy_nield_area_filter_min_max(result, kernel, filtertype2, 0, 0, xres, yres);
         g_object_unref(kernel);
     }
 }
@@ -369,7 +368,7 @@ execute(ModuleArgs *args)
 static gboolean
 kernel_filter(GwyFile *data, gint id, gpointer user_data)
 {
-    GwyField *kernel, *mask = (GwyField*)user_data;
+    GwyNield *mask = (GwyNield*)user_data, *kernel;
 
     if (!(kernel = gwy_file_get_image_mask(data, id)))
         return FALSE;
