@@ -1,6 +1,6 @@
 /*
- *  $Id: maskcor.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2004-2023 David Necas (Yeti), Petr Klapetek.
+ *  $Id: maskcor.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -42,7 +42,8 @@ typedef enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *result;
+    GwyField *score;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -72,7 +73,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Searches for a detail in another image using correlation."),
     "Petr Klapetek <klapetek@gwyddion.net>, Yeti <yeti@gwyddion.net>",
-    "3.2",
+    "4.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -145,8 +146,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field);
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.mask = gwy_field_new_nield_alike(args.field);
+    args.score = gwy_field_new_alike(args.field, TRUE);
     args.params = gwy_params_new_from_settings(define_module_params());
 
     outcome = run_gui(&args, data, id);
@@ -154,11 +155,12 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome == GWY_DIALOG_CANCEL)
         goto end;
 
+    /* Only one of args.score and args.mask is filled with useful data, depending on the output type! */
     execute(&args);
 
     output = gwy_params_get_enum(args.params, PARAM_RESULT);
     if (output == MASKCOR_SCORE) {
-        newid = gwy_file_add_image(data, args.result);
+        newid = gwy_file_add_image(data, args.score);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                             data, GWY_FILE_IMAGE, newid,
@@ -167,14 +169,15 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
     }
     else {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-        gwy_container_set_object(GWY_CONTAINER(data), mquark, args.result);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+        gwy_dict_set_object(GWY_DICT(data), mquark, args.mask);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
 
 end:
     g_object_unref(args.params);
-    g_object_unref(args.result);
+    g_object_unref(args.score);
+    g_object_unref(args.mask);
 }
 
 static GwyDialogOutcome
@@ -191,7 +194,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     dialog = GWY_DIALOG(gui.dialog);
     gwy_dialog_add_buttons(dialog, GWY_RESPONSE_UPDATE, GWY_RESPONSE_RESET, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    gui.dataview = gwy_create_preview(args->result, NULL, PREVIEW_SIZE);
+    gui.dataview = gwy_create_preview(args->score, NULL, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(gui.dataview), data, GWY_FILE_IMAGE, id,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE);
     hbox = gwy_create_dialog_preview_hbox(GTK_DIALOG(dialog), GWY_DATA_VIEW(gui.dataview), FALSE);
@@ -226,7 +229,8 @@ param_changed(ModuleGUI *gui, gint id)
     GwyParamTable *table = gui->table;
 
     if (id < 0 || id == PARAM_KERNEL) {
-        GwyField *mask = NULL, *kernel = gwy_params_get_image(params, PARAM_KERNEL);
+        GwyField *kernel = gwy_params_get_image(params, PARAM_KERNEL);
+        GwyNield *mask = NULL;
         GwyAppDataId dataid = gwy_params_get_data_id(params, PARAM_KERNEL);
 
         gtk_dialog_set_response_sensitive(GTK_DIALOG(gui->dialog), GWY_RESPONSE_UPDATE, !!kernel);
@@ -235,7 +239,7 @@ param_changed(ModuleGUI *gui, gint id)
             GwyFile *data = gwy_data_browser_get_file(dataid.datano);
             mask = gwy_file_get_image_mask(data, dataid.id);
         }
-        gwy_param_table_set_sensitive(table, PARAM_USE_MASK, !!mask && gwy_field_get_max(mask) > 0.0);
+        gwy_param_table_set_sensitive(table, PARAM_USE_MASK, !!mask && gwy_nield_max(mask) > 0);
     }
     if (id < 0 || id == PARAM_RESULT) {
         MaskcorResult output = gwy_params_get_enum(params, PARAM_RESULT);
@@ -261,7 +265,7 @@ preview(gpointer user_data)
     ModuleArgs *args = gui->args;
 
     execute(args);
-    gwy_field_data_changed(args->result);
+    gwy_field_data_changed(args->score);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
@@ -281,35 +285,29 @@ kernel_filter(GwyFile *data, gint id, gpointer user_data)
 }
 
 static void
-mark_only_maxima(GwyField *field, GwyField *mask)
+mark_only_maxima(GwyField *field, GwyNield *mask)
 {
-    gint n, i, j, ngrains;
-    gint *grain_maxima, *grains;
-    const gdouble *data;
-    gdouble *mdata;
+    gint n = gwy_field_get_xres(field) * gwy_field_get_yres(field);
+    gint ngrains = gwy_nield_number_contiguous(mask);
 
-    n = gwy_field_get_xres(field) * gwy_field_get_yres(field);
-    data = gwy_field_get_data_const(field);
-    mdata = gwy_field_get_data(mask);
+    const gdouble *data = gwy_field_get_data_const(field);
+    gint *grains = gwy_nield_get_data(mask);
+    gint *grain_maxima = g_new(gint, ngrains + 1);
 
-    grains = g_new0(gint, n);
-    ngrains = gwy_field_number_grains(mask, grains);
-    grain_maxima = g_new(gint, ngrains + 1);
-    for (i = 1; i <= ngrains; i++)
+    for (gint i = 1; i <= ngrains; i++)
         grain_maxima[i] = -1;
 
-    /* sum grain sizes and find maxima */
-    for (i = 0; i < n; i++) {
-        j = grains[i];
+    /* Sum grain sizes and find maxima. */
+    for (gint i = 0; i < n; i++) {
+        gint j = grains[i];
         if (j && (grain_maxima[j] < 0.0 || data[grain_maxima[j]] < data[i]))
             grain_maxima[j] = i;
     }
-    g_free(grains);
 
-    /* mark only maxima */
-    gwy_field_clear(mask);
-    for (i = 1; i <= ngrains; i++)
-        mdata[grain_maxima[i]] = 1;
+    /* Mark only maxima. */
+    gwy_nield_clear(mask);
+    for (gint i = 1; i <= ngrains; i++)
+        grains[grain_maxima[i]] = 1;
 
     g_free(grain_maxima);
 }
@@ -317,7 +315,8 @@ mark_only_maxima(GwyField *field, GwyField *mask)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *markfield, *tmp = NULL, *result = args->result, *kernel, *kmask = NULL;
+    GwyField *score = args->score, *kernel, *kweight = NULL;
+    GwyNield *mask = args->mask, *kmask = NULL;
     GwyParams *params = args->params;
     gboolean use_mask = gwy_params_get_boolean(params, PARAM_USE_MASK);
     gboolean plot_mask = gwy_params_get_boolean(params, PARAM_PLOT_MASK);
@@ -326,15 +325,17 @@ execute(ModuleArgs *args)
     GwyCorrSearchType method = gwy_params_get_enum(params, PARAM_METHOD);
     MaskcorResult output = gwy_params_get_enum(params, PARAM_RESULT);
     gdouble min, max;
-    gint xres, yres;
 
     kernel = gwy_params_get_image(params, PARAM_KERNEL);
-    if (use_mask)
+    if (use_mask) {
         kmask = gwy_params_get_image_mask(params, PARAM_KERNEL);
+        kweight = gwy_field_new_alike(kernel, FALSE);
+        gwy_field_fill_mask(kweight, kmask, 0.0, 1.0);
+    }
 
-    gwy_field_correlation_search(args->field, kernel, kmask, result,
-                                 method, regcoeff, GWY_EXTERIOR_BORDER, 0.0);
-    gwy_field_invalidate(result);
+    gwy_field_correlation_search(args->field, kernel, kweight, score, method, regcoeff, GWY_EXTERIOR_BORDER, 0.0);
+    gwy_field_invalidate(score);
+    g_clear_object(&kweight);
 
     if (output == MASKCOR_SCORE)
         return;
@@ -346,7 +347,7 @@ execute(ModuleArgs *args)
         threshold = 2.0*(threshold - 1.0);
     }
     else {
-        gwy_field_get_min_max(result, &min, &max);
+        gwy_field_min_max(score, &min, &max);
         threshold = max*threshold + min*(1.0 - threshold);
     }
 
@@ -360,24 +361,24 @@ execute(ModuleArgs *args)
      *
      * This makes impossible to use kernel mask but plot rectangles.  Do we care?
      */
-    markfield = gwy_field_copy(result);
-    gwy_field_threshold(markfield, threshold, 0.0, 1.0);
+    gwy_nield_mark_by_threshold(mask, score, threshold, TRUE);
     if (output == MASKCOR_MAXIMA)
-        mark_only_maxima(result, markfield);
+        mark_only_maxima(score, mask);
 
     if (plot_mask) {
-        if (!kmask) {
-            kmask = tmp = gwy_field_new_alike(kernel, FALSE);
-            gwy_field_fill(kmask, 1.0);
+        if (kmask)
+            g_object_ref(kmask);
+        else {
+            kmask = gwy_field_new_nield_alike(kernel);
+            gwy_nield_fill(kmask, 1);
         }
-        xres = gwy_field_get_xres(result);
-        yres = gwy_field_get_yres(result);
-        gwy_field_area_filter_min_max(markfield, kmask, GWY_MIN_MAX_FILTER_DILATION, 0, 0, xres, yres);
-        g_clear_object(&tmp);
+        gint xres = gwy_field_get_xres(score), yres = gwy_field_get_yres(score);
+        /* Use score because the caller should only take the mask in this case. */
+        gwy_field_fill_mask(score, mask, 0.0, 1.0);
+        gwy_field_area_filter_min_max(score, kmask, GWY_MIN_MAX_FILTER_DILATION, 0, 0, xres, yres);
+        g_object_unref(kmask);
+        gwy_nield_mark_by_threshold(mask, score, 0.5, TRUE);
     }
-
-    gwy_field_copy_data(markfield, result);
-    g_object_unref(markfield);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
