@@ -1,6 +1,6 @@
 /*
- *  $Id: maskops.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: maskops.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -40,7 +40,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Basic operations with mask: inversion, removal, extraction."),
     "Yeti <yeti@gwyddion.net>",
-    "1.7",
+    "2.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -99,20 +99,20 @@ module_register(void)
 static void
 mask_invert(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *mfield;
+    GwyNield *mask;
     GQuark mquark;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mfield,
+    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(mfield && mquark);
+    g_return_if_fail(mask && mquark);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    gwy_field_grains_invert(mfield);
-    gwy_field_data_changed(mfield);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_nield_invert(mask);
+    gwy_nield_data_changed(mask);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
@@ -128,31 +128,33 @@ mask_remove(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(mquark);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_dict_remove(GWY_DICT(data), mquark);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
 static void
 mask_extract(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *mfield;
-    gint id, newid;
+    GwyField *field;
+    GwyNield *mask;
+    gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mfield,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(mfield);
+    g_return_if_fail(mask);
 
-    mfield = gwy_field_copy(mfield);
-    gwy_field_clamp(mfield, 0.0, 1.0);
-    gwy_unit_clear(gwy_field_get_unit_z(mfield));
+    field = gwy_field_new_alike(field, FALSE);
+    gwy_unit_clear(gwy_field_get_unit_z(field));
+    gwy_field_fill_mask(field, mask, 0.0, 1.0);
 
-    newid = gwy_file_add_image(data, mfield);
+    gint newid = gwy_file_add_image(data, field);
 
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
-    g_object_unref(mfield);
+    g_object_unref(field);
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Mask"), TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -163,31 +165,32 @@ mask_extract(GwyFile *data, GwyRunModeFlags mode)
 static void
 extract_grain_numbers(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *mfield;
-    gint *grains;
-    gint id, newid, n, i;
-    gdouble *d;
+    GwyField *field;
+    GwyNield *mask;
+    gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mfield,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(mfield);
+    g_return_if_fail(mask);
 
-    n = gwy_field_get_xres(mfield)*gwy_field_get_yres(mfield);
-    grains = g_new0(gint, n);
-    gwy_field_number_grains(mfield, grains);
-    mfield = gwy_field_copy(mfield);
-    d = gwy_field_get_data(mfield);
-    for (i = 0; i < n; i++)
+    /* We do *not* renumber the grains. Most functions renumber contiguous when creating the output. If something
+     * numbered them differently, we want to preserve these numbers. */
+    field = gwy_field_new_alike(field, FALSE);
+    gwy_unit_clear(gwy_field_get_unit_z(field));
+
+    guint n = gwy_nield_get_xres(mask)*gwy_nield_get_yres(mask);
+    const gint *grains = gwy_nield_get_data_const(mask);
+    gdouble *d = gwy_field_get_data(field);
+    for (guint i = 0; i < n; i++)
         d[i] = grains[i];
-    g_free(grains);
-    gwy_unit_clear(gwy_field_get_unit_z(mfield));
 
-    newid = gwy_file_add_image(data, mfield);
+    gint newid = gwy_file_add_image(data, field);
 
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
-    g_object_unref(mfield);
+    g_object_unref(field);
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Grain Numbers"), TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                         data, GWY_FILE_IMAGE, newid,
@@ -198,27 +201,27 @@ extract_grain_numbers(GwyFile *data, GwyRunModeFlags mode)
 static void
 remove_touching(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *mfield;
+    GwyNield *mask;
     GQuark mquark;
     gint id;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mfield,
+    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(mfield);
+    g_return_if_fail(mask);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    gwy_field_grains_remove_touching_border(mfield);
-    gwy_field_data_changed(mfield);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gwy_nield_clear_touching_border(mask, TRUE);
+    gwy_nield_data_changed(mask);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
 static void
 mask_thin(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *mask;
+    GwyNield *mask;
     GQuark quark;
     gint id;
 
@@ -229,9 +232,9 @@ mask_thin(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(mask);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
-    gwy_field_grains_thin(mask);
-    gwy_field_data_changed(mask);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
+    gwy_nield_thin(mask);
+    gwy_nield_data_changed(mask);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
