@@ -1,5 +1,5 @@
 /*
- *  $Id: mcrop.c 28858 2025-11-13 14:32:56Z yeti-dn $
+ *  $Id: mcrop.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2024 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -193,10 +193,10 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         quark = gwy_file_key_image(id);
         otherquark = gwy_file_key_image(otherid);
         if (otherdata == data)
-            gwy_app_undo_qcheckpoint(GWY_CONTAINER(data), quark, otherquark, 0);
+            gwy_app_undo_qcheckpoint(GWY_DICT(data), quark, otherquark, 0);
         else {
-            gwy_app_undo_qcheckpoint(GWY_CONTAINER(data), quark, 0);
-            gwy_app_undo_qcheckpoint(GWY_CONTAINER(otherdata), otherquark, 0);
+            gwy_app_undo_qcheckpoint(GWY_DICT(data), quark, 0);
+            gwy_app_undo_qcheckpoint(GWY_DICT(otherdata), otherquark, 0);
         }
         gwy_file_set_image(data, id, args.cropped);
         gwy_file_set_image(otherdata, otherid, args.croppedother);
@@ -279,8 +279,8 @@ update_display(ModuleGUI *gui)
         gwy_data_view_set_field(dataview, args->diff);
         if (diff_colourmap) {
             mapping = GWY_COLOR_MAPPING_FIXED;
-            gwy_field_get_min_max(args->diff, &min, &max);
-            gwy_field_get_autorange(args->diff, &dispmin, &dispmax);
+            gwy_field_min_max(args->diff, &min, &max);
+            gwy_field_autorange(args->diff, &dispmin, &dispmax);
             gwy_set_gradient_for_residuals(gui->diff_gradient, min, max, &dispmin, &dispmax);
             gwy_data_view_set_fixed_color_range(dataview, dispmin, dispmax);
             gwy_data_view_set_gradient(dataview, gui->diff_gradient);
