@@ -1,5 +1,5 @@
 /*
- *  $Id: measure_lattice.c 29083 2026-01-05 17:55:55Z yeti-dn $
+ *  $Id: measure_lattice.c 29521 2026-02-23 10:24:50Z yeti-dn $
  *  Copyright (C) 2015-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -14,7 +14,7 @@
  *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#define DEBUG 1
+
 #include "config.h"
 #include <glib/gi18n-lib.h>
 #include <stdlib.h>
@@ -69,7 +69,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     /* We always keep the direct-space selection here. */
     gboolean have_xy;
     gdouble xy[4];
@@ -131,7 +131,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Measures parameters of two-dimensional lattices."),
     "Yeti <yeti@gwyddion.net>",
-    "3.5",
+    "3.6",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -213,14 +213,14 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     /* Replace the field with an adjusted one. Keep the average for adjusting the fixed range for preview. */
     args.field = gwy_field_copy(args.field);
-    args.avg = gwy_field_get_avg(args.field);
+    args.avg = gwy_field_mean(args.field);
     gwy_field_add(args.field, -args.avg);
     gwy_field_set_xoffset(args.field, -0.5*gwy_field_get_xreal(args.field));
     gwy_field_set_yoffset(args.field, -0.5*gwy_field_get_yreal(args.field));
 
     /* Restore lattice from data if any is present. */
     GQuark selection_key = gwy_file_key_image_selection(id, "lattice");
-    if (gwy_container_gis_object(GWY_CONTAINER(data), selection_key, &selection))
+    if (gwy_dict_gis_object(GWY_DICT(data), selection_key, &selection))
         args.have_xy = gwy_selection_get_object(selection, 0, args.xy);
 
     args.params = gwy_params_new_from_settings(define_module_params());
@@ -231,7 +231,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (args.have_xy && outcome == GWY_DIALOG_HAVE_RESULT) {
         selection = gwy_selection_lattice_new();
         gwy_selection_set_data(selection, 1, args.xy);
-        gwy_container_pass_object(GWY_CONTAINER(data), selection_key, selection);
+        gwy_dict_pass_object(GWY_DICT(data), selection_key, selection);
     }
 
     g_object_unref(args.params);
@@ -522,7 +522,8 @@ calculate_acf(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
     GwyParams *params = args->params;
-    GwyField *acf = gui->acf, *mid, *mask = args->mask, *field = args->field;
+    GwyField *acf = gui->acf, *mid, *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gboolean fix_hacf = gwy_params_get_boolean(params, PARAM_FIX_HACF);
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
@@ -531,10 +532,10 @@ calculate_acf(ModuleGUI *gui)
     gwy_field_area_acf_2d(field, mask, masking, acf, 0, 0, xres, yres, acfwidth, acfheight, NULL);
     if (fix_hacf) {
         mid = gwy_field_area_extract(acf, 0, acfheight/2-1, acfwidth, 3);
-        mask = gwy_field_new(acfwidth, 3, acfwidth, 3, TRUE);
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 1, acfwidth, 1, 1.0);
-        gwy_field_set_val(mask, acfwidth/2, 1, 0.0);
-        gwy_field_laplace_solve(mid, mask, -1, 1.0);
+        mask = gwy_nield_new(acfwidth, 3);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, 0, 1, acfwidth, 1, 1);
+        gwy_nield_set_val(mask, acfwidth/2, 1, 0);
+        gwy_field_laplace_solve(mid, mask, GWY_LAPLACE_MASKED, 1.0);
         gwy_field_area_copy(mid, acf, 0, 1, acfwidth, 1, 0, acfheight/2-1);
         g_object_unref(mask);
         g_object_unref(mid);
@@ -556,8 +557,9 @@ calculate_psdf(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
     GwyParams *params = args->params;
-    GwyField *psdf = gui->psdf, *mask = args->mask, *field = args->field;
-    GwyField *extmask = NULL, *extfield, *fullpsdf;
+    GwyField *psdf = gui->psdf, *field = args->field;
+    GwyField *extfield, *fullpsdf;
+    GwyNield *mask = args->mask, *extmask = NULL;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     GwyWindowingType windowing = GWY_WINDOWING_HANN;
     gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
@@ -566,14 +568,14 @@ calculate_psdf(ModuleGUI *gui)
     gdouble *p;
 
     field = gwy_field_copy(field);
-    gwy_field_add(field, -gwy_field_get_avg(field));
+    gwy_field_add(field, -gwy_field_mean(field));
     gwy_field_fft_window(field, windowing);
     extfield = gwy_field_extend(field, 0, extxres - xres, 0, extyres - yres,
                                 GWY_EXTERIOR_FIXED_VALUE, 0.0, FALSE);
     g_clear_object(&field);
     if (mask) {
-        extmask = gwy_field_extend(mask, 0, extxres - xres, 0, extyres - yres,
-                                   GWY_EXTERIOR_FIXED_VALUE, masking == GWY_MASK_INCLUDE ? 1.0 : 0.0, FALSE);
+        extmask = gwy_nield_extend(mask, 0, extxres - xres, 0, extyres - yres,
+                                   GWY_EXTERIOR_FIXED_VALUE, masking == GWY_MASK_INCLUDE ? 1 : 0);
     }
 
     fullpsdf = gwy_field_new_alike(extfield, FALSE);
@@ -601,10 +603,25 @@ calculate_psdf(ModuleGUI *gui)
     n = psdfwidth*psdfheight;
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(p,n) private(i)
+            shared(p,n)
 #endif
-    for (i = 0; i < n; i++)
-        p[i] = (p[i] >= 0.0 ? sqrt(p[i]) : -sqrt(-p[i]));
+    for (gint k = 0; k < n; k++)
+        p[k] = (p[k] >= 0.0 ? sqrt(p[k]) : -sqrt(-p[k]));
+}
+
+static gboolean
+calc_cut_to_zoom(gint xres, gint yres, gint zoom, gint *pwidth, gint *pheight)
+{
+    gint width = (xres/zoom) | 1;
+    gint height = (yres/zoom) | 1;
+    if (width < 17)
+        width = MAX(width, MIN(17, xres));
+    if (height < 17)
+        height = MAX(height, MIN(17, yres));
+
+    *pwidth = width;
+    *pheight = height;
+    return width >= xres && height >= yres;
 }
 
 static void
@@ -613,7 +630,7 @@ calculate_zoomed_field(ModuleGUI *gui)
     ModuleArgs *args = gui->args;
     ImageMode image_mode = gwy_params_get_enum(args->params, PARAM_IMAGE_MODE);
     GwyField *field, *zoomed;
-    guint xres, yres, width, height, zoom;
+    gint zoom;
 
     if (image_mode == IMAGE_ACF) {
         zoom = gwy_params_get_enum(args->params, PARAM_ZOOM_ACF);
@@ -628,21 +645,11 @@ calculate_zoomed_field(ModuleGUI *gui)
         return;
     }
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    if (zoom == 1)
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint width, height;
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
         zoomed = g_object_ref(field);
     else {
-        width = (xres/zoom) | 1;
-        height = (yres/zoom) | 1;
-
-        if (width < 17)
-            width = MAX(width, MIN(17, xres));
-
-        if (height < 17)
-            height = MAX(height, MIN(17, yres));
-
         zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
         gwy_field_set_xoffset(zoomed, -0.5*gwy_field_get_xreal(zoomed));
         gwy_field_set_yoffset(zoomed, -0.5*gwy_field_get_yreal(zoomed));
