@@ -1,5 +1,5 @@
 /*
- *  $Id: median-bg.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: median-bg.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -115,7 +115,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.bg = gwy_field_new_alike(args.field, TRUE);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -125,7 +125,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         && !execute(&args, gwy_data_browser_get_window_for_data(data, GWY_FILE_IMAGE, id)))
         goto end;
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
@@ -202,19 +202,17 @@ preview(gpointer user_data)
 static gboolean
 execute(ModuleArgs *args, GtkWindow *wait_window)
 {
-    GwyField *bg = args->bg, *result = args->result, *kernel;
+    GwyField *bg = args->bg, *result = args->result;
     gint size = gwy_params_get_int(args->params, PARAM_RADIUS);
-    gint xres, yres, kres = 2*size + 1, n;
-    gboolean ok;
+    gint kres = 2*size + 1;
 
     gwy_app_wait_start(wait_window, _("Median-leveling..."));
 
-    kernel = gwy_field_new(kres, kres, 1.0, 1.0, TRUE);
-    n = gwy_field_elliptic_area_fill(kernel, 0, 0, kres, kres, 1.0);
+    GwyNield *kernel = gwy_nield_new(kres, kres);
+    gint n = gwy_nield_elliptic_fill(kernel);
     gwy_field_copy_data(args->field, bg);
-    xres = gwy_field_get_xres(result);
-    yres = gwy_field_get_yres(result);
-    ok = gwy_field_area_filter_kth_rank(bg, kernel, 0, 0, xres, yres, n/2, gwy_app_wait_set_fraction);
+    gint xres = gwy_field_get_xres(result), yres = gwy_field_get_yres(result);
+    gboolean ok = gwy_field_area_filter_kth_rank(bg, kernel, 0, 0, xres, yres, n/2, gwy_app_wait_set_fraction);
 
     gwy_app_wait_finish();
 
