@@ -1,6 +1,6 @@
 /*
- *  $Id: merge.c 29059 2026-01-02 14:27:52Z yeti-dn $
- *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: merge.c 29407 2026-01-30 15:34:09Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -68,7 +68,7 @@ typedef struct {
     GwyParams *params;
     GwyField *field;
     GwyField *result;
-    GwyField *result_mask;
+    GwyNield *result_mask;
 } ModuleArgs;
 
 typedef struct {
@@ -125,7 +125,7 @@ static void             create_merged_field  (ModuleArgs *args,
 static void             put_fields           (GwyField *field1,
                                               GwyField *field2,
                                               GwyField *result,
-                                              GwyField *outsidemask,
+                                              GwyNield *outsidemask,
                                               GwyMergeBoundaryType boundary,
                                               gint px1,
                                               gint py1,
@@ -145,7 +145,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Merges two images."),
     "Petr Klapetek <klapetek@gwyddion.net>, Yeti <yeti@gwyddion.net>",
-    "4.0",
+    "4.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -170,13 +170,13 @@ static GwyParamDef*
 define_module_params(void)
 {
     static const GwyEnum directions[] = {
-        { N_("Up"),           GWY_MERGE_DIRECTION_UP,    },
-        { N_("Down"),         GWY_MERGE_DIRECTION_DOWN,  },
+        { N_("Up"),                  GWY_MERGE_DIRECTION_UP,    },
+        { N_("Down"),                GWY_MERGE_DIRECTION_DOWN,  },
         { gwy_NC("adverb", "Right"), GWY_MERGE_DIRECTION_RIGHT, },
         { gwy_NC("adverb", "Left"),  GWY_MERGE_DIRECTION_LEFT,  },
     };
     static const GwyEnum modes[] = {
-        { N_("Correlation"),     GWY_MERGE_MODE_CORRELATE, },
+        { N_("Correlation"),            GWY_MERGE_MODE_CORRELATE, },
         { gwy_NC("merge-mode", "Join"), GWY_MERGE_MODE_JOIN,      },
         { gwy_NC("merge-mode", "None"), GWY_MERGE_MODE_NONE,      },
     };
@@ -243,7 +243,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_MASK_COLOR
                         | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_REAL_SQUARE, FALSE);
-    if (args.result_mask && gwy_field_get_max(args.result_mask) > 0.0)
+    if (args.result_mask && gwy_nield_number_contiguous(args.result_mask))
         gwy_file_set_image_mask(data, newid, args.result_mask);
     gwy_log_add(data, GWY_FILE_IMAGE, -1, newid);
 
@@ -581,7 +581,8 @@ create_merged_field(ModuleArgs *args, gint px1, gint py1, gint px2, gint py2,
                     gboolean create_mask, gboolean crop_to_rectangle)
 {
     GwyField *field1 = args->field, *field2 = gwy_params_get_image(args->params, PARAM_OHTER_IMAGE);
-    GwyField *result, *outsidemask = NULL;
+    GwyField *result;
+    GwyNield *outsidemask = NULL;
     gint xres1, xres2, yres1, yres2, newxres, newyres;
 
     xres1 = gwy_field_get_xres(field1);
@@ -598,10 +599,8 @@ create_merged_field(ModuleArgs *args, gint px1, gint py1, gint px2, gint py2,
     result = args->result = gwy_field_new_alike(field1, FALSE);
     gwy_field_resize(result, newxres, newyres);
 
-    if (create_mask && !crop_to_rectangle) {
-        outsidemask = args->result_mask = gwy_field_new_alike(result, FALSE);
-        gwy_unit_clear(gwy_field_get_unit_z(outsidemask));
-    }
+    if (create_mask && !crop_to_rectangle)
+        outsidemask = args->result_mask = gwy_field_new_nield_alike(result);
     put_fields(field1, field2, result, outsidemask, boundary, px1, py1, px2, py2);
 
     if (crop_to_rectangle) {
@@ -615,7 +614,7 @@ create_merged_field(ModuleArgs *args, gint px1, gint py1, gint px2, gint py2,
 
 static void
 put_fields(GwyField *field1, GwyField *field2,
-           GwyField *result, GwyField *outsidemask,
+           GwyField *result, GwyNield *outsidemask,
            GwyMergeBoundaryType boundary,
            gint px1, gint py1, gint px2, gint py2)
 {
@@ -629,7 +628,7 @@ put_fields(GwyField *field1, GwyField *field2,
     gwy_debug("result %dx%d", result->xres, result->yres);
     gwy_debug("px1: %d, py1: %d, px2: %d, py2: %d", px1, py1, px2, py2);
 
-    gwy_field_fill(result, fmin(gwy_field_get_min(field1), gwy_field_get_min(field2)));
+    gwy_field_fill(result, fmin(gwy_field_min(field1), gwy_field_min(field2)));
 
     w1 = gwy_field_get_xres(field1);
     h1 = gwy_field_get_yres(field1);
@@ -646,9 +645,9 @@ put_fields(GwyField *field1, GwyField *field2,
     }
 
     if (outsidemask) {
-        gwy_field_fill(outsidemask, 1.0);
-        gwy_field_area_clear(outsidemask, px1, py1, w1, h1);
-        gwy_field_area_clear(outsidemask, px2, py2, w2, h2);
+        gwy_nield_fill(outsidemask, 1);
+        gwy_nield_area_clear(outsidemask, px1, py1, w1, h1);
+        gwy_nield_area_clear(outsidemask, px2, py2, w2, h2);
     }
 
     /* adjust boundary to be as smooth as possible */
@@ -689,10 +688,6 @@ put_fields(GwyField *field1, GwyField *field2,
     yreal = result->yres * gwy_field_get_dy(field1);
     gwy_field_set_xreal(result, xreal);
     gwy_field_set_yreal(result, yreal);
-    if (outsidemask) {
-        gwy_field_set_xreal(outsidemask, xreal);
-        gwy_field_set_yreal(outsidemask, yreal);
-    }
 }
 
 static void
