@@ -1,6 +1,6 @@
 /*
- *  $Id: mfm_field.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: mfm_field.c 29520 2026-02-23 09:32:20Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ typedef enum {
 
 typedef struct {
     GwyParams *params;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
 } ModuleArgs;
 
@@ -78,7 +78,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Simulation of magnetic field above perpendicular media"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2017",
 };
@@ -168,17 +168,19 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     GwyDialogOutcome outcome;
     ModuleArgs args;
     gint id, newid, datano, out;
+    GwyField *field;
     g_return_if_fail(mode & RUN_MODES);
 
-    gwy_data_browser_get_current(GWY_APP_MASK_FIELD, &args.mask,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &args.mask,
                                  GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &datano,
+                                 GWY_APP_FILE_ID, &datano,
                                  0);
     g_return_if_fail(args.mask);
-    args.result = gwy_field_new_alike(args.mask, TRUE);
+    args.result = gwy_field_new_alike(field, TRUE);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -284,7 +286,7 @@ param_changed(ModuleGUI *gui, gint id)
         if (out == GWY_MFM_FIELD_OUTPUT_MEFF || out == GWY_MFM_FIELD_OUTPUT_FIELD || probe != GWY_MFM_PROBE_BAR)
             bar_sensitive = FALSE;
         else
-            bar_sensitive= TRUE;
+            bar_sensitive = TRUE;
 
         gwy_param_table_set_sensitive(table, PARAM_MTIP, bar_sensitive);
         gwy_param_table_set_sensitive(table, PARAM_BX, bar_sensitive);
@@ -323,15 +325,18 @@ execute(ModuleArgs *args)
     gdouble by = gwy_params_get_double(params, PARAM_BY)*1e-9;
     gdouble mtip = gwy_params_get_double(params, PARAM_MTIP)*1e3;
     gboolean walls = gwy_params_get_boolean(params, PARAM_WALLS);
-    GwyField *field = args->mask, *result = args->result;
+    GwyField *result = args->result;
+    GwyNield *mask = args->mask;
     GwyMfmFieldOutputType out = gwy_params_get_enum(params, PARAM_OUT);
     GwyMFMProbeType probe = gwy_params_get_enum(params, PARAM_PROBE);
 
     /* FIXME: This could be done directly if we had a function equivalent to
      * gwy_field_mfm_perpendicular_stray_field() which calculated
      * derivatives by Z. */
+    GwyField *field = gwy_field_new_alike(result, FALSE);
+    gwy_field_fill_mask(field, mask, -sigma, sigma);
     if (out == GWY_MFM_FIELD_OUTPUT_FIELD || out == GWY_MFM_FIELD_OUTPUT_MEFF || out == GWY_MFM_FIELD_OUTPUT_FORCE) {
-        gwy_field_mfm_perpendicular_stray_field(field, result, height, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height, thickness, walls, wall_delta);
 
         if (angle > 0)
             gwy_field_mfm_perpendicular_stray_field_angle_correction(result, angle, GWY_ORIENTATION_HORIZONTAL);
@@ -353,10 +358,10 @@ execute(ModuleArgs *args)
         fzb = gwy_field_new_alike(result, TRUE);
         fz = gwy_field_new_alike(result, TRUE);
 
-        gwy_field_mfm_perpendicular_stray_field(field, result, height-dd, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height-dd, thickness, walls, wall_delta);
         gwy_field_mfm_perpendicular_medium_force(result, fza, probe, mtip, bx, by, length);
 
-        gwy_field_mfm_perpendicular_stray_field(field, result, height+dd, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height+dd, thickness, walls, wall_delta);
         gwy_field_mfm_perpendicular_medium_force(result, fzb, probe, mtip, bx, by, length);
 
         gwy_field_subtract_fields(fz, fza, fzb);
@@ -367,23 +372,21 @@ execute(ModuleArgs *args)
 
         gwy_field_copy_data(fz, result);
         g_clear_object(&fz);
-
     }
-    else if (out == GWY_MFM_FIELD_OUTPUT_FORCE_DDX) //this is done numerically now
-    {
+    else if (out == GWY_MFM_FIELD_OUTPUT_FORCE_DDX) {
+        //this is done numerically now
         fza = gwy_field_new_alike(result, TRUE);
         fzb = gwy_field_new_alike(result, TRUE);
         fzc = gwy_field_new_alike(result, TRUE);
         fz = gwy_field_new_alike(result, TRUE);
 
-
-        gwy_field_mfm_perpendicular_stray_field(field, result, height-dd, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height-dd, thickness, walls, wall_delta);
         gwy_field_mfm_perpendicular_medium_force(result, fza, probe, mtip, bx, by, length);
 
-        gwy_field_mfm_perpendicular_stray_field(field, result, height, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height, thickness, walls, wall_delta);
         gwy_field_mfm_perpendicular_medium_force(result, fzb, probe, mtip, bx, by, length);
 
-        gwy_field_mfm_perpendicular_stray_field(field, result, height+dd, thickness, sigma, walls, wall_delta);
+        gwy_field_mfm_perpendicular_stray_field(field, result, height+dd, thickness, walls, wall_delta);
         gwy_field_mfm_perpendicular_medium_force(result, fzc, probe, mtip, bx, by, length);
 
         gwy_field_multiply(fzb, 2.0);
@@ -399,6 +402,7 @@ execute(ModuleArgs *args)
         gwy_field_copy_data(fz, result);
         g_clear_object(&fz);
     }
+    g_object_unref(field);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
