@@ -1,5 +1,5 @@
 /*
- *  $Id: mfm_findshift.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: mfm_findshift.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -112,11 +112,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field1,
                                  GWY_APP_FIELD_ID, &op1.id,
-                                 GWY_APP_CONTAINER_ID, &op1.datano,
+                                 GWY_APP_FILE_ID, &op1.datano,
                                  0);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
