@@ -1,6 +1,6 @@
 /*
- *  $Id: multiprofile.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2020-2025 David Necas (Yeti).
+ *  $Id: multiprofile.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2020-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -49,7 +49,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGraphModel *gmodel;
 } ModuleArgs;
 
@@ -100,7 +100,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Displays and extracts scan line graphs from multiple images simultaneously."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "2.0",
     "David Nečas (Yeti)",
     "2020",
 };
@@ -388,7 +388,7 @@ param_changed(ModuleGUI *gui, gint id)
     }
 
     if (id < 0 || id == PARAM_MASKING || id == PARAM_MODE) {
-        GwyField *mask = args->mask;
+        GwyNield *mask = args->mask;
         MultiprofMode mode = gwy_params_get_enum(params, PARAM_MODE);
         GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
         gwy_param_table_set_sensitive(table, PARAM_USE_FIRST_MASK,
@@ -488,15 +488,21 @@ display_changed(ModuleGUI *gui, GtkToggleButton *toggle)
 }
 
 static GwyField*
-get_chosen_image(ModuleArgs *args, guint i, gboolean want_mask)
+get_chosen_image(ModuleArgs *args, guint i)
 {
     GwyParams *params = args->params;
-
     if (!gwy_params_get_boolean(params, PARAM_ENABLED_0 + i))
         return NULL;
-    return (want_mask
-            ? gwy_params_get_image_mask(params, PARAM_IMAGE_0 + i)
-            : gwy_params_get_image(params, PARAM_IMAGE_0 + i));
+    return gwy_params_get_image(params, PARAM_IMAGE_0 + i);
+}
+
+static GwyNield*
+get_chosen_mask(ModuleArgs *args, guint i)
+{
+    GwyParams *params = args->params;
+    if (!gwy_params_get_boolean(params, PARAM_ENABLED_0 + i))
+        return NULL;
+    return gwy_params_get_image_mask(params, PARAM_IMAGE_0 + i);
 }
 
 static gboolean
@@ -532,75 +538,6 @@ execute(ModuleArgs *args)
         multiprofile_do_stats(args);
 }
 
-/* XXX: Duplicate code with tools/cprofile.c */
-static void
-extract_row_profile(GwyField *field, GwyField *mask, GwyMaskingType masking,
-                    GArray *xydata, gint row, gint thickness)
-{
-    gint xres, yres, ifrom, ito, i, j;
-    const gdouble *d, *drow, *m, *mrow;
-    gdouble dx;
-    GwyXY *xy;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    dx = gwy_field_get_dx(field);
-    d = gwy_field_get_data_const(field);
-
-    g_array_set_size(xydata, xres);
-    xy = &g_array_index(xydata, GwyXY, 0);
-    gwy_clear(xy, xres);
-
-    ifrom = row - (thickness - 1)/2;
-    ifrom = MAX(ifrom, 0);
-    ito = row + thickness/2 + 1;
-    ito = MIN(ito, yres);
-
-    if (mask && masking != GWY_MASK_IGNORE)
-        m = gwy_field_get_data_const(mask);
-    else {
-        m = NULL;
-        for (j = 0; j < xres; j++)
-            xy[j].x = ito - ifrom;
-    }
-
-    for (i = ifrom; i < ito; i++) {
-        drow = d + i*xres;
-        if (m) {
-            mrow = m + i*xres;
-            if (masking == GWY_MASK_INCLUDE) {
-                for (j = 0; j < xres; j++) {
-                    if (mrow[j] > 0.0) {
-                        xy[j].y += drow[j];
-                        xy[j].x += 1.0;
-                    }
-                }
-            }
-            else {
-                for (j = 0; j < xres; j++) {
-                    if (mrow[j] <= 0.0) {
-                        xy[j].y += drow[j];
-                        xy[j].x += 1.0;
-                    }
-                }
-            }
-        }
-        else {
-            for (j = 0; j < xres; j++)
-                xy[j].y += drow[j];
-        }
-    }
-
-    for (i = j = 0; j < xres; j++) {
-        if (xy[j].x > 0.0) {
-            xy[i].y = xy[j].y/xy[j].x;
-            xy[i].x = dx*j;
-            i++;
-        }
-    }
-    g_array_set_size(xydata, i);
-}
-
 static void
 multiprofile_do_profiles(ModuleArgs *args)
 {
@@ -609,43 +546,38 @@ multiprofile_do_profiles(ModuleArgs *args)
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, NULL);
     gboolean use_first_mask = gwy_params_get_boolean(args->params, PARAM_USE_FIRST_MASK);
     GwyGraphModel *gmodel = args->gmodel;
-    GwyGraphCurveModel *gcmodel;
-    GwyField *field, *mask = NULL;
-    GArray *xydata;
-    gint lineno, yres;
-    gchar *title;
-    guint i;
-
-    field = get_chosen_image(args, 0, FALSE);
-    yres = gwy_field_get_yres(field);
-    lineno = GWY_ROUND(lineno_frac*(yres - 1.0));
+    GwyField *field = get_chosen_image(args, 0);
+    gint yres = gwy_field_get_yres(field);
+    gint lineno = GWY_ROUND(lineno_frac*(yres - 1.0));
     lineno = CLAMP(lineno, 0, yres-1);
 
     gwy_graph_model_remove_all_curves(gmodel);
 
-    xydata = g_array_new(FALSE, FALSE, sizeof(GwyXY));
-    for (i = 0; i < NARGS; i++) {
-        if (!(field = get_chosen_image(args, i, FALSE)))
+    for (guint i = 0; i < NARGS; i++) {
+        if (!(field = get_chosen_image(args, i)))
             continue;
 
+        GwyNield *mask = NULL;
         if (masking != GWY_MASK_IGNORE)
-            mask = get_chosen_image(args, use_first_mask ? 0 : i, TRUE);
+            mask = get_chosen_mask(args, use_first_mask ? 0 : i);
 
-        extract_row_profile(field, mask, masking, xydata, lineno, thickness);
-        gcmodel = gwy_graph_curve_model_new();
-        gwy_graph_curve_model_set_data_interleaved(gcmodel, (gdouble*)xydata->data, xydata->len);
-        title = g_strdup_printf("%u", i+1);
-        g_object_set(gcmodel,
-                     "mode", GWY_GRAPH_CURVE_LINE,
-                     "color", gwy_graph_get_preset_color(i),
-                     "description", title,
-                     NULL);
-        g_free(title);
-
-        gwy_graph_model_add_curve(gmodel, gcmodel);
-        g_object_unref(gcmodel);
+        gint npoints;
+        GwyXY *xy = gwy_field_row_profile(field, mask, masking, lineno, thickness, &npoints);
+        if (npoints) {
+            GwyGraphCurveModel *gcmodel = gwy_graph_curve_model_new();
+            gwy_graph_curve_model_set_data_interleaved(gcmodel, (gdouble*)xy, npoints);
+            gchar *title = g_strdup_printf("%u", i+1);
+            g_object_set(gcmodel,
+                         "mode", GWY_GRAPH_CURVE_LINE,
+                         "color", gwy_graph_get_preset_color(i),
+                         "description", title,
+                         NULL);
+            g_free(title);
+            gwy_graph_model_add_curve(gmodel, gcmodel);
+            g_object_unref(gcmodel);
+        }
+        g_free(xy);
     }
-    g_array_free(xydata, TRUE);
 }
 
 static GwyGraphCurveModel*
@@ -697,92 +629,83 @@ multiprofile_do_stats(ModuleArgs *args)
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, NULL);
     MultiprofMode mode = gwy_params_get_enum(args->params, PARAM_MODE);
     GwyGraphModel *gmodel = args->gmodel;
-    GwyField *field, *mask, *bigfield, *bigmask = NULL;
-    GwyLine *avg, *aux1, *aux2, *weight;
-    GArray *xydata;
-    gint lineno, xres, yres, ifrom, ito, blockheight;
-    gdouble dx;
-    guint i, nimages;
+
+    GwyField *field = get_chosen_image(args, 0);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble dx = gwy_field_get_dx(field);
+    gint lineno = GWY_ROUND(lineno_frac*(yres - 1.0));
+    lineno = CLAMP(lineno, 0, yres-1);
+
+    gint ifrom = lineno - (thickness - 1)/2;
+    ifrom = MAX(ifrom, 0);
+    gint ito = lineno + thickness/2 + 1;
+    ito = MIN(ito, yres);
+    gint blockheight = ito - ifrom;
 
     gwy_graph_model_remove_all_curves(gmodel);
 
-    field = get_chosen_image(args, 0, FALSE);
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    dx = gwy_field_get_dx(field);
-    lineno = GWY_ROUND(lineno_frac*(yres - 1.0));
-    lineno = CLAMP(lineno, 0, yres-1);
-
-    ifrom = lineno - (thickness - 1)/2;
-    ifrom = MAX(ifrom, 0);
-    ito = lineno + thickness/2 + 1;
-    ito = MIN(ito, yres);
-    blockheight = ito - ifrom;
-
-    nimages = 0;
-    for (i = 0; i < NARGS; i++) {
-        if (get_chosen_image(args, i, FALSE))
+    gint nimages = 0;
+    for (guint i = 0; i < NARGS; i++) {
+        if (get_chosen_image(args, i))
             nimages++;
     }
     g_return_if_fail(nimages);
 
-    bigfield = gwy_field_new(xres, nimages*blockheight, dx*xres, 1.0, FALSE);
+    GwyField *bigfield = gwy_field_new(xres, nimages*blockheight, dx*xres, 1.0, FALSE);
+    GwyNield *bigmask = NULL;
     if (masking != GWY_MASK_IGNORE)
-        bigmask = gwy_field_new_alike(bigfield, FALSE);
+        bigmask = gwy_field_new_nield_alike(bigfield);
 
     nimages = 0;
-    for (i = 0; i < NARGS; i++) {
-        if (!(field = get_chosen_image(args, i, FALSE)))
+    for (guint i = 0; i < NARGS; i++) {
+        if (!(field = get_chosen_image(args, i)))
             continue;
 
         gwy_field_area_copy(field, bigfield, 0, ifrom, xres, blockheight, 0, nimages*blockheight);
         if (bigmask) {
-            mask = get_chosen_image(args, i, TRUE);
-            if (mask) {
-                gwy_field_area_copy(mask, bigmask, 0, ifrom, xres, blockheight, 0, nimages*blockheight);
-            }
-            else {
-                gwy_field_area_fill(bigmask, NULL, GWY_MASK_IGNORE, 0, nimages*blockheight, xres, blockheight,
+            GwyNield *mask = get_chosen_mask(args, i);
+            if (mask)
+                gwy_nield_area_copy(mask, bigmask, 0, ifrom, xres, blockheight, 0, nimages*blockheight);
+            else
+                gwy_nield_area_fill(bigmask, NULL, GWY_MASK_IGNORE, 0, nimages*blockheight, xres, blockheight,
                                     masking == GWY_MASK_INCLUDE);
-            }
         }
         nimages++;
     }
 
-    xydata = g_array_new(FALSE, FALSE, sizeof(GwyXY));
-    avg = gwy_line_new(1, 1.0, FALSE);
-    weight = gwy_line_new(1, 1.0, FALSE);
-
-    gwy_field_area_get_line_stats(bigfield, bigmask, masking, avg, weight,
-                                  0, 0, xres, nimages*blockheight,
-                                  GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL);
+    GArray *xydata = g_array_new(FALSE, FALSE, sizeof(GwyXY));
+    GwyLine *weight = gwy_line_new(1, 1.0, FALSE);
+    GwyLine *avg = gwy_field_area_line_stats(bigfield, bigmask, masking,
+                                             0, 0, xres, nimages*blockheight,
+                                             GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL, weight);
     add_curve(gmodel, avg, weight, gwy_graph_get_preset_color(0), _("Mean"), xydata);
 
-    aux1 = gwy_line_new_alike(avg, FALSE);
-    aux2 = gwy_line_new_alike(avg, FALSE);
     if (mode == MULTIPROF_MODE_MEAN_RMS) {
-        gwy_field_area_get_line_stats(bigfield, bigmask, masking, aux1, NULL,
-                                      0, 0, xres, nimages*blockheight,
-                                      GWY_LINE_STAT_RMS, GWY_ORIENTATION_VERTICAL);
-        gwy_line_subtract_lines(aux2, avg, aux1);
-        add_curve(gmodel, aux2, weight, &lower_colour, _("Lower"), xydata);
-        gwy_line_sum_lines(aux2, avg, aux1);
-        add_curve(gmodel, aux2, weight, &upper_colour, _("Upper"), xydata);
+        GwyLine *rms = gwy_field_area_line_stats(bigfield, bigmask, masking,
+                                                 0, 0, xres, nimages*blockheight,
+                                                 GWY_LINE_STAT_RMS, GWY_ORIENTATION_VERTICAL, NULL);
+        GwyLine *aux = gwy_line_new_alike(avg, FALSE);
+        gwy_line_subtract_lines(aux, avg, rms);
+        add_curve(gmodel, aux, weight, &lower_colour, _("Lower"), xydata);
+        gwy_line_sum_lines(aux, avg, rms);
+        add_curve(gmodel, aux, weight, &upper_colour, _("Upper"), xydata);
+        g_object_unref(aux);
+        g_object_unref(rms);
     }
     else {
-        gwy_field_area_get_line_stats(bigfield, bigmask, masking, aux1, NULL,
-                                      0, 0, xres, nimages*blockheight,
-                                      GWY_LINE_STAT_MINIMUM, GWY_ORIENTATION_VERTICAL);
-        gwy_field_area_get_line_stats(bigfield, bigmask, masking, aux2, NULL,
-                                      0, 0, xres, nimages*blockheight,
-                                      GWY_LINE_STAT_MAXIMUM, GWY_ORIENTATION_VERTICAL);
-        add_curve(gmodel, aux1, weight, &lower_colour, _("Lower"), xydata);
-        add_curve(gmodel, aux2, weight, &upper_colour, _("Upper"), xydata);
+        GwyLine *lower = gwy_field_area_line_stats(bigfield, bigmask, masking,
+                                                   0, 0, xres, nimages*blockheight,
+                                                   GWY_LINE_STAT_MINIMUM, GWY_ORIENTATION_VERTICAL, NULL);
+        GwyLine *upper = gwy_field_area_line_stats(bigfield, bigmask, masking,
+                                                   0, 0, xres, nimages*blockheight,
+                                                   GWY_LINE_STAT_MAXIMUM, GWY_ORIENTATION_VERTICAL, NULL);
+        add_curve(gmodel, lower, weight, &lower_colour, _("Lower"), xydata);
+        add_curve(gmodel, upper, weight, &upper_colour, _("Upper"), xydata);
+        g_object_unref(lower);
+        g_object_unref(upper);
     }
 
     g_object_unref(avg);
-    g_object_unref(aux1);
-    g_object_unref(aux2);
     g_object_unref(weight);
     g_object_unref(bigfield);
     g_clear_object(&bigmask);
