@@ -1,6 +1,6 @@
 /*
- *  $Id: neural.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2012-2024 David Necas (Yeti), Petr Klapetek.
+ *  $Id: neural.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2012-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -156,7 +156,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Neural network SPM data processing"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2012",
 };
@@ -264,7 +264,7 @@ neural_train(G_GNUC_UNUSED GwyFile *data, GwyRunModeFlags mode)
     args.params = params = gwy_params_new_from_settings(define_module_params_train());
     gwy_data_browser_get_current(GWY_APP_FIELD_ID, &dataid.id,
                                  GWY_APP_FIELD, &field,
-                                 GWY_APP_CONTAINER_ID, &dataid.datano,
+                                 GWY_APP_FILE_ID, &dataid.datano,
                                  0);
     gwy_params_set_image_id(params, PARAM_MODEL, dataid);
     signalfield = gwy_params_get_image(params, PARAM_SIGNAL);
@@ -378,16 +378,11 @@ create_network_list(GtkTreeModel *model, GtkWidget **scroll)
         { N_("Hidden"), NETWORK_HIDDEN, },
     };
 
-    GtkCellRenderer *renderer;
-    GtkTreeViewColumn *column;
-    GtkWidget *networklist;
-    guint i;
+    GtkWidget *networklist = gtk_tree_view_new_with_model(model);
 
-    networklist = gtk_tree_view_new_with_model(model);
-
-    for (i = 0; i < G_N_ELEMENTS(columns); i++) {
-        renderer = gtk_cell_renderer_text_new();
-        column = gtk_tree_view_column_new_with_attributes(_(columns[i].name), renderer, NULL);
+    for (guint i = 0; i < G_N_ELEMENTS(columns); i++) {
+        GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+        GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes(_(columns[i].name), renderer, NULL);
         gtk_tree_view_column_set_cell_data_func(column, renderer,
                                                 network_cell_renderer, GUINT_TO_POINTER(columns[i].value), NULL);
         gtk_tree_view_append_column(GTK_TREE_VIEW(networklist), column);
@@ -718,26 +713,30 @@ calculate_scaling(GwyField *field, gdouble *factor, gdouble *shift)
 {
     gdouble min, max;
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     *shift = min;
     *factor = 1.0/(max - *shift);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static gboolean
 train_do(GwyNeuralNetwork *nn, GwyLine *errors, GwyGraphCurveModel *gcmodel,
-         GwyField *model, GwyField *signal, GwyField *mask,
+         GwyField *model, GwyField *signal, GwyNield *mask,
          GwyMaskingType masking, gdouble sfactor, gdouble sshift,
          guint trainsteps)
 {
     NeuralNetworkData *nndata = &nn->data;
-    GwyField *scaled;
-    guint width = nndata->width, height = nndata->height, xres, yres;
-    guint n, k, npixels, irow, col, row;
-    guint *indices;
-    const gdouble *dtmodel, *dtmask = NULL;
-    gdouble *dtsignal;
-    GTimer *timer;
-    gdouble eo = 0.0, eh = 0.0, lasttime = 0.0;
+    guint width = nndata->width, height = nndata->height;
     gboolean ok = FALSE;
 
     /* Not only optimisation, also prevents changing scaling parameters. */
@@ -747,41 +746,36 @@ train_do(GwyNeuralNetwork *nn, GwyLine *errors, GwyGraphCurveModel *gcmodel,
     gwy_graph_curve_model_set_data_from_line(gcmodel, errors, 0, 1);
     if (!gwy_app_wait_set_message(_("Training...")))
         return FALSE;
-    timer = g_timer_new();
 
     nndata->outfactor = sfactor;
     nndata->outshift = sshift;
     calculate_scaling(model, &nndata->infactor, &nndata->inshift);
 
-    scaled = gwy_field_copy(model);
+    GwyField *scaled = gwy_field_copy(model);
     gwy_field_normalize(scaled);
-    xres = gwy_field_get_xres(scaled);
-    yres = gwy_field_get_yres(scaled);
-    dtmodel = gwy_field_get_data_const(scaled);
-    dtsignal = gwy_field_get_data(signal);
-    if (masking != GWY_MASK_IGNORE && mask)
-        dtmask = gwy_field_get_data_const(mask);
-    else
-        masking = GWY_MASK_IGNORE;
+    gint xres = gwy_field_get_xres(scaled), yres = gwy_field_get_yres(scaled);
+    const gdouble *dtmodel = gwy_field_get_data_const(scaled);
+    gdouble *dtsignal = gwy_field_get_data(signal);
+    const gint *dtmask = mask ? gwy_nield_get_data_const(mask) : NULL;
 
-    indices = g_new(guint, (xres - width)*(yres - height));
-    npixels = 0;
-    for (row = height/2; row < yres + height/2 - height; row++) {
-        for (col = width/2; col < xres + width/2 - width; col++) {
-            if (!dtmask
-                || (masking == GWY_MASK_INCLUDE && dtmask[row*xres + col] >= 1.0)
-                || (masking == GWY_MASK_EXCLUDE && dtmask[row*xres + col] <= 0.0))
+    guint *indices = g_new(guint, (xres - width)*(yres - height));
+    guint npixels = 0;
+    for (guint row = height/2; row < yres + height/2 - height; row++) {
+        for (guint col = width/2; col < xres + width/2 - width; col++) {
+            if (nielded_included(dtmask + row*xres + col, masking))
                 indices[npixels++] = (row - height/2)*xres + col - width/2;
         }
     }
     g_assert(dtmask || npixels == (xres - width)*(yres - height));
 
-    for (n = 0; n < trainsteps; n++) {
+    GTimer *timer = g_timer_new();
+    gdouble eo = 0.0, eh = 0.0, lasttime = 0.0;
+    for (guint n = 0; n < trainsteps; n++) {
         /* FIXME: Randomisation leads to weird spiky NN error curves. */
         /* shuffle(indices, (xres - width)*(yres - height), rng); even though
          * it may improve convergence. */
-        for (k = 0; k < npixels; k++) {
-            for (irow = 0; irow < height; irow++)
+        for (guint k = 0; k < npixels; k++) {
+            for (guint irow = 0; irow < height; irow++)
                 gwy_assign(nn->input + irow*width, dtmodel + indices[k] + irow*xres, width);
             nn->target[0] = sfactor*(dtsignal[indices[k] + height/2*xres + width/2] - sshift);
             gwy_neural_network_train_step(nn, 0.3, 0.3, &eo, &eh);
@@ -846,7 +840,7 @@ evaluate(GwyNeuralNetwork *nn,
     gwy_unit_power_multiply(unit, 1, gwy_field_get_unit_z(model), nndata->inpowerz, unit);
 
     /* Fill the borders with the average of result. */
-    avg = gwy_field_area_get_avg(result, NULL, GWY_MASK_IGNORE, width/2, height/2, xres - width, yres - height);
+    avg = gwy_field_area_mean(result, NULL, GWY_MASK_IGNORE, width/2, height/2, xres - width, yres - height);
     gwy_field_area_fill(result, NULL, GWY_MASK_IGNORE, 0, 0, xres, height/2, avg);
     gwy_field_area_fill(result, NULL, GWY_MASK_IGNORE, 0, height/2, width/2, yres - height, avg);
     gwy_field_area_fill(result, NULL, GWY_MASK_IGNORE, xres + width/2 - width, height/2, width - width/2, yres - height, avg);
@@ -879,12 +873,12 @@ train_network(NeuralTrainGUI *gui)
     NeuralTrainArgs *args = gui->args;
     GwyParams *params = args->params;
     gint trainsteps = gwy_params_get_int(params, PARAM_TRAINSTEPS);
-    GwyMaskingType masking = gwy_params_get_enum(params, PARAM_MASKING);
     GwyParamTable *table = gui->table_training;
     GwyNeuralNetwork *nn = args->nn;
     GwyField *model = gwy_params_get_image(params, PARAM_MODEL);
     GwyField *signal = gwy_params_get_image(params, PARAM_SIGNAL);
-    GwyField *mask = gwy_params_get_image_mask(params, PARAM_SIGNAL);
+    GwyNield *mask = gwy_params_get_image_mask(params, PARAM_SIGNAL);
+    GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     GwyField *result = gui->result, *diff = gui->diff;
     GwyLine *errors;
     GwyGraphCurveModel *gcmodel;
