@@ -1,6 +1,6 @@
 /*
- *  $Id: outliers.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2004,2008 David Necas (Yeti), Petr Klapetek.
+ *  $Id: outliers.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates mask of outliers."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.5",
+    "1.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -55,46 +55,35 @@ module_register(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *dfield, *maskfield;
+    GwyField *field;
+    GwyNield *mask;
     GQuark dquark, mquark;
     gdouble thresh = 3.0;
-    gboolean has_mask;
-    gint xres, yres, count, id;
+    gint id;
 
     g_return_if_fail(mode & RUN_MODES);
     gwy_data_browser_get_current(GWY_APP_FIELD_KEY, &dquark,
-                                 GWY_APP_FIELD, &dfield,
+                                 GWY_APP_FIELD, &field,
                                  GWY_APP_MASK_FIELD_KEY, &mquark,
-                                 GWY_APP_MASK_FIELD, &maskfield,
+                                 GWY_APP_MASK_FIELD, &mask,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    g_return_if_fail(dfield && dquark);
-    has_mask = !!maskfield;
-    maskfield = gwy_field_new_alike(dfield, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(maskfield));
+    g_return_if_fail(field && dquark);
+    gboolean has_mask = !!mask;
+    mask = gwy_field_new_nield_alike(field);
 
-    gwy_field_mask_outliers(dfield, maskfield, thresh);
+    gwy_field_mark_outliers(field, mask, thresh);
 
     /* Do not create useless undo levels if there was no mask and the new mask would be empty.  And do not create
      * empty masks at all, just remove the mask instead.  */
-    xres = gwy_field_get_xres(maskfield);
-    yres = gwy_field_get_yres(maskfield);
-    gwy_field_area_count_in_range(maskfield, NULL, GWY_MASK_IGNORE, 0, 0, xres, yres, 0.0, 0.0, &count, NULL);
-    count = xres*yres - count;
+    gint count = gwy_nield_number_contiguous(mask);
 
     if (count || has_mask) {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-
-        if (count) {
-            gwy_file_pass_image_mask(data, id, maskfield);
-            maskfield = NULL;
-        }
-        else
-            gwy_container_remove(GWY_CONTAINER(data), mquark);
-
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+        gwy_file_set_image_mask(data, id, count ? mask : NULL);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
-    g_clear_object(&maskfield);
+    g_clear_object(&mask);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
