@@ -1,5 +1,5 @@
 /*
- *  $Id: pfm.c 28861 2025-11-14 13:02:11Z yeti-dn $
+ *  $Id: pfm.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -115,9 +115,9 @@ define_module_params(void)
 {
     static GwyParamDef *paramdef = NULL;
     static const GwyEnum rotates[] = {
-        { N_("Clockwise"),        ROTATE_CW,    },
-        { N_("Counterclocwise"),  ROTATE_CCW,   },
-        { gwy_NC("rotation", "None"),    ROTATE_NONE,  },
+        { N_("Clockwise"),               ROTATE_CW,   },
+        { N_("Counterclocwise"),         ROTATE_CCW,  },
+        { gwy_NC("rotation", "None"),    ROTATE_NONE, },
     };
     static const GwyEnum outputs[] = {
         { N_("In-plane angles"),  OUTPUT_2D,    },
@@ -456,14 +456,13 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
             angle = -rotrange/2 + m*rotrange/nrot;
 
             rotdfield = gwy_field_new_rotated(vpfm_90_a, NULL, angle,
-                                              GWY_INTERPOLATION_LINEAR,
-                                              GWY_ROTATE_RESIZE_SAME_SIZE);
+                                              GWY_INTERPOLATION_LINEAR, GWY_ROTATE_RESIZE_SAME_SIZE);
             gwy_field_area_copy(rotdfield, kernel, xborder, yborder, xres - 2*xborder, yres - 2*yborder, 0, 0);
 
             gwy_field_correlation_search(vpfm_0_a, kernel, NULL, score, GWY_CORRELATION_POC,
                                          0.1, GWY_EXTERIOR_MIRROR, 0);
 
-            rotscore = gwy_field_get_max(score);
+            rotscore = gwy_field_max(score);
             rotdata[m] = rotscore;
             //printf("%g %g\n", gwy_rad2deg(angle), rotscore);
             if (rotscore > bestrotscore) {
@@ -515,17 +514,13 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 
     if (bestrot != 0) {
         rvpfm_90_a = gwy_field_new_rotated(vpfm_90_a, NULL, bestrot,
-                                           GWY_INTERPOLATION_LINEAR,
-                                           GWY_ROTATE_RESIZE_SAME_SIZE);
+                                           GWY_INTERPOLATION_LINEAR, GWY_ROTATE_RESIZE_SAME_SIZE);
         rvpfm_90_p = gwy_field_new_rotated(vpfm_90_p, NULL, bestrot,
-                                           GWY_INTERPOLATION_LINEAR,
-                                           GWY_ROTATE_RESIZE_SAME_SIZE);
+                                           GWY_INTERPOLATION_LINEAR, GWY_ROTATE_RESIZE_SAME_SIZE);
         rlpfm_90_a = gwy_field_new_rotated(lpfm_90_a, NULL, bestrot,
-                                           GWY_INTERPOLATION_LINEAR,
-                                           GWY_ROTATE_RESIZE_SAME_SIZE);
+                                           GWY_INTERPOLATION_LINEAR, GWY_ROTATE_RESIZE_SAME_SIZE);
         rlpfm_90_p = gwy_field_new_rotated(lpfm_90_p, NULL, bestrot,
-                                           GWY_INTERPOLATION_LINEAR,
-                                           GWY_ROTATE_RESIZE_SAME_SIZE);
+                                           GWY_INTERPOLATION_LINEAR, GWY_ROTATE_RESIZE_SAME_SIZE);
 
         vpfm_90_a_data = gwy_field_get_data(rvpfm_90_a);
         vpfm_90_p_data = gwy_field_get_data(rvpfm_90_p);
