@@ -1,5 +1,5 @@
 /*
- *  $Id: pid.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: pid.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2012-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -169,7 +169,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -348,7 +348,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     /* Primitive normalisation. */
     zpos = surface[0];
     accumulator = 0;
-    zrange = (gwy_field_get_max(field) - gwy_field_get_min(field));
+    zrange = (gwy_field_max(field) - gwy_field_min(field));
     strength = fstrength/zrange;
 
     /* Scan, forming forward and backward data and error signals. */
