@@ -1,6 +1,6 @@
 /*
- *  $Id: polydistort.c 28844 2025-11-10 16:07:51Z yeti-dn $
- *  Copyright (C) 2007-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: polydistort.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2007-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -51,10 +51,10 @@ typedef enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *show;
     GwyField *result_field;
-    GwyField *result_mask;
+    GwyNield *result_mask;
     GwyField *result_show;
 } ModuleArgs;
 
@@ -105,7 +105,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Applies polynomial distortion in the horizontal plane."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2007",
 };
@@ -207,7 +207,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (args.result_mask)
         gwy_file_set_image_mask(data, newid, args.result_mask);
     if (args.result_show)
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), args.result_show);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), args.result_show);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE
@@ -424,9 +424,15 @@ execute(ModuleArgs *args, gboolean main_field, gboolean aux_fields)
         return;
 
     if (args->mask) {
+        GwyField *mask_field = gwy_field_new_alike(args->field, FALSE);
+        gwy_field_fill_mask(mask_field, args->mask, 0.0, 1.0);
+        GwyField *distorted = gwy_field_new_alike(args->field, FALSE);
+        distort_one_field(params, mask_field, distorted, TRUE);
+        g_object_unref(mask_field);
         if (!args->result_mask)
-            args->result_mask = gwy_field_new_alike(args->mask, FALSE);
-        distort_one_field(params, args->mask, args->result_mask, TRUE);
+            args->result_mask = gwy_field_new_nield_alike(distorted);
+        gwy_nield_mark_by_threshold(args->result_mask, distorted, 0.5, TRUE);
+        g_object_unref(distorted);
     }
     if (args->show) {
         if (!args->result_show)
@@ -478,7 +484,7 @@ distort_one_field(GwyParams *params,
     GwyExteriorType exterior = gwy_params_get_enum(params, PARAM_EXTERIOR);
     gdouble val = 0.0;
     if (exterior == GWY_EXTERIOR_FIXED_VALUE)
-        val = gwy_field_get_min(field);
+        val = gwy_field_min(field);
 
     gwy_field_distort(field, result, distort_transform, transform_param, interp, exterior, val);
     g_free(transform_param);
