@@ -1,6 +1,6 @@
 /*
- *  $Id: polylevel.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2004-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: polylevel.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -40,7 +40,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyField *bg;
 } ModuleArgs;
@@ -100,7 +100,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Subtracts polynomial background."),
     "Yeti <yeti@gwyddion.net>",
-    "4.1",
+    "4.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -164,13 +164,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome != GWY_DIALOG_PROCEED)
             goto end;
     }
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     do_extract = gwy_params_get_boolean(args.params, PARAM_DO_EXTRACT);
     args.result = g_object_ref(args.field);
@@ -200,7 +200,8 @@ static void
 execute(ModuleArgs *args, GtkListStore *coeffmodel)
 {
     GwyParams *params = args->params;
-    GwyField *field = args->field, *mask = args->mask, *result = args->result, *bg = args->bg;
+    GwyField *field = args->field, *result = args->result, *bg = args->bg;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint max_degree = gwy_params_get_int(params, PARAM_MAX_DEGREE);
     gint col_degree = gwy_params_get_int(params, PARAM_COL_DEGREE);
@@ -263,20 +264,17 @@ execute(ModuleArgs *args, GtkListStore *coeffmodel)
 static void
 create_preview_data(ModuleArgs *args, ModuleArgs *preview_args)
 {
-    gint xres, yres;
-    gdouble zoomval;
-
     preview_args->params = args->params;
     preview_args->mask = NULL;
-    xres = gwy_field_get_xres(args->field);
-    yres = gwy_field_get_yres(args->field);
-    zoomval = (gdouble)PREVIEW_SIZE/MAX(xres, yres);
+
+    gint xres = gwy_field_get_xres(args->field), yres = gwy_field_get_yres(args->field);
+    gdouble zoomval = (gdouble)PREVIEW_SIZE/MAX(xres, yres);
     if (zoomval <= 1.0) {
         xres = MAX(xres*zoomval, 3);
         yres = MAX(yres*zoomval, 3);
         preview_args->field = gwy_field_new_resampled(args->field, xres, yres, GWY_INTERPOLATION_ROUND);
         if (args->mask)
-            preview_args->mask = gwy_field_new_resampled(args->mask, xres, yres, GWY_INTERPOLATION_ROUND);
+            preview_args->mask = gwy_nield_new_resampled(args->mask, xres, yres);
     }
     else {
         preview_args->field = g_object_ref(args->field);
