@@ -1,5 +1,5 @@
 /*
- *  $Id: presentationops.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: presentationops.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -119,8 +119,8 @@ presentation_remove(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     g_return_if_fail(quark);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
-    gwy_container_remove(GWY_CONTAINER(data), quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
+    gwy_dict_remove(GWY_DICT(data), quark);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 }
 
@@ -168,10 +168,10 @@ presentation_logscale(GwyFile *data, GwyRunModeFlags mode)
 
     xres = gwy_field_get_xres(dfield);
     yres = gwy_field_get_yres(dfield);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
     if (!sfield) {
         sfield = gwy_field_copy(dfield);
-        gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), sfield);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(id), sfield);
     }
     else {
         gwy_field_resize(sfield, xres, yres);
@@ -230,8 +230,8 @@ presentation_attach(GwyFile *data, GwyRunModeFlags mode)
         goto end;
 
     dfield = gwy_field_copy(args.target);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
-    gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), dfield);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
+    gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(id), dfield);
 
 end:
     g_object_unref(args.params);
