@@ -1,5 +1,5 @@
 /*
- *  $Id: preview.h 28742 2025-10-30 17:25:43Z yeti-dn $
+ *  $Id: preview.h 29511 2026-02-20 16:41:00Z yeti-dn $
  *  Copyright (C) 2015-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -28,7 +28,7 @@ enum {
 };
 
 enum {
-    RESPONSE_ESTIMATE,
+    RESPONSE_ESTIMATE = GWY_RESPONSE_USER,
     RESPONSE_REFINE,
     RESPONSE_CALCULATE,
     RESPONSE_SAVE,
