@@ -60,6 +60,7 @@ GwyModuleInfo* _gwy_module_query__grain_filter(void);
 GwyModuleInfo* _gwy_module_query__grain_edge(void);
 GwyModuleInfo* _gwy_module_query__grain_makesel(void);
 GwyModuleInfo* _gwy_module_query__grain_mark(void);
+GwyModuleInfo* _gwy_module_query__grain_number(void);
 GwyModuleInfo* _gwy_module_query__grain_stat(void);
 GwyModuleInfo* _gwy_module_query__grain_summary(void);
 GwyModuleInfo* _gwy_module_query__grain_wshed(void);
@@ -188,6 +189,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__grain_edge, "grain_edge", },
   { _gwy_module_query__grain_makesel, "grain_makesel", },
   { _gwy_module_query__grain_mark, "grain_mark", },
+  { _gwy_module_query__grain_number, "grain_number", },
   { _gwy_module_query__grain_stat, "grain_stat", },
   { _gwy_module_query__grain_summary, "grain_summary", },
   { _gwy_module_query__grain_wshed, "grain_wshed", },
