@@ -1,5 +1,5 @@
 /*
- *  $Id: psdf2d.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: psdf2d.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2009-2022 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -59,7 +59,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *psdf;
     GwyField *modulus;
     GwySelection *selection;
@@ -114,7 +114,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates two-dimensional power spectrum density function and extracts its linear profiles."),
     "Yeti <yeti@gwyddion.net>",
-    "2.3",
+    "2.4",
     "David Nečas (Yeti)",
     "2009",
 };
@@ -196,7 +196,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                             gwy_field_get_unit_xy(args.field), 2,
                             gwy_field_get_unit_z(args.psdf));
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -220,7 +220,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         add_line_selection_from_points(data, zoomed, newid, args.selection);
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("2D PSDF"), TRUE);
         gwy_file_set_palette(data, GWY_FILE_IMAGE, newid, "DFit");
-        gwy_container_set_enum(GWY_CONTAINER(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_AUTO);
+        gwy_dict_set_enum(GWY_DICT(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_AUTO);
         gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
     }
     if (args.gmodel && gwy_graph_model_get_n_curves(args.gmodel)) {
@@ -465,7 +465,7 @@ preview(gpointer user_data)
         m = gwy_line_max(angspec);
         if (m > 0.0) {
             gdouble Std = gwy_line_max_pos_r(angspec);
-            gdouble Stdi = gwy_line_avg(angspec)/m;
+            gdouble Stdi = gwy_line_mean(angspec)/m;
 
             gwy_results_fill_values(gui->results, "Std", Std, "Stdi", Stdi, NULL);
         }
@@ -547,7 +547,7 @@ update_curve(ModuleGUI *gui, gint i)
     else
         lineres = resolution;
 
-    gwy_field_get_profile(psdf, gui->line, xl0, yl0, xl1, yl1, lineres, thickness, interpolation);
+    gwy_field_profile(psdf, gui->line, xl0, yl0, xl1, yl1, lineres, thickness, interpolation);
 #if 0
     gwy_line_multiply(gui->line, h);
 #endif
@@ -584,25 +584,31 @@ calculate_zoomed_fields(ModuleGUI *gui)
     g_object_unref(zoomed);
 }
 
-static GwyField*
-cut_field_to_zoom(GwyField *field, gint zoom)
+static gboolean
+calc_cut_to_zoom(gint xres, gint yres, gint zoom, gint *pwidth, gint *pheight)
 {
-    GwyField *zoomed;
-    guint xres, yres, width, height;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    width = (xres/zoom) | 1;
-    height = (yres/zoom) | 1;
+    gint width = (xres/zoom) | 1;
+    gint height = (yres/zoom) | 1;
     if (width < 17)
         width = MAX(width, MIN(17, xres));
     if (height < 17)
         height = MAX(height, MIN(17, yres));
 
-    if (width >= xres && height >= yres)
+    *pwidth = width;
+    *pheight = height;
+    return width >= xres && height >= yres;
+}
+
+static GwyField*
+cut_field_to_zoom(GwyField *field, gint zoom)
+{
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    guint width, height;
+
+    if (calc_cut_to_zoom(xres, yres, zoom, &width, &height))
         return g_object_ref(field);
 
-    zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
+    GwyField *zoomed = gwy_field_area_extract(field, (xres - width + 1)/2, (yres - height + 1)/2, width, height);
     gwy_field_set_xoffset(zoomed, -0.5*gwy_field_get_xreal(zoomed));
     gwy_field_set_yoffset(zoomed, -0.5*gwy_field_get_yreal(zoomed));
 
@@ -639,33 +645,31 @@ add_line_selection_from_points(GwyFile *data,
     gwy_selection_set_data(linesel, nsel, seldata);
     g_free(seldata);
 
-    gwy_container_pass_object(GWY_CONTAINER(data), gwy_file_key_image_selection(id, "line"), linesel);
+    gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_selection(id, "line"), linesel);
 }
 
 static void
 execute(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *mask = args->mask, *field = args->field, *psdf = args->psdf, *modulus = args->modulus;
+    GwyField *field = args->field, *psdf = args->psdf, *modulus = args->modulus;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     GwyWindowingType windowing = gwy_params_get_enum(params, PARAM_WINDOWING);
-    gint xres = gwy_field_get_xres(field);
-    gint yres = gwy_field_get_yres(field);
-    guint n, i;
-    gdouble *p;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint n = xres*yres;
 
-    n = xres*yres;
     gwy_field_area_psdf_2d(field, mask, masking, psdf, 0, 0, xres, yres, windowing, 1);
 
     /* We do not really care about modulus units nor its absolute scale.
      * We just have it to display the square root... */
     gwy_field_assign(modulus, psdf);
-    p = gwy_field_get_data(modulus);
+    gdouble *p = gwy_field_get_data(modulus);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(p,n) private(i)
+            shared(p,n)
 #endif
-    for (i = 0; i < n; i++)
+    for (gint i = 0; i < n; i++)
         p[i] = (p[i] >= 0.0 ? sqrt(p[i]) : -sqrt(-p[i]));
 }
 
