@@ -1,6 +1,6 @@
 /*
- *  $Id: psdf_logphi.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2015-2021 David Necas (Yeti).
+ *  $Id: psdf_logphi.c 29393 2026-01-28 17:56:48Z yeti-dn $
+ *  Copyright (C) 2015-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -51,7 +51,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Two-dimensional FFT (Fast Fourier Transform) transformed to coordinates (log-frequency, angle)."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2015",
 };
@@ -103,7 +103,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new(1, 1, 1.0, 1.0, FALSE);
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -150,53 +150,48 @@ execute(ModuleArgs *args)
 {
     enum { N = 4 };
 
-    GwyField *field = args->field, *lpsdf = args->result, *reout, *imout;
-    gint pxres, pyres, fxres, fyres, i, j;
-    gdouble *ldata, *redata, *imdata, *cosphi, *sinphi;
-    gdouble xreal, yreal, f0, f_max, b;
+    GwyField *field = args->field, *lpsdf = args->result;
     gdouble sigma = gwy_params_get_double(args->params, PARAM_SIGMA);
     GwyWindowingType window = gwy_params_get_enum(args->params, PARAM_WINDOW);
 
-    reout = gwy_field_new_alike(field, FALSE);
-    imout = gwy_field_new_alike(field, FALSE);
+    GwyField *reout = gwy_field_new_alike(field, FALSE);
+    GwyField *imout = gwy_field_new_alike(field, FALSE);
     gwy_field_fft_2d(field, NULL, reout, imout, window, GWY_TRANSFORM_DIRECTION_FORWARD, TRUE, 1);
 
-    pxres = gwy_field_get_xres(reout);
-    pyres = gwy_field_get_yres(reout);
-    redata = gwy_field_get_data(reout);
-    imdata = gwy_field_get_data(imout);
-    for (i = 0; i < pxres*pyres; i++)
+    gint pxres = gwy_field_get_xres(reout), pyres = gwy_field_get_yres(reout);
+    gdouble *redata = gwy_field_get_data(reout);
+    gdouble *imdata = gwy_field_get_data(imout);
+    for (gint i = 0; i < pxres*pyres; i++)
         redata[i] = redata[i]*redata[i] + imdata[i]*imdata[i];
     gwy_field_fft_2d_center(reout);
     gwy_field_filter_gaussian(reout, sigma);
     redata = gwy_field_get_data(reout);
-    for (i = 0; i < pxres*pyres; i++)
+    for (gint i = 0; i < pxres*pyres; i++)
         redata[i] = sqrt(redata[i]);
 
-    fxres = pxres/2;
-    fyres = pyres/2;
+    gint fxres = pxres/2;
+    gint fyres = pyres/2;
     gwy_field_resize(lpsdf, fxres, fyres);
-    ldata = gwy_field_get_data(lpsdf);
+    gdouble *ldata = gwy_field_get_data(lpsdf);
 
-    xreal = gwy_field_get_xreal(field);
-    yreal = gwy_field_get_yreal(field);
-    f0 = 2.0/MIN(xreal, yreal);
-    f_max = 0.5*MIN(pxres/xreal, pyres/yreal);
+    gdouble xreal = gwy_field_get_xreal(field);
+    gdouble yreal = gwy_field_get_yreal(field);
+    gdouble f0 = 2.0/MIN(xreal, yreal);
+    gdouble f_max = 0.5*MIN(pxres/xreal, pyres/yreal);
     if (f_max <= f0) {
         g_warning("Minimum frequency is not smaller than maximum frequency.");
     }
-    b = log(f_max/f0)/fyres;
+    gdouble b = log(f_max/f0)/fyres;
 
     /* Incorporate some prefactors to sinphi[] and cosphi[], knowing that
      * cosine is only ever used for x and sine for y frequencies. */
-    cosphi = g_new(gdouble, (N+1)*fxres);
-    sinphi = g_new(gdouble, (N+1)*fxres);
-    for (j = 0; j < fxres; j++) {
+    gdouble *cosphi = g_new(gdouble, (N+1)*fxres);
+    gdouble *sinphi = g_new(gdouble, (N+1)*fxres);
+    for (gint j = 0; j < fxres; j++) {
         gdouble phi_from = 2.0*G_PI*j/fxres;
         gdouble phi_to = 2.0*G_PI*(j + 1.0)/fxres;
-        gint pi;
 
-        for (pi = 0; pi <= N; pi++) {
+        for (gint pi = 0; pi <= N; pi++) {
             gdouble phi = ((pi + 0.5)*phi_from + (N - 0.5 - pi)*phi_to)/N;
             cosphi[j*(N+1) + pi] = cos(phi)*xreal;
             sinphi[j*(N+1) + pi] = sin(phi)*yreal;
@@ -205,31 +200,28 @@ execute(ModuleArgs *args)
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(fxres,fyres,pxres,pyres,cosphi,sinphi,f0,b,reout,ldata) \
-            private(i,j)
+            shared(fxres,fyres,pxres,pyres,cosphi,sinphi,f0,b,reout,ldata)
 #endif
-    for (i = 0; i < fyres; i++) {
+    for (gint i = 0; i < fyres; i++) {
         gdouble f_from = f0*exp(b*i);
         gdouble f_to = f0*exp(b*(i + 1.0));
 
-        for (j = 0; j < fxres; j++) {
+        for (gint j = 0; j < fxres; j++) {
             const gdouble *cosphi_j = cosphi + j*(N+1);
             const gdouble *sinphi_j = sinphi + j*(N+1);
             guint n = 0;
             gdouble s = 0.0;
-            gint fi, pi;
 
-            for (fi = 0; fi <= N; fi++) {
+            for (gint fi = 0; fi <= N; fi++) {
                 gdouble f = ((fi + 0.5)*f_from + (N - 0.5 - fi)*f_to)/N;
-                for (pi = 0; pi <= N; pi++) {
+                for (gint pi = 0; pi <= N; pi++) {
                     gdouble x = f*cosphi_j[pi] + pxres/2.0;
                     gdouble y = f*sinphi_j[pi] + pyres/2.0;
-                    gdouble p;
 
                     if (G_UNLIKELY(x < 0.5 || y < 0.5 || x > pxres - 1.5 || y > pyres - 1.5))
                         continue;
 
-                    p = gwy_field_get_dval(reout, x, y, GWY_INTERPOLATION_SCHAUM);
+                    gdouble p = gwy_field_get_dval(reout, x, y, GWY_INTERPOLATION_SCHAUM);
                     s += p;
                     n++;
                 }
