@@ -1,5 +1,5 @@
 /*
- *  $Id: psf-fit.c 28844 2025-11-10 16:07:51Z yeti-dn $
+ *  $Id: psf-fit.c 29406 2026-01-29 22:51:34Z yeti-dn $
  *  Copyright (C) 2017-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -246,7 +246,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.field = field;
     args.psf = gwy_field_new_alike(field, TRUE);
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -260,9 +260,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (output & ((1 << PSF_OUTPUT_CONVOLVED) | (1 << PSF_OUTPUT_DIFFERECE))) {
         convolved = gwy_field_new_alike(field, FALSE);
         gwy_field_assign(convolved, ideal);
-        gwy_field_add(convolved, -gwy_field_get_avg(convolved));
+        gwy_field_add(convolved, -gwy_field_mean(convolved));
         field_convolve_default(convolved, args.psf);
-        gwy_field_add(convolved, gwy_field_get_avg(field));
+        gwy_field_add(convolved, gwy_field_mean(field));
     }
 
     if (output & (1 << PSF_OUTPUT_PSF))
@@ -474,7 +474,7 @@ prepare_field(GwyField *field, GwyWindowingType window)
     GwyField *wfield;
 
     wfield = gwy_field_copy(field);
-    gwy_field_add(wfield, -gwy_field_get_avg(wfield));
+    gwy_field_add(wfield, -gwy_field_mean(wfield));
     gwy_field_fft_window(wfield, window);
 
     return wfield;
