@@ -1,6 +1,6 @@
 /*
- *  $Id: psf.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2017-2023 David Necas (Yeti), Petr Klapetek.
+ *  $Id: psf.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2017-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -126,6 +126,7 @@ static gboolean         method_is_full_sized       (PSFMethodType method);
 static void             estimate_tf_region         (GwyField *wmeas,
                                                     GwyField *wideal,
                                                     GwyField *psf,
+                                                    GwyNield *mask,
                                                     gint *col,
                                                     gint *row,
                                                     gint *width,
@@ -154,7 +155,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Transfer function estimation"),
     "Petr Klapetek <klapetek@gwyddion.net>, Yeti <yeti@gwyddion.net>",
-    "4.1",
+    "4.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2017",
 };
@@ -237,7 +238,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     xres = gwy_field_get_xres(field);
     yres = gwy_field_get_yres(field);
     if (MIN(xres, yres) < 24) {
-        if (mode ==GWY_RUN_INTERACTIVE) {
+        if (mode == GWY_RUN_INTERACTIVE) {
             GtkWidget *dialog = gtk_message_dialog_new(gwy_data_browser_get_window_for_data(data, GWY_FILE_IMAGE, id),
                                                        GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
                                                        GTK_BUTTONS_OK,
@@ -457,17 +458,18 @@ dialog_response(ModuleGUI *gui, gint response)
 
     if (response == RESPONSE_ESTIMATE) {
         GwyField *ideal = gwy_params_get_image(params, PARAM_IDEAL);
-        GwyField *wmeas, *wideal, *psf;
         GwyWindowingType windowing = gwy_params_get_enum(params, PARAM_WINDOWING);
         gint col, row, width, height, txres, tyres, border;
 
-        wmeas = gwy_field_new_alike(args->field, FALSE);
-        wideal = gwy_field_new_alike(ideal, FALSE);
+        GwyField *wmeas = gwy_field_new_alike(args->field, FALSE);
+        GwyField *wideal = gwy_field_new_alike(ideal, FALSE);
         prepare_field(args->field, wmeas, windowing);
         prepare_field(ideal, wideal, windowing);
 
-        psf = gwy_field_new_alike(args->field, TRUE);
-        estimate_tf_region(wmeas, wideal, psf, &col, &row, &width, &height);
+        GwyField *psf = gwy_field_new_alike(args->field, TRUE);
+        GwyNield *mask = gwy_field_new_nield_alike(psf);
+        estimate_tf_region(wmeas, wideal, psf, mask, &col, &row, &width, &height);
+        g_object_unref(mask);
         g_object_unref(psf);
         g_object_unref(wideal);
         g_object_unref(wmeas);
@@ -513,7 +515,7 @@ calculate_l2_norm(GwyField *field, gboolean as_integral,
 {
     gdouble l2norm, q;
 
-    l2norm = gwy_field_get_mean_square(field);
+    l2norm = gwy_field_mean_square(field);
 
     /* In the integral formulation, we calculate the integral of squared values and units of dx dy are reflected in
      * the result.  In non-integral, we calculate a mere sum of squared values and the result has the same units as
@@ -549,7 +551,7 @@ preview(gpointer user_data)
     gwy_results_set_unit(results, "x", gwy_field_get_unit_xy(psf));
     gwy_results_set_unit(results, "y", gwy_field_get_unit_xy(psf));
     gwy_results_set_unit(results, "z", gwy_field_get_unit_z(psf));
-    gwy_field_get_min_max(psf, &min, &max);
+    gwy_field_min_max(psf, &min, &max);
     unit = gwy_unit_new(NULL);
     l2norm = calculate_l2_norm(psf, as_integral, unit);
     gwy_results_set_unit(results, "u", unit);
@@ -588,8 +590,8 @@ switch_display(ModuleGUI *gui)
             gdouble min, max, dispmin, dispmax;
 
             mapping = GWY_COLOR_MAPPING_FIXED;
-            gwy_field_get_min_max(args->difference, &min, &max);
-            gwy_field_get_autorange(args->difference, &dispmin, &dispmax);
+            gwy_field_min_max(args->difference, &min, &max);
+            gwy_field_autorange(args->difference, &dispmin, &dispmax);
             gwy_set_gradient_for_residuals(gui->diff_gradient, min, max, &dispmin, &dispmax);
             gwy_data_view_set_fixed_color_range(dataview, dispmin, dispmax);
         }
@@ -672,9 +674,9 @@ execute(ModuleArgs *args)
     }
 
     gwy_field_assign(convolved, ideal);
-    gwy_field_add(convolved, -gwy_field_get_avg(convolved));
+    gwy_field_add(convolved, -gwy_field_mean(convolved));
     field_convolve_default(convolved, psf);
-    gwy_field_add(convolved, gwy_field_get_avg(measured));
+    gwy_field_add(convolved, gwy_field_mean(measured));
     gwy_field_subtract_fields(difference, measured, convolved);
 
     /* Change the normalisation to the discrete (i.e. wrong) one after all calculations are done. */
@@ -709,24 +711,20 @@ set_transfer_function_units(GwyField *ideal, GwyField *measured, GwyField *trans
 static gdouble
 measure_tf_width(GwyField *psf)
 {
-    GwyField *mask, *abspsf;
-    gint xres, yres;
-    gdouble s2;
-
-    xres = gwy_field_get_xres(psf);
-    yres = gwy_field_get_yres(psf);
-    mask = gwy_field_copy(psf);
-    gwy_field_threshold(mask, 0.15*gwy_field_get_max(mask), 0.0, 1.0);
-    if (gwy_field_get_val(mask, xres/2, yres/2) == 0.0) {
+    gint xres = gwy_field_get_xres(psf), yres = gwy_field_get_yres(psf);
+    GwyNield *mask = gwy_field_new_nield_alike(psf);
+    gwy_nield_mark_by_threshold(mask, psf, 0.15*gwy_field_max(psf), TRUE);
+    if (!gwy_nield_get_val(mask, xres/2, yres/2)) {
         g_object_unref(mask);
         return 0.0;
     }
 
-    gwy_field_grains_extract_grain(mask, xres/2, yres/2);
-    gwy_field_grains_grow(mask, 0.5*log(xres*yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
-    abspsf = gwy_field_copy(psf);
+    gwy_nield_isolate_at(mask, xres/2, yres/2, NULL);
+    gwy_nield_grow(mask, 0.5*log(xres*yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
+
+    GwyField *abspsf = gwy_field_copy(psf);
     gwy_field_abs(abspsf);
-    s2 = gwy_field_area_get_dispersion(abspsf, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, NULL, NULL);
+    gdouble s2 = gwy_field_area_dispersion(abspsf, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, NULL, NULL);
     g_object_unref(mask);
     g_object_unref(abspsf);
 
@@ -739,7 +737,7 @@ prepare_field(GwyField *field, GwyField *wfield, GwyWindowingType window)
     /* Prepare field in place if requested. */
     if (wfield != field)
         gwy_field_assign(wfield, field);
-    gwy_field_add(wfield, -gwy_field_get_avg(wfield));
+    gwy_field_add(wfield, -gwy_field_mean(wfield));
     gwy_field_fft_window(wfield, window);
 }
 
@@ -750,15 +748,12 @@ method_is_full_sized(PSFMethodType method)
 }
 
 static void
-estimate_tf_region(GwyField *wmeas, GwyField *wideal, GwyField *psf, /* scratch buffer */
+estimate_tf_region(GwyField *wmeas, GwyField *wideal,
+                   GwyField *psf, GwyNield *mask, /* scratch buffers */
                    gint *col, gint *row, gint *width, gint *height)
 {
-    gint xres, yres, i, j, imin, jmin, imax, jmax, ext;
-    const gdouble *d;
-    gdouble m;
+    gint xres = gwy_field_get_xres(wmeas), yres = gwy_field_get_yres(wmeas);
 
-    xres = gwy_field_get_xres(wmeas);
-    yres = gwy_field_get_yres(wmeas);
     *col = xres/3;
     *row = yres/3;
     *width = xres - 2*(*col);
@@ -767,44 +762,22 @@ estimate_tf_region(GwyField *wmeas, GwyField *wideal, GwyField *psf, /* scratch
      * size overestimation here.
      * XXX: We might want to use a proportional to 1/sqrt(xres*yres) here. */
     gwy_field_deconvolve_regularized(wmeas, wideal, psf, 4.0);
-    d = gwy_field_get_data_const(psf);
+    gwy_field_abs(psf);
 
-    /* FIXME: From here it the same as to libgwyddion/filter.c psf_sigmaopt_estimate_size(). */
-    imax = yres/2;
-    jmax = xres/2;
-    m = 0.0;
-    for (i = *row; i < *row + *height; i++) {
-        for (j = *col; j < *col + *width; j++) {
-            if (d[i*xres + j] > m) {
-                m = d[i*xres + j];
-                imax = i;
-                jmax = j;
-            }
-        }
-    }
+    /* FIXME: From here it the same as to libgwyddion/filters--convdeconv.c psf_sigmaopt_estimate_size(). */
+    gdouble xmax = xres/2, ymax = yres/2;
+    gwy_field_local_maximum(psf, &xmax, &ymax, xres/5 + 1, yres/5 + 1);
+    gint imax = GWY_ROUND(ymax), jmax = GWY_ROUND(xmax);
     gwy_debug("maximum at (%d,%d)", imax, jmax);
-    gwy_field_threshold(psf, 0.05*m, 0.0, 1.0);
-    g_return_if_fail(d[imax*xres + jmax] > 0.0);
-    gwy_field_grains_extract_grain(psf, jmax, imax);
 
-    imin = imax;
-    jmin = jmax;
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
-            if (d[i*xres + j] > 0.0) {
-                if (i < imin)
-                    imin = i;
-                if (i > imax)
-                    imax = i;
-                if (j < jmin)
-                    jmin = j;
-                if (j > jmax)
-                    jmax = j;
-            }
-        }
-    }
+    gwy_nield_mark_by_threshold(mask, psf, 0.05*gwy_field_get_val(psf, jmax, imax), TRUE);
+    gint bbox[4];
+    gwy_nield_isolate_at(mask, imax, jmax, bbox);
+    gint jmin = bbox[0], imin = bbox[1];
+    jmax = jmin + bbox[2]-1;
+    imax = imin + bbox[3]-1;
 
-    ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
+    gint ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
     *col = jmin - ext;
     *row = imin - ext;
     *width = jmax+1 - jmin + 2*ext;
@@ -843,6 +816,7 @@ typedef struct {
     GwyField *psf;         /* Real-space PSF */
     GwyField *wideal;      /* Windowed ideal. */
     GwyField *wmeas;       /* Windowed measured. */
+    GwyNield *mask;
     gint col, row;
     gint width, height;
 } PSFSigmaOptData;
@@ -863,7 +837,8 @@ psf_sigmaopt_prepare(ModuleArgs *args, PSFSigmaOptData *sodata)
     prepare_field(ideal, sodata->wideal, windowing);
     if (method == PSF_METHOD_PSEUDO_WIENER) {
         sodata->psf = gwy_field_new_alike(args->field, FALSE);
-        estimate_tf_region(sodata->wmeas, sodata->wideal, sodata->psf,
+        sodata->mask = gwy_field_new_nield_alike(args->psf);
+        estimate_tf_region(sodata->wmeas, sodata->wideal, sodata->psf, sodata->mask,
                            &sodata->col, &sodata->row, &sodata->width, &sodata->height);
     }
 }
@@ -871,6 +846,7 @@ psf_sigmaopt_prepare(ModuleArgs *args, PSFSigmaOptData *sodata)
 static void
 psf_sigmaopt_free(PSFSigmaOptData *sodata)
 {
+    g_clear_object(&sodata->mask);
     g_clear_object(&sodata->psf);
     g_object_unref(sodata->wmeas);
     g_object_unref(sodata->wideal);
@@ -889,9 +865,9 @@ psf_sigmaopt_evaluate(gdouble logsigma, gpointer user_data)
     sigma = exp(logsigma);
     psf_deconvolve_wiener(sodata->wmeas, sodata->wideal, psf, sigma);
     gwy_field_area_abs(psf, sodata->col, sodata->row, sodata->width, sodata->height);
-    w = gwy_field_area_get_dispersion(psf, NULL, GWY_MASK_IGNORE,
-                                      sodata->col, sodata->row, sodata->width, sodata->height,
-                                      NULL, NULL);
+    w = gwy_field_area_dispersion(psf, NULL, GWY_MASK_IGNORE,
+                                  sodata->col, sodata->row, sodata->width, sodata->height,
+                                  NULL, NULL);
     return sqrt(w);
 }
 
@@ -955,8 +931,8 @@ psf_deconvolve_wiener(GwyField *field,
     g_return_if_fail(ideal->yres == yres);
     gwy_field_resize(out, xres, yres);
 
-    orms = gwy_field_get_rms(ideal);
-    frms = gwy_field_get_rms(field);
+    orms = gwy_field_rms(ideal);
+    frms = gwy_field_rms(field);
     if (!orms) {
         g_warning("Deconvolution by zero.");
         gwy_field_clear(out);
