@@ -1,5 +1,5 @@
 /*
- *  $Id: ptranslate.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: ptranslate.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2024 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -188,7 +188,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
     }
     else {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &dquark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &dquark);
         gwy_field_assign(args.field, args.result);
         gwy_field_data_changed(args.field);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
