@@ -1,5 +1,5 @@
 /*
- *  $Id: rank.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: rank.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -138,8 +138,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     if (ok) {
         gwy_field_normalize(args.result);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), args.result);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_picture(id), args.result);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
 
@@ -256,7 +256,7 @@ local_rank(GwyField *field, gint size, const gint *xsize, gint col, gint row)
 static void
 execute_minmax(ModuleArgs *args)
 {
-    GwyField *showfield = args->result, *kernel;
+    GwyField *showfield = args->result;
     GwyMinMaxFilterType filtertype;
     gint size;
 
@@ -264,8 +264,8 @@ execute_minmax(ModuleArgs *args)
     filtertype = (gwy_params_get_enum(args->params, PARAM_TYPE) == FILTER_NORMALIZATION
                   ? GWY_MIN_MAX_FILTER_NORMALIZATION
                   : GWY_MIN_MAX_FILTER_RANGE);
-    kernel = gwy_field_new(size, size, size, size, TRUE);
-    gwy_field_elliptic_area_fill(kernel, 0, 0, size, size, 1.0);
+    GwyNield *kernel = gwy_nield_new(size, size);
+    gwy_nield_elliptic_fill(kernel);
     gwy_field_copy_data(args->field, showfield);
     gwy_field_area_filter_min_max(showfield, kernel, filtertype, 0, 0, showfield->xres, showfield->yres);
     g_object_unref(kernel);
