@@ -1,6 +1,6 @@
 /*
- *  $Id: relate.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2018-2021 David Necas (Yeti).
+ *  $Id: relate.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2018-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -80,7 +80,7 @@ typedef struct {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGraphModel *gmodel;
     gdouble *xdata;
     gdouble *ydata;
@@ -222,7 +222,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Plots one image data as a function of another and finds relations."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas",
     "2018",
 };
@@ -430,20 +430,30 @@ find_relate_func(RelateFunction id)
     return NULL;
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static void
 replot_data(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
     GwyGraphModel *gmodel = args->gmodel;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyField *otherfield = gwy_params_get_image(args->params, PARAM_OTHER_IMAGE);
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
-    GwyGraphCurveModel *gcmodel;
-    const gdouble *d1, *d2, *m;
     gdouble *xdata = args->xdata, *ydata = args->ydata;
-    gint nc, n, i, ndata;
 
-    nc = gwy_graph_model_get_n_curves(gmodel);
+    gint nc = gwy_graph_model_get_n_curves(gmodel);
+    GwyGraphCurveModel *gcmodel;
     if (nc > 0)
         gcmodel = gwy_graph_model_get_curve(gmodel, 0);
     else {
@@ -467,19 +477,20 @@ replot_data(ModuleGUI *gui)
                  "unit-y", gwy_field_get_unit_z(otherfield),
                  NULL);
 
-    n = gwy_field_get_xres(field) * gwy_field_get_yres(field);
-    d1 = gwy_field_get_data_const(field);
-    d2 = gwy_field_get_data_const(otherfield);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint n = xres*yres, ndata = 0;
+
+    const gdouble *d1 = gwy_field_get_data_const(field);
+    const gdouble *d2 = gwy_field_get_data_const(otherfield);
     if (!mask) {
         gwy_assign(xdata, d1, n);
         gwy_assign(ydata, d2, n);
         ndata = n;
     }
     else {
-        m = gwy_field_get_data_const(mask);
-        ndata = 0;
-        for (i = 0; i < n; i++) {
-            if ((masking == GWY_MASK_INCLUDE && m[i] >= 1.0) || (masking == GWY_MASK_EXCLUDE && m[i] <= 0.0)) {
+        const gint *m = gwy_nield_get_data_const(mask);
+        for (gint i = 0; i < n; i++) {
+            if (nielded_included(m + i, masking)) {
                 xdata[ndata] = d1[i];
                 ydata[ndata] = d2[i];
                 ndata++;
@@ -667,17 +678,15 @@ plot_fit(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
     RelateFunction func = gwy_params_get_enum(args->params, PARAM_FUNC);
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     const RelateFuncInfo *finfo = find_relate_func(func);
     GwyGraphModel *gmodel = args->gmodel;
-    GwyGraphCurveModel *gcmodel;
     gdouble min, max;
-    gdouble *xdata, *ydata;
-    RelateEvalFunc evalfunc;
-    gint i, ndata = args->ndata, nc, xres, yres;
 
-    nc = gwy_graph_model_get_n_curves(gmodel);
+    GwyGraphCurveModel *gcmodel;
+    gint nc = gwy_graph_model_get_n_curves(gmodel);
     if (nc < 2) {
         gcmodel = gwy_graph_curve_model_new();
         g_object_set(gcmodel,
@@ -691,15 +700,14 @@ plot_fit(ModuleGUI *gui)
     else
         gcmodel = gwy_graph_model_get_curve(gmodel, 1);
 
-    ndata = PLOT_FUNC_SAMPLES;
-    xdata = g_new(gdouble, 2*ndata);
-    ydata = xdata + ndata;
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    gwy_field_area_get_min_max(field, mask, masking, 0, 0, xres, yres, &min, &max);
+    gint ndata = PLOT_FUNC_SAMPLES;
+    gdouble *xdata = g_new(gdouble, 2*ndata);
+    gdouble *ydata = xdata + ndata;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gwy_field_area_min_max(field, mask, masking, 0, 0, xres, yres, &min, &max);
 
-    evalfunc = finfo->func;
-    for (i = 0; i < ndata; i++) {
+    RelateEvalFunc evalfunc = finfo->func;
+    for (gint i = 0; i < ndata; i++) {
         gdouble t = i/(ndata - 1.0);
 
         xdata[i] = t*max + (1.0 - t)*min;
