@@ -1,6 +1,6 @@
 /*
- *  $Id: resample.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2019-2021 David Necas (Yeti).
+ *  $Id: resample.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2019-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -77,7 +77,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Resamples data to specified pixel size."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -121,72 +121,72 @@ define_module_params(void)
 static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
-    GwyField *fields[3];
+    GwyField *field, *show;
+    GwyNield *mask;
     GwyParams *params;
-    gint xres, yres, oldid, newid, i;
+    gint oldid, newid;
     ModuleArgs args;
-    gdouble xoff, yoff, dx, dy;
-    GwyInterpolationType interp;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_SHOW_FIELD, &show,
                                  GWY_APP_FIELD_ID, &oldid,
                                  0);
-    g_return_if_fail(fields[0]);
-    args.field = fields[0];
-    args.orig_xres = gwy_field_get_xres(fields[0]);
-    args.orig_yres = gwy_field_get_yres(fields[0]);
-    args.orig_dx = gwy_field_get_dx(fields[0]);
-    args.orig_dy = gwy_field_get_dy(fields[0]);
+    g_return_if_fail(field);
+    args.field = field;
+    args.orig_xres = gwy_field_get_xres(field);
+    args.orig_yres = gwy_field_get_yres(field);
+    args.orig_dx = gwy_field_get_dx(field);
+    args.orig_dy = gwy_field_get_dy(field);
 
     args.params = params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome != GWY_DIALOG_PROCEED)
             goto end;
     }
 
+    GwyInterpolationType interp = gwy_params_get_enum(params, PARAM_INTERP);
+    gint xres, yres;
     recalculate_new_resolutions(&args, &xres, &yres);
-    xoff = gwy_field_get_xoffset(fields[0]);
-    yoff = gwy_field_get_yoffset(fields[0]);
-    dx = gwy_params_get_double(params, PARAM_DX);
-    dy = gwy_params_get_double(params, PARAM_DY);
-    interp = gwy_params_get_enum(params, PARAM_INTERP);
+    gdouble xoff = gwy_field_get_xoffset(field);
+    gdouble yoff = gwy_field_get_yoffset(field);
+    gdouble dx = gwy_params_get_double(params, PARAM_DX);
+    gdouble dy = gwy_params_get_double(params, PARAM_DY);
     xoff *= (xres*dx)/(args.orig_xres*args.orig_dx);
     yoff *= (yres*dy)/(args.orig_yres*args.orig_dy);
-    for (i = 0; i < 3; i++) {
-        if (!fields[i])
-            continue;
-        fields[i] = gwy_field_new_resampled(fields[i], xres, yres, (i == 1 ? GWY_INTERPOLATION_LINEAR : interp));
-        gwy_field_set_xreal(fields[i], xres*dx);
-        gwy_field_set_yreal(fields[i], yres*dy);
-        gwy_field_set_xoffset(fields[i], xoff);
-        gwy_field_set_yoffset(fields[i], yoff);
-        if (i == 1)
-            gwy_field_threshold(fields[1], 0.5, 0.0, 1.0);
-    }
 
-    newid = gwy_file_add_image(data, fields[0]);
+    field = gwy_field_new_resampled(field, xres, yres, interp);
+    gwy_field_set_xreal(field, xres*dx);
+    gwy_field_set_yreal(field, yres*dy);
+    gwy_field_set_xoffset(field, xoff);
+    gwy_field_set_yoffset(field, yoff);
 
+    newid = gwy_file_add_image(data, field);
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, oldid,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-    if (fields[1])
-        gwy_file_set_image_mask(data, newid, fields[1]);
-    if (fields[2])
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), fields[2]);
+    if (mask) {
+        mask = gwy_nield_new_resampled(mask, xres, yres);
+        gwy_file_pass_image_mask(data, newid, mask);
+    }
+    if (show) {
+        show = gwy_field_new_resampled(show, xres, yres, interp);
+        gwy_field_set_xreal(show, xres*dx);
+        gwy_field_set_yreal(show, yres*dy);
+        gwy_field_set_xoffset(show, xoff);
+        gwy_field_set_yoffset(show, yoff);
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
+    }
 
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Resampled Data"), TRUE);
     gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
-
-    for (i = 0; i < 3; i++)
-        g_clear_object(fields + i);
+    g_object_unref(field);
 
 end:
     g_object_unref(params);
