@@ -1,6 +1,6 @@
 /*
- *  $Id: rotate.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: rotate.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -66,9 +66,6 @@ static void             param_changed          (ModuleGUI *gui,
                                                 gint id);
 static void             preview                (gpointer user_data);
 static void             update_grid            (ModuleGUI *gui);
-static void             fix_mask_exterior      (GwyField *mask,
-                                                GwyField *exterior_mask,
-                                                gdouble fill_value);
 static GwyPlaneSymmetry guess_unrotate_symmetry(GwyField *field,
                                                 gdouble *corrections);
 static gdouble          get_rotation_angle     (ModuleArgs *args);
@@ -78,7 +75,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Rotates data by arbitrary angle or to make characteristic directions parallel with x or y axis."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "3.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -155,24 +152,21 @@ static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     const gchar *name = gwy_process_func_current();
-    GwyField *fields[3], *exterior_mask = NULL;
-    gint oldid, newid, i;
+    GwyField *field, *show;
+    GwyNield *mask, *exterior_mask = NULL;
+    gint oldid, newid;
     ModuleArgs args;
     GwyParams *params;
-    GwyInterpolationType interp;
-    GwyRotateResizeType resize;
-    gboolean create_mask;
-    gdouble angle;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_SHOW_FIELD, &show,
                                  GWY_APP_FIELD_ID, &oldid,
                                  0);
-    g_return_if_fail(fields[0]);
+    g_return_if_fail(field);
 
-    args.field = fields[0];
+    args.field = field;
     args.is_unrotate = gwy_strequal(name, "unrotate");
     if (args.is_unrotate) {
         args.symm = guess_unrotate_symmetry(args.field, args.corrections);
@@ -181,57 +175,63 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     else
         params = args.params = gwy_params_new_from_settings(define_rotate_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         GwyDialogOutcome outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(params);
         if (outcome != GWY_DIALOG_PROCEED)
             goto end;
     }
 
-    angle = get_rotation_angle(&args);
-    interp = gwy_params_get_enum(params, PARAM_INTERPOLATION);
-    resize = gwy_params_get_enum(params, PARAM_RESIZE);
-    create_mask = gwy_params_get_boolean(params, PARAM_CREATE_MASK);
+    gdouble angle = get_rotation_angle(&args);
+    GwyInterpolationType interp = gwy_params_get_enum(params, PARAM_INTERPOLATION);
+    GwyRotateResizeType resize = gwy_params_get_enum(params, PARAM_RESIZE);
+    gboolean create_mask = gwy_params_get_boolean(params, PARAM_CREATE_MASK);
 
-    if (fields[1] || (create_mask && resize != GWY_ROTATE_RESIZE_CUT))
-        exterior_mask = gwy_field_new(1, 1, 1.0, 1.0, FALSE);
+    if (mask || (create_mask && resize != GWY_ROTATE_RESIZE_CUT))
+        exterior_mask = gwy_nield_new(1, 1);
 
-    fields[0] = gwy_field_new_rotated(fields[0], exterior_mask, angle, interp, resize);
-    if (fields[1]) {
-        fields[1] = gwy_field_new_rotated(fields[1], NULL, angle, GWY_INTERPOLATION_ROUND, resize);
+    field = gwy_field_new_rotated(field, exterior_mask, angle, interp, resize);
+    if (mask) {
+        GwyField *mask_field = gwy_field_new_alike(args.field, FALSE);
+        gwy_field_fill_mask(mask_field, mask, 0.0, 1.0);
+        GwyField *rotated = gwy_field_new_rotated(mask_field, NULL, angle, GWY_INTERPOLATION_ROUND, resize);
+        g_object_unref(mask_field);
+        mask = gwy_field_new_nield_alike(rotated);
+        gwy_nield_mark_by_threshold(mask, rotated, 0.5, TRUE);
+        g_object_unref(rotated);
         /* The rotation fill exterior with average value of inside; which is kind of random and anyway unwanted for
          * masks.  Fill the exterior with either 0 or 1 (if we were asked to add an exterior mask). */
-        fix_mask_exterior(fields[1], exterior_mask, create_mask ? 1.0 : 0.0);
+        gwy_nield_area_fill(mask, exterior_mask, GWY_MASK_INCLUDE,
+                            0, 0, gwy_nield_get_xres(mask), gwy_nield_get_yres(mask),
+                            create_mask ? 1 : 0);
+        g_object_unref(mask_field);
     }
     else {
         /* If we were asked to add an exterior mask use exterior_mask as the mask.  Otherwise do nothing. */
         if (exterior_mask) {
             g_object_ref(exterior_mask);
-            fields[1] = exterior_mask;
+            mask = exterior_mask;
         }
     }
     g_clear_object(&exterior_mask);
 
-    if (fields[2])
-        fields[2] = gwy_field_new_rotated(fields[2], NULL, angle, interp, resize);
+    if (show)
+        show = gwy_field_new_rotated(show, NULL, angle, interp, resize);
 
-    newid = gwy_file_add_image(data, fields[0]);
+    newid = gwy_file_add_image(data, field);
 
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, oldid,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-    if (fields[1])
-        gwy_file_set_image_mask(data, newid, fields[1]);
-    if (fields[2])
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), fields[2]);
+    if (mask)
+        gwy_file_pass_image_mask(data, newid, mask);
+    if (show)
+        gwy_dict_pass_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
 
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Rotated Data"), TRUE);
     gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
 
-    for (i = 0; i < 3; i++)
-        g_clear_object(fields + i);
-
 end:
     g_object_unref(params);
 }
@@ -336,13 +336,12 @@ preview(gpointer user_data)
     ModuleGUI *gui = (ModuleGUI*)user_data;
     ModuleArgs *args = gui->args;
     GwyParams *params = args->params;
-    GwyField *rfield;
     gdouble angle = get_rotation_angle(args);
     GwyInterpolationType interp = gwy_params_get_enum(params, PARAM_INTERPOLATION);
     GwyRotateResizeType resize = gwy_params_get_enum(params, PARAM_RESIZE);
     GwyDataView *dataview = GWY_DATA_VIEW(gui->dataview);
 
-    rfield = gwy_field_new_rotated(gui->smallfield, NULL, angle, interp, resize);
+    GwyField *rfield = gwy_field_new_rotated(gui->smallfield, NULL, angle, interp, resize);
     gwy_data_view_set_field(dataview, rfield);
     g_object_unref(rfield);
     gwy_set_data_preview_size(dataview, PREVIEW_SIZE);
@@ -369,21 +368,6 @@ update_grid(ModuleGUI *gui)
     gwy_selection_set_data(selection, 1, xy);
 }
 
-static void
-fix_mask_exterior(GwyField *mask, GwyField *exterior_mask,
-                  gdouble fill_value)
-{
-    const gdouble *exm = gwy_field_get_data_const(exterior_mask);
-    gdouble *m = gwy_field_get_data(mask);
-    gint n, k;
-
-    n = gwy_field_get_xres(mask) * gwy_field_get_yres(mask);
-    for (k = 0; k < n; k++) {
-        if (exm[k])
-            m[k] = fill_value;
-    }
-}
-
 static GwyPlaneSymmetry
 guess_unrotate_symmetry(GwyField *field, gdouble *corrections)
 {
