@@ -1,6 +1,6 @@
 /*
- *  $Id: scale.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: scale.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -62,7 +62,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Scales data by arbitrary factor."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek & Dirk Kähler",
     "2003",
 };
@@ -110,23 +110,23 @@ static void
 module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     gdouble step = 1e-4;
-    GwyField *fields[3];
-    gint xres, yres, oldid, newid, i;
+    GwyField *field, *show;
+    GwyNield *mask;
+    gint oldid, newid;
     gdouble ratio, aspectratio;
-    GwyInterpolationType interp;
     ModuleArgs args;
     GwyParams *params;
 
     g_return_if_fail(mode & RUN_MODES);
-    gwy_data_browser_get_current(GWY_APP_FIELD, fields + 0,
-                                 GWY_APP_MASK_FIELD, fields + 1,
-                                 GWY_APP_SHOW_FIELD, fields + 2,
+    gwy_data_browser_get_current(GWY_APP_FIELD, &field,
+                                 GWY_APP_MASK_FIELD, &mask,
+                                 GWY_APP_SHOW_FIELD, &show,
                                  GWY_APP_FIELD_ID, &oldid,
                                  0);
-    g_return_if_fail(fields[0]);
+    g_return_if_fail(field);
 
-    args.orig_xres = gwy_field_get_xres(fields[0]);
-    args.orig_yres = gwy_field_get_yres(fields[0]);
+    args.orig_xres = gwy_field_get_xres(field);
+    args.orig_yres = gwy_field_get_yres(field);
     args.minratio = GWY_ROUND(2.0/MIN(args.orig_xres, args.orig_yres)/step)*step;
     args.maxratio = 16384.0/MAX(args.orig_xres, args.orig_yres);
     args.minratio = MAX(args.minratio, MIN_RATIO);
@@ -152,34 +152,30 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
             goto end;
     }
 
-    xres = gwy_params_get_int(params, PARAM_XRES);
-    yres = gwy_params_get_int(params, PARAM_YRES);
-    interp = gwy_params_get_enum(params, PARAM_INTERPOLATION);
+    gint xres = gwy_params_get_int(params, PARAM_XRES);
+    gint yres = gwy_params_get_int(params, PARAM_YRES);
+    GwyInterpolationType interp = gwy_params_get_enum(params, PARAM_INTERPOLATION);
 
-    fields[0] = gwy_field_new_resampled(fields[0], xres, yres, interp);
-    if (fields[1]) {
-        fields[1] = gwy_field_new_resampled(fields[1], xres, yres, GWY_INTERPOLATION_LINEAR);
-        gwy_field_threshold(fields[1], 0.5, 0.0, 1.0);
-    }
-    if (fields[2])
-        fields[2] = gwy_field_new_resampled(fields[2], xres, yres, interp);
-
-    newid = gwy_file_add_image(data, fields[0]);
+    field = gwy_field_new_resampled(field, xres, yres, interp);
+    newid = gwy_file_add_image(data, field);
 
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_sync_items(data, GWY_FILE_IMAGE, oldid,
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_RANGE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-    if (fields[1])
-        gwy_file_set_image_mask(data, newid, fields[1]);
-    if (fields[2])
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(newid), fields[2]);
+
+    if (mask) {
+        mask = gwy_nield_new_resampled(mask, xres, yres);
+        gwy_file_pass_image_mask(data, newid, mask);
+    }
+    if (show) {
+        show = gwy_field_new_resampled(show, xres, yres, interp);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_picture(newid), show);
+    }
 
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, _("Scaled Data"), TRUE);
     gwy_log_add(data, GWY_FILE_IMAGE, oldid, newid);
-
-    for (i = 0; i < 3; i++)
-        g_clear_object(fields + i);
+    g_object_unref(field);
 
 end:
     g_object_unref(params);
