@@ -1,5 +1,5 @@
 /*
- *  $Id: semsim.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: semsim.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -155,7 +155,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_unit_clear(gwy_field_get_unit_z(args.result));
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -163,8 +163,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
 
     if (execute(&args, gwy_data_browser_get_window_for_data(data, GWY_FILE_IMAGE, id))) {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), args.result);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_picture(id), args.result);
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
 
@@ -261,7 +261,6 @@ semsim_do_integration(SEMSimCommon *common, ModuleArgs *args)
 {
     GwyField *show = args->result;
     gint xres = gwy_field_get_xres(show), yres = gwy_field_get_yres(show);
-    gint i, j, k;
     gdouble dx = common->dx, dy = common->dy, dz = common->dz;
     gdouble sigma_r2 = G_SQRT2*gwy_params_get_double(args->params, PARAM_SIGMA) * dx;
     const gdouble *d = gwy_field_get_data_const(common->extfield);
@@ -274,9 +273,9 @@ semsim_do_integration(SEMSimCommon *common, ModuleArgs *args)
 
     weight_table = g_new(WeightItem, (2*extv + 1)*(2*exth + 1));
     nw = 0;
-    for (i = -extv; i <= extv; i++) {
+    for (gint i = -extv; i <= extv; i++) {
         gdouble x = i*dy/sigma_r2;
-        for (j = -exth; j <= exth; j++) {
+        for (gint j = -exth; j <= exth; j++) {
             gdouble y = j*dx/sigma_r2;
             gdouble w = exp(-(x*x + y*y));
             if (w >= 1e-6) {
@@ -289,16 +288,15 @@ semsim_do_integration(SEMSimCommon *common, ModuleArgs *args)
 
 #ifdef _OPENMP
 #pragma omp parallel if (gwy_threads_are_enabled()) default(none) \
-            private(i,j,k) \
             shared(d,s,erftable,weight_table,nw,extv,exth,extxres,xres,yres,dz,pcancelled)
 #endif
     {
         gint ifrom = gwy_omp_chunk_start(yres), ito = gwy_omp_chunk_end(yres);
 
-        for (i = ifrom; i < ito; i++) {
-            for (j = 0; j < xres; j++) {
+        for (gint i = ifrom; i < ito; i++) {
+            for (gint j = 0; j < xres; j++) {
                 gdouble sum = 0.0, z0 = d[(i + extv)*extxres + (j + exth)];
-                for (k = 0; k < nw; k++) {
+                for (gint k = 0; k < nw; k++) {
                     gdouble z = d[i*extxres + j + weight_table[k].k];
                     gdouble w = weight_table[k].w;
                     if (z >= z0)
@@ -402,7 +400,7 @@ create_erf_table(GwyField *field, gdouble sigma, gdouble *zstep)
     gdouble *table;
     gint i;
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     dz = (max - min)/(ERF_TABLE_SIZE - 1);
     table = g_new(gdouble, ERF_TABLE_SIZE + 1);
     for (i = 0; i <= ERF_TABLE_SIZE; i++)
