@@ -1,5 +1,5 @@
 /*
- *  $Id: shade.c 28910 2025-11-24 18:11:09Z yeti-dn $
+ *  $Id: shade.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -123,7 +123,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new_alike(args.field, TRUE);
     gwy_unit_clear(gwy_field_get_unit_z(args.result));
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -132,9 +132,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
 
-    gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_image_picture(id), args.result);
+    gwy_dict_set_object(GWY_DICT(data), gwy_file_key_image_picture(id), args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -245,8 +245,8 @@ mix_with_plane(GwyField *shaded,
 {
     gdouble plane_min, plane_max, shade_min, shade_max, plane_range, shade_range, q;
 
-    gwy_field_get_min_max(plane, &plane_min, &plane_max);
-    gwy_field_get_min_max(shaded, &shade_min, &shade_max);
+    gwy_field_min_max(plane, &plane_min, &plane_max);
+    gwy_field_min_max(shaded, &shade_min, &shade_max);
     plane_range = plane_max - plane_min;
     shade_range = shade_max - shade_min;
 
