@@ -1,6 +1,6 @@
 /*
- *  $Id: slope_dist.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: slope_dist.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -45,7 +45,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
+    GwyNield *mask;
     GwyField *result;
     GwyGraphModel *gmodel;
     /* Cached input data properties. */
@@ -96,7 +96,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates one- or two-dimensional distribution of slopes or graph of their angular distribution."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -166,7 +166,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, 1.0, 1.0, TRUE);
     args.gmodel = gwy_graph_model_new();
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -308,16 +308,15 @@ preview(gpointer user_data)
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
-static inline gboolean
-is_counted(const gdouble *m, guint k, GwyMaskingType masking)
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
 {
-    if (!m || masking == GWY_MASK_IGNORE)
-        return TRUE;
-
     if (masking == GWY_MASK_INCLUDE)
-        return m[k] > 0.0;
-    else
-        return m[k] <= 0.0;
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
 }
 
 static void
@@ -363,41 +362,38 @@ static GwyField*
 slope_do_2d(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint kernel_size = gwy_params_get_int(params, PARAM_KERNEL_SIZE);
     gint size = gwy_params_get_int(params, PARAM_SIZE);
     gboolean logscale = gwy_params_get_boolean(params, PARAM_LOGSCALE);
     gboolean fit_plane = gwy_params_get_boolean(params, PARAM_FIT_PLANE);
-    const gdouble *xd, *yd;
-    gdouble minxd, maxxd, minyd, maxyd, max;
-    gint xres, yres, n;
-    gint xider, yider, i;
-    gulong *count;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint border = fit_plane ? kernel_size : 2;
+    gint n = (xres - border)*(yres - border);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    n = fit_plane ? kernel_size : 2;
-    n = (xres - n)*(yres - n);
-
-    gwy_field_get_min_max(args->xder, &minxd, &maxxd);
+    gdouble minxd, maxxd;
+    gwy_field_min_max(args->xder, &minxd, &maxxd);
     maxxd = MAX(fabs(minxd), fabs(maxxd));
-    gwy_field_get_min_max(args->yder, &minyd, &maxyd);
+
+    gdouble minyd, maxyd;
+    gwy_field_min_max(args->yder, &minyd, &maxyd);
     maxyd = MAX(fabs(minyd), fabs(maxyd));
-    max = MAX(maxxd, maxyd);
+
+    gdouble max = MAX(maxxd, maxyd);
     if (!max)
         max = 1.0;
 
-    count = g_new0(gulong, size*size);
-    xd = gwy_field_get_data_const(args->xder);
-    yd = gwy_field_get_data_const(args->yder);
-    const gdouble *m = mask ? gwy_field_get_data(mask) : NULL;
-    for (i = 0; i < n; i++) {
-        if (is_counted(m, i, masking)) {
-            xider = size*(xd[i]/(2.0*max) + 0.5);
+    gulong *count = g_new0(gulong, size*size);
+    const gdouble *xd = gwy_field_get_data_const(args->xder);
+    const gdouble *yd = gwy_field_get_data_const(args->yder);
+    const gint *m = mask ? gwy_nield_get_data(mask) : NULL;
+    for (gint i = 0; i < n; i++) {
+        if (nielded_included(m + i, masking)) {
+            gint xider = size*(xd[i]/(2.0*max) + 0.5);
             xider = CLAMP(xider, 0, size-1);
-            yider = size*(yd[i]/(2.0*max) + 0.5);
+            gint yider = size*(yd[i]/(2.0*max) + 0.5);
             yider = CLAMP(yider, 0, size-1);
 
             count[yider*size + xider]++;
@@ -411,29 +407,23 @@ static void
 slope_do_graph_phi(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint kernel_size = gwy_params_get_int(params, PARAM_KERNEL_SIZE);
     gint size = gwy_params_get_int(params, PARAM_SIZE);
     gboolean fit_plane = gwy_params_get_boolean(params, PARAM_FIT_PLANE);
-    GwyLine *line;
-    const gdouble *xd, *yd;
-    gdouble *data;
-    gint xres, yres, n, i;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint border = fit_plane ? kernel_size : 2;
+    gint n = (xres - border)*(yres - border);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    n = fit_plane ? kernel_size : 2;
-    n = (xres - n)*(yres - n);
-
-    line = gwy_line_new(size, 360, TRUE);
-    data = gwy_line_get_data(line);
-    xd = gwy_field_get_data_const(args->xder);
-    yd = gwy_field_get_data_const(args->yder);
-    const gdouble *m = mask ? gwy_field_get_data(mask) : NULL;
-    for (i = 0; i < n; i++) {
-        if (is_counted(m, i, masking)) {
+    GwyLine *line = gwy_line_new(size, 360, TRUE);
+    gdouble *data = gwy_line_get_data(line);
+    const gdouble *xd = gwy_field_get_data_const(args->xder);
+    const gdouble *yd = gwy_field_get_data_const(args->yder);
+    const gint *m = mask ? gwy_nield_get_data(mask) : NULL;
+    for (gint i = 0; i < n; i++) {
+        if (nielded_included(m + i, masking)) {
             gdouble phi = gwy_canonicalize_angle(atan2(yd[i], -xd[i]), TRUE, TRUE);
             gdouble d = (xd[i]*xd[i] + yd[i]*yd[i]);
             gint iphi = floor(size*phi/(2.0*G_PI));
@@ -451,35 +441,28 @@ static void
 slope_do_graph_theta(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint kernel_size = gwy_params_get_int(params, PARAM_KERNEL_SIZE);
     gint size = gwy_params_get_int(params, PARAM_SIZE);
     gboolean fit_plane = gwy_params_get_boolean(params, PARAM_FIT_PLANE);
-    GwyLine *line;
-    const gdouble *yd;
-    gdouble *xd, *data;
-    gint xres, yres, n, i, nc;
-    gdouble max;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint border = fit_plane ? kernel_size : 2;
+    gint n = (xres - border)*(yres - border);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    n = fit_plane ? kernel_size : 2;
-    n = (xres - n)*(yres - n);
-
-    line = gwy_line_new(size, 90, TRUE);
-    data = gwy_line_get_data(line);
-    xd = gwy_field_get_data(args->xder);
-    yd = gwy_field_get_data_const(args->yder);
-    for (i = 0; i < n; i++)
+    GwyLine *line = gwy_line_new(size, 90, TRUE);
+    gdouble *data = gwy_line_get_data(line);
+    gdouble *xd = gwy_field_get_data(args->xder);
+    const gdouble *yd = gwy_field_get_data_const(args->yder);
+    for (gint i = 0; i < n; i++)
         xd[i] = gwy_rad2deg(atan(hypot(xd[i], yd[i])));
-    gwy_field_area_get_min_max(args->xder, mask, masking, 0, 0, xres, yres, NULL, &max);
+    gdouble max = gwy_field_area_max(args->xder, mask, masking, 0, 0, xres, yres);
     gwy_line_set_real(line, max);
-    nc = 0;
-    const gdouble *m = mask ? gwy_field_get_data(mask) : NULL;
-    for (i = 0; i < n; i++) {
-        if (is_counted(m, i, masking)) {
+    gint nc = 0;
+    const gint *m = mask ? gwy_nield_get_data(mask) : NULL;
+    for (gint i = 0; i < n; i++) {
+        if (nielded_included(m + i, masking)) {
             gint itheta = floor(size*xd[i]/max);
 
             itheta = CLAMP(itheta, 0, size-1);
@@ -499,35 +482,28 @@ static void
 slope_do_graph_gradient(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     gint kernel_size = gwy_params_get_int(params, PARAM_KERNEL_SIZE);
     gint size = gwy_params_get_int(params, PARAM_SIZE);
     gboolean fit_plane = gwy_params_get_boolean(params, PARAM_FIT_PLANE);
-    GwyLine *line;
-    const gdouble *yd;
-    gdouble *xd, *data;
-    gint xres, yres, n, i, nc;
-    gdouble max;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint border = fit_plane ? kernel_size : 2;
+    gint n = (xres - border)*(yres - border);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    n = fit_plane ? kernel_size : 2;
-    n = (xres - n)*(yres - n);
-
-    xd = gwy_field_get_data(args->xder);
-    yd = gwy_field_get_data_const(args->yder);
-    for (i = 0; i < n; i++)
+    gdouble *xd = gwy_field_get_data(args->xder);
+    const gdouble *yd = gwy_field_get_data_const(args->yder);
+    for (gint i = 0; i < n; i++)
         xd[i] = hypot(xd[i], yd[i]);
-    gwy_field_area_get_min_max(args->xder, mask, masking, 0, 0, xres, yres, NULL, &max);
+    gdouble max = gwy_field_area_max(args->xder, mask, masking, 0, 0, xres, yres);
 
-    line = gwy_line_new(size, max, TRUE);
-    data = gwy_line_get_data(line);
-    nc = 0;
-    const gdouble *m = mask ? gwy_field_get_data(mask) : NULL;
-    for (i = 0; i < n; i++) {
-        if (is_counted(m, i, masking)) {
+    GwyLine *line = gwy_line_new(size, max, TRUE);
+    gdouble *data = gwy_line_get_data(line);
+    gint nc = 0;
+    const gint *m = mask ? gwy_nield_get_data(mask) : NULL;
+    for (gint i = 0; i < n; i++) {
+        if (nielded_included(m + i, masking)) {
             gint ider = floor(size*xd[i]/max);
 
             ider = CLAMP(ider, 0, size-1);
