@@ -1,5 +1,5 @@
 /*
- *  $Id: smm.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: smm.c 29520 2026-02-23 09:32:20Z yeti-dn $
  *  Copyright (C) 2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -169,7 +169,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Interprets SMM measurement on a calibration sample"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.0",
+    "1.1",
     "Petr Klapetek & David Nečas (Yeti)",
     "2023",
 };
@@ -782,11 +782,12 @@ static gboolean
 image_filter(GwyFile *data, gint id, gpointer user_data)
 {
     ModuleArgs *args = (ModuleArgs*)user_data;
-    GwyField *otherfield, *field = args->field;
+    GwyField *field = args->field;
+    GwyNield *othermask;
 
-    if (!(otherfield = gwy_file_get_image(data, id)))
+    if (!(othermask = gwy_file_get_image_mask(data, id)))
         return FALSE;
-    return !gwy_field_is_incompatible(field, otherfield, GWY_DATA_MISMATCH_RES);
+    return !gwy_nield_is_incompatible_with_field(othermask, field, GWY_DATA_MISMATCH_RES);
 }
 
 static void
@@ -802,29 +803,26 @@ static void
 execute(ModuleArgs *args)
 {
     GwyParams *params = args->params;
-    GwyField *mask, *dfa, *dfb;
-    gdouble xdata[NARGS], freq, refimp, aval, bval, res11m, ims11m;
+    GwyField* dfa = gwy_params_get_image(params, PARAM_IMAGE_A);
+    GwyField* dfb = gwy_params_get_image(params, PARAM_IMAGE_B);
+    SMMSignal signala = gwy_params_get_enum(params, PARAM_SIGNAL_A);
+    SMMSignal signalb = gwy_params_get_enum(params, PARAM_SIGNAL_B);
+    SMMShow show = gwy_params_get_enum(params, PARAM_SHOW);
+    gdouble freq = gwy_params_get_double(params, PARAM_FREQ)*1e9;
+    gdouble refimp = gwy_params_get_double(params, PARAM_REFIMP);
+    gdouble xdata[NARGS], res11m, ims11m;
     double complex s11m, s11n, s11c, zs, zr;
-    gint i, ndata, show, signala, signalb;
     gboolean enabled, fit;
     gdouble capacitance, mult;
 
-    dfa = gwy_params_get_image(params, PARAM_IMAGE_A);
-    dfb = gwy_params_get_image(params, PARAM_IMAGE_B);
-    signala = gwy_params_get_enum(params, PARAM_SIGNAL_A);
-    signalb = gwy_params_get_enum(params, PARAM_SIGNAL_B);
-    show = gwy_params_get_enum(params, PARAM_SHOW);
-    freq = gwy_params_get_double(params, PARAM_FREQ)*1e9;
-    refimp = gwy_params_get_double(params, PARAM_REFIMP);
-
     //the situations below should be prevented elsewhere
     if (gwy_field_is_incompatible(dfa, dfb, GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL))
         return;
 
-    for (i = 0; i < NARGS; i++) {
+    for (gint i = 0; i < NARGS; i++) {
         if (gwy_params_get_boolean(params, PARAM_ENABLED_0 + i)) {
-            mask = gwy_params_get_image(params, PARAM_IMAGE_0 + i);
-            if (gwy_field_is_incompatible(dfa, mask, GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL)) {
+            GwyField *field = gwy_params_get_image(params, PARAM_IMAGE_0 + i);
+            if (gwy_field_is_incompatible(dfa, field, GWY_DATA_MISMATCH_RES | GWY_DATA_MISMATCH_REAL)) {
                 return;
             }
         }
@@ -832,8 +830,8 @@ execute(ModuleArgs *args)
 
     zr = refimp;
 
-    ndata = 0;
-    for (i = 0; i < NARGS; i++) {
+    gint ndata = 0;
+    for (gint i = 0; i < NARGS; i++) {
         enabled = gwy_params_get_boolean(params, PARAM_ENABLED_0 + i);
         fit = gwy_params_get_boolean(params, PARAM_FIT_0 + i);
         capacitance = gwy_params_get_double(params, PARAM_CAPACITANCE_0 + i);
@@ -845,13 +843,11 @@ execute(ModuleArgs *args)
             args->rnominal[ndata] = creal(s11n);
             args->inominal[ndata] = cimag(s11n);
 
-            mask = gwy_params_get_image(params, PARAM_IMAGE_0 + i);
-
-            aval =  gwy_field_area_get_avg(dfa, mask, GWY_MASK_INCLUDE, 0, 0,
-                                           gwy_field_get_xres(dfa), gwy_field_get_yres(dfa));
-
-            bval =  gwy_field_area_get_avg(dfb, mask, GWY_MASK_INCLUDE, 0, 0,
-                                           gwy_field_get_xres(dfb), gwy_field_get_yres(dfb));
+            GwyNield *mask = gwy_params_get_image_mask(params, PARAM_IMAGE_0 + i);
+            gdouble aval = gwy_field_area_mean(dfa, mask, GWY_MASK_INCLUDE, 0, 0,
+                                               gwy_field_get_xres(dfa), gwy_field_get_yres(dfa));
+            gdouble bval = gwy_field_area_mean(dfb, mask, GWY_MASK_INCLUDE, 0, 0,
+                                               gwy_field_get_xres(dfb), gwy_field_get_yres(dfb));
 
             if (signala == SMM_SIGNAL_REAL && signalb == SMM_SIGNAL_IMAGINARY) {
                 res11m = aval;
