@@ -1,5 +1,5 @@
 /*
- *  $Id: sphere-revolve.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: sphere-revolve.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -120,7 +120,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.bg = gwy_field_new_alike(args.field, TRUE);
 
     args.params = gwy_params_new_from_settings(define_module_params());
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -130,7 +130,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         && !execute(&args, gwy_data_browser_get_window_for_data(data, GWY_FILE_IMAGE, id)))
         goto end;
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
@@ -228,7 +228,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     yres = gwy_field_get_yres(bg);
     rdata = gwy_field_get_data(bg);
 
-    q = gwy_field_get_rms(field)/sqrt(5.0/6.0);
+    q = gwy_field_rms(field)/sqrt(5.0/6.0);
     sphere = make_sphere(radius, gwy_field_get_xres(field));
 
     /* Scale-freeing.
