@@ -1,6 +1,6 @@
 /*
- *  $Id: stitch.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2017-2025 David Necas (Yeti), Petr Klapetek, Petr Grolich.
+ *  $Id: stitch.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2017-2026 David Necas (Yeti), Petr Klapetek, Petr Grolich.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, pgrolich@cmi.cz.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -15,8 +15,6 @@
  *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* TODO: Option to create a mask over missing data. */
-
 #include "config.h"
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -71,7 +69,7 @@ typedef struct {
     gdouble yoffset[NARGS];
     gdouble zoffset[NARGS];
     GwyField *result;
-    GwyField *mask;
+    GwyNield *mask;
 } ModuleArgs;
 
 typedef struct {
@@ -123,7 +121,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Stitch multiple images based on offsets of origins."),
     "Petr Grolich <pgrolich.cmi.cz>",
-    "2.0",
+    "2.1",
     "Petr Klapetek & Petr Grolich",
     "2017",
 };
@@ -174,11 +172,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     gint datano, id;
     gwy_data_browser_get_current(GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &datano,
+                                 GWY_APP_FILE_ID, &datano,
                                  0);
     sanitise_args(&args);
     args.result = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, 1.0, 1.0, TRUE);
-    args.mask = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, 1.0, 1.0, TRUE);
+    args.mask = gwy_nield_new(PREVIEW_SIZE, PREVIEW_SIZE);
 
     GwyDialogOutcome outcome = run_gui(&args, data, id);
     gwy_params_save_to_settings(args.params);
@@ -307,7 +305,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
             dfield = gwy_file_get_image(data, active_object->id);
             xoffset = gwy_field_get_xoffset(dfield);
             yoffset = gwy_field_get_yoffset(dfield);
-            zoffset = gwy_field_get_avg(dfield);
+            zoffset = gwy_field_mean(dfield);
         }
 
         gui.xoffset[i] = gtk_adjustment_new(0, -10000, 10000, 0.1, 1, 0);
@@ -395,7 +393,7 @@ format_values(ModuleGUI *gui, guint i)
     GwyField *dfield = gwy_file_get_image(data, args->objects[i].id);
     gtk_adjustment_set_value(gui->xoffset[i], gwy_field_get_xoffset(dfield)/gui->xyvf->magnitude);
     gtk_adjustment_set_value(gui->yoffset[i], gwy_field_get_yoffset(dfield)/gui->xyvf->magnitude);
-    gtk_adjustment_set_value(gui->zoffset[i], gwy_field_get_avg(dfield)/gui->zvf->magnitude);
+    gtk_adjustment_set_value(gui->zoffset[i], gwy_field_mean(dfield)/gui->zvf->magnitude);
 }
 
 static void
@@ -496,7 +494,8 @@ static void
 execute(ModuleArgs *args)
 {
     gboolean keep_offsets = gwy_params_get_boolean(args->params, PARAM_KEEP_OFFSETS);
-    GwyField *dfield = NULL, *df_shift, *result = args->result, *mask = args->mask;
+    GwyField *dfield = NULL, *df_shift, *result = args->result;
+    GwyNield *mask = args->mask;
     gint i, xres = 0, yres = 0, width, height, nfields = 0, destcol, destrow;
     gdouble xreal = 0.0, yreal = 0.0, left = 0.0, top = 0.0, right = 0.0, bottom = 0.0, x, y;
     GwyUnit *siunitxy = NULL, *siunitz = NULL;
@@ -547,14 +546,8 @@ execute(ModuleArgs *args)
     gwy_unit_assign(gwy_field_get_unit_xy(result), siunitxy);
     gwy_unit_assign(gwy_field_get_unit_z(result), siunitz);
 
-    gwy_field_resize(mask, xres, yres);
-    gwy_field_fill(mask, 1.0);
-    gwy_field_set_xreal(mask, gwy_field_get_xreal(result));
-    gwy_field_set_yreal(mask, gwy_field_get_yreal(result));
-    gwy_field_set_xoffset(mask, gwy_field_get_xoffset(result));
-    gwy_field_set_yoffset(mask, gwy_field_get_yoffset(result));
-    gwy_unit_assign(gwy_field_get_unit_xy(mask), siunitxy);
-    gwy_unit_clear(gwy_field_get_unit_xy(mask));
+    gwy_nield_resize(mask, xres, yres);
+    gwy_nield_fill(mask, 1);
 
     for (i = 0; i < NARGS; i++) {
         if (!args->enabled[i])
@@ -586,7 +579,7 @@ execute(ModuleArgs *args)
             height = MIN(height, yres - destrow);
 
             gwy_field_area_copy(df_shift, result, 0, 0, width, height, destcol, destrow);
-            gwy_field_area_clear(mask, destcol, destrow, width, height);
+            gwy_nield_area_clear(mask, destcol, destrow, width, height);
             g_object_unref(df_shift);
         }
     }
