@@ -1,6 +1,6 @@
 /*
- *  $Id: straighten_path.c 28970 2025-12-10 15:45:57Z yeti-dn $
- *  Copyright (C) 2016-2021 David Necas (Yeti).
+ *  $Id: straighten_path.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2016-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -42,7 +42,7 @@ typedef struct {
     GwyParams *params;
     GwyField *field;
     GwyField *result;
-    GwyField *result_mask;
+    GwyNield *result_mask;
     GwySelection *selection;
     /* Cached values for input data field. */
     gboolean realsquare;
@@ -94,7 +94,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extracts a straightened part of image along a curve."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti)",
     "2016",
 };
@@ -156,13 +156,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_clear1(args);
     args.field = field;
     args.params = params = gwy_params_new_from_settings(define_module_params());
-    gwy_container_gis_boolean(GWY_CONTAINER(data), gwy_file_key_image_real_square(id), &args.realsquare);
+    gwy_dict_gis_boolean(GWY_DICT(data), gwy_file_key_image_real_square(id), &args.realsquare);
     yres = gwy_field_get_yres(field);
     args.result = gwy_field_new(5, yres, 5, yres, TRUE);
-    args.result_mask = gwy_field_new_alike(args.result, TRUE);
+    args.result_mask = gwy_field_new_nield_alike(args.result);
 
     GQuark selection_key = gwy_file_key_image_selection(id, "path");
-    if (gwy_container_gis_object(GWY_CONTAINER(data), selection_key, &selection)
+    if (gwy_dict_gis_object(GWY_DICT(data), selection_key, &selection)
         && gwy_selection_get_data(GWY_SELECTION(selection), NULL) > 1) {
         gwy_debug("init selection from container");
         args.selection = gwy_selection_copy(selection);
@@ -180,7 +180,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     outcome = run_gui(&args, data, id);
     gwy_params_save_to_settings(params);
-    gwy_container_set_object(GWY_CONTAINER(data), selection_key, args.selection);
+    gwy_dict_set_object(GWY_DICT(data), selection_key, args.selection);
 
     if (outcome == GWY_DIALOG_CANCEL)
         goto end;
@@ -201,8 +201,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                         data, GWY_FILE_IMAGE, newid,
                         GWY_FILE_ITEM_COLOR_MAPPING | GWY_FILE_ITEM_RANGE
                         | GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
-    if (gwy_field_get_max(args.result_mask) > 0.0)
-        gwy_file_set_image_mask(data, newid, args.result_mask);
+    gint ngrains = gwy_nield_number_contiguous(args.result_mask);
+    gwy_file_set_image_mask(data, newid, ngrains ? args.result_mask : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
 
 end:
@@ -352,7 +352,7 @@ preview(gpointer user_data)
 
     execute(args, gui->selection);
     gwy_field_data_changed(args->result);
-    gwy_field_data_changed(args->result_mask);
+    gwy_nield_data_changed(args->result_mask);
     gwy_set_data_preview_size(GWY_DATA_VIEW(gui->view_result), PREVIEW_SIZE);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
@@ -590,59 +590,47 @@ rescale_points(GwySelection *selection, GwyField *field,
 }
 
 static void
-resize_result_field(GwyField *result, gint n, gint thickness, gdouble h)
+execute(ModuleArgs *args, GwySelection *selection)
 {
+    GwyField *field = args->field, *result = args->result;
+    GwyNield *mask = args->result_mask;
+    GwyInterpolationType interp = gwy_params_get_enum(args->params, PARAM_INTERP);
+    guint thickness = gwy_params_get_int(args->params, PARAM_THICKNESS);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble dx, dy, qx, qy, length;
+    guint i, j, k;
+    gboolean have_exterior = FALSE;
+
+    guint n = gwy_selection_get_data(selection, NULL);
+    GwyXY *rpoints = rescale_points(selection, field, args->realsquare, &dx, &dy, &qx, &qy);
+    gdouble h = MIN(dx, dy);
+    GwySpline *spline = gwy_spline_new_from_points(rpoints, n);
+    gwy_spline_set_closed(spline, gwy_params_get_boolean(args->params, PARAM_CLOSED));
+    gwy_spline_set_slackness(spline, gwy_params_get_double(args->params, PARAM_SLACKNESS));
+    g_free(rpoints);
+
+    length = gwy_spline_length(spline);
+
+    /* This would give natural sampling for a straight line along some axis. */
+    n = GWY_ROUND(length + 1.0);
     gwy_field_resize(result, thickness, n);
     gwy_field_set_xreal(result, h*thickness);
     gwy_field_set_yreal(result, h*n);
     gwy_field_set_xoffset(result, 0.0);
     gwy_field_set_yoffset(result, 0.0);
-}
-
-static void
-execute(ModuleArgs *args, GwySelection *selection)
-{
-    GwyField *mask = args->result_mask, *field = args->field, *result = args->result;
-    GwyInterpolationType interp = gwy_params_get_enum(args->params, PARAM_INTERP);
-    guint thickness = gwy_params_get_int(args->params, PARAM_THICKNESS);
-    GwySpline *spline;
-    GwyXY *points, *tangents, *coords;
-    gdouble dx, dy, qx, qy, h, length;
-    guint n, i, j, k;
-    gboolean have_exterior = FALSE;
-    gint xres, yres;
-    gdouble *m;
-
-    n = gwy_selection_get_data(selection, NULL);
-    points = rescale_points(selection, field, args->realsquare, &dx, &dy, &qx, &qy);
-    h = MIN(dx, dy);
-    spline = gwy_spline_new_from_points(points, n);
-    gwy_spline_set_closed(spline, gwy_params_get_boolean(args->params, PARAM_CLOSED));
-    gwy_spline_set_slackness(spline, gwy_params_get_double(args->params, PARAM_SLACKNESS));
-    g_free(points);
-
-    length = gwy_spline_length(spline);
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    /* This would give natural sampling for a straight line along some axis. */
-    n = GWY_ROUND(length + 1.0);
-    resize_result_field(result, n, thickness, h);
     gwy_field_copy_units(field, result);
-    resize_result_field(mask, n, thickness, h);
-    gwy_field_copy_units(field, mask);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
-    gwy_field_clear(mask);
+    gwy_nield_resize(mask, thickness, n);
+    gwy_nield_clear(mask);
     if (n < 2) {
         gwy_field_clear(result);
         return;
     }
 
-    points = g_new(GwyXY, n);
-    tangents = g_new(GwyXY, n);
-    coords = g_new(GwyXY, n*thickness);
+    GwyXY *points = g_new(GwyXY, n);
+    GwyXY *tangents = g_new(GwyXY, n);
+    GwyXY *coords = g_new(GwyXY, n*thickness);
     gwy_spline_sample_uniformly(spline, points, tangents, n);
-    m = gwy_field_get_data(mask);
+    gint *m = gwy_nield_get_data(mask);
     for (i = k = 0; i < n; i++) {
         gdouble xc = qx*points[i].x, yc = qy*points[i].y;
         gdouble vx = qx*tangents[i].y, vy = -qy*tangents[i].x;
@@ -655,7 +643,7 @@ execute(ModuleArgs *args, GwySelection *selection)
             coords[k].x = x;
             coords[k].y = y;
             if (y > yres || x > xres || y < 0.0 || x < 0.0) {
-                m[i*thickness + j] = 1.0;
+                m[i*thickness + j] = 1;
                 have_exterior = TRUE;
             }
         }
