@@ -1,6 +1,6 @@
 /*
- *  $Id: terracefit.c 29081 2026-01-05 17:43:25Z yeti-dn $
- *  Copyright (C) 2019-2021 David Necas (Yeti).
+ *  $Id: terracefit.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2019-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -108,8 +108,13 @@ typedef struct {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *mask;
-    /* The field for DATA is actually the mask.  And we never output SEGMENTED (the colour terraces). */
+    GwyNield *mask;
+    GwyNield *marked;
+    GwyNield *terraceids;
+    /* We simply keep the input field in result[PREVIEW_DATA] for consistency, but DATA really means ‘input + marked’.
+     * We never output SEGMENTED (the colour terraces) as an image.
+     * FIXME: Logically, SEGMENTED is the terraceids Nield. But DataView cannot show it like this (yet). So we also
+     * have a Field to display it. */
     GwyField *result[PREVIEW_NTYPES];
 } ModuleArgs;
 
@@ -188,7 +193,7 @@ static void             dialog_response         (ModuleGUI *gui,
                                                  gint response);
 static void             run_segmentation        (gpointer user_data);
 static void             terrace_fit             (ModuleGUI *gui);
-static FitResult*       terrace_do              (GwyField *marked,
+static FitResult*       terrace_do              (GwyNield *marked,
                                                  GwyField *residuum,
                                                  GwyField *background,
                                                  GwyField *terraces,
@@ -230,7 +235,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fits terraces with polynomial background."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "3.0",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -323,10 +328,13 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(args.field);
 
     for (i = 0; i < PREVIEW_NTYPES; i++) {
-        args.result[i] = gwy_field_new_alike(args.field, TRUE);
         if (i == PREVIEW_DATA)
-            gwy_unit_clear(gwy_field_get_unit_z(args.result[i]));
+            args.result[i] = g_object_ref(args.field);
+        else
+            args.result[i] = gwy_field_new_alike(args.field, TRUE);
     }
+    args.marked = gwy_field_new_nield_alike(args.field);
+    args.terraceids = gwy_field_new_nield_alike(args.field);
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
@@ -340,6 +348,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 end:
     for (i = 0; i < PREVIEW_NTYPES; i++)
         g_object_unref(args.result[i]);
+    g_object_unref(args.terraceids);
+    g_object_unref(args.marked);
     g_object_unref(args.params);
 }
 
@@ -360,36 +370,33 @@ create_output_fields(ModuleArgs *args, GwyFile *data, gint id)
         { OUTPUT_BACKGROUND, PREVIEW_BACKGROUND, FALSE, },
     };
     OutputFlags output = gwy_params_get_flags(args->params, PARAM_OUTPUT);
-    GwyField *mask, *invmask, *field;
-    const gchar *title;
-    GQuark quark;
-    gint newid;
-    guint i;
 
-    mask = args->result[PREVIEW_SEGMENTED];
-    for (i = 0; i < G_N_ELEMENTS(output_map); i++) {
+    for (guint i = 0; i < G_N_ELEMENTS(output_map); i++) {
         if (!(output & output_map[i].output))
             continue;
 
-        field = args->result[output_map[i].preview];
         if (output_map[i].output == OUTPUT_SEGMENTED) {
-            quark = gwy_file_key_image_mask(id);
-            gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
-            gwy_file_pass_image_mask(data, id, gwy_field_copy(field));
+            /* The actual output is the mask. We use the terrace ids directly as we segmented it. */
+            GQuark quark = gwy_file_key_image_mask(id);
+            gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
+            gwy_file_set_image_mask(data, id, args->terraceids);
             gwy_log_add(data, GWY_FILE_IMAGE, id, id);
             continue;
         }
-        newid = gwy_file_add_image(data, field);
+
+        GwyField *field = args->result[output_map[i].preview];
+        gint newid = gwy_file_add_image(data, field);
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                             data, GWY_FILE_IMAGE, newid,
                             GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE | GWY_FILE_ITEM_MASK_COLOR, FALSE);
         if (output_map[i].add_inv_mask) {
-            invmask = gwy_field_copy(mask);
-            gwy_field_grains_invert(invmask);
+            GwyNield *invmask = gwy_nield_copy(args->terraceids);
+            gwy_nield_invert(invmask);
+            gwy_nield_number_contiguous(invmask);
             gwy_file_pass_image_mask(data, gwy_file_key_image_mask(newid), invmask);
         }
-        title = _(gwy_enum_to_string(output_map[i].output, output_flags, G_N_ELEMENTS(output_flags)));
+        const gchar *title = _(gwy_enum_to_string(output_map[i].output, output_flags, G_N_ELEMENTS(output_flags)));
         gwy_file_set_title(data, GWY_FILE_IMAGE, newid, title, TRUE);
         gwy_log_add(data, GWY_FILE_IMAGE, id, newid);
     }
@@ -422,7 +429,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gtk_dialog_add_button(GTK_DIALOG(dialog), C_("verb", "_Fit"), RESPONSE_FIT);
     gwy_dialog_add_buttons(dialog, GWY_RESPONSE_RESET, GTK_RESPONSE_CANCEL, GTK_RESPONSE_OK, 0);
 
-    gui.dataview = gwy_create_preview(args->field, args->result[0], PREVIEW_SIZE);
+    gui.dataview = gwy_create_preview(args->field, args->marked, PREVIEW_SIZE);
     gwy_setup_data_view(GWY_DATA_VIEW(gui.dataview), data, GWY_FILE_IMAGE, id,
                         GWY_FILE_ITEM_COLOR_MAPPING | GWY_FILE_ITEM_RANGE
                         | GWY_FILE_ITEM_PALETTE | GWY_FILE_ITEM_REAL_SQUARE | GWY_FILE_ITEM_MASK_COLOR);
@@ -447,7 +454,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     if (outcome != GWY_DIALOG_CANCEL && (gwy_params_get_flags(args->params, PARAM_OUTPUT) & OUTPUT_SEGMENTED)) {
         GwyRGBA color = gwy_params_get_color(args->params, PARAM_MASK_COLOR);
-        gwy_container_set_boxed(GWY_CONTAINER(data), GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
+        gwy_dict_set_boxed(GWY_DICT(data), GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
     }
 
     g_object_unref(gui.diff_gradient);
@@ -734,14 +741,13 @@ switch_preview(ModuleGUI *gui)
     PreviewMode display = gwy_params_get_enum(args->params, PARAM_DISPLAY);
     GwyDataView *dataview = GWY_DATA_VIEW(gui->dataview);
 
+    gwy_data_view_set_field(dataview, args->result[display]);
     if (display == PREVIEW_DATA) {
-        gwy_data_view_set_field(dataview, args->field);
-        gwy_data_view_set_mask(dataview, args->result[PREVIEW_DATA]);
+        gwy_data_view_set_mask(dataview, args->marked);
         gwy_setup_data_view(dataview, gui->data, GWY_FILE_IMAGE, gui->id,
                             GWY_FILE_ITEM_COLOR_MAPPING | GWY_FILE_ITEM_RANGE);
     }
     else {
-        gwy_data_view_set_field(dataview, args->result[display]);
         gwy_data_view_set_mask(dataview, NULL);
     }
 
@@ -849,65 +855,54 @@ update_diff_gradient(ModuleGUI *gui)
 {
     gdouble min, max, dispmin, dispmax;
 
-    gwy_field_get_min_max(gui->args->result[PREVIEW_RESIDUUM], &min, &max);
-    gwy_field_get_autorange(gui->args->result[PREVIEW_RESIDUUM], &dispmin, &dispmax);
+    gwy_field_min_max(gui->args->result[PREVIEW_RESIDUUM], &min, &max);
+    gwy_field_autorange(gui->args->result[PREVIEW_RESIDUUM], &dispmin, &dispmax);
     gwy_debug("residuum min %g, max %g", min, max);
     gwy_set_gradient_for_residuals(gui->diff_gradient, min, max, &dispmin, &dispmax);
     gwy_data_view_set_fixed_color_range(GWY_DATA_VIEW(gui->dataview), dispmin, dispmax);
 }
 
 static void
-improve_edge_connectivity(GwyField *steps,
-                          GwyField *tmp,
+improve_edge_connectivity(GwyNield *steps,
+                          GwyNield *tmp,
                           gdouble radius)
 {
-    gint xres, yres, i, r, r2lim;
-    const gdouble *d;
-    gdouble *t;
+    gwy_nield_clear(tmp);
 
-    gwy_field_clear(tmp);
-    xres = gwy_field_get_xres(steps);
-    yres = gwy_field_get_yres(steps);
-    d = gwy_field_get_data_const(steps);
-    t = gwy_field_get_data(tmp);
-    r = (gint)floor(radius);
-    r2lim = (gint)0.7*radius*radius;
+    const gint *d = gwy_nield_get_data_const(steps);
+    gint xres = gwy_nield_get_xres(steps), yres = gwy_nield_get_yres(steps);
+    gint *t = gwy_nield_get_data(tmp);
+    gint r = (gint)floor(radius);
+    gint r2lim = (gint)0.7*radius*radius;
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(xres,yres,r,r2lim,t,d) \
-            private(i)
+            shared(xres,yres,r,r2lim,t,d)
 #endif
-    for (i = r; i < yres-r; i++) {
-        gint j;
-
-        for (j = r; j < xres-r; j++) {
-            gint ii, jj;
-
-            if (d[i*xres + j] <= 0.0)
+    for (gint i = r; i < yres-r; i++) {
+        for (gint j = r; j < xres-r; j++) {
+            if (d[i*xres + j] <= 0)
                 continue;
 
-            for (ii = -r; ii <= r; ii++) {
-                for (jj = -r; jj <= r; jj++) {
-                    if (ii*ii + jj*jj > 0.7*r2lim
-                        && d[(i+ii)*xres + (j+jj)] >= 1.0
-                        && d[(i-ii)*xres + (j-jj)] >= 1.0) {
+            for (gint ii = -r; ii <= r; ii++) {
+                for (gint jj = -r; jj <= r; jj++) {
+                    if (ii*ii + jj*jj > 0.7*r2lim && d[(i+ii)*xres + (j+jj)] > 0 && d[(i-ii)*xres + (j-jj)] > 0) {
                         gint ic = (ii > 0 ? i + ii/2 : i - (-ii)/2);
                         gint jc = (jj > 0 ? j + jj/2 : j - (-jj)/2);
-                        if (d[ic*xres + jc] <= 0.0)
-                            t[ic*xres + jc] += 1.0;
+                        if (d[ic*xres + jc] <= 0)
+                            t[ic*xres + jc] += 1;
                     }
                 }
             }
         }
     }
 
-    gwy_field_max_of_fields(steps, steps, tmp);
+    gwy_nield_union(steps, tmp);
 }
 
 static GArray*
-find_terrace_coordinates(GwyField *field, GwyField *mask, GwyParams *params,
-                         GwyField *marked, GwyField *terraceids,
+find_terrace_coordinates(GwyField *field, GwyNield *mask, GwyParams *params,
+                         GwyNield *marked, GwyNield *terraceids, GwyField *buffer,
                          gdouble *pxc, gdouble *pyc)
 {
     gboolean use_only_mask = gwy_params_get_boolean(params, PARAM_USE_ONLY_MASK);
@@ -918,75 +913,69 @@ find_terrace_coordinates(GwyField *field, GwyField *mask, GwyParams *params,
     gdouble min_area_frac = gwy_params_get_double(params, PARAM_MIN_AREA_FRAC);
     gint xres = gwy_field_get_xres(field);
     gint yres = gwy_field_get_yres(field);
-    gint i, j, g, minsize, ngrains, n = xres*yres, npixels;
-    const gdouble *d = gwy_field_get_data_const(field);
-    gint *grains, *sizes;
+    gint n = xres*yres;
     GArray *terracecoords;
-    gdouble threshold, xc, yc;
-    gdouble *ti;
 
     if (mask && use_only_mask) {
         /* Use provided mask as requested. */
-        gwy_field_copy_data(mask, marked);
+        gwy_nield_copy_data(mask, marked);
         if (masking == GWY_MASK_EXCLUDE)
-            gwy_field_grains_invert(marked);
+            gwy_nield_invert(marked);
     }
     else {
         /* Mark flat areas in the field. */
-        gwy_field_copy_data(field, marked);
-        gwy_field_filter_gauss_step(marked, edge_kernel_size);
-        threshold = edge_threshold*gwy_field_get_max(marked);
-        gwy_field_threshold(marked, threshold, 0.0, 1.0);
+        gwy_field_copy_data(field, buffer);
+        gwy_field_filter_gauss_step(buffer, edge_kernel_size);
+        gdouble threshold = edge_threshold*gwy_field_max(buffer);
+        gwy_nield_mark_by_threshold(marked, buffer, threshold, TRUE);
         /* Use terraceids as a buffer. */
         improve_edge_connectivity(marked, terraceids, 11.5);
         improve_edge_connectivity(marked, terraceids, 9.5);
-        gwy_field_grains_invert(marked);
-        gwy_field_grains_shrink(marked, edge_broadening, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
+        gwy_nield_invert(marked);
+        gwy_nield_shrink(marked, edge_broadening, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
 
         /* Combine with existing mask if required. */
         if (mask && masking != GWY_MASK_IGNORE) {
             if (masking == GWY_MASK_INCLUDE)
-                gwy_field_grains_intersect(marked, mask);
-            else {
-                gwy_field_grains_invert(marked);
-                gwy_field_grains_add(marked, mask);
-                gwy_field_grains_invert(marked);
-            }
+                gwy_nield_intersect(marked, mask);
+            else
+                gwy_nield_merge(marked, mask, GWY_MERGE_SUBTRACT);
         }
     }
 
     /* Keep only large areas.  This inherently limits the maximum number of areas too. */
-    minsize = GWY_ROUND(min_area_frac*n);
-    gwy_field_grains_remove_by_size(marked, minsize);
+    gint minsize = GWY_ROUND(min_area_frac*n);
+    if (!gwy_nield_number_contiguous(marked))
+        return NULL;
+    gwy_nield_clear_by_size(marked, minsize);
+    if (!gwy_nield_number_contiguous(marked))
+        return NULL;
 
     /* Gather coordinates for each terrace into an array. */
-    grains = g_new0(gint, n);
-    ngrains = gwy_field_number_grains(marked, grains);
-    if (!ngrains) {
-        g_free(grains);
-        return NULL;
-    }
-
-    sizes = gwy_field_get_grain_sizes(marked, ngrains, grains, NULL);
+    gint ngrains;
+    gint *sizes = gwy_nield_sizes(marked, &ngrains);
     terracecoords = g_array_sized_new(FALSE, FALSE, sizeof(TerraceCoords), ngrains);
-    for (g = 1; g <= ngrains; g++) {
-        TerraceCoords tc;
-
-        tc.ncoords = 0;
-        tc.xyz = g_new(GwyXYZ, sizes[g]);
-        tc.pixels = g_new(guint, sizes[g]);
+    for (gint g = 1; g <= ngrains; g++) {
+        TerraceCoords tc = {
+            .ncoords = 0,
+            .xyz = g_new(GwyXYZ, sizes[g]),
+            .pixels = g_new(guint, sizes[g]),
+        };
         g_array_append_val(terracecoords, tc);
     }
 
     /* Normalise coordinates to have centre of mass at 0. */
-    ti = gwy_field_get_data(terraceids);
+    const gdouble *d = gwy_field_get_data_const(field);
+    const gint *grains = gwy_nield_get_data_const(marked);
+    gint *ti = gwy_nield_get_data(terraceids);
     gwy_clear(sizes, ngrains+1);
-    xc = yc = 0.0;
-    npixels = 0;
-    for (i = 0; i < yres; i++) {
+    gdouble xc = 0.0, yc = 0.0;
+    guint npixels = 0;
+    for (gint i = 0; i < yres; i++) {
         gdouble y = (2.0*i + 1 - yres)/(yres - 1);
-        for (j = 0; j < xres; j++) {
+        for (gint j = 0; j < xres; j++) {
             guint k = i*xres + j;
+            gint g;
             if ((g = grains[k])) {
                 TerraceCoords *tc = &coord_index(terracecoords, g-1);
                 GwyXYZ *xyz = tc->xyz + tc->ncoords;
@@ -1006,19 +995,18 @@ find_terrace_coordinates(GwyField *field, GwyField *mask, GwyParams *params,
     xc /= npixels;
     yc /= npixels;
 
-    for (g = 0; g < ngrains; g++) {
+    for (gint g = 0; g < ngrains; g++) {
         TerraceCoords *tc = &coord_index(terracecoords, g);
         GwyXYZ *xyz = tc->xyz;
         guint ncoords = tc->ncoords;
 
-        for (i = 0; i < ncoords; i++) {
+        for (guint i = 0; i < ncoords; i++) {
             xyz[i].x -= xc;
             xyz[i].y -= yc;
         }
     }
 
     g_free(sizes);
-    g_free(grains);
 
     *pxc = xc;
     *pyc = yc;
@@ -1548,25 +1536,21 @@ estimate_step_parameters(const gdouble *heights, guint n,
 
 static void
 fill_fitted_image(GwyField *field,
-                  GwyField *marked,
+                  GwyNield *marked,
                   GwyField *residuum,
                   GwyField *fitted)
 {
-    gint xres = gwy_field_get_xres(field);
-    gint yres = gwy_field_get_yres(field);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gint n = xres*yres;
     const gdouble *d = gwy_field_get_data_const(field);
     const gdouble *r = gwy_field_get_data_const(residuum);
-    const gdouble *m = gwy_field_get_data_const(marked);
-    gdouble *f;
-    gint n = xres*yres, k;
-    gdouble avg;
+    const gint *m = gwy_nield_get_data_const(marked);
+    gdouble avg = gwy_field_mean(field);
 
-    avg = gwy_field_get_avg(field);
     gwy_field_fill(fitted, avg);
-
-    f = gwy_field_get_data(fitted);
-    for (k = 0; k < n; k++) {
-        if (m[k] > 0.0)
+    gdouble *f = gwy_field_get_data(fitted);
+    for (gint k = 0; k < n; k++) {
+        if (m[k] > 0)
             f[k] = d[k] - r[k];
     }
 }
@@ -1574,7 +1558,6 @@ fill_fitted_image(GwyField *field,
 static void
 terrace_fit(ModuleGUI *gui)
 {
-    GwyField *marked, *fitted, *residuum, *background, *levelled, *terraces;
     GtkTreeModel *model;
     ModuleArgs *args = gui->args;
     FitResult *fres;
@@ -1586,12 +1569,12 @@ terrace_fit(ModuleGUI *gui)
     gwy_app_wait_cursor_start(GTK_WINDOW(gui->dialog));
     gui->fit_ok = FALSE;
 
-    marked = args->result[PREVIEW_DATA];
-    fitted = args->result[PREVIEW_FITTED];
-    residuum = args->result[PREVIEW_RESIDUUM];
-    terraces = args->result[PREVIEW_TERRACES];
-    levelled = args->result[PREVIEW_LEVELLED];
-    background = args->result[PREVIEW_BACKGROUND];
+    GwyNield *marked = args->marked;
+    GwyField *fitted = args->result[PREVIEW_FITTED];
+    GwyField *residuum = args->result[PREVIEW_RESIDUUM];
+    GwyField *terraces = args->result[PREVIEW_TERRACES];
+    GwyField *levelled = args->result[PREVIEW_LEVELLED];
+    GwyField *background = args->result[PREVIEW_BACKGROUND];
 
     gwy_param_table_set_sensitive(gui->table_param, PARAM_FIT_REPORT_STYLE, FALSE);
     gwy_param_table_set_sensitive(gui->table_terraces, PARAM_TERRACE_REPORT_STYLE, FALSE);
@@ -1631,39 +1614,49 @@ terrace_fit(ModuleGUI *gui)
     gwy_app_wait_cursor_finish(GTK_WINDOW(gui->dialog));
 }
 
+static void
+copy_terraceids_to_field(GwyNield *terraceids, GwyField *field)
+{
+    gsize n = gwy_nield_get_xres(terraceids)*gwy_nield_get_yres(terraceids);
+    const gint *m = gwy_nield_get_data_const(terraceids);
+    gdouble *d = gwy_field_get_data(field);
+    for (gsize i = 0; i < n; i++)
+        d[i] = m[i];
+}
+
 static void
 run_segmentation(gpointer user_data)
 {
     ModuleGUI *gui = (ModuleGUI*)user_data;
     ModuleArgs *args = gui->args;
-    GwyField *marked, *terraceids;
-    GtkTreeModel *model;
-    GArray *terracecoords, *terraceinfo;
-    guint g, nterraces;
 
     gui->fit_ok = FALSE;
     free_terrace_coordinates(gui->terracecoords);
     gui->terracecoords = NULL;
-    terraceinfo = gui->terraceinfo;
 
     gtk_dialog_set_response_sensitive(GTK_DIALOG(gui->dialog), GTK_RESPONSE_OK, FALSE);
 
-    marked = args->result[PREVIEW_DATA];
-    terraceids = args->result[PREVIEW_SEGMENTED];
+    GwyNield *marked = args->marked, *terraceids = args->terraceids;
+    GwyField *terraceids_field = args->result[PREVIEW_SEGMENTED];
 
     gwy_param_table_set_sensitive(gui->table_param, PARAM_FIT_REPORT_STYLE, FALSE);
     gwy_param_table_set_sensitive(gui->table_terraces, PARAM_TERRACE_REPORT_STYLE, FALSE);
-    model = gtk_tree_view_get_model(GTK_TREE_VIEW(gui->terracelist));
+    GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(gui->terracelist));
     gwy_null_store_set_n_rows(GWY_NULL_STORE(model), 0);
+    GArray *terraceinfo = gui->terraceinfo;
     g_array_set_size(terraceinfo, 0);
-    terracecoords = find_terrace_coordinates(args->field, args->mask, args->params,
-                                             marked, terraceids, &gui->xc, &gui->yc);
+    /* Use terraceids_field as a buffer. */
+    GwyField *buffer = terraceids_field;
+    GArray *terracecoords = find_terrace_coordinates(args->field, args->mask, args->params,
+                                                     marked, terraceids, buffer, &gui->xc, &gui->yc);
     gui->terracecoords = terracecoords;
 
     if (terracecoords) {
-        nterraces = terracecoords->len;
+        copy_terraceids_to_field(terraceids, terraceids_field);
+
+        guint nterraces = terracecoords->len;
         gwy_param_table_set_label(gui->table_param, LABEL_FIT_RESULT, "");
-        for (g = 0; g < nterraces; g++) {
+        for (guint g = 0; g < nterraces; g++) {
             TerraceCoords *tc = &coord_index(terracecoords, g);
             TerraceInfo info;
 
@@ -1673,15 +1666,17 @@ run_segmentation(gpointer user_data)
         }
         gwy_null_store_set_n_rows(GWY_NULL_STORE(model), nterraces);
     }
-    else
+    else {
+        gwy_field_clear(terraceids_field);
         gwy_param_table_set_label(gui->table_param, LABEL_FIT_RESULT, _("No terraces were found"));
+    }
 
     gtk_dialog_set_response_sensitive(GTK_DIALOG(gui->dialog), RESPONSE_REFINE, !!terracecoords);
 
     update_results(gui, NULL);
     update_terrace_colours(gui);
-    gwy_field_data_changed(marked);
-    gwy_field_data_changed(terraceids);
+    gwy_nield_data_changed(marked);
+    gwy_field_data_changed(terraceids_field);
     reset_images(gui);
 }
 
@@ -1690,7 +1685,7 @@ update_results(ModuleGUI *gui, FitResult *fres)
 {
     ModuleArgs *args = gui->args;
     GwyResults *results = gui->results;
-    GwyField *mask = args->mask;
+    GwyNield *mask = args->mask;
     GwyMaskingType masking = gwy_params_get_masking(args->params, PARAM_MASKING, &mask);
     gboolean independent = gwy_params_get_boolean(args->params, PARAM_INDEPENDENT);
 
@@ -1734,53 +1729,44 @@ update_terrace_colours(ModuleGUI *gui)
 }
 
 static void
-fill_terraces(GwyField *terraces, GwyField *marked,
+fill_terraces(GwyField *terraces, GwyNield *marked,
               GArray *terracecoords,
               const gdouble *sheights, gboolean independent)
 {
-    GwyField *mask;
-    guint i, g, nterraces, xres, yres, ng;
+    guint nterraces = terracecoords->len;
     gint minlevel = 0;
-    gint *grains;
-    gdouble *d, *zmap;
-
-    nterraces = terracecoords->len;
     if (!independent) {
         minlevel = G_MAXINT;
-        for (g = 0; g < nterraces; g++) {
+        for (guint g = 0; g < nterraces; g++) {
             TerraceCoords *tc = &coord_index(terracecoords, g);
             minlevel = MIN(minlevel, tc->level);
         }
     }
 
-    mask = gwy_field_copy(marked);
-    xres = gwy_field_get_xres(mask);
-    yres = gwy_field_get_yres(mask);
-    gwy_field_grains_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
-    gwy_field_grains_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
-    gwy_field_grains_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
-    gwy_field_grains_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
-
-    grains = g_new0(gint, xres*yres);
-    ng = gwy_field_number_grains(mask, grains);
-    zmap = g_new(gdouble, ng+1);
+    GwyNield *mask = gwy_nield_copy(marked);
+    guint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
+    gwy_nield_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
+    gwy_nield_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
+    gwy_nield_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
+    gwy_nield_grow(mask, 25, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
+    guint ng = gwy_nield_number_contiguous(mask);
+    const gint *grains = gwy_nield_get_data_const(mask);
+    gdouble *zmap = g_new(gdouble, ng+1);
     zmap[0] = 0.0;
 
-    for (g = 0; g < nterraces; g++) {
+    for (guint g = 0; g < nterraces; g++) {
         TerraceCoords *tc = &coord_index(terracecoords, g);
 
-        i = grains[tc->pixels[0]];
+        gint i = grains[tc->pixels[0]];
         zmap[i] = (independent ? sheights[g] : (tc->level+1 - minlevel)*sheights[0]);
     }
 
     gwy_field_clear(terraces);
-    d = gwy_field_get_data(terraces);
-    for (i = 0; i < xres*yres; i++) {
+    gdouble *d = gwy_field_get_data(terraces);
+    for (guint i = 0; i < xres*yres; i++)
         d[i] = zmap[grains[i]];
-    }
-    g_free(grains);
 
-    gwy_field_laplace_solve(terraces, mask, 0, 1.0);
+    gwy_field_laplace_solve(terraces, mask, GWY_LAPLACE_UNMASKED, 1.0);
     g_object_unref(mask);
 }
 
@@ -1831,7 +1817,7 @@ static gboolean
 analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
                  const gdouble *heights, gdouble sheight)
 {
-    guint xres, yres, nterraces, g, gg, i, j, k, kk, nreached;
+    guint xres, yres, nterraces, i, j, kk, nreached;
     gdouble edge_kernel_size = gwy_params_get_double(params, PARAM_EDGE_KERNEL_SIZE);
     gdouble edge_broadening = gwy_params_get_double(params, PARAM_EDGE_BROADENING);
     gint maxdist2, ldiff;
@@ -1846,21 +1832,21 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
 
     /* Find boundary pixels of all terraces. */
     ids = g_new0(guint, xres*yres);
-    for (g = 0; g < nterraces; g++) {
+    for (guint g = 0; g < nterraces; g++) {
         TerraceCoords *tc = &coord_index(terracecoords, g);
         guint ncoords = tc->ncoords;
 
-        for (k = 0; k < ncoords; k++)
+        for (guint k = 0; k < ncoords; k++)
             ids[tc->pixels[k]] = g+1;
     }
 
     boundaries = g_new0(GArray*, nterraces);
-    for (g = 0; g < nterraces; g++) {
+    for (guint g = 0; g < nterraces; g++) {
         TerraceCoords *tc = &coord_index(terracecoords, g);
         guint ncoords = tc->ncoords;
 
         boundaries[g] = g_array_new(FALSE, FALSE, sizeof(guint));
-        for (k = 0; k < ncoords; k++) {
+        for (guint k = 0; k < ncoords; k++) {
             kk = tc->pixels[k];
             i = kk/xres;
             j = kk % xres;
@@ -1883,32 +1869,24 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
     neighcounts = g_new0(guint, nterraces*nterraces);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(nterraces,boundaries,maxdist2,neighcounts) \
-            private(k,g,gg)
+            shared(nterraces,boundaries,maxdist2,neighcounts)
 #endif
-    for (k = 0; k < (nterraces-1)*nterraces/2; k++) {
-        guint nb, nb2, ib, ib2, n;
-        guint *b, *b2;
+    for (guint k = 0; k < (nterraces-1)*nterraces/2; k++) {
+        guint g = (guint)floor(0.5*(sqrt(8*k+1) + 1) + 0.00001);
+        guint gg = k - g*(g-1)/2;
 
-        g = (guint)floor(0.5*(sqrt(8*k+1) + 1) + 0.00001);
-        gg = k - g*(g-1)/2;
+        guint nb = boundaries[g]->len/2;
+        guint nb2 = boundaries[gg]->len/2;
+        guint *b = &g_array_index(boundaries[g], guint, 0);
+        guint n = 0;
 
-        nb = boundaries[g]->len/2;
-        nb2 = boundaries[gg]->len/2;
-        b = &g_array_index(boundaries[g], guint, 0);
-        n = 0;
-
-        for (ib = 0; ib < nb; ib++) {
-            gint xb1, yb1;
-
-            yb1 = *(b++);
-            xb1 = *(b++);
-            b2 = &g_array_index(boundaries[gg], guint, 0);
-            for (ib2 = 0; ib2 < nb2; ib2++) {
-                gint dxb2, dyb2;
-
-                dyb2 = *(b2++) - yb1;
-                dxb2 = *(b2++) - xb1;
+        for (guint ib = 0; ib < nb; ib++) {
+            gint yb1 = *(b++);
+            gint xb1 = *(b++);
+            guint *b2 = &g_array_index(boundaries[gg], guint, 0);
+            for (guint ib2 = 0; ib2 < nb2; ib2++) {
+                gint dyb2 = *(b2++) - yb1;
+                gint dxb2 = *(b2++) - xb1;
 
                 if (dxb2*dxb2 + dyb2*dyb2 <= maxdist2)
                     n++;
@@ -1920,15 +1898,15 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
         neighcounts[g*nterraces + gg] = neighcounts[gg*nterraces + g] = n;
     }
 
-    for (g = 0; g < nterraces; g++)
+    for (guint g = 0; g < nterraces; g++)
         g_array_free(boundaries[g], TRUE);
     g_free(boundaries);
 
     /* Here comes the difficult part.  Make a consistent guess which terrace
      * is at what level based on relations to neighbours. */
     neighter = g_new0(guint, nterraces);
-    for (g = 0; g < nterraces; g++) {
-        for (gg = 0; gg < nterraces; gg++) {
+    for (guint g = 0; g < nterraces; g++) {
+        for (guint gg = 0; gg < nterraces; gg++) {
             if (neighcounts[g*nterraces + gg]) {
                 neighter[g]++;
                 gwy_debug("%u and %u are neighbours (%u), level diff %d (%g nm)",
@@ -1939,9 +1917,8 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
     }
 
     /* Find a terrace with the most neighbours. */
-    g = 0;
-    k = 0;
-    for (gg = 0; gg < nterraces; gg++) {
+    guint g = 0, k = 0;
+    for (guint gg = 0; gg < nterraces; gg++) {
         if (neighter[gg] > k) {
             k = neighter[gg];
             g = gg;
@@ -1963,7 +1940,7 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
 
         for (g = 0; g < nterraces; g++) {
             TerraceCoords *tc = &coord_index(terracecoords, g);
-            for (gg = 0; gg < nterraces; gg++) {
+            for (guint gg = 0; gg < nterraces; gg++) {
                 TerraceCoords *tc2 = &coord_index(terracecoords, gg);
 
                 if (!reached[g] || reached[gg] || !neighcounts[g*nterraces + gg])
@@ -1987,7 +1964,7 @@ analyse_topology(GArray *terracecoords, GwyParams *params, GwyField *terraces,
 
         for (g = 0; g < nterraces; g++) {
             TerraceCoords *tc = &coord_index(terracecoords, g);
-            for (gg = 0; gg < nterraces; gg++) {
+            for (guint gg = 0; gg < nterraces; gg++) {
                 TerraceCoords *tc2 = &coord_index(terracecoords, gg);
 
                 if (!reached[g] || !reached[gg] || !neighcounts[g*nterraces + gg])
@@ -2015,7 +1992,7 @@ fail:
 }
 
 static FitResult*
-terrace_do(GwyField *marked, GwyField *residuum,
+terrace_do(GwyNield *marked, GwyField *residuum,
            GwyField *background, GwyField *terraces,
            GArray *terracecoords, GArray *terraceinfo,
            GwyParams *params,
@@ -2189,36 +2166,37 @@ static void
 run_survey(ModuleGUI *gui)
 {
     ModuleArgs *args = gui->args;
-    GwyField *marked, *residuum, *terraces, *terraceids, *field = args->field, *mask = args->mask;
+    GwyField *field = args->field;
+    GwyNield *mask = args->mask;
     GwyParams *surveyparams = gwy_params_duplicate(args->params);
     GwyResultsReportType report_style = gwy_params_get_report_type(args->params, PARAM_TERRACE_REPORT_STYLE);
-    GArray *terracecoords = NULL, *degrees, *broadenings, *terraceinfo, *surveyout;
-    guint i, w, ndegrees, nbroadenings, totalwork;
     const gchar *message;
     FitResult *fres;
-    GString *str;
     gdouble xc, yc;
 
     report_style |= GWY_RESULTS_REPORT_MACHINE;
-    marked = gwy_field_new_alike(field, FALSE);
-    terraceids = gwy_field_new_alike(field, FALSE);
-    residuum = gwy_field_new_alike(field, FALSE);
-    terraces = gwy_field_new_alike(field, FALSE);
+    GwyNield *marked = gwy_field_new_nield_alike(field);
+    GwyNield *terraceids = gwy_field_new_nield_alike(field);
+    GwyField *residuum = gwy_field_new_alike(field, FALSE);
+    GwyField *terraces = gwy_field_new_alike(field, FALSE);
+    GwyField *buffer = gwy_field_new_alike(field, FALSE);
 
-    terraceinfo = g_array_new(FALSE, FALSE, sizeof(TerraceInfo));
+    GArray *terraceinfo = g_array_new(FALSE, FALSE, sizeof(TerraceInfo));
     g_array_append_vals(terraceinfo, gui->terraceinfo->data, gui->terraceinfo->len);
-    surveyout = g_array_new(FALSE, FALSE, sizeof(TerraceSurveyRow));
+    GArray *surveyout = g_array_new(FALSE, FALSE, sizeof(TerraceSurveyRow));
 
-    degrees = g_array_new(FALSE, FALSE, sizeof(gint));
-    broadenings = g_array_new(FALSE, FALSE, sizeof(gdouble));
-    totalwork = prepare_survey(args->params, degrees, broadenings);
-    ndegrees = degrees->len;
-    nbroadenings = broadenings->len;
+    GArray *degrees = g_array_new(FALSE, FALSE, sizeof(gint));
+    GArray *broadenings = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    GArray *terracecoords = NULL;
+    guint totalwork = prepare_survey(args->params, degrees, broadenings);
+    guint ndegrees = degrees->len;
+    guint nbroadenings = broadenings->len;
 
     gwy_app_wait_start(GTK_WINDOW(gui->dialog), _("Fitting in progress..."));
 
     /* We only want to re-run segmentation when broadening changes.  This means we must have broadening (or any other
      * segmentation parameter) in the outer cycle and polynomial degree as the inner cycle! */
+    guint w;
     for (w = 0; w < totalwork; w++) {
         TerraceSurveyRow srow;
 
@@ -2226,7 +2204,7 @@ run_survey(ModuleGUI *gui)
         gwy_params_set_double(surveyparams, PARAM_EDGE_BROADENING, g_array_index(broadenings, gdouble, w/ndegrees));
         if (w/nbroadenings != (w-1)/nbroadenings) {
             free_terrace_coordinates(terracecoords);
-            terracecoords = find_terrace_coordinates(field, mask, surveyparams, marked, terraceids, &xc, &yc);
+            terracecoords = find_terrace_coordinates(field, mask, surveyparams, marked, terraceids, buffer, &xc, &yc);
         }
         fres = terrace_do(marked, residuum, NULL, terraces, terracecoords, terraceinfo, surveyparams, xc, yc, FALSE,
                           &message);
@@ -2262,6 +2240,7 @@ run_survey(ModuleGUI *gui)
     g_object_unref(residuum);
     g_object_unref(marked);
     g_object_unref(terraceids);
+    g_object_unref(buffer);
     g_object_unref(surveyparams);
 
     if (w != totalwork) {
@@ -2269,12 +2248,12 @@ run_survey(ModuleGUI *gui)
         return;
     }
 
-    str = g_string_new(NULL);
+    GString *str = g_string_new(NULL);
     gwy_format_result_table_strings(str, report_style, 11,
                                     "Poly degree", "Edge kernel size", "Edge threshold", "Edge broadening",
                                     "Min area frac", "Fit OK", "Num terraces", "Step height", "Step height err",
                                     "Msq residual", "Discrepancy");
-    for (i = 0; i < surveyout->len; i++) {
+    for (guint i = 0; i < surveyout->len; i++) {
         TerraceSurveyRow *srow = &g_array_index(surveyout, TerraceSurveyRow, i);
         gwy_format_result_table_mixed(str, report_style, "ivvvvyivvvv",
                                       srow->poly_degree,
