@@ -1,5 +1,5 @@
 /*
- *  $Id: threshold.c 29068 2026-01-02 16:17:44Z yeti-dn $
+ *  $Id: threshold.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2010-2021 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -153,24 +153,24 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(field);
 
     args.field = field;
-    gwy_field_get_min_max(field, &args.min, &args.max);
-    args.avg = gwy_field_get_avg(field);
-    args.rms = gwy_field_get_rms(field);
+    gwy_field_min_max(field, &args.min, &args.max);
+    args.avg = gwy_field_mean(field);
+    args.rms = gwy_field_rms(field);
     find_out_display_range(data, id, field, &args.disp_min, &args.disp_max);
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         args.result = gwy_field_new_alike(field, TRUE);
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome != GWY_DIALOG_HAVE_RESULT)
             goto end;
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         gwy_field_copy_data(args.result, field);
     }
     else {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         args.result = g_object_ref(field);
         execute(&args, NULL);
     }
@@ -312,18 +312,18 @@ find_out_display_range(GwyFile *data, gint id, GwyField *field,
                        gdouble *disp_min, gdouble *disp_max)
 {
     GwyColorMappingType color_mapping = GWY_COLOR_MAPPING_FULL;
-    GwyContainer *container = GWY_CONTAINER(data);
+    GwyDict *container = GWY_DICT(data);
 
-    gwy_container_gis_enum(container, gwy_file_key_image_color_mapping(id), &color_mapping);
+    gwy_dict_gis_enum(container, gwy_file_key_image_color_mapping(id), &color_mapping);
     if (color_mapping == GWY_COLOR_MAPPING_FULL || color_mapping == GWY_COLOR_MAPPING_ADAPT)
-        gwy_field_get_min_max(field, disp_min, disp_max);
+        gwy_field_min_max(field, disp_min, disp_max);
     else if (color_mapping == GWY_COLOR_MAPPING_FIXED) {
-        gwy_field_get_min_max(field, disp_min, disp_max);
-        gwy_container_gis_double(container, gwy_file_key_image_range_min(id), disp_min);
-        gwy_container_gis_double(container, gwy_file_key_image_range_max(id), disp_max);
+        gwy_field_min_max(field, disp_min, disp_max);
+        gwy_dict_gis_double(container, gwy_file_key_image_range_min(id), disp_min);
+        gwy_dict_gis_double(container, gwy_file_key_image_range_max(id), disp_max);
     }
     else if (color_mapping == GWY_COLOR_MAPPING_AUTO)
-        gwy_field_get_autorange(field, disp_min, disp_max);
+        gwy_field_autorange(field, disp_min, disp_max);
     else {
         g_assert_not_reached();
     }
