@@ -1,5 +1,5 @@
 /*
- *  $Id: tilt.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: tilt.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2008-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -128,7 +128,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
