@@ -1,5 +1,5 @@
 /*
- *  $Id: tip_blind.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: tip_blind.c 29506 2026-02-19 17:25:08Z yeti-dn $
  *  Copyright (C) 2004-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -63,13 +63,12 @@ typedef struct {
     GwyParamTable *table;
 } ModuleGUI;
 
-typedef GwyField* (*TipFunc)(GwyField *tip,
-                             GwyField *surface,
-                             gdouble threshold,
-                             gboolean use_edges,
-                             gint *count,
-                             GwySetFractionFunc set_fraction,
-                             GwySetMessageFunc set_message);
+typedef gint (*TipFunc)(GwyField *field,
+                        GwyField *tip,
+                        gdouble threshold,
+                        gboolean use_edges,
+                        GwySetFractionFunc set_fraction,
+                        GwySetMessageFunc set_message);
 
 static gboolean         module_register     (void);
 static GwyParamDef*     define_module_params(void);
@@ -169,7 +168,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_clear1(args);
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
-                                 GWY_APP_CONTAINER_ID, &dataid.datano,
+                                 GWY_APP_FILE_ID, &dataid.datano,
                                  0);
     g_return_if_fail(args.field);
 
@@ -287,7 +286,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gwy_param_table_append_header(table, -1, _("Options"));
     gwy_param_table_append_slider(table, PARAM_THRESHOLD);
     gwy_param_table_slider_set_mapping(table, PARAM_THRESHOLD, GWY_SCALE_MAPPING_LOG);
-    rms = gwy_field_get_rms(args->field);
+    rms = gwy_field_rms(args->field);
     vf = gwy_unit_get_format(gwy_field_get_unit_z(args->field), GWY_UNIT_FORMAT_VFMARKUP, 1e-3*rms, NULL);
     vf->precision++;
     gwy_param_table_slider_set_factor(table, PARAM_THRESHOLD, 1.0/vf->magnitude);
@@ -448,9 +447,9 @@ execute(ModuleArgs *args, gboolean full, GtkWindow *wait_window)
     gboolean use_boundaries = gwy_params_get_boolean(params, PARAM_USE_BOUNDARIES);
     gboolean split_to_stripes = gwy_params_get_boolean(params, PARAM_SPLIT_TO_STRIPES);
     gint nstripes = (split_to_stripes ? gwy_params_get_int(params, PARAM_NSTRIPES) : 0);
-    TipFunc tipfunc = full ? gwy_tip_estimate_full : gwy_tip_estimate_partial;
-    gboolean keep, ok;
-    gint count = -1;
+    TipFunc tipfunc = full ? gwy_field_tip_estimate_full : gwy_field_tip_estimate_partial;
+    gboolean keep;
+    gint status = -1;
 
     gwy_app_wait_start(wait_window, _("Initializing..."));
 
@@ -477,16 +476,15 @@ execute(ModuleArgs *args, gboolean full, GtkWindow *wait_window)
                 continue;
 
             gwy_debug("[%u] (%u, %u) of %u", i, row, height, yres);
-            count = -1;
             stripe = gwy_field_area_extract(surface, 0, row, xres, height);
-            ok = !!tipfunc(args->stripetips[i], stripe, threshold, use_boundaries, &count,
-                           gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+            status = tipfunc(stripe, args->stripetips[i], threshold, use_boundaries,
+                             gwy_app_wait_set_fraction, gwy_app_wait_set_message);
             g_object_unref(stripe);
             /* Cancelled by user */
-            if (!ok)
+            if (status < 0)
                 break;
-            args->goodtips[i] = ok && count > 0;
-            gwy_debug("[%u] count = %d", i, count);
+            args->goodtips[i] = status > 0;
+            gwy_debug("[%u] status = %d", i, status);
             anygood += args->goodtips[i];
         }
         if (i < nstripes) {
@@ -494,18 +492,16 @@ execute(ModuleArgs *args, gboolean full, GtkWindow *wait_window)
             anygood = 0;
             gwy_clear(args->goodtips, nstripes);
         }
-        if ((ok = anygood > 0))
+        if ((status = anygood > 0))
             size_plot(args);
     }
     else {
-        ok = (tipfunc(tip, surface, threshold, use_boundaries, &count,
-                      gwy_app_wait_set_fraction, gwy_app_wait_set_message)
-              && count > 0);
-        gwy_debug("count = %d", count);
+        status = tipfunc(surface, tip, threshold, use_boundaries, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+        gwy_debug("status = %d", status);
     }
     gwy_app_wait_finish();
 
-    return ok;
+    return status > 0;
 }
 
 static void
