@@ -1,5 +1,5 @@
 /*
- *  $Id: tip_model.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: tip_model.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2004-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -270,7 +270,7 @@ fill_tip_params(ModuleArgs *args, gdouble *zrange)
     gdouble *values;
     gdouble min, max;
 
-    gwy_field_get_min_max(args->field, &min, &max);
+    gwy_field_min_max(args->field, &min, &max);
     *zrange = max - min;
 
     g_return_val_if_fail(model, NULL);
