@@ -1,6 +1,6 @@
 /*
- *  $Id: tipops.c 28821 2025-11-06 16:00:41Z yeti-dn $
- *  Copyright (C) 2004-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: tipops.c 29541 2026-02-24 14:02:16Z yeti-dn $
+ *  Copyright (C) 2004-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -37,7 +37,7 @@ enum {
 typedef struct {
     GwyParams *params;
     GwyField *field;
-    GwyField *result;
+    GObject *result;
 } ModuleArgs;
 
 typedef struct {
@@ -66,7 +66,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Tip operations: dilation (convolution), erosion (reconstruction) and certainty map."),
     "Petr Klapetek <klapetek@gwyddion.net>, Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -155,7 +155,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         goto end;
 
     if (op == DILATION || op == EROSION) {
-        newid = gwy_file_add_image(data, args.result);
+        newid = gwy_file_add_image(data, GWY_FIELD(args.result));
         gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
         gwy_file_sync_items(data, GWY_FILE_IMAGE, id,
                             data, GWY_FILE_IMAGE, newid,
@@ -166,8 +166,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
     else {
         quark = gwy_file_key_image_mask(id);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
-        gwy_file_set_image(data, id, args.result);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
+        gwy_file_set_image_mask(data, id, GWY_NIELD(args.result));
         gwy_log_add(data, GWY_FILE_IMAGE, id, id);
     }
 
@@ -211,13 +211,33 @@ tip_image_filter(GwyFile *data, gint id, gpointer user_data)
     GwyField *field = (GwyField*)user_data;
     GwyField *tip = gwy_file_get_image(data, id);
 
-    if (gwy_field_get_xreal(tip) > gwy_field_get_xreal(field)/4
-        || gwy_field_get_yreal(tip) > gwy_field_get_yreal(field)/4)
+    if (gwy_field_get_xreal(tip) > gwy_field_get_xreal(field)/3
+        || gwy_field_get_yreal(tip) > gwy_field_get_yreal(field)/3)
         return FALSE;
 
     return !gwy_field_is_incompatible(tip, field, GWY_DATA_MISMATCH_LATERAL | GWY_DATA_MISMATCH_VALUE);
 }
 
+static gboolean
+tip_needs_resampling(GwyField *surface, GwyField *tip, gint *newxres, gint *newyres)
+{
+    if (gwy_field_is_incompatible(tip, surface, GWY_DATA_MISMATCH_MEASURE)) {
+        *newxres = gwy_field_get_xres(tip);
+        *newyres = gwy_field_get_yres(tip);
+        return FALSE;
+    }
+
+    *newxres = GWY_ROUND(gwy_field_get_xreal(tip)/gwy_field_get_dx(surface));
+    *newxres = MAX(*newxres, 1);
+
+    *newyres = GWY_ROUND(gwy_field_get_yreal(tip)/gwy_field_get_dy(surface));
+    *newyres = MAX(*newyres, 1);
+
+    // Return FALSE in stupid edge cases like 1×1 tips or when the mismatch is so small that resampling does not
+    // change the pixel size.
+    return (*newxres != gwy_field_get_xres(tip) || *newyres != gwy_field_get_yres(tip));
+}
+
 static void
 param_changed(ModuleGUI *gui, gint id)
 {
@@ -229,22 +249,17 @@ param_changed(ModuleGUI *gui, gint id)
             gtk_dialog_set_response_sensitive(GTK_DIALOG(gui->dialog), GTK_RESPONSE_OK, FALSE);
         else {
             GwyField *tip = gwy_params_get_image(params, PARAM_TIP), *field = args->field;
+            gint txres, tyres;
 
-            if (!gwy_field_is_incompatible(tip, field, GWY_DATA_MISMATCH_MEASURE))
-                gwy_param_table_set_label(gui->table, MESSAGE_RESAMPLING, NULL);
-            else {
-                gint xres = GWY_ROUND(gwy_field_get_xreal(tip)/gwy_field_get_dx(field));
-                gint yres = GWY_ROUND(gwy_field_get_yreal(tip)/gwy_field_get_dy(field));
-                gchar *s;
-
-                xres = MAX(xres, 1);
-                yres = MAX(yres, 1);
-                s = g_strdup_printf(_("Tip pixel size does not match data.\n"
-                                      "It will be resampled from %d×%d to %d×%d."),
-                                    gwy_field_get_xres(tip), gwy_field_get_yres(tip), xres, yres);
+            if (tip_needs_resampling(field, tip, &txres, &tyres)) {
+                gchar *s = g_strdup_printf(_("Tip pixel size does not match data.\n"
+                                             "It will be resampled from %d×%d to %d×%d."),
+                                           gwy_field_get_xres(tip), gwy_field_get_yres(tip), txres, tyres);
                 gwy_param_table_set_label(gui->table, MESSAGE_RESAMPLING, s);
                 g_free(s);
             }
+            else
+                gwy_param_table_set_label(gui->table, MESSAGE_RESAMPLING, NULL);
         }
     }
 }
@@ -252,24 +267,41 @@ param_changed(ModuleGUI *gui, gint id)
 static gboolean
 execute(ModuleArgs *args, TipOperation op, GtkWindow *wait_window)
 {
-    GwyField *field = args->field, *result, *tip = gwy_params_get_image(args->params, PARAM_TIP);
+    GwyField *field = args->field, *tip = gwy_params_get_image(args->params, PARAM_TIP);
     gboolean ok = FALSE;
 
     g_return_val_if_fail(tip, FALSE);
-    result = args->result = gwy_field_new_alike(field, FALSE);
 
     gwy_app_wait_start(wait_window, _("Initializing..."));
-    if (op == DILATION)
-        ok = !!gwy_tip_dilation(tip, field, result, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
-    else if (op == EROSION)
-        ok = !!gwy_tip_erosion(tip, field, result, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
-    else if (op == CERTAINTY_MAP)
-        ok = !!gwy_tip_cmap(tip, field, result, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+
+    gint txres, tyres;
+    if (tip_needs_resampling(field, tip, &txres, &tyres))
+        tip = gwy_field_new_resampled(tip, txres, tyres, GWY_INTERPOLATION_BSPLINE);
+    else
+        g_object_ref(tip);
+
+    if (op == DILATION) {
+        GwyField *result = gwy_field_new_alike(field, FALSE);
+        args->result = G_OBJECT(result);
+        ok = gwy_field_tip_dilation(field, tip, result, TRUE, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+    }
+    else if (op == EROSION) {
+        GwyField *result = gwy_field_new_alike(field, FALSE);
+        args->result = G_OBJECT(result);
+        ok = gwy_field_tip_erosion(field, tip, result, TRUE, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+    }
+    else if (op == CERTAINTY_MAP) {
+        GwyNield *result = gwy_field_new_nield_alike(field);
+        args->result = G_OBJECT(result);
+        ok = gwy_field_tip_certainty_map(field, tip, result, TRUE, gwy_app_wait_set_fraction, gwy_app_wait_set_message);
+    }
     else {
         g_assert_not_reached();
     }
     gwy_app_wait_finish();
 
+    g_object_unref(tip);
+
     return ok;
 }
 
