@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tipshape.c 28945 2025-12-03 10:10:57Z yeti-dn $
+ *  @(#) $Id: tipshape.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2018-2021 David Necas (Yeti), Anna Charvatova Campbell
  *  E-mail: yeti@gwyddion.net, acampbellova@cmi.cz
  *
@@ -129,7 +129,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -168,7 +168,7 @@ run_gui(ModuleArgs *args)
 
     dx = gwy_field_get_dx(args->field);
     dy = gwy_field_get_dy(args->field);
-    gwy_field_get_min_max(args->field, &zmin, &zmax);
+    gwy_field_min_max(args->field, &zmin, &zmax);
 
     unit = gwy_field_get_unit_xy(args->field);
     vfxy = gwy_unit_get_format_with_digits(unit, GWY_UNIT_FORMAT_VFMARKUP, 5.0*fmax(dx, dy), 5, NULL);
@@ -328,7 +328,7 @@ tipshape_calc(ModuleArgs *args, GwyLine *line, GwyLine *uline)
     n = gwy_field_get_xres(args->field) * gwy_field_get_yres(args->field);
     dx = gwy_field_get_dx(args->field);
     dy = gwy_field_get_dy(args->field);
-    zmax = gwy_field_get_max(args->field);
+    zmax = gwy_field_max(args->field);
 
     gwy_line_resize(line, rangeres);
     gwy_line_clear(line);
@@ -384,10 +384,10 @@ get_zedge_max(GwyField *field)
     xres = gwy_field_get_xres(field);
     yres = gwy_field_get_yres(field);
 
-    ztop = gwy_field_area_get_max(field, NULL, GWY_MASK_IGNORE, 0, 0, xres, 1);
-    zleft = gwy_field_area_get_max(field, NULL, GWY_MASK_IGNORE, 0, 0, 1, yres);
-    zright = gwy_field_area_get_max(field, NULL, GWY_MASK_IGNORE, xres-1, 0, 1, yres);
-    zbot = gwy_field_area_get_max(field, NULL, GWY_MASK_IGNORE, 0, yres-1, xres, 1);
+    ztop = gwy_field_area_max(field, NULL, GWY_MASK_IGNORE, 0, 0, xres, 1);
+    zleft = gwy_field_area_max(field, NULL, GWY_MASK_IGNORE, 0, 0, 1, yres);
+    zright = gwy_field_area_max(field, NULL, GWY_MASK_IGNORE, xres-1, 0, 1, yres);
+    zbot = gwy_field_area_max(field, NULL, GWY_MASK_IGNORE, 0, yres-1, xres, 1);
 
     return fmax(fmax(ztop, zbot), fmax(zleft, zright));
 }
