@@ -1,5 +1,5 @@
 /*
- *  $Id: volumize.c 28861 2025-11-14 13:02:11Z yeti-dn $
+ *  $Id: volumize.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2015-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -110,8 +110,8 @@ create_brick_from_field(GwyField *dfield)
 
     xreal = gwy_field_get_xreal(dfield);
     yreal = gwy_field_get_yreal(dfield);
-    offset = gwy_field_get_min(lowres);
-    zreal = gwy_field_get_max(lowres) - offset;
+    offset = gwy_field_min(lowres);
+    zreal = gwy_field_max(lowres) - offset;
 
     brick = gwy_brick_new(xres, yres, zres, xreal, yreal, zreal, TRUE);
 
