@@ -1,6 +1,6 @@
 /*
- *  $Id: wpour_mark.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2014-2021 David Necas (Yeti).
+ *  $Id: wpour_mark.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2014-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -62,8 +62,8 @@ typedef struct {
     GwyParams *params;
     GwyField *field;
     GwyField *preproc;
-    GwyField *mask;
-    GwyField *result;
+    GwyNield *mask;
+    GwyNield *result;
 } ModuleArgs;
 
 typedef struct {
@@ -84,8 +84,7 @@ static GwyDialogOutcome run_gui                 (ModuleArgs *args,
 static void             param_changed           (ModuleGUI *gui,
                                                  gint id);
 static void             preview                 (gpointer user_data);
-static void             add_slope_contribs      (GwyField *workspace,
-                                                 GwyField *field,
+static void             add_slope_contribs      (GwyField *field,
                                                  gdouble gradient_contrib,
                                                  gdouble curvature_contrib);
 static void             normal_vector_difference(GwyField *result,
@@ -94,7 +93,6 @@ static void             normal_vector_difference(GwyField *result,
 static gdouble          create_barriers         (GwyField *field,
                                                  gdouble level);
 static void             prefill_minima          (GwyField *field,
-                                                 GwyField *workspace,
                                                  IntList *inqueue,
                                                  IntList *outqueue,
                                                  gdouble depth,
@@ -108,7 +106,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Segments image using watershed with pre- and postprocessing."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2014",
 };
@@ -181,12 +179,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  0);
     g_return_if_fail(args.field && mquark);
 
-    args.result = gwy_field_new_alike(args.field, TRUE);
-    gwy_unit_clear(gwy_field_get_unit_z(args.result));
+    args.result = gwy_field_new_nield_alike(args.field);
     args.preproc = gwy_field_new_alike(args.field, TRUE);
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -195,13 +192,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &mquark);
-    if (gwy_field_get_max(args.result) > 0.0) {
-        gwy_file_pass_image_mask(data, id, args.result);
-        args.result = NULL;
-    }
-    else
-        gwy_container_remove(GWY_CONTAINER(data), mquark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &mquark);
+    gint ngrains = gwy_nield_number_contiguous(args.result);
+    gwy_file_set_image_mask(data, id, ngrains ? args.result : NULL);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -293,7 +286,7 @@ preview(gpointer user_data)
 
     execute(args);
     gwy_field_data_changed(args->preproc);
-    gwy_field_data_changed(args->result);
+    gwy_nield_data_changed(args->result);
     gwy_dialog_have_result(GWY_DIALOG(gui->dialog));
 }
 
@@ -348,7 +341,8 @@ int_list_free(IntList *list)
 static void
 execute(ModuleArgs *args)
 {
-    GwyField *result = args->result, *field = args->field, *preproc = args->preproc, *mask = args->mask;
+    GwyField *field = args->field, *preproc = args->preproc;
+    GwyNield *result = args->result, *mask = args->mask;
     GwyParams *params = args->params;
     gboolean combine = gwy_params_get_boolean(params, PARAM_COMBINE);
     GwyMergeType combine_type = gwy_params_get_enum(params, PARAM_COMBINE_TYPE);
@@ -361,72 +355,62 @@ execute(ModuleArgs *args)
     gdouble prefill_height = gwy_params_get_double(params, PARAM_PREFILL_HEIGHT);
     IntList *inqueue = int_list_new(0);
     IntList *outqueue = int_list_new(0);
-    guint xres, yres;
-    gdouble barmax;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
 
     gwy_field_copy_data(field, preproc);
     if (inverted)
         gwy_field_invert_value(preproc);
 
-    /* Use result as a scratch buffer. */
-    gwy_field_add(preproc, -gwy_field_get_max(preproc));
+    gwy_field_add(preproc, -gwy_field_max(preproc));
     if (blur_fwhm)
         gwy_field_area_filter_gaussian(preproc, blur_fwhm*FWHM2SIGMA, 0, 0, xres, yres);
-    add_slope_contribs(result, preproc, gradient_contrib, curvature_contrib);
-    barmax = create_barriers(preproc, barrier_level);
-    prefill_minima(preproc, result, inqueue, outqueue, prefill_level, prefill_height);
+
+    add_slope_contribs(preproc, gradient_contrib, curvature_contrib);
+    gdouble barmax = create_barriers(preproc, barrier_level);
+    prefill_minima(preproc, inqueue, outqueue, prefill_level, prefill_height);
 
     replace_value(preproc, barmax, HUGE_VAL);
-    gwy_field_waterpour(preproc, result, NULL);
+    gwy_field_waterpour(preproc, result);
     /* Lower the barriers again to avoid HUGE_VAL in the preview. */
     replace_value(preproc, HUGE_VAL, barmax);
 
     int_list_free(outqueue);
     int_list_free(inqueue);
 
-    if (mask && combine) {
-        if (combine_type == GWY_MERGE_UNION)
-            gwy_field_grains_add(result, mask);
-        else if (combine_type == GWY_MERGE_INTERSECTION)
-            gwy_field_grains_intersect(result, mask);
-    }
+    if (combine)
+        gwy_nield_merge(result, mask, combine_type);
 
 #if 0
     /* FIXME: neither grains nor gnetwork used for anything at this moment. */
-    grains = g_new0(gint, xres*yres);
-    ngrains = gwy_field_number_grains(result, grains);
-    gnetwork = analyse_grain_network(preproc, grains);
-    g_free(grains);
+    ngrains = gwy_nield_number_contiguous(result);
+    gnetwork = analyse_grain_network(preproc, result);
     g_hash_table_destroy(gnetwork);
 #endif
 }
 
 static void
-add_slope_contribs(GwyField *workspace, GwyField *field,
+add_slope_contribs(GwyField *field,
                    gdouble gradient_contrib, gdouble curvature_contrib)
 {
-    GwyField *xder, *yder;
     gdouble r, rg, rc;
 
     if (!gradient_contrib && !curvature_contrib)
         return;
 
-    r = gwy_field_get_rms(field);
+    r = gwy_field_rms(field);
     if (!r)
         return;
 
-    xder = gwy_field_new_alike(field, FALSE);
-    yder = gwy_field_new_alike(field, FALSE);
+    GwyField *workspace = gwy_field_new_alike(field, FALSE);
+    GwyField *xder = gwy_field_new_alike(field, FALSE);
+    GwyField *yder = gwy_field_new_alike(field, FALSE);
 
     gwy_field_filter_slope(field, xder, yder);
     gwy_field_multiply(field, 1.0 - MAX(gradient_contrib, curvature_contrib));
 
     /* We need this for both operations. */
     gwy_field_hypot_of_fields(workspace, xder, yder);
-    rg = gwy_field_get_rms(workspace);
+    rg = gwy_field_rms(workspace);
 
     if (gradient_contrib) {
         gwy_field_multiply(workspace, gradient_contrib * r/rg);
@@ -437,7 +421,7 @@ add_slope_contribs(GwyField *workspace, GwyField *field,
         gwy_field_multiply(xder, 1.0/rg);
         gwy_field_multiply(yder, 1.0/rg);
         normal_vector_difference(workspace, xder, yder);
-        rc = gwy_field_get_rms(workspace);
+        rc = gwy_field_rms(workspace);
         if (rc) {
             gwy_field_multiply(workspace, curvature_contrib * r/rc);
             gwy_field_sum_fields(field, field, workspace);
@@ -446,9 +430,9 @@ add_slope_contribs(GwyField *workspace, GwyField *field,
 
     g_object_unref(yder);
     g_object_unref(xder);
+    g_object_unref(workspace);
 
     gwy_field_invalidate(field);
-    gwy_field_invalidate(workspace);
 }
 
 static void
@@ -510,7 +494,7 @@ create_barriers(GwyField *field, gdouble level)
     guint k, xres = field->xres, yres = field->yres;
     gdouble min, max, barmax;
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     barmax = 1.01*max;
     if (min == max)
         return barmax;
@@ -530,14 +514,14 @@ create_barriers(GwyField *field, gdouble level)
 }
 
 static void
-prefill_minima(GwyField *field, GwyField *workspace,
+prefill_minima(GwyField *field,
                IntList *inqueue, IntList *outqueue,
                gdouble depth, gdouble height)
 {
     guint i, j, k, m, xres = field->xres, yres = field->yres;
     gdouble min, max;
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     if (min == max)
         return;
 
@@ -552,19 +536,21 @@ prefill_minima(GwyField *field, GwyField *workspace,
         }
     }
 
-    /* Simple height prefilling which floods all pixels with heights only
-     * little above the minimum. */
+    /* Simple height prefilling which floods all pixels with heights only little above the minimum. */
     if (height > 0.0) {
         gdouble heightthreshold = height*(max - min);
-        gdouble *d = gwy_field_get_data(field), *w = gwy_field_get_data(workspace);
+        gdouble *d = gwy_field_get_data(field);
+        GwyNield *workspace = gwy_field_new_nield_alike(field);
+        gint *w = gwy_nield_get_data(workspace);
 
         gwy_field_mark_extrema(field, workspace, FALSE);
 
         inqueue->len = 0;
         for (k = 0; k < xres*yres; k++) {
-            if (w[k])
+            if (w[k] > 0)
                 int_list_add(inqueue, k);
         }
+        g_object_unref(workspace);
 
         while (inqueue->len) {
             outqueue->len = 0;
