@@ -1,5 +1,5 @@
 /*
- *  $Id: wrapvalue.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: wrapvalue.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2019-2022 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -156,7 +156,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_KEY, &quark,
                                  0);
     g_return_if_fail(args.field);
-    gwy_field_get_min_max(args.field, &args.min, &args.max);
+    gwy_field_min_max(args.field, &args.min, &args.max);
     unit = gwy_field_get_unit_z(args.field);
     if (gwy_unit_equal_string(unit, "deg"))
         args.unit_type = DATA_UNIT_DEG;
@@ -169,7 +169,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -178,7 +178,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (outcome != GWY_DIALOG_HAVE_RESULT)
         execute(&args);
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
     gwy_file_set_image(data, id, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
@@ -291,8 +291,6 @@ execute(ModuleArgs *args)
     GwyField *field = args->field, *result = args->result;
     gdouble offset = gwy_params_get_double(args->params, PARAM_OFFSET);
     gdouble range = get_range(args);
-    gdouble *d;
-    gint n, i;
 
     if (!(range > 0.0)) {
         gwy_field_clear(result);
@@ -300,14 +298,14 @@ execute(ModuleArgs *args)
     }
 
     gwy_field_copy_data(field, result);
-    n = gwy_field_get_xres(result)*gwy_field_get_yres(result);
-    d = gwy_field_get_data(result);
+
+    gint n = gwy_field_get_xres(result)*gwy_field_get_yres(result);
+    gdouble *d = gwy_field_get_data(result);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i) \
             shared(d,n,offset,range)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gint i = 0; i < n; i++) {
         d[i] = fmod(d[i] - offset, range);
         if (d[i] < 0.0)
             d[i] += range;
