@@ -1,5 +1,5 @@
 /*
- *  $Id: xydenoise.c 28821 2025-11-06 16:00:41Z yeti-dn $
+ *  $Id: xydenoise.c 29393 2026-01-28 17:56:48Z yeti-dn $
  *  Copyright (C) 2012-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -182,33 +182,30 @@ static void
 execute(ModuleArgs *args)
 {
     GwyField *fieldx = args->field, *fieldy = gwy_params_get_image(args->params, PARAM_OTHER_IMAGE);
-    GwyField *rx, *ix, *ry, *iy, *result = args->result, *iresult;
+    GwyField *result = args->result;
     gboolean do_average = gwy_params_get_boolean(args->params, PARAM_DO_AVERAGE);
-    gdouble *rxdata, *rydata, *ixdata, *iydata;
-    gint i, n;
+    gint n = gwy_field_get_xres(fieldx) * gwy_field_get_yres(fieldy);
 
-    n = gwy_field_get_xres(fieldx) * gwy_field_get_yres(fieldy);
-    iresult = gwy_field_new_alike(fieldx, TRUE);
-    rx = gwy_field_new_alike(fieldx, TRUE);
-    ix = gwy_field_new_alike(fieldx, TRUE);
-    ry = gwy_field_new_alike(fieldx, TRUE);
-    iy = gwy_field_new_alike(fieldx, TRUE);
+    GwyField *iresult = gwy_field_new_alike(fieldx, TRUE);
+    GwyField *rx = gwy_field_new_alike(fieldx, TRUE);
+    GwyField *ix = gwy_field_new_alike(fieldx, TRUE);
+    GwyField *ry = gwy_field_new_alike(fieldx, TRUE);
+    GwyField *iy = gwy_field_new_alike(fieldx, TRUE);
 
     /* FIXME: Why we do not use the raw function? */
     gwy_field_fft_2d(fieldx, NULL, rx, ix, GWY_WINDOWING_NONE, GWY_TRANSFORM_DIRECTION_FORWARD, FALSE, 0);
     gwy_field_fft_2d(fieldy, NULL, ry, iy, GWY_WINDOWING_NONE, GWY_TRANSFORM_DIRECTION_FORWARD, FALSE, 0);
 
-    rxdata = gwy_field_get_data(rx);
-    rydata = gwy_field_get_data(ry);
-    ixdata = gwy_field_get_data(ix);
-    iydata = gwy_field_get_data(iy);
+    gdouble *rxdata = gwy_field_get_data(rx);
+    gdouble *rydata = gwy_field_get_data(ry);
+    gdouble *ixdata = gwy_field_get_data(ix);
+    gdouble *iydata = gwy_field_get_data(iy);
 
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
-            shared(n,rxdata,ixdata,rydata,iydata,do_average) \
-            private(i)
+            shared(n,rxdata,ixdata,rydata,iydata,do_average)
 #endif
-    for (i = 0; i < n; i++) {
+    for (gint i = 0; i < n; i++) {
         gdouble xmodulus = sqrt(rxdata[i]*rxdata[i] + ixdata[i]*ixdata[i]);
         gdouble cosxphase = rxdata[i]/fmax(xmodulus, G_MINDOUBLE);
         gdouble sinxphase = ixdata[i]/fmax(xmodulus, G_MINDOUBLE);
