@@ -1,6 +1,6 @@
 /*
- *  $Id: zero_crossing.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2003-2021 David Necas (Yeti), Petr Klapetek.
+ *  $Id: zero_crossing.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -77,7 +77,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Zero crossing edge detection."),
     "Yeti <Yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2019",
 };
@@ -142,7 +142,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_unit_clear(gwy_field_get_unit_z(args.result));
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -153,8 +153,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         do_edge(args.result, args.gaussconv, nrms*gwy_params_get_double(args.params, PARAM_THRESHOLD));
     }
 
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &squark);
-    gwy_container_set_object(GWY_CONTAINER(data), squark, args.result);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &squark);
+    gwy_dict_set_object(GWY_DICT(data), squark, args.result);
     gwy_log_add(data, GWY_FILE_IMAGE, id, id);
 
 end:
@@ -247,40 +247,33 @@ preview(gpointer user_data)
 static gdouble
 do_log(GwyField *field, GwyField *gauss, gdouble gaussian_fwhm)
 {
-    const gdouble *data;
-    gint xres, yres, i, j;
-    gdouble nrms;
-
     gwy_field_copy_data(field, gauss);
     gwy_field_filter_gaussian(gauss, gaussian_fwhm*FWHM2SIGMA);
     gwy_field_filter_laplacian(gauss);
 
-    xres = gwy_field_get_xres(gauss);
-    yres = gwy_field_get_yres(gauss);
-    data = gwy_field_get_data_const(gauss);
-    nrms = 0.0;
+    gint xres = gwy_field_get_xres(gauss), yres = gwy_field_get_yres(gauss);
+    const gdouble *data = gwy_field_get_data_const(gauss);
+    gdouble nrms = 0.0;
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(+:nrms) \
-            private(i,j) \
             shared(xres,yres,data)
 #endif
-    for (i = 0; i < yres-1; i++) {
+    for (gint i = 0; i < yres-1; i++) {
         const gdouble *row = data + i*xres;
-        for (j = 0; j < xres; j++)
+        for (gint j = 0; j < xres; j++)
             nrms += (row[j] - row[j + xres])*(row[j] - row[j + xres]);
     }
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(+:nrms) \
-            private(i,j) \
             shared(xres,yres,data)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         const gdouble *row = data + i*xres;
-        for (j = 0; j < xres-1; j++)
+        for (gint j = 0; j < xres-1; j++)
             nrms += (row[j] - row[j + 1])*(row[j] - row[j + 1]);
     }
 
@@ -291,25 +284,19 @@ do_log(GwyField *field, GwyField *gauss, gdouble gaussian_fwhm)
 static void
 do_edge(GwyField *result, GwyField *gauss, gdouble threshold)
 {
-    gdouble *data;
-    const gdouble *bdata;
-    gint xres, yres, i, j;
-
     gwy_field_clear(result);
 
-    xres = gwy_field_get_xres(result);
-    yres = gwy_field_get_yres(result);
-    data = gwy_field_get_data(result);
-    bdata = gwy_field_get_data_const(gauss);
+    gint xres = gwy_field_get_xres(result), yres = gwy_field_get_yres(result);
+    gdouble *data = gwy_field_get_data(result);
+    const gdouble *bdata = gwy_field_get_data_const(gauss);
 
     /* Vertical pass */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(xres,yres,bdata,data,threshold)
 #endif
-    for (i = 1; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
+    for (gint i = 1; i < yres; i++) {
+        for (gint j = 0; j < xres; j++) {
             gint n = i*xres + j;
             gdouble dm = bdata[n - xres];
             gdouble dp = bdata[n];
@@ -332,11 +319,10 @@ do_edge(GwyField *result, GwyField *gauss, gdouble threshold)
     /* Horizontal pass */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(xres,yres,bdata,data,threshold)
 #endif
-    for (i = 0; i < yres; i++) {
-        for (j = 1; j < xres; j++) {
+    for (gint i = 0; i < yres; i++) {
+        for (gint j = 1; j < xres; j++) {
             gint n = i*xres + j;
             gdouble dm = bdata[n - 1];
             gdouble dp = bdata[n];
