@@ -4,54 +4,54 @@
  * It contains prototypes for `functions' that are actually macros in C but are
  * used as functions and we want to have them in Python.
  */
-gboolean     gwy_container_contains_by_name   (GwyContainer *container,
+gboolean     gwy_dict_contains_by_name   (GwyDict *container,
                                                const gchar *n);
-gboolean     gwy_container_remove_by_name     (GwyContainer *container,
+gboolean     gwy_dict_remove_by_name     (GwyDict *container,
                                                const gchar *n);
-gboolean     gwy_container_rename_by_name     (GwyContainer *container,
+gboolean     gwy_dict_rename_by_name     (GwyDict *container,
                                                const gchar *n,
                                                const gchar *new_name,
                                                gboolean force);
-void         gwy_container_set_boolean_by_name(GwyContainer *container,
+void         gwy_dict_set_boolean_by_name(GwyDict *container,
                                                const gchar *n,
                                                gboolean v);
-void         gwy_container_set_double_by_name (GwyContainer *container,
+void         gwy_dict_set_double_by_name (GwyDict *container,
                                                const gchar *n,
                                                gdouble v);
-void         gwy_container_set_enum_by_name   (GwyContainer *container,
+void         gwy_dict_set_enum_by_name   (GwyDict *container,
                                                const gchar *n,
                                                guint v);
-void         gwy_container_set_int32_by_name  (GwyContainer *container,
+void         gwy_dict_set_int32_by_name  (GwyDict *container,
                                                const gchar *n,
                                                gint32 v);
-void         gwy_container_set_int64_by_name  (GwyContainer *container,
+void         gwy_dict_set_int64_by_name  (GwyDict *container,
                                                const gchar *n,
                                                gint64 v);
-void         gwy_container_set_object_by_name (GwyContainer *container,
+void         gwy_dict_set_object_by_name (GwyDict *container,
                                                const gchar *n,
                                                GObject *v);
-void         gwy_container_set_uchar_by_name  (GwyContainer *container,
+void         gwy_dict_set_uchar_by_name  (GwyDict *container,
                                                const gchar *n,
                                                guchar v);
-gboolean     gwy_container_get_boolean_by_name(GwyContainer *container,
+gboolean     gwy_dict_get_boolean_by_name(GwyDict *container,
                                                const gchar *n);
-gdouble      gwy_container_get_double_by_name (GwyContainer *container,
+gdouble      gwy_dict_get_double_by_name (GwyDict *container,
                                                const gchar *n);
-guint        gwy_container_get_enum_by_name   (GwyContainer *container,
+guint        gwy_dict_get_enum_by_name   (GwyDict *container,
                                                const gchar *n);
-gint32       gwy_container_get_int32_by_name  (GwyContainer *container,
+gint32       gwy_dict_get_int32_by_name  (GwyDict *container,
                                                const gchar *n);
-gint64       gwy_container_get_int64_by_name  (GwyContainer *container,
+gint64       gwy_dict_get_int64_by_name  (GwyDict *container,
                                                const gchar *n);
-guchar       gwy_container_get_uchar_by_name  (GwyContainer *container,
+guchar       gwy_dict_get_uchar_by_name  (GwyDict *container,
                                                const gchar *n);
-GObject*     gwy_container_get_object_by_name (GwyContainer *container,
+GObject*     gwy_dict_get_object_by_name (GwyDict *container,
                                                const gchar *n);
-const gchar* gwy_container_get_string_by_name (GwyContainer *container,
+const gchar* gwy_dict_get_string_by_name (GwyDict *container,
                                                const gchar *n);
 
 GwyBrick*           gwy_brick_copy            (GwyBrick *brick);
-GwyContainer*       gwy_container_copy        (GwyContainer *container);
+GwyDict*       gwy_dict_copy        (GwyDict *container);
 GwyDataField*       gwy_data_field_copy       (GwyDataField *data_field);
 gdouble             gwy_data_field_get_xmeasure    (GwyDataField *data_field);
 gdouble             gwy_data_field_get_ymeasure    (GwyDataField *data_field);
