@@ -1,5 +1,5 @@
 /*
- *  $Id: pygwy-console.c 28808 2025-11-05 18:26:20Z yeti-dn $
+ *  $Id: pygwy-console.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2008 Jan Horak
  *  E-mail: xhorak@gmail.com
  *  Copyright (C) 2014-2016 David Necas (Yeti).
@@ -65,7 +65,7 @@ static void       pygwy_console_save_as            (GtkToolButton *button,
                                                     gpointer user_data);
 static void       pygwy_console_run                (GtkToolButton *button,
                                                     gpointer user_data);
-static void       pygwy_console                    (GwyContainer *data,
+static void       pygwy_console                    (GwyDict *data,
                                                     GwyRunModeFlags mode,
                                                     const gchar *name);
 static void       pygwy_console_command_execute    (GtkEntry *entry,
@@ -295,7 +295,7 @@ pygwy_console_create_gui(void)
 }
 
 static void
-pygwy_console(GwyContainer *data, GwyRunModeFlags mode, const gchar *name)
+pygwy_console(GwyDict *data, GwyRunModeFlags mode, const gchar *name)
 {
     PyObject *d;
 
