@@ -1,5 +1,5 @@
 /*
- *  $Id: pygwy.c 28808 2025-11-05 18:26:20Z yeti-dn $
+ *  $Id: pygwy.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -81,17 +81,17 @@ typedef struct {
 
 static gboolean         module_register               (void);
 static gboolean         check_pygtk_availability      (void);
-static void             pygwy_procvolxyz_run          (GwyContainer *data,
+static void             pygwy_procvolxyz_run          (GwyDict *data,
                                                        GwyRunModeFlags mode,
                                                        const gchar *name);
 static void             pygwy_graph_run               (GwyGraph *graph,
                                                        const gchar *name);
-static gboolean         pygwy_file_save_run           (GwyContainer *data,
+static gboolean         pygwy_file_save_run           (GwyDict *data,
                                                        const gchar *filename,
                                                        GwyRunModeFlags mode,
                                                        GError **error,
                                                        const gchar *name);
-static GwyContainer*    pygwy_file_load_run           (const gchar *filename,
+static GwyDict*    pygwy_file_load_run           (const gchar *filename,
                                                        GwyRunModeFlags mode,
                                                        GError **error,
                                                        const gchar *name);
@@ -751,7 +751,7 @@ update_module_code(PygwyModuleInfo *info)
 }
 
 static void
-pygwy_procvolxyz_run(GwyContainer *data, GwyRunModeFlags mode, const gchar *name)
+pygwy_procvolxyz_run(GwyDict *data, GwyRunModeFlags mode, const gchar *name)
 {
     PygwyModuleInfo *info;
     PyObject *py_container = NULL, *res = NULL;
@@ -817,7 +817,7 @@ fail:
 }
 
 static gboolean
-pygwy_file_save_run(GwyContainer *data, const gchar *filename, GwyRunModeFlags mode,
+pygwy_file_save_run(GwyDict *data, const gchar *filename, GwyRunModeFlags mode,
                     GError **error,
                     const gchar *name)
 {
@@ -855,11 +855,11 @@ fail:
     return ok;
 }
 
-static GwyContainer*
+static GwyDict*
 pygwy_file_load_run(const gchar *filename, GwyRunModeFlags mode, GError **error,
                     const gchar *name)
 {
-    GwyContainer *container = NULL;
+    GwyDict *container = NULL;
     PyObject *res = NULL;
     PygwyModuleInfo *info;
     gchar *class_name;
@@ -887,7 +887,7 @@ pygwy_file_load_run(const gchar *filename, GwyRunModeFlags mode, GError **error,
     class_name = find_out_class_name(res);
     if (class_name && gwy_strequal(class_name, "Container")) {
         PyGObject *pyg_res = (PyGObject*)res;
-        container = (GwyContainer*)g_object_ref(pyg_res->obj);
+        container = (GwyDict*)g_object_ref(pyg_res->obj);
     }
     g_free(class_name);
 
