@@ -1,5 +1,5 @@
 /*
- *  $Id: annealing.c 29059 2026-01-02 14:27:52Z yeti-dn $
+ *  $Id: annealing.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2019-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -163,12 +163,12 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     sanitise_params(&args);
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -623,14 +623,11 @@ process_sublattice_vertical2(guint *domain, guint xres, guint yres, guint sublat
                              guint32 *exp_table, const guint32 *random_numbers,
                              guint *cell_status)
 {
-    guint i;
-
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres) \
-            private(i)
+            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres)
 #endif
-    for (i = 0; i < yres/2; i++) {
+    for (guint i = 0; i < yres/2; i++) {
         guint hoff = (i + sublattice) % 2, voff = (sublattice % 4)/2;
         guint j, k = (xres/2)*i;
 
@@ -647,18 +644,15 @@ process_sublattice_horizontal2(guint *domain, guint xres, guint yres, guint subl
                                guint32 *exp_table, const guint32 *random_numbers,
                                guint *cell_status)
 {
-    guint i;
-
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres) \
-            private(i)
+            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres)
 #endif
-    for (i = 0; i < yres/2; i++) {
+    for (guint i = 0; i < yres/2; i++) {
         guint hoff = (sublattice % 4)/2;
-        guint j, k = (xres/2)*i;
+        guint k = (xres/2)*i;
 
-        for (j = 0; j < xres/2; j++, k++) {
+        for (guint j = 0; j < xres/2; j++, k++) {
             guint voff = (j + sublattice) % 2;
 
             if ((cell_status[k] & CELL_STATUS_TRY_SWAPPING)
@@ -674,18 +668,15 @@ process_sublattice_vertical3(guint *domain, guint xres, guint yres,
                              const guint32 *random_numbers,
                              guint *cell_status)
 {
-    guint i;
-
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres) \
-            private(i)
+            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres)
 #endif
-    for (i = 0; i < yres/2; i++) {
+    for (guint i = 0; i < yres/2; i++) {
         guint hoff = (i + sublattice) % 2, voff = (sublattice % 4)/2;
-        guint j, k = (xres/2)*i;
+        guint k = (xres/2)*i;
 
-        for (j = 0; j < xres/2; j++, k++) {
+        for (guint j = 0; j < xres/2; j++, k++) {
             if ((cell_status[k] & CELL_STATUS_TRY_SWAPPING)
                 && maybe_swap3(domain, xres, yres, 2*i + voff, 2*j + hoff, TRUE, exp_table, random_numbers[k]))
                 cell_status[k] &= ~CELL_STATUS_HAVE_RNUM;
@@ -699,18 +690,15 @@ process_sublattice_horizontal3(guint *domain, guint xres, guint yres,
                                const guint32 *random_numbers,
                                guint *cell_status)
 {
-    guint i;
-
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres) \
-            private(i)
+            shared(domain,random_numbers,cell_status,exp_table,sublattice,xres,yres)
 #endif
-    for (i = 0; i < yres/2; i++) {
+    for (guint i = 0; i < yres/2; i++) {
         guint hoff = (sublattice % 4)/2;
-        guint j, k = (xres/2)*i;
+        guint k = (xres/2)*i;
 
-        for (j = 0; j < xres/2; j++, k++) {
+        for (guint j = 0; j < xres/2; j++, k++) {
             guint voff = (j + sublattice) % 2;
 
             if ((cell_status[k] & CELL_STATUS_TRY_SWAPPING)
