@@ -1,5 +1,5 @@
 /*
- *  $Id: ballistic.c 28844 2025-11-10 16:07:51Z yeti-dn $
+ *  $Id: ballistic.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2015-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -93,8 +93,8 @@ static void             dialog_response      (ModuleGUI *gui,
 static void             preview              (gpointer user_data);
 
 static const EvolutionStatInfo evolution_info[GRAPH_NGRAPHS] = {
-    { gwy_field_get_avg, 0, 1 },
-    { gwy_field_get_rms, 0, 1 },
+    { gwy_field_mean, 0, 1 },
+    { gwy_field_rms, 0, 1 },
 };
 
 static const GwyEnum graph_outputs[GRAPH_NGRAPHS] = {
@@ -163,11 +163,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
