@@ -1,5 +1,5 @@
 /*
- *  $Id: columnar.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: columnar.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -125,8 +125,8 @@ static gdouble          zero_crossing_corrlen(GwyField *field);
 static gdouble          count_maxima         (GwyField *field);
 
 static const EvolutionStatInfo evolution_info[GRAPH_NGRAPHS] = {
-    { gwy_field_get_max, 0, 1, },
-    { gwy_field_get_rms, 0, 1, },
+    { gwy_field_max, 0, 1, },
+    { gwy_field_rms, 0, 1, },
     { count_maxima,           0, 0, },
     { calculate_skew,         0, 0, },
     { calculate_kurtoris,     0, 0, },
@@ -219,11 +219,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.field = field;
     /* Cheat a bit here.  Using field's rms means coverage of order unity wipes out most of the original topography.
      * So divide by the default coverage. */
-    args.zscale = field ? gwy_field_get_rms(field)/10.0 : -1.0;
+    args.zscale = field ? gwy_field_rms(field)/10.0 : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -876,7 +876,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         nsub = 0;
     }
 
-    zoff = gwy_field_get_max(field);
+    zoff = gwy_field_max(field);
     gwy_field_add(field, -zoff);
     zmax = zsum = nextgraphx = 0.0;
     nextconvolve = melting ? 0.0 : G_MAXDOUBLE;
@@ -987,7 +987,7 @@ static gdouble
 calculate_skew(GwyField *field)
 {
     gdouble skew;
-    gwy_field_get_stats(field, NULL, NULL, NULL, &skew, NULL);
+    gwy_field_stats(field, NULL, NULL, NULL, &skew, NULL);
     return skew;
 }
 
@@ -995,7 +995,7 @@ static gdouble
 calculate_kurtoris(GwyField *field)
 {
     gdouble kurtosis;
-    gwy_field_get_stats(field, NULL, NULL, NULL, NULL, &kurtosis);
+    gwy_field_stats(field, NULL, NULL, NULL, NULL, &kurtosis);
     return kurtosis;
 }
 
