@@ -1,6 +1,6 @@
 /*
- *  $Id: cpde.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2019-2023 David Necas (Yeti).
+ *  $Id: cpde.c 29407 2026-01-30 15:34:09Z yeti-dn $
+ *  Copyright (C) 2019-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -132,7 +132,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates images by assorted coupled partial differential equation models."),
     "Yeti <yeti@gwyddion.net>",
-    "3.1",
+    "3.2",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -195,11 +195,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -457,10 +457,8 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     gwy_params_get_unit(params, PARAM_DIMS0 + GWY_DIMS_PARAM_ZUNIT, &power10z);
     height *= gwy_exp10(power10z);
 
-    if (field && do_initialise) {
+    if (field && do_initialise)
         gwy_field_copy_data(args->field, field);
-        gwy_field_renormalize(args->field, 0.0, 1.0);
-    }
     else
         init_field_randomly(field, gwy_params_get_int(params, PARAM_SEED));
 
@@ -474,11 +472,11 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 
     /* The invalidation and repetition seems excessive. For diffreact all the information is sometimes only in the few
      * last bits of the double values – and then then cached stats transformation in Field is not good enough. */
-    gwy_field_add(field, -gwy_field_get_avg(field));
+    gwy_field_add(field, -gwy_field_mean(field));
     gwy_field_invalidate(field);
-    gwy_field_add(field, -gwy_field_get_avg(field));
+    gwy_field_add(field, -gwy_field_mean(field));
     gwy_field_invalidate(field);
-    rms = gwy_field_get_rms(field);
+    rms = gwy_field_rms(field);
     if (rms > 0.0) {
         gwy_field_multiply(field, height/rms);
         gwy_field_invalidate(field);
@@ -546,26 +544,23 @@ static gdouble
 checker_smooth(gint xres, gint yres, gdouble *r, gdouble *tmp)
 {
     gdouble rr = 0.0;
-    gint i;
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(+:rr) \
-            shared(r,tmp,xres,yres) \
-            private(i)
+            shared(r,tmp,xres,yres)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gint ix = i*xres;
         gint ixp = ((i + 1) % yres)*xres;
         gint ixm = ((i + yres-1) % yres)*xres;
         gdouble t;
-        gint j;
 
         t = smooth8(r + ixm, r + ix, r + ixp, xres-1, 0, 1);
         tmp[ix] = t;
         rr += t*t;
 
-        for (j = 1; j < xres-1; j++) {
+        for (gint j = 1; j < xres-1; j++) {
             t = smooth8(r + ixm, r + ix, r + ixp, j-1, j, j+1);
             tmp[ix + j] = t;
             rr += t*t;
@@ -599,16 +594,15 @@ static void
 do_iter_turing(gint xres, gint yres, gdouble *domain, const gdouble *constants, gdouble size)
 {
     gdouble realdt, cr0, cr1, rr0, rr1;
-    gint i, n = xres*yres;
+    gint n = xres*yres;
 
     cr0 = cr1 = 0.0;
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(+:cr0,cr1) \
-            shared(domain,xres,yres,n,constants,size) \
-            private(i)
+            shared(domain,xres,yres,n,constants,size)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gdouble *c0 = domain;
         gdouble *c1 = domain + n;
         gdouble *r0 = domain + 2*n;
@@ -624,7 +618,6 @@ do_iter_turing(gint xres, gint yres, gdouble *domain, const gdouble *constants,
         gint ixp = ((i + 1) % yres)*xres;
         gint ixm = ((i + yres-1) % yres)*xres;
         gdouble cx0, cx1, c0lap, c1lap;
-        gint j;
 
         cx0 = c0[ix];
         cx1 = c1[ix];
@@ -635,7 +628,7 @@ do_iter_turing(gint xres, gint yres, gdouble *domain, const gdouble *constants,
         cr0 += cx0*cx0;
         cr1 += cx1*cx1;
 
-        for (j = 1; j < xres-1; j++) {
+        for (gint j = 1; j < xres-1; j++) {
             cx0 = c0[ix + j];
             cx1 = c1[ix + j];
             c0lap = laplacian8(c0 + ixm, c0 + ix, c0 + ixp, j-1, j, j+1);
@@ -661,7 +654,7 @@ do_iter_turing(gint xres, gint yres, gdouble *domain, const gdouble *constants,
     rr1 = checker_smooth(xres, yres, domain + 3*n, domain + 4*n);
     rr1 = sqrt(cr1/rr1);
     realdt = 0.5*MIN(rr0, rr1);
-    for (i = 0; i < 2*n; i++)
+    for (gint i = 0; i < 2*n; i++)
         domain[i] += realdt*domain[2*n + i];
 }
 
@@ -673,21 +666,24 @@ cpde_turing(ModuleArgs *args, GTimer *timer, gdouble preview_time)
     gdouble chaos = gwy_params_get_double(params, PARAM_TURING_CHAOS);
     guint niters = gwy_params_get_int(params, PARAM_NITERS);
     GwyField *field = args->result;
-    gdouble *domain, *d = gwy_field_get_data(field);
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble *d = gwy_field_get_data(field);
     GwySynthUpdateType update;
-    gint xres, yres;
-    guint i;
-    gdouble constants[5];
+    gdouble rms, constants[5];
+
+    gwy_field_add(field, -gwy_field_mean(field));
+    if ((rms = gwy_field_rms(field)) > 0.0)
+        gwy_field_multiply(field, 1.0/rms);
 
     /* Size correction to improve the h-scaling for small size parameters which is not linear. Still not perfect, but
      * better than the assumption of a perfect linearity. */
     size /= 1.00496 + 0.0114095*chaos - (3.22188 - chaos*3.50729)*exp(-cbrt(size/0.0534325));
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    domain = g_new(gdouble, 5*xres*yres);
-    for (i = 0; i < xres*yres; i++)
-        domain[i + xres*yres] = domain[i] = d[i] - 0.5;
+    gdouble *domain = g_new(gdouble, 5*xres*yres);
+    for (guint i = 0; i < xres*yres; i++) {
+        domain[i] = 4.5*d[i];
+        domain[i + xres*yres] = 1.5*d[i];
+    }
 
     constants[0] = 1.12;
     constants[1] = -1.4;
@@ -695,7 +691,7 @@ cpde_turing(ModuleArgs *args, GTimer *timer, gdouble preview_time)
     constants[3] = 0.75 + 0.5*chaos;
     constants[4] = G_PI/(138.0 - 18.0*chaos);
 
-    for (i = 0; i < niters; i++) {
+    for (guint i = 0; i < niters; i++) {
         do_iter_turing(xres, yres, domain, constants, size);
         if (i % 20 == 0) {
             update = gwy_synth_update_progress(timer, preview_time, i, niters);
@@ -767,7 +763,7 @@ do_iter_diffreact(gint xres, gint yres, gdouble *domain_in, gdouble *domain_out,
 {
     const gdouble A = constants[0], B = constants[1];
     const gdouble r = constants[2], f = constants[3];
-    gint i, n = xres*yres;
+    gint n = xres*yres;
 
     /* XXX: Here the idiots who made incompatible changes in the OpenMP standard strike again.
      * We cannot have default(none) and cannot list A, B, r and f anywhere. Some versions require them to be specified
@@ -775,10 +771,9 @@ do_iter_diffreact(gint xres, gint yres, gdouble *domain_in, gdouble *domain_out,
      * declare the very same thing explicitly. */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) \
-            shared(domain_in,domain_out,xres,yres,n) \
-            private(i)
+            shared(domain_in,domain_out,xres,yres,n)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gdouble *u0 = domain_in;
         gdouble *v0 = domain_in + n;
         gdouble *u1 = domain_out;
@@ -787,7 +782,6 @@ do_iter_diffreact(gint xres, gint yres, gdouble *domain_in, gdouble *domain_out,
         gint ixp = ((i + 1) % yres)*xres;
         gint ixm = ((i + yres-1) % yres)*xres;
         gdouble cu0, cv0, ulap, vlap, c, du, dv;
-        gint j;
 
         cu0 = u0[ix];
         cv0 = v0[ix];
@@ -799,7 +793,7 @@ do_iter_diffreact(gint xres, gint yres, gdouble *domain_in, gdouble *domain_out,
         u1[ix] = fmin(fmax(cu0 + du, 0.0), 1.0);
         v1[ix] = fmin(fmax(cv0 + dv, 0.0), 1.0);
 
-        for (j = 1; j < xres-1; j++) {
+        for (gint j = 1; j < xres-1; j++) {
             cu0 = u0[ix + j];
             cv0 = v0[ix + j];
             ulap = laplacian8(u0 + ixm, u0 + ix, u0 + ixp, j-1, j, j+1);
@@ -826,11 +820,11 @@ do_iter_diffreact(gint xres, gint yres, gdouble *domain_in, gdouble *domain_out,
 static guint*
 generate_positions(GRand *rng, guint xres, guint yres, gdouble p, guint *npos)
 {
-    guint i, np = GWY_ROUND(xres*yres*p/2)*2;
+    guint np = GWY_ROUND(xres*yres*p/2)*2;
     gint sx, sy, x, y;
     guint *pos = g_new(guint, np);
 
-    for (i = 0; i < np/2; i++) {
+    for (gint i = 0; i < np/2; i++) {
         x = g_rand_int_range(rng, 0, xres);
         y = g_rand_int_range(rng, 0, yres);
         pos[2*i] = x + xres*y;
@@ -861,12 +855,13 @@ cpde_diffreact(ModuleArgs *args, GTimer *timer, gdouble preview_time)
     gint quantity = gwy_params_get_enum(params, PARAM_DIFFREACT_QUANTITY);
     guint seed = gwy_params_get_int(params, PARAM_SEED);
     GwyField *field = args->result;
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    guint n = xres*yres;
     GwySynthUpdateType update;
-    guint i, j, xres, yres, n, nsrc;
-    GRand *rng = g_rand_new();
-    gdouble *domain1, *domain2;
+    guint i, j, nsrc;
     gdouble constants[4];
-    guint *sources;
+
+    gwy_field_renormalize(field, 0.0, 1.0);
 
     /* The demos like
      * https://github.com/amandaghassaei/gpu-io/blob/main/examples/reaction-diffusion/index.js
@@ -876,18 +871,16 @@ cpde_diffreact(ModuleArgs *args, GTimer *timer, gdouble preview_time)
      *
      * If we want to create a pattern with a certain character, i.e. corresponding to a small region where the
      * constants are more or less uniform, we need to a different source of high and low values. */
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    n = xres*yres;
 
+    GRand *rng = g_rand_new();
     g_rand_set_seed(rng, seed);
-    sources = generate_positions(rng, xres, yres, psrc, &nsrc);
+    guint *sources = generate_positions(rng, xres, yres, psrc, &nsrc);
     g_rand_free(rng);
 
-    domain1 = g_new(gdouble, 2*n);
+    gdouble *domain1 = g_new(gdouble, 2*n);
     gwy_assign(domain1, gwy_field_get_data(field), n);
     gwy_assign(domain1 + n, domain1, n);
-    domain2 = g_new(gdouble, 2*n);
+    gdouble *domain2 = g_new(gdouble, 2*n);
     gwy_assign(domain2, domain1, 2*n);
 
     constants[0] = 0.2097;
