@@ -1,5 +1,5 @@
 /*
- *  $Id: deposit.c 28844 2025-11-10 16:07:51Z yeti-dn $
+ *  $Id: deposit.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2010-2021 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -160,11 +160,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_data_browser_get_current(GWY_APP_FIELD, &args.field,
                                  GWY_APP_FIELD_ID, &id,
                                  0);
-    args.zscale = args.field ? gwy_field_get_rms(args.field) : -1.0;
+    args.zscale = args.field ? gwy_field_rms(args.field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, args.field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -521,7 +521,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gint *pndeposited)
     gdouble xreal, yreal, diff, dx, dy;
     gdouble *rdisizes = NULL, *extdata;
     GwyXYZ *r = NULL, *v = NULL, *a = NULL, *f = NULL;
-    gint i, k, nloc, maxloc = 1, maxsteps = 10000;
+    gint nloc, maxloc = 1, maxsteps = 10000;
     gdouble preview_time = (animated ? 1.25 : 0.0);
     gdouble norm;
     GTimer *timer;
@@ -595,7 +595,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gint *pndeposited)
     if (!gwy_app_wait_set_message("Running revise..."))
         goto end;
 
-    for (i = 0; i < revise; i++) {
+    for (gint i = 0; i < revise; i++) {
         /* Try to add some particles if necessary, do this only for first part of molecular dynamics steps. */
         if (ndeposited < nparticles && i < 3*revise/4) {
             nloc = 0;
@@ -610,13 +610,11 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gint *pndeposited)
         /* test succesive LJ steps on substrate */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(k) \
             shared(r,f,ndeposited,rdisizes,diff,extdata,xres,yres,dx,dy)
 #endif
-        for (k = 0; k < ndeposited; k++) {
+        for (gint k = 0; k < ndeposited; k++) {
             gdouble rxk = r[k].x, ryk = r[k].y, rzk = r[k].z, sizek = rdisizes[k];
             GwyXYZ fk = { 0.0, 0.0, 0.0 };
-            gint m;
 
             if (rxk/dx < 0.0 || rxk/dx >= xres || ryk/dy < 0.0 || ryk/dy >= yres) {
                 f[k] = fk;
@@ -624,7 +622,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gint *pndeposited)
             }
 
             /* Forces from other particles. */
-            for (m = 0; m < ndeposited; m++) {
+            for (gint m = 0; m < ndeposited; m++) {
                 if (m != k)
                     lj_potential_grad_spheres(r[m].x, r[m].y, r[m].z, rxk, ryk, rzk, sizek, rdisizes[m], &fk);
             }
@@ -644,10 +642,9 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gint *pndeposited)
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(k) \
             shared(r,v,a,f,ndeposited,rdisizes,xres,yres,dx,dy,xreal,yreal)
 #endif
-        for (k = 0; k < ndeposited; k++) {
+        for (gint k = 0; k < ndeposited; k++) {
             const gdouble mass = 1.0, timestep = 0.5;
             GwyXYZ rk = r[k], vk = v[k], ak = a[k];
             gdouble sizek = rdisizes[k];
