@@ -1,6 +1,6 @@
 /*
- *  $Id: diffusion.c 28822 2025-11-06 16:01:09Z yeti-dn $
- *  Copyright (C) 2014-2021 David Necas (Yeti).
+ *  $Id: diffusion.c 29407 2026-01-30 15:34:09Z yeti-dn $
+ *  Copyright (C) 2014-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -180,8 +180,8 @@ static void             diffusion_state_free     (DiffusionState *dstate);
 static gdouble          count_grains             (GwyField *field);
 
 static const EvolutionStatInfo evolution_info[GRAPH_NGRAPHS] = {
-    { gwy_field_get_variation, 1, 1, },
-    { count_grains,                 0, 0, },
+    { gwy_field_variation, 1, 1, },
+    { count_grains,            0, 0, },
 };
 
 static const GwyEnum graph_outputs[GRAPH_NGRAPHS] = {
@@ -194,7 +194,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates surfaces by diffusion limited aggregation."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2014",
 };
@@ -257,11 +257,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -1005,10 +1005,10 @@ diffusion_state_free(DiffusionState *dstate)
 static gdouble
 count_grains(GwyField *field)
 {
-    gint ngrains, n = gwy_field_get_xres(field)*gwy_field_get_yres(field);
-    gint *grains = g_new0(gint, n);
-    ngrains = gwy_field_number_grains_periodic(field, grains);
-    g_free(grains);
+    GwyNield *nield = gwy_field_new_nield_alike(field);
+    gwy_nield_mark_by_threshold(nield, field, 0.5, TRUE);
+    gint ngrains = gwy_nield_number_contiguous_periodic(nield);
+    g_object_unref(nield);
     return ngrains;
 }
 
