@@ -1,6 +1,6 @@
 /*
- *  $Id: discs.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2018-2021 David Necas (Yeti).
+ *  $Id: discs.c 29447 2026-02-07 12:14:37Z yeti-dn $
+ *  Copyright (C) 2018-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -102,7 +102,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates random more or less touching discs."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2018",
 };
@@ -164,11 +164,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -662,25 +662,22 @@ static void
 find_initial_candidates(GArray *discs, GArray *candidates, GArray *shifts,
                         gdouble xreal, gdouble yreal, gdouble minr, gdouble separation)
 {
-    guint i, j, k, n;
-    gulong *counts;
-
-    n = discs->len;
     g_array_set_size(candidates, 0);
+
     /* Parallelise by splitting on i, giving each thread its own candidate array.  Except that i is a non-linear
      * index; we do much less work for larger i, so linearise it. */
-    counts = g_new0(gulong, n);
-    for (i = 0; i < n; i++) {
-        for (j = i; j < n; j++)
+    guint n = discs->len;
+    gulong *counts = g_new0(gulong, n);
+    for (guint i = 0; i < n; i++) {
+        for (guint j = i; j < n; j++)
             counts[i] += n+1 - j;
     }
-    for (i = 1; i < n; i++)
+    for (guint i = 1; i < n; i++)
         counts[i] += counts[i-1];
 
 #ifdef _OPENMP
 #pragma omp parallel if (gwy_threads_are_enabled()) default(none) \
-            shared(discs,candidates,shifts,counts,n,xreal,yreal,minr,separation) \
-            private(i,j,k)
+            shared(discs,candidates,shifts,counts,n,xreal,yreal,minr,separation)
 #endif
     {
         GArray *tcand = g_array_new(FALSE, FALSE, sizeof(Disc));
@@ -688,6 +685,7 @@ find_initial_candidates(GArray *discs, GArray *candidates, GArray *shifts,
         gulong workto = gwy_omp_chunk_end(counts[n-1]);
         guint ifrom = 0, ito = n;
         gdouble maxr = 0.5*fmin(xreal, yreal);
+        guint i;
 
         for (i = 0; i < n; i++) {
             if (counts[i] > workfrom) {
@@ -703,8 +701,8 @@ find_initial_candidates(GArray *discs, GArray *candidates, GArray *shifts,
         }
 
         for (i = ifrom; i < ito; i++) {
-            for (j = i; j < n; j++) {
-                for (k = j; k < n; k++)
+            for (guint j = i; j < n; j++) {
+                for (guint k = j; k < n; k++)
                     find_candidates_one_triplet(discs, tcand, shifts, i, j, k, xreal, yreal, minr, maxr, separation);
             }
         }
@@ -777,21 +775,16 @@ generate_discs(GArray *discs, gdouble xreal, gdouble yreal, gdouble minr, gdoubl
 }
 
 static void
-circular_area_fill_periodic(GwyField *field, gint col, gint row,
-                            gdouble radius, gdouble value)
+circular_area_fill_periodic(GwyNield *field, gint col, gint row,
+                            gdouble radius, gint value)
 {
-    gint i, j, ii, jj, r, r2, xres, yres, jfrom, jto;
-    gdouble *d, *drow;
-    gdouble s;
-
     if (radius < 0.0)
         return;
 
-    r2 = floor(radius*radius + 1e-12);
-    r = floor(radius + 1e-12);
-    xres = field->xres;
-    yres = field->yres;
-    d = gwy_field_get_data(field);
+    gint r2 = floor(radius*radius + 1e-12);
+    gint r = floor(radius + 1e-12);
+    gint xres = field->xres, yres = field->yres;
+    gint *d = gwy_nield_get_data(field);
 
     /* Ensure circle centre inside the base area. */
     col %= xres;
@@ -802,60 +795,54 @@ circular_area_fill_periodic(GwyField *field, gint col, gint row,
     if (row < 0)
         row += yres;
 
-    for (i = -r; i <= r; i++) {
-        ii = (i + row + yres) % yres;
-        drow = d + ii*xres;
+    for (gint i = -r; i <= r; i++) {
+        gint ii = (i + row + yres) % yres;
+        gint *drow = d + ii*xres;
 
-        s = sqrt(r2 - i*i);
-        jfrom = col + ceil(-s);
-        jto = col + floor(s);
-        /* If we are to fill the entire row just do it simply.  As a benefit,
-         * we can assume we fill less than one entire row in the other cases. */
+        gdouble s = sqrt(r2 - i*i);
+        gint jfrom = col + ceil(-s);
+        gint jto = col + floor(s);
+        /* If we are to fill the entire row just do it simply.  As a benefit, we can assume we fill less than one
+         * entire row in the other cases. */
         if (jto+1 - jfrom >= xres) {
-            for (j = xres; j; j--, drow++)
+            for (gint j = xres; j; j--, drow++)
                 *drow = value;
         }
         /* Sticking outside to the left. */
         else if (jfrom < 0) {
-            for (j = 0; j <= jto; j++)
+            for (gint j = 0; j <= jto; j++)
                 drow[j] = value;
-            jj = (jfrom + xres) % xres;
-            for (j = jj; j < xres; j++)
+            gint jj = (jfrom + xres) % xres;
+            for (gint j = jj; j < xres; j++)
                 drow[j] = value;
         }
         /* Sticking outside to the right. */
         else if (jto >= xres) {
-            jj = (jto + 1) % xres;
-            for (j = 0; j < jj; j++)
+            gint jj = (jto + 1) % xres;
+            for (gint j = 0; j < jj; j++)
                 drow[j] = value;
-            for (j = jfrom; j < xres; j++)
+            for (gint j = jfrom; j < xres; j++)
                 drow[j] = value;
         }
         /* Entirely inside. */
         else {
-            for (j = jfrom; j <= jto; j++)
+            for (gint j = jfrom; j <= jto; j++)
                 drow[j] = value;
         }
     }
 }
 
 static void
-generate_seed_discs(ModuleArgs *args, GwyField *field, GArray *discs, GwyRandGenSet *rngset)
+generate_seed_discs(ModuleArgs *args, GwyNield *field, GArray *discs, GwyRandGenSet *rngset)
 {
     GwyParams *params = args->params;
     gdouble separation = gwy_params_get_double(params, PARAM_SEPARATION);
     gdouble radius_init = gwy_params_get_double(params, PARAM_RADIUS_INIT);
     gdouble radius_init_noise = gwy_params_get_double(params, PARAM_RADIUS_INIT_NOISE);
-    gint i, xres, yres, failcount;
-    GRand *rng;
+    gint xres = gwy_nield_get_xres(field), yres = gwy_nield_get_xres(field);
+    GRand *rng = gwy_rand_gen_set_rng(rngset, RNG_POSITION);
 
-    rng = gwy_rand_gen_set_rng(rngset, RNG_POSITION);
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_xres(field);
-    gwy_field_fill(field, 1.0);
-
-    failcount = 0;
+    gint failcount = 0;
     while (failcount < 15) {
         Disc d;
 
@@ -865,6 +852,7 @@ generate_seed_discs(ModuleArgs *args, GwyField *field, GArray *discs, GwyRandGen
         if (radius_init_noise)
             d.r *= exp(gwy_rand_gen_set_gaussian(rngset, RNG_RADIUS_INIT, radius_init_noise));
 
+        gint i;
         for (i = 0; i < discs->len; i++) {
             const Disc *p = &g_array_index(discs, Disc, i);
             gdouble dx, dy, s;
@@ -905,44 +893,39 @@ execute(ModuleArgs *args)
     gdouble separation = gwy_params_get_double(params, PARAM_SEPARATION);
     gdouble gap_thickness = gwy_params_get_double(params, PARAM_GAP_THICKNESS);
     gint opening_size = gwy_params_get_int(params, PARAM_OPENING_SIZE);
-    GwyField *discfield = args->result, *workspace = NULL, *shifted;
-    guint xres, yres, ext, i, gno;
-    gint ngrains, power10z;
-    GwyRandGenSet *rngset;
-    GArray *discs;
-    gint *grains;
-    gdouble *heights, *d;
+    GwyField *result = args->result;
+    GwyNield *discfield = NULL, *workspace = NULL;
+    gint xres = gwy_field_get_xres(result), yres = gwy_field_get_yres(result);
 
-    xres = gwy_field_get_xres(discfield);
-    yres = gwy_field_get_yres(discfield);
-
-    rngset = gwy_rand_gen_set_new(RNG_NRNGS);
+    GwyRandGenSet *rngset = gwy_rand_gen_set_new(RNG_NRNGS);
     gwy_rand_gen_set_init(rngset, gwy_params_get_int(params, PARAM_SEED));
 
+    gint power10z;
     gwy_params_get_unit(params, PARAM_DIMS0 + GWY_DIMS_PARAM_ZUNIT, &power10z);
     height *= gwy_exp10(power10z);
 
-    discs = g_array_new(FALSE, FALSE, sizeof(Disc));
+    GArray *discs = g_array_new(FALSE, FALSE, sizeof(Disc));
+    discfield = gwy_field_new_nield_alike(result);
     generate_seed_discs(args, discfield, discs, rngset);
     generate_discs(discs, 1.0*xres, 1.0*yres, radius_min, separation);
-    gwy_field_fill(discfield, 1.0);
-    ext = 0;
+    gwy_nield_fill(discfield, 1);
+
+    gint ext = 0;
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
             reduction(max:ext) \
-            shared(discs,discfield) \
-            private(i)
+            shared(discs,discfield)
 #endif
-    for (i = 0; i < discs->len; i++) {
+    for (gint i = 0; i < discs->len; i++) {
         const Disc *p = &g_array_index(discs, Disc, i);
 
-        circular_area_fill_periodic(discfield, floor(p->x), floor(p->y), p->r, 0.0);
+        circular_area_fill_periodic(discfield, floor(p->x), floor(p->y), p->r, 0);
         ext = MAX(ext, (gint)ceil(p->r));
     }
 
     if (height_noise) {
         /* Recycle r (which is no longer needed) for heights. */
-        for (i = 0; i < discs->len; i++) {
+        for (gint i = 0; i < discs->len; i++) {
             Disc *p = &g_array_index(discs, Disc, i);
             gdouble z = gwy_rand_gen_set_gaussian(rngset, RNG_HEIGHT, height_noise);
             p->r = sqrt(z*z + 1.0) + z;   /* To (0, ∞) */
@@ -951,71 +934,74 @@ execute(ModuleArgs *args)
 
     if (apply_opening)
         ext = MAX(ext, 4*opening_size/3 + 1);
-    gwy_field_invalidate(discfield);
+
+    gwy_nield_invalidate(discfield);
 
     if (make_tiles) {
-        workspace = gwy_field_extend(discfield, ext, ext, ext, ext, GWY_EXTERIOR_PERIODIC, 0.0, FALSE);
-        gwy_field_grains_invert(workspace);
-        gwy_field_grains_grow(workspace, 0.5*MIN(xres, yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
-        gwy_field_grains_invert(workspace);
+        workspace = gwy_nield_extend(discfield, ext, ext, ext, ext, GWY_EXTERIOR_PERIODIC, 0);
+        gwy_nield_invert(workspace);
+        gwy_nield_grow(workspace, 0.5*MIN(xres, yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE);
         if (gap_thickness >= 2.0) {
-            gwy_field_grains_grow(workspace, 0.7*gap_thickness, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
-            gwy_field_grains_shrink(workspace, 0.2*gap_thickness, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
+            gwy_nield_invert(workspace);
+            gwy_nield_grow(workspace, 0.7*gap_thickness, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
+            gwy_nield_shrink(workspace, 0.2*gap_thickness, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
+            gwy_nield_invert(workspace);
         }
-        gwy_field_grains_invert(workspace);
     }
     else
-        gwy_field_grains_invert(discfield);
+        gwy_nield_invert(discfield);
 
     if (apply_opening) {
-        shifted = gwy_field_new(opening_size, opening_size, opening_size, opening_size, TRUE);
-        gwy_field_elliptic_area_fill(shifted, 0, 0, opening_size, opening_size, 1.0);
-        gwy_field_area_filter_min_max(workspace, shifted, GWY_MIN_MAX_FILTER_OPENING,
+        GwyNield *shifted = gwy_nield_new(opening_size, opening_size);
+        gwy_nield_elliptic_fill(shifted);
+        gwy_nield_area_filter_min_max(workspace, shifted, GWY_MIN_MAX_FILTER_OPENING,
                                       0, 0, xres + 2*ext, yres + 2*ext);
         g_object_unref(shifted);
     }
     if (make_tiles)
-        gwy_field_area_copy(workspace, discfield, ext, ext, xres, yres, 0, 0);
+        gwy_nield_area_copy(workspace, discfield, ext, ext, xres, yres, 0, 0);
+
+    g_clear_object(&workspace);
 
     if (height_noise) {
-        grains = g_new0(gint, xres*yres);
-        ngrains = gwy_field_number_grains_periodic(discfield, grains);
-        heights = g_new0(gdouble, ngrains+1);
-        heights[0] = 0.0;
+        gint ngrains = gwy_nield_number_contiguous(discfield);
+        const gint *grains = gwy_nield_get_data_const(discfield);
+        gdouble *heights = g_new0(gdouble, ngrains+1);
 
         /* First assign heights to all grains which contain the original disc centre.  Conflicts are resolved on the
          * first come first served basis since it (usually) means larger discs have precedence.  */
-        for (i = 0; i < discs->len; i++) {
+        for (gint i = 0; i < discs->len; i++) {
             Disc *p = &g_array_index(discs, Disc, i);
-            gint col = GWY_ROUND(p->x), row = GWY_ROUND(p->y);
+            gint gno, col = GWY_ROUND(p->x), row = GWY_ROUND(p->y);
             col = CLAMP(col, 0, xres-1);
             row = CLAMP(row, 0, yres-1);
             if ((gno = grains[row*xres + col]) && !heights[gno])
                 heights[gno] = p->r;
         }
         /* Generate the remaining heights arbitrarily. */
-        for (gno = 1; gno <= ngrains; gno++) {
+        for (gint gno = 1; gno <= ngrains; gno++) {
             if (!heights[gno]) {
                 gdouble z = gwy_rand_gen_set_gaussian(rngset, RNG_HEIGHT, height_noise);
                 heights[gno] = sqrt(z*z + 1.0) + z;   /* To (0, ∞) */
             }
         }
 
-        d = gwy_field_get_data(discfield);
-        for (i = 0; i < xres*yres; i++)
+        gdouble *d = gwy_field_get_data(result);
+        for (gint i = 0; i < xres*yres; i++)
             d[i] = heights[grains[i]];
         g_free(heights);
-        g_free(grains);
     }
-    gwy_field_multiply(discfield, height);
+    else
+        gwy_field_fill_mask(result, discfield, 0.0, 1.0);
+
+    gwy_field_multiply(result, height);
 
     if (args->field && do_initialise)
-        gwy_field_sum_fields(discfield, discfield, args->field);
+        gwy_field_sum_fields(result, result, args->field);
 
+    g_object_unref(discfield);
     g_array_free(discs, TRUE);
     gwy_rand_gen_set_free(rngset);
-
-    g_clear_object(&workspace);
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
