@@ -1,5 +1,5 @@
 /*
- *  $Id: domains.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: domains.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -203,11 +203,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -430,7 +430,7 @@ init_ufield_from_surface(GwyField *field, GwyField *ufield, GRand *rng)
     gdouble *u = gwy_field_get_data(ufield);
 
     if (field) {
-        gdouble med = gwy_field_get_median(field);
+        gdouble med = gwy_field_median(field);
         const gdouble *d = gwy_field_get_data_const(field);
 
         for (k = xres*yres; k; k--, d++, u++)
@@ -462,7 +462,6 @@ field_mc_step8(GwyField *vfield, const gint *u, gint *unew,
 {
     guint xres = vfield->xres, yres = vfield->yres, n = xres*yres;
     const gdouble *v = gwy_field_get_data_const(vfield), *r = gwy_field_get_data_const(random_numbers);
-    guint i, j;
 
     /* Top row. */
     unew[0] = mc_step8(u[0],
@@ -470,26 +469,27 @@ field_mc_step8(GwyField *vfield, const gint *u, gint *unew,
                        u[xres+1], u[2*xres-1], u[n-xres+1], u[n-1],
                        r[0], T, B, v[0]);
 
-    for (j = 1; j < xres-1; j++) {
+    for (guint j = 1; j < xres-1; j++) {
         unew[j] = mc_step8(u[j],
                            u[j-1], u[j+1], u[j+xres], u[j + n-xres],
                            u[j+xres-1], u[j+xres+1], u[j-1 + n-xres], u[j+1 + n-xres],
                            r[j], T, B, v[j]);
     }
 
-    j = xres-1;
-    unew[j] = mc_step8(u[j],
-                       u[0], u[j+xres], u[j-1], u[n-1],
-                       u[2*xres-2],  u[xres], u[n-2], u[n-xres],
-                       r[j], T, B, v[j]);
+    {
+        guint j = xres-1;
+        unew[j] = mc_step8(u[j],
+                           u[0], u[j+xres], u[j-1], u[n-1],
+                           u[2*xres-2],  u[xres], u[n-2], u[n-xres],
+                           r[j], T, B, v[j]);
+    }
 
     /* Inner rows. */
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(xres,yres,u,unew,v,r,T,B) \
-            private(i,j)
+            shared(xres,yres,u,unew,v,r,T,B)
 #endif
-    for (i = 1; i < yres-1; i++) {
+    for (guint i = 1; i < yres-1; i++) {
         gint *unewrow = unew + i*xres;
         const gint *urow = u + i*xres;
         const gint *uprevrow = u + (i - 1)*xres;
@@ -502,39 +502,46 @@ field_mc_step8(GwyField *vfield, const gint *u, gint *unew,
                               uprevrow[1], uprevrow[xres-1], unextrow[1], unextrow[xres-1],
                               rrow[0], T, B, vrow[0]);
 
-        for (j = 1; j < xres-1; j++) {
+        for (guint j = 1; j < xres-1; j++) {
             unewrow[j] = mc_step8(urow[j],
                                   uprevrow[j], urow[j-1], urow[j+1], unextrow[j],
                                   uprevrow[j-1], uprevrow[j+1], unextrow[j-1], unextrow[j+1],
                                   rrow[j], T, B, vrow[j]);
         }
 
-        j = xres-1;
-        unewrow[j] = mc_step8(urow[j],
-                              uprevrow[j], urow[0], urow[xres-2], unextrow[j],
-                              uprevrow[0], uprevrow[xres-2], unextrow[0], unextrow[xres-2],
-                              rrow[j], T, B, vrow[j]);
+        {
+            guint j = xres-1;
+            unewrow[j] = mc_step8(urow[j],
+                                  uprevrow[j], urow[0], urow[xres-2], unextrow[j],
+                                  uprevrow[0], uprevrow[xres-2], unextrow[0], unextrow[xres-2],
+                                  rrow[j], T, B, vrow[j]);
+        }
     }
 
     /* Bottom row. */
-    j = i = n-xres;
-    unew[j] = mc_step8(u[j],
-                       u[j+1], u[0], u[n-1], u[j-xres],
-                       u[j - xres-1], u[j - xres+1], u[1], u[xres-1],
-                       r[j], T, B, v[j]);
+    guint i = n-xres;
+    {
+        guint j = n-xres;
+        unew[j] = mc_step8(u[j],
+                           u[j+1], u[0], u[n-1], u[j-xres],
+                           u[j - xres-1], u[j - xres+1], u[1], u[xres-1],
+                           r[j], T, B, v[j]);
+    }
 
-    for (j = 1; j < xres-1; j++) {
+    for (guint j = 1; j < xres-1; j++) {
         unew[i + j] = mc_step8(u[i + j],
                                u[i + j-1], u[i + j+1], u[i + j-xres], u[j],
                                u[i + j-xres-1], u[i + j-xres+1], u[j-1], u[j+1],
                                r[i + j], T, B, v[i + j]);
     }
 
-    j = n-1;
-    unew[j] = mc_step8(u[j],
-                       u[i], u[j-xres], u[xres-1], u[j-1],
-                       u[0], u[xres-2], u[i-2], u[i-xres],
-                       r[j], T, B, v[j]);
+    {
+        guint j = n-1;
+        unew[j] = mc_step8(u[j],
+                           u[i], u[j-xres], u[xres-1], u[j-1],
+                           u[0], u[xres-2], u[i-2], u[i-xres],
+                           r[j], T, B, v[j]);
+    }
 }
 
 static inline gdouble
@@ -549,14 +556,12 @@ field_rk4_step(GwyField *vfield, const gint *u,
 {
     guint xres = vfield->xres, yres = vfield->yres, n = xres*yres;
     gdouble *v = gwy_field_get_data(vfield);
-    guint k;
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(u,v,n,mu,nu,dt) \
-            private(k)
+            shared(u,v,n,mu,nu,dt)
 #endif
-    for (k = 0; k < n; k++)
+    for (guint k = 0; k < n; k++)
         v[k] = v_rk4_step(v[k], u[k], mu, nu, dt);
 }
 
