@@ -1,5 +1,5 @@
 /*
- *  $Id: dunes.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: dunes.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2022 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -162,11 +162,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -537,8 +537,8 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     if (field && do_initialise) {
         gdouble min, avg, q;
 
-        min = gwy_field_get_min(field);
-        avg = gwy_field_get_avg(field);
+        min = gwy_field_min(field);
+        avg = gwy_field_mean(field);
         if (avg > min) {
             q = coverage/(avg - min);
             f = gwy_field_get_data_const(field);
