@@ -1,5 +1,5 @@
 /*
- *  $Id: fbrownian.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: fbrownian.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2014-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -160,11 +160,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -488,7 +488,7 @@ execute(ModuleArgs *args)
     recurse(fbm, 0, 0, fbm->xres-1, fbm->yres-1, 0);
     fbrownian_state_free(fbm);
 
-    rms = gwy_field_get_rms(result);
+    rms = gwy_field_rms(result);
     if (rms)
         gwy_field_multiply(result, sigma/rms);
 
