@@ -1,5 +1,5 @@
 /*
- *  $Id: fourier.c 29099 2026-01-07 17:02:38Z yeti-dn $
+ *  $Id: fourier.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2007-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -148,11 +148,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -363,25 +363,20 @@ static void
 init_gauss_generalized(GwyField *finit_re, GwyField *buf_re, GwyField *buf_im,
                        gdouble tau, gdouble p)
 {
-    gint i, xres, yres;
     gdouble tau2 = tau*tau;
-    gdouble *bre, *fre;
 
-    xres = gwy_field_get_xres(finit_re);
-    yres = gwy_field_get_yres(finit_re);
-    bre = gwy_field_get_data(buf_re);
+    gint xres = gwy_field_get_xres(finit_re), yres = gwy_field_get_yres(finit_re);
+    gdouble *bre = gwy_field_get_data(buf_re);
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(bre,p,tau2,xres,yres) \
-            private(i)
+            shared(bre,p,tau2,xres,yres)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gdouble y = (i <= yres/2 ? i : yres-i);
         gdouble *row = bre + i*xres;
-        gint j;
 
-        for (j = 0; j < xres; j++) {
+        for (gint j = 0; j < xres; j++) {
             gdouble x = (j <= xres/2 ? j : xres-j);
             gdouble r = (x*x + y*y)/tau2;
 
@@ -392,13 +387,12 @@ init_gauss_generalized(GwyField *finit_re, GwyField *buf_re, GwyField *buf_im,
     gwy_field_fft_2d_raw(buf_re, NULL, finit_re, buf_im, GWY_TRANSFORM_DIRECTION_BACKWARD);
 
     /* Calculate magnitude of Fourier coefficients from PSDF. */
-    fre = gwy_field_get_data(finit_re);
+    gdouble *fre = gwy_field_get_data(finit_re);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(fre,xres,yres) \
-            private(i)
+            shared(fre,xres,yres)
 #endif
-    for (i = 0; i < xres*yres; i++)
+    for (gint i = 0; i < xres*yres; i++)
         fre[i] = sqrt(fabs(fre[i]));
 }
 
@@ -418,20 +412,17 @@ execute(ModuleArgs *args)
     gdouble gauss_p = gwy_params_get_double(params, PARAM_GAUSS_P);
     gdouble lorentz_tau = gwy_params_get_double(params, PARAM_LORENTZ_TAU)*G_PI/2.0;
     gdouble power_p = gwy_params_get_double(params, PARAM_POWER_P);
-    GwyField *in_re, *in_im, *out_im, *out_re = args->result;
-    gdouble *re, *im, *finit;
-    gint xres, yres, i, power10z;
+    GwyField *out_re = args->result;
+    gint xres = gwy_field_get_xres(out_re), yres = gwy_field_get_yres(out_re);
+    gint power10z;
     gdouble rms;
-    GRand *rng;
 
-    rng = g_rand_new();
+    GRand *rng = g_rand_new();
     g_rand_set_seed(rng, gwy_params_get_int(params, PARAM_SEED));
 
-    xres = gwy_field_get_xres(out_re);
-    yres = gwy_field_get_yres(out_re);
-    out_im = gwy_field_new_alike(out_re, FALSE);
-    in_re = gwy_field_new_alike(out_re, FALSE);
-    in_im = gwy_field_new_alike(out_re, FALSE);
+    GwyField *out_im = gwy_field_new_alike(out_re, FALSE);
+    GwyField *in_re = gwy_field_new_alike(out_re, FALSE);
+    GwyField *in_im = gwy_field_new_alike(out_re, FALSE);
 
     if (gauss_generalized && gauss_enable) {
         init_gauss_generalized(out_re, in_re, in_im, gauss_tau, gauss_p);
@@ -441,28 +432,26 @@ execute(ModuleArgs *args)
     else
         gwy_field_fill(out_re, 1.0);
 
-    re = gwy_field_get_data(in_re);
-    im = gwy_field_get_data(in_im);
-    finit = gwy_field_get_data(out_re);
+    gdouble *re = gwy_field_get_data(in_re);
+    gdouble *im = gwy_field_get_data(in_im);
+    gdouble *finit = gwy_field_get_data(out_re);
 
     /* Doing this always exactly the same way is necessary for reproducibility and stability.  */
-    for (i = 0; i < xres*yres; i++) {
+    for (gint i = 0; i < xres*yres; i++) {
         re[i] = g_rand_double(rng);
         im[i] = g_rand_double(rng);
     }
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(re,im,finit,xres,yres,freq_min,freq_max,power_enable,gauss_enable,lorentz_enable,power_p,gauss_tau,lorentz_tau) \
-            private(i)
+            shared(re,im,finit,xres,yres,freq_min,freq_max,power_enable,gauss_enable,lorentz_enable,power_p,gauss_tau,lorentz_tau)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         gdouble y = (i <= yres/2 ? i : yres-i)/(0.5*yres);
         gdouble *rrow = re + i*xres, *irow = im + i*xres;
         const gdouble *frow = finit + i*xres;
-        gint j;
 
-        for (j = 0; j < xres; j++) {
+        for (gint j = 0; j < xres; j++) {
             gdouble x = (j <= xres/2 ? j : xres-j)/(0.5*xres);
             gdouble r = sqrt(x*x + y*y);
             gdouble f, phi, s, c, t;
@@ -500,7 +489,7 @@ execute(ModuleArgs *args)
 
     gwy_params_get_unit(params, PARAM_DIMS0 + GWY_DIMS_PARAM_ZUNIT, &power10z);
     sigma *= gwy_exp10(power10z);
-    rms = gwy_field_get_rms(out_re);
+    rms = gwy_field_rms(out_re);
     if (rms)
         gwy_field_multiply(out_re, sigma/rms);
 
