@@ -1,5 +1,5 @@
 /*
- *  $Id: linenoise.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: linenoise.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2010-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -280,11 +280,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -920,18 +920,14 @@ make_noise_hum(ModuleArgs *args, gdouble sigma, GwyRandGenSet *rngset, PointNois
     GwyParams *params = args->params;
     gdouble wavelength = gwy_params_get_double(params, PARAM_HUM_WAVELENGTH);
     gdouble spread = gwy_params_get_double(params, PARAM_HUM_SPREAD);
-    gint ncomp = gwy_params_get_int(params, PARAM_HUM_NCOMP);
+    guint ncomp = gwy_params_get_int(params, PARAM_HUM_NCOMP);
     GwyField *field = args->result;
-    gdouble *data;
-    guint xres, yres, i, j, k;
-    HumComponent *humcomp;
+    guint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    HumComponent *humcomp = g_new(HumComponent, ncomp*yres);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    humcomp = g_new(HumComponent, ncomp*yres);
     /* Fill contributions in a manner stable wrt ncomp. */
-    for (k = 0; k < ncomp; k++) {
-        for (i = 0; i < yres; i++) {
+    for (guint k = 0; k < ncomp; k++) {
+        for (guint i = 0; i < yres; i++) {
             HumComponent *hc = humcomp + i*ncomp + k;
 
             hc->amplitude = point_noise(rngset, sigma);
@@ -939,34 +935,33 @@ make_noise_hum(ModuleArgs *args, gdouble sigma, GwyRandGenSet *rngset, PointNois
             hc->phase = 2.0*G_PI*gwy_rand_gen_set_double(rngset, RNG_POS);
         }
     }
-    for (i = 0; i < yres; i++) {
+    for (guint i = 0; i < yres; i++) {
         HumComponent *block = humcomp + i*ncomp;
         gdouble s = 0.0;
 
-        for (k = 0; k < ncomp; k++)
+        for (guint k = 0; k < ncomp; k++)
             s += block[k].amplitude * block[k].amplitude;
         if (!s)
             s = 1.0;
         s = G_SQRT2*sigma/sqrt(s);
 
-        for (k = 0; k < ncomp; k++)
+        for (guint k = 0; k < ncomp; k++)
             block[k].amplitude *= s;
     }
 
-    data = gwy_field_get_data(field);
+    gdouble *data = gwy_field_get_data(field);
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            shared(data,humcomp,xres,yres,ncomp) \
-            private(i,j,k)
+            shared(data,humcomp,xres,yres,ncomp)
 #endif
-    for (i = 0; i < yres; i++) {
+    for (guint i = 0; i < yres; i++) {
         gdouble *row = data + i*xres;
         const HumComponent *block = humcomp + i*ncomp;
 
-        for (j = 0; j < xres; j++) {
+        for (guint j = 0; j < xres; j++) {
             gdouble s = 0.0;
 
-            for (k = 0; k < ncomp; k++)
+            for (guint k = 0; k < ncomp; k++)
                 s += sin(j*block[k].frequency + block[k].phase)*block[k].amplitude;
             row[j] += s;
         }
