@@ -1,5 +1,5 @@
 /*
- *  $Id: objects.c 28822 2025-11-06 16:01:09Z yeti-dn $
+ *  $Id: objects.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2009-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -310,11 +310,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
