@@ -1,5 +1,5 @@
 /*
- *  $Id: phases.c 29099 2026-01-07 17:02:38Z yeti-dn $
+ *  $Id: phases.c 29447 2026-02-07 12:14:37Z yeti-dn $
  *  Copyright (C) 2017-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -136,11 +136,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -358,44 +358,50 @@ generate_narrow_freq_surface(gdouble freq, gdouble freq_range,
 }
 
 static void
-threshold_based_on_distance(GwyField *field, GwyField *buf1, GwyField *buf2, GwyField *result)
+threshold_based_on_distance(GwyField *field, GwyField *result)
 {
-    gdouble thresh;
+    gdouble thresh = gwy_field_otsu_threshold(field);
+    GwyNield *buf1 = gwy_field_new_nield_alike(field);
+    GwyNield *buf2 = gwy_field_new_nield_alike(field);
+    GwyField *distances1 = gwy_field_new_alike(field, FALSE);
+    GwyField *distances2 = gwy_field_new_alike(field, FALSE);
 
-    thresh = gwy_field_otsu_threshold(field);
+    /* Valleys. */
+    gwy_nield_mark_by_threshold(buf1, field, thresh, FALSE);
+    gwy_nield_thin(buf1);
+    gwy_field_mark_extrema(field, buf2, FALSE);
+    gwy_nield_union(buf1, buf2);
+    gwy_nield_invert(buf1);
+    gwy_nield_distance_transform(buf1, distances1, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
 
-    gwy_field_copy_data(field, buf1);
-    gwy_field_threshold(buf1, thresh, 0.0, 1.0);
-    gwy_field_grains_invert(buf1);
-    gwy_field_grains_thin(buf1);
-    gwy_field_mark_extrema(field, result, FALSE);
-    gwy_field_max_of_fields(buf1, result, buf1);
-    gwy_field_grains_invert(buf1);
-    gwy_field_grain_distance_transform(buf1);
+    /* Peaks. */
+    gwy_nield_mark_by_threshold(buf1, field, thresh, TRUE);
+    gwy_nield_thin(buf1);
+    gwy_field_mark_extrema(field, buf2, TRUE);
+    gwy_nield_union(buf1, buf2);
+    gwy_nield_invert(buf1);
+    gwy_nield_distance_transform(buf1, distances2, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
 
-    gwy_field_copy_data(field, buf2);
-    gwy_field_threshold(buf2, thresh, 0.0, 1.0);
-    gwy_field_grains_thin(buf2);
-    gwy_field_mark_extrema(field, result, TRUE);
-    gwy_field_max_of_fields(buf2, result, buf2);
-    gwy_field_grains_invert(buf2);
-    gwy_field_grain_distance_transform(buf2);
-
-    gwy_field_subtract_fields(result, buf1, buf2);
+    gwy_field_subtract_fields(result, distances1, distances2);
     gwy_field_threshold(result, 0.0, 0.0, 1.0);
+
+    g_object_unref(distances2);
+    g_object_unref(distances1);
+    g_object_unref(buf2);
+    g_object_unref(buf1);
 }
 
 static void
-regularise_with_asf(GwyField *field, GwyField *buf, GwyField *kernel, guint maxksize)
+regularise_with_asf(GwyField *field, GwyField *buf, GwyNield *kernel, guint maxksize)
 {
     guint i, res, xres = field->xres, yres = field->yres;
 
     gwy_field_copy_data(field, buf);
     for (i = 1; i <= maxksize; i++) {
         res = 2*i + 1;
-        gwy_field_resize(kernel, res, res);
-        gwy_field_clear(kernel);
-        gwy_field_elliptic_area_fill(kernel, 0, 0, res, res, 1.0);
+        gwy_nield_resize(kernel, res, res);
+        gwy_nield_clear(kernel);
+        gwy_nield_elliptic_fill(kernel);
         gwy_field_area_filter_min_max(field, kernel, GWY_MIN_MAX_FILTER_OPENING, 0, 0, xres, yres);
         gwy_field_area_filter_min_max(field, kernel, GWY_MIN_MAX_FILTER_CLOSING, 0, 0, xres, yres);
         gwy_field_area_filter_min_max(buf, kernel, GWY_MIN_MAX_FILTER_CLOSING, 0, 0, xres, yres);
@@ -414,7 +420,7 @@ execute(ModuleArgs *args)
     gdouble size_noise = gwy_params_get_double(params, PARAM_SIZE_NOISE);
     gdouble freq_range = size_noise, freq = G_PI/size;
     GwyField *field = args->field, *result = args->result;
-    GwyField *buf1, *buf2, *buf3, *kernel, *tmp;
+    GwyField *buf1, *buf2, *buf3, *tmp;
     guint xres, yres, kxres, kyres, extsize, extxres, extyres, asfradius;
     gint power10z;
     GwyRandGenSet *rngset;
@@ -448,14 +454,13 @@ execute(ModuleArgs *args)
     extxres = gwy_field_get_xres(tmp);
     extyres = gwy_field_get_yres(tmp);
     gwy_field_resize(buf1, extxres, extyres);
-    gwy_field_resize(buf2, extxres, extyres);
     gwy_field_resize(buf3, extxres, extyres);
 
-    kernel = gwy_field_new(kxres, kyres, 1.0, 1.0, TRUE);
-    gwy_field_elliptic_area_fill(kernel, 0, 0, kxres, kyres, 1.0);
+    GwyNield *kernel = gwy_nield_new(kxres, kyres);
+    gwy_nield_elliptic_fill(kernel);
     gwy_field_area_filter_min_max(result, kernel, GWY_MIN_MAX_FILTER_NORMALIZATION, 0, 0, xres, yres);
     gwy_field_copy_data(tmp, buf3);
-    threshold_based_on_distance(buf3, buf1, buf2, tmp);
+    threshold_based_on_distance(buf3, tmp);
     regularise_with_asf(tmp, buf1, kernel, asfradius);
 
     gwy_field_area_copy(tmp, result, extsize, extsize, xres, yres, 0, 0);
