@@ -1,5 +1,5 @@
 /*
- *  $Id: plateaus.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: plateaus.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -193,7 +193,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
     args.sampled_splines = g_array_new(FALSE, FALSE, sizeof(SampledSpline));
     args.spline_grid = g_new(GArray*, GRID_SIZE*GRID_SIZE);
     for (i = 0; i < GRID_SIZE*GRID_SIZE; i++)
@@ -202,7 +202,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
     sanitise_params(&args);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -749,7 +749,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     gdouble size_power = gwy_params_get_double(params, PARAM_SIZE_POWER);
     gboolean cancelled = FALSE, *pcancelled = &cancelled;
     GwyField *field = args->field, *result = args->result;
-    guint xres, yres, i, j, k, nseg, expected_nobj, noverlap;
+    guint xres, yres, k, nseg, expected_nobj, noverlap;
     GArray *splines = args->sampled_splines, *candidates = NULL;
     GArray **spline_grid = args->spline_grid;
     GwySynthUpdateType update;
@@ -821,6 +821,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
                 precompute_sampled_spline(spline, &ss);
                 if (!sampled_spline_is_selfintersecting(&ss)) {
                     find_intersection_candidates(&ss, splines, spline_grid, candidates, xres, yres);
+                    guint j;
                     for (j = 0; j < candidates->len; j++) {
                         k = g_array_index(candidates, guint, j);
                         if (sampled_splines_intersect(&ss, &g_array_index(splines, SampledSpline, k)))
@@ -842,7 +843,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 
     /* Generate raw heights at an arbitrary scalre and transform them to get something like the requested scale. */
     s = sw = 0.0;
-    for (i = 0; i < splines->len; i++) {
+    for (guint i = 0; i < splines->len; i++) {
         SampledSpline *ss = &g_array_index(splines, SampledSpline, i);
         r0 = ss->r0;
         ss->height = pow(ss->r0, height_power) * exp(gwy_rand_gen_set_gaussian(rngset, RNG_HEIGHT, height_noise));
@@ -850,7 +851,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         sw += r0*r0;
     }
     s /= sw;
-    for (i = 0; i < splines->len; i++) {
+    for (guint i = 0; i < splines->len; i++) {
         SampledSpline *ss = &g_array_index(splines, SampledSpline, i);
         ss->height *= height/s;
     }
@@ -863,8 +864,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     vevents = gather_vertical_events(splines, &nseg);
 #ifdef _OPENMP
 #pragma omp parallel if (gwy_threads_are_enabled()) default(none) \
-            shared(xres,yres,d,splines,vevents,nseg,pcancelled) \
-            private(i,j)
+            shared(xres,yres,d,splines,vevents,nseg,pcancelled)
 #endif
     {
         guint tno = gwy_omp_thread_num(), nthreads = gwy_omp_num_threads();
@@ -873,7 +873,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         gint nhevents, xbeforeedge, ybeforeedge = -1;
         gdouble x, y, z;
 
-        for (i = tno; i < yres; i += nthreads) {
+        for (guint i = tno; i < yres; i += nthreads) {
             y = i + 0.5;
             ybeforeedge = move_to_larger(vevents, 2*nseg, active_set, y, ybeforeedge);
             gather_image_row_events(active_set, splines, y, hevents);
@@ -881,7 +881,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
             nhevents = hevents->len;
             xbeforeedge = -1;
             z = 0.0;
-            for (j = 0; j < xres; j++) {
+            for (guint j = 0; j < xres; j++) {
                 x = j + 0.5;
                 while (xbeforeedge < nhevents-1 && g_array_index(hevents, Edge, xbeforeedge+1).t <= x) {
                     const Edge *edge = &g_array_index(hevents, Edge, xbeforeedge+1);
