@@ -166,11 +166,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_FIELD_ID, &id,
                                  0);
     args.field = field;
-    args.zscale = field ? gwy_field_get_rms(field) : -1.0;
+    args.zscale = field ? gwy_field_rms(field) : -1.0;
 
     args.params = gwy_params_new_from_settings(define_module_params());
     gwy_synth_sanitise_params(args.params, PARAM_DIMS0, field);
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -511,51 +511,44 @@ execute(ModuleArgs *args)
     gint rmin = gwy_params_get_int(params, PARAM_RMIN);
     gint rmax = gwy_params_get_int(params, PARAM_RMAX);
     gdouble rpower = gwy_params_get_double(params, PARAM_RPOWER);
-    GwyField *field = args->field, *result = args->result, *extfield;
-    gint xres, yres, n, ninq, k, i, j, m, r, still_free, target_n;
-    GRand *rng_r, *rng_old, *rng_new;
-    GwyRandGenSet *rngset;
-    SegmentLists *seglists = NULL;
-    gint power10z;
-    gint *queue;
-    gint8 *stage;
-    gdouble *d, *rcdf;
+    GwyField *field = args->field, *result = args->result;
+    gint xres = gwy_field_get_xres(result), yres = gwy_field_get_yres(result);
 
-    xres = gwy_field_get_xres(result);
-    yres = gwy_field_get_yres(result);
-
-    rngset = gwy_rand_gen_set_new(RNG_NRNGS);
+    GwyRandGenSet *rngset = gwy_rand_gen_set_new(RNG_NRNGS);
     gwy_rand_gen_set_init(rngset, gwy_params_get_int(params, PARAM_SEED));
     /* We do not use the distributions, but we would still like to have independent random number streams. */
-    rng_r = gwy_rand_gen_set_rng(rngset, RNG_SIZE);
-    rng_old = gwy_rand_gen_set_rng(rngset, RNG_OLD);
-    rng_new = gwy_rand_gen_set_rng(rngset, RNG_NEW);
+    GRand *rng_r = gwy_rand_gen_set_rng(rngset, RNG_SIZE);
+    GRand *rng_old = gwy_rand_gen_set_rng(rngset, RNG_OLD);
+    GRand *rng_new = gwy_rand_gen_set_rng(rngset, RNG_NEW);
 
+    gint power10z;
     gwy_params_get_unit(params, PARAM_DIMS0 + GWY_DIMS_PARAM_ZUNIT, &power10z);
     height *= gwy_exp10(power10z);
 
     /* When the disc wraps around the image twice some indices can become negative because (i + res) % res no longer
      * saves us. Just silently descrease the maximum size. */
     rmax = MIN(rmax, MIN(xres, yres));
+
+    gdouble *rcdf;
+    SegmentLists *seglists = NULL;
     prepare_discs(rmin, rmax, rpower, &seglists, &rcdf);
 
     gwy_field_clear(result);
-    d = gwy_field_get_data(result);
-    n = xres*yres;
-    ninq = 0;
-    queue = g_new(guint, n);
-    stage = g_new0(gint8, n);
+    gint n = xres*yres;
+    gint ninq = 0;
+    gint *queue = g_new(guint, n);
+    gint8 *stage = g_new0(gint8, n);
 
-    still_free = n;
-    target_n = GWY_ROUND(coverage*n);
+    gint still_free = n;
+    gint target_n = GWY_ROUND(coverage*n);
     while (n - still_free < target_n) {
-        r = choose_radius_bisect(rmin, rmax, rcdf, rng_r);
+        gint k, r = choose_radius_bisect(rmin, rmax, rcdf, rng_r);
         if (!ninq || g_rand_double(rng_new) < pnew) {
             k = g_rand_int_range(rng_new, 0, n);
         }
         else {
             while (ninq) {
-                m = g_rand_int_range(rng_old, 0, ninq);
+                gint m = g_rand_int_range(rng_old, 0, ninq);
                 k = queue[m];
                 if (stage[k] == EDGE)
                     break;
@@ -567,28 +560,34 @@ execute(ModuleArgs *args)
             /* We should terminate because still_free = 0, not here. */
             g_assert(ninq);
         }
-        i = k/xres;
-        j = k % xres;
+        gint i = k/xres;
+        gint j = k % xres;
 
         process_circle(stage, xres, yres, j, i, seglists + r, queue, &ninq, &still_free);
     }
 
-    for (k = 0; k < n; k++)
-        d[k] = (stage[k] == OUTSIDE);
+    GwyNield *mask = gwy_field_new_nield_alike(result);
+    gint *md = gwy_nield_get_data(mask);
+    for (gint k = 0; k < n; k++)
+        md[k] = (stage[k] == OUTSIDE);
 
-    extfield = gwy_field_extend(result, xres/4, xres/4, yres/4, yres/4, GWY_EXTERIOR_PERIODIC, 0.0, FALSE);
-    gwy_field_grain_distance_transform(extfield);
+    GwyNield *extmask = gwy_nield_extend(mask, xres/4, xres/4, yres/4, yres/4, GWY_EXTERIOR_PERIODIC, 0);
+    g_object_unref(mask);
+    gint extxres = gwy_nield_get_xres(extmask), extyres = gwy_nield_get_yres(extmask);
+    GwyField *extfield = gwy_field_new(extxres, extyres, extxres, extyres, FALSE);
+    gwy_nield_distance_transform(extmask, extfield, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
+    g_object_unref(extmask);
     gwy_field_area_copy(extfield, result, xres/4, yres/4, xres, yres, 0, 0);
     g_object_unref(extfield);
-    d = gwy_field_get_data(result);
 
-    for (k = 0; k < n; k++) {
+    gdouble *d = gwy_field_get_data(result);
+    for (gint k = 0; k < n; k++) {
         if (stage[k] == OUTSIDE) {
             gdouble t = (d[k] + 1)/edge_width;
             d[k] = height*(1.0 - exp(-0.5*t*t));
         }
         else
-            d[k] = 0;
+            d[k] = 0.0;
     }
 
     if (field && do_initialise)
