@@ -1,5 +1,5 @@
 /*
- *  $Id: roddeposit.c 28860 2025-11-14 12:59:38Z yeti-dn $
+ *  $Id: roddeposit.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2007,2009,2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -261,7 +261,7 @@ run_noninteractive(RodDepositSynthArgs *args,
         args->seed = g_random_int() & 0x7fffffff;
 
     if (replace) {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
             out = gwy_field_new_alike(dfield, FALSE);
         if (add && dfield)
@@ -329,7 +329,7 @@ run_noninteractive(RodDepositSynthArgs *args,
             }
             else {
                 newid = 0;
-                newdata = gwy_container_new();
+                newdata = gwy_dict_new();
                 gwy_file_set_image(newdata, newid, out);
                 gwy_data_browser_add(newdata);
                 gwy_data_browser_reset_visibility(newdata,
@@ -388,7 +388,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
     vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
     gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 4);
 
-    controls.mydata = gwy_container_new();
+    controls.mydata = gwy_dict_new();
     dfield = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE,
                            dimsargs->measure*PREVIEW_SIZE,
                            dimsargs->measure*PREVIEW_SIZE,
@@ -492,8 +492,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
 
-    controls.aspect_noise = gtk_adjustment_new(args->aspect_noise,
-                                         0, 2, 0.01, 0.1, 0);
+    controls.aspect_noise = gtk_adjustment_new(args->aspect_noise, 0, 2, 0.01, 0.1, 0);
     g_object_set_data(G_OBJECT(controls.aspect_noise),
                       "target", &args->aspect_noise);
     spin = gwy_table_attach_adjbar(table, row, _("A_spect ratio variance:"), "",
@@ -559,7 +558,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.outstats),
                                  args->outstats);
     g_signal_connect_swapped(controls.outstats, "toggled",
-                     G_CALLBACK(outstats_changed), &controls);
+                             G_CALLBACK(outstats_changed), &controls);
     gtk_table_attach(GTK_TABLE(table), controls.outstats,
                      0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
@@ -603,7 +602,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
             if (controls.data_done) { //this should never be needed
                report = create_xyz_report(&controls);
                gwy_save_auxiliary_data(_("Save Fit Report"), GTK_WINDOW(dialog),
-                                    -1, report->str);
+                                       -1, report->str);
                g_string_free(report, TRUE);
             }
             break;
@@ -622,7 +621,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
             preview(&controls);
 
         if (controls.dims->args->replace) {
-            gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+            gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
             gwy_field_copy_data(controls.out, controls.original);
             gwy_field_data_changed(controls.original);
             gwy_log_add(data, GWY_FILE_IMAGE, id, id);
@@ -639,7 +638,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
             }
             else {
                 newid = 0;
-                data = gwy_container_new();
+                data = gwy_dict_new();
                 gwy_file_set_image(data, newid, controls.out);
                 gwy_data_browser_add(data);
                 gwy_data_browser_reset_visibility(data,
@@ -679,8 +678,7 @@ rod_deposit_synth_dialog(RodDepositSynthArgs *args,
 
             gwy_graph_curve_model_set_data_from_line(gcmodel,
                                                      controls.stats_width, 0, 0);
-            g_object_set(gmodel, "unit-x", gwy_unit_copy(gwy_line_get_unit_x(controls.stats_width)),
-                                 NULL);
+            g_object_set(gmodel, "unit-x", gwy_unit_copy(gwy_line_get_unit_x(controls.stats_width)), NULL);
             g_object_set(gmodel,
                          "title", "Particle width histogram",
                          "axis-label-bottom", _("Particle width"),
@@ -902,24 +900,21 @@ preview(RodDepositSynthControls *controls)
     gint ndata;
     gboolean success;
 
-    dfield = GWY_FIELD(gwy_container_get_object_by_name(controls->mydata,
+    dfield = GWY_FIELD(gwy_dict_get_object_by_name(controls->mydata,
                                                              "/0/data"));
 
     if (!controls->original || !controls->dims->args->add) {   //no dfield or not to be used
         if (!controls->out) {
-
             mag = gwy_exp10(controls->dims->args->xypow10) * controls->dims->args->measure;
             controls->out = gwy_field_new(controls->dims->args->xres, controls->dims->args->yres,
-                                        mag*controls->dims->args->xres, mag*controls->dims->args->yres,
-                                        TRUE);
+                                          mag*controls->dims->args->xres, mag*controls->dims->args->yres,
+                                          TRUE);
 
             siunit = gwy_field_get_unit_xy(controls->out);
             gwy_unit_set_from_string(siunit, controls->dims->args->xyunits);
-
         }
-        else if (gwy_field_get_xres(controls->out) != controls->dims->args->xres ||
-                 gwy_field_get_yres(controls->out) != controls->dims->args->yres)
-        {
+        else if (gwy_field_get_xres(controls->out) != controls->dims->args->xres
+                 || gwy_field_get_yres(controls->out) != controls->dims->args->yres) {
             gwy_field_resample(controls->out,
                                controls->dims->args->xres,
                                controls->dims->args->yres,
@@ -927,16 +922,15 @@ preview(RodDepositSynthControls *controls)
         }
 
         mag = gwy_exp10(controls->dims->args->xypow10) * controls->dims->args->measure;
-        if (gwy_field_get_xreal(controls->out) != mag*controls->dims->args->xres ||
-            gwy_field_get_yreal(controls->out) != mag*controls->dims->args->yres)
-        {
+        if (gwy_field_get_xreal(controls->out) != mag*controls->dims->args->xres
+            || gwy_field_get_yreal(controls->out) != mag*controls->dims->args->yres) {
             gwy_field_set_xreal(controls->out, mag*controls->dims->args->xres);
             gwy_field_set_yreal(controls->out, mag*controls->dims->args->yres);
-
         }
 
         gwy_field_fill(controls->out, 0);
-    } else {
+    }
+    else {
         if (controls->out && (gwy_field_get_xres(controls->original)!=gwy_field_get_xres(controls->out) ||
             gwy_field_get_yres(controls->original)!=gwy_field_get_yres(controls->out)))
         {
@@ -1260,7 +1254,7 @@ rod_deposit_synth_do(const RodDepositSynthArgs *args,
 //    printf("do (%d %d) %g %g, norm %g\n", gwy_field_get_xres(dfield), gwy_field_get_yres(dfield),
 //                           gwy_field_get_xreal(dfield), gwy_field_get_yreal(dfield), norm);
 //    printf("size %g width %g, coverage %g, revise %d, field real %g x %g, rms %g\n",
-//           args->size, args->width, args->coverage, args->revise, oxreal, oyreal, gwy_field_get_rms(dfield));
+//           args->size, args->width, args->coverage, args->revise, oxreal, oyreal, gwy_field_rms(dfield));
 
     rngset = gwy_rand_gen_set_new(1);
     gwy_rand_gen_set_init(rngset, args->seed);
@@ -1970,23 +1964,23 @@ rod_deposit_synth_load_args(GwyFile *container,
 {
     *args = rod_deposit_synth_defaults;
 
-    gwy_container_gis_int32_by_name(container, active_page_key,
+    gwy_dict_gis_int32_by_name(container, active_page_key,
                                     &args->active_page);
-    gwy_container_gis_boolean_by_name(container, animated_key, &args->animated);
-    gwy_container_gis_boolean_by_name(container, outstats_key, &args->outstats);
-    gwy_container_gis_int32_by_name(container, seed_key, &args->seed);
-    gwy_container_gis_boolean_by_name(container, randomize_key,
+    gwy_dict_gis_boolean_by_name(container, animated_key, &args->animated);
+    gwy_dict_gis_boolean_by_name(container, outstats_key, &args->outstats);
+    gwy_dict_gis_int32_by_name(container, seed_key, &args->seed);
+    gwy_dict_gis_boolean_by_name(container, randomize_key,
                                       &args->randomize);
-    gwy_container_gis_double_by_name(container, size_key, &args->size);
-    gwy_container_gis_double_by_name(container, width_key, &args->width);
-    gwy_container_gis_double_by_name(container, coverage_key, &args->coverage);
-    gwy_container_gis_double_by_name(container, aspect_key, &args->aspect);
-    gwy_container_gis_double_by_name(container, aspect_noise_key, &args->aspect_noise);
-    gwy_container_gis_double_by_name(container, gravity_key, &args->gravity);
-    gwy_container_gis_double_by_name(container, mobility_key, &args->mobility);
-    gwy_container_gis_double_by_name(container, ljsurface_key, &args->ljsurface);
-    gwy_container_gis_double_by_name(container, ljparticle_key, &args->ljparticle);
-    gwy_container_gis_int32_by_name(container, revise_key, &args->revise);
+    gwy_dict_gis_double_by_name(container, size_key, &args->size);
+    gwy_dict_gis_double_by_name(container, width_key, &args->width);
+    gwy_dict_gis_double_by_name(container, coverage_key, &args->coverage);
+    gwy_dict_gis_double_by_name(container, aspect_key, &args->aspect);
+    gwy_dict_gis_double_by_name(container, aspect_noise_key, &args->aspect_noise);
+    gwy_dict_gis_double_by_name(container, gravity_key, &args->gravity);
+    gwy_dict_gis_double_by_name(container, mobility_key, &args->mobility);
+    gwy_dict_gis_double_by_name(container, ljsurface_key, &args->ljsurface);
+    gwy_dict_gis_double_by_name(container, ljparticle_key, &args->ljparticle);
+    gwy_dict_gis_int32_by_name(container, revise_key, &args->revise);
     rod_deposit_synth_sanitize_args(args);
 
     gwy_clear(dimsargs, 1);
@@ -1999,23 +1993,23 @@ rod_deposit_synth_save_args(GwyFile *container,
                             const RodDepositSynthArgs *args,
                             const GwyDimensionArgs *dimsargs)
 {
-    gwy_container_set_int32_by_name(container, active_page_key,
+    gwy_dict_set_int32_by_name(container, active_page_key,
                                     args->active_page);
-    gwy_container_set_boolean_by_name(container, animated_key, args->animated);
-    gwy_container_set_boolean_by_name(container, outstats_key, args->outstats);
-    gwy_container_set_int32_by_name(container, seed_key, args->seed);
-    gwy_container_set_boolean_by_name(container, randomize_key,
+    gwy_dict_set_boolean_by_name(container, animated_key, args->animated);
+    gwy_dict_set_boolean_by_name(container, outstats_key, args->outstats);
+    gwy_dict_set_int32_by_name(container, seed_key, args->seed);
+    gwy_dict_set_boolean_by_name(container, randomize_key,
                                       args->randomize);
-    gwy_container_set_double_by_name(container, size_key, args->size);
-    gwy_container_set_double_by_name(container, width_key, args->width);
-    gwy_container_set_double_by_name(container, coverage_key, args->coverage);
-    gwy_container_set_double_by_name(container, aspect_key, args->aspect);
-    gwy_container_set_double_by_name(container, aspect_noise_key, args->aspect_noise);
-    gwy_container_set_double_by_name(container, gravity_key, args->gravity);
-    gwy_container_set_double_by_name(container, mobility_key, args->mobility);
-    gwy_container_set_double_by_name(container, ljsurface_key, args->ljsurface);
-    gwy_container_set_double_by_name(container, ljparticle_key, args->ljparticle);
-    gwy_container_set_int32_by_name(container, revise_key, args->revise);
+    gwy_dict_set_double_by_name(container, size_key, args->size);
+    gwy_dict_set_double_by_name(container, width_key, args->width);
+    gwy_dict_set_double_by_name(container, coverage_key, args->coverage);
+    gwy_dict_set_double_by_name(container, aspect_key, args->aspect);
+    gwy_dict_set_double_by_name(container, aspect_noise_key, args->aspect_noise);
+    gwy_dict_set_double_by_name(container, gravity_key, args->gravity);
+    gwy_dict_set_double_by_name(container, mobility_key, args->mobility);
+    gwy_dict_set_double_by_name(container, ljsurface_key, args->ljsurface);
+    gwy_dict_set_double_by_name(container, ljparticle_key, args->ljparticle);
+    gwy_dict_set_int32_by_name(container, revise_key, args->revise);
 
     gwy_dimensions_save_args(dimsargs, container, prefix);
 }
