@@ -1,6 +1,6 @@
 /*
- *  $Id: corrlen.c 29023 2025-12-19 13:06:16Z yeti-dn $
- *  Copyright (C) 2020-2024 David Necas (Yeti), Petr Klapetek.
+ *  $Id: corrlen.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2020-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -137,7 +137,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Correlation length tool."),
     "Yeti <yeti@gwyddion.net>",
-    "3.0",
+    "3.1",
     "David Nečas (Yeti)",
     "2020",
 };
@@ -839,17 +839,17 @@ calculate(GwyToolCorrLen *tool)
     GwyParams *params = tool->params;
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     GwyOrientation orientation = gwy_params_get_enum(params, PARAM_ORIENTATION);
     CorrlenModelType model = gwy_params_get_enum(params, PARAM_MODEL);
     gint level = gwy_params_get_int(params, PARAM_LEVEL);
-    GwyField *field_to_use, *mask_to_use;
+    GwyField *field_to_use = NULL;
+    GwyNield *mask_to_use = NULL;
     GwyGraphModel *gmodel;
     GwyGraphCurveModel *gcmodel;
     GwyResults *results = tool->results;
     GwyLine *psdf, *acf, *fit, *acf_corr;
-    gdouble xoff, yoff;
     gdouble L, T_estim, acf_1e, acf_0, T_corr, sigma, sigma_corr;
     gdouble T_acf, sigma_acf, T_psdf, sigma_psdf;
     gint col, row, w, h, fxres, fyres, ncut, acfres, K;
@@ -867,22 +867,20 @@ calculate(GwyToolCorrLen *tool)
     if (w < 4 || h < 4)
         return FALSE;
 
-    xoff = gwy_field_get_xoffset(field);
-    yoff = gwy_field_get_yoffset(field);
+    gdouble xoff = gwy_field_get_xoffset(field), yoff = gwy_field_get_yoffset(field);
 
-    mask_to_use = NULL;
     if (orientation == GWY_ORIENTATION_VERTICAL) {
         field_to_use = gwy_field_new(1, 1, 1, 1, FALSE);
         gwy_field_area_transpose(field, col, row, w, h, field_to_use, FALSE);
         if (mask && masking != GWY_MASK_IGNORE) {
-            mask_to_use = gwy_field_new(1, 1, 1, 1, FALSE);
-            gwy_field_area_transpose(mask, col, row, w, h, mask_to_use, FALSE);
+            mask_to_use = gwy_nield_new(1, 1);
+            gwy_nield_area_transpose(mask, col, row, w, h, mask_to_use, FALSE);
         }
     }
     else {
         field_to_use = gwy_field_area_extract(field, col, row, w, h);
         if (mask && masking != GWY_MASK_IGNORE)
-            mask_to_use = gwy_field_area_extract(mask, col, row, w, h);
+            mask_to_use = gwy_nield_area_extract(mask, col, row, w, h);
     }
     fxres = gwy_field_get_xres(field_to_use);
     fyres = gwy_field_get_yres(field_to_use);
@@ -891,7 +889,7 @@ calculate(GwyToolCorrLen *tool)
     /* level=0 means really do nothing with individual lines */
     if (level)
         gwy_field_row_level_poly(field_to_use, mask_to_use, masking, level-1, NULL);
-    gwy_field_add(field_to_use, -gwy_field_get_avg(field));
+    gwy_field_add(field_to_use, -gwy_field_mean(field));
 
     /************************************************************************
      *
