@@ -1,6 +1,6 @@
 /*
- *  $Id: cprofile.c 28788 2025-11-04 17:13:02Z yeti-dn $
- *  Copyright (C) 2019-2022 David Necas (Yeti).
+ *  $Id: cprofile.c 29276 2026-01-17 12:27:05Z yeti-dn $
+ *  Copyright (C) 2019-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -99,7 +99,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Profile tool which reads horizontal and/or vertical scan lines."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti)",
     "2019",
 };
@@ -567,61 +567,56 @@ update_all_curves(GwyToolCprofile *tool)
     gwy_null_store_set_n_rows(store, n);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static void
 extract_column_profile(GwyField *dfield,
-                       GwyField *mask, GwyMaskingType masking,
+                       GwyNield *mask, GwyMaskingType masking,
                        GArray *xydata, gint col, gint thickness)
 {
-    gint xres, yres, jfrom, jto, i, j, count;
-    const gdouble *d, *drow, *m, *mrow;
-    gdouble dy, z;
-    GwyXY xy;
-
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    dy = gwy_field_get_dy(dfield);
-    d = gwy_field_get_data_const(dfield);
+    gint xres = gwy_field_get_xres(dfield), yres = gwy_field_get_yres(dfield);
+    gdouble dy = gwy_field_get_dy(dfield);
+    const gdouble *d = gwy_field_get_data_const(dfield);
 
     g_array_set_size(xydata, 0);
 
-    jfrom = col - (thickness - 1)/2;
+    gint jfrom = col - (thickness - 1)/2;
     jfrom = MAX(jfrom, 0);
-    jto = col + thickness/2 + 1;
+    gint jto = col + thickness/2 + 1;
     jto = MIN(jto, xres);
 
-    m = (mask ? gwy_field_get_data_const(mask) : NULL);
-    for (i = 0; i < yres; i++) {
-        drow = d + i*xres + jfrom;
-        z = 0.0;
+    const gint *m = (mask ? gwy_nield_get_data_const(mask) : NULL);
+    for (gint i = 0; i < yres; i++) {
+        const gdouble *drow = d + i*xres + jfrom;
+        gdouble z = 0.0;
+        gint count = 0;
         if (m) {
-            mrow = m + i*xres + jfrom;
+            const gint *mrow = m + i*xres + jfrom;
             count = 0;
-            if (masking == GWY_MASK_INCLUDE) {
-                for (j = 0; j < jto - jfrom; j++) {
-                    if (mrow[j] > 0.0) {
-                        z += drow[j];
-                        count++;
-                    }
-                }
-            }
-            else {
-                for (j = 0; j < jto - jfrom; j++) {
-                    if (mrow[j] <= 0.0) {
-                        z += drow[j];
-                        count++;
-                    }
+            for (gint j = 0; j < jto - jfrom; j++) {
+                if (nielded_included(mrow + j, masking)) {
+                    z += drow[j];
+                    count++;
                 }
             }
         }
         else {
             count = jto - jfrom;
-            for (j = 0; j < count; j++)
+            for (gint j = 0; j < count; j++)
                 z += drow[j];
         }
 
         if (count) {
-            xy.x = dy*i;
-            xy.y = z/count;
+            GwyXY xy = { .x = dy*i, .y = z/count };
             g_array_append_val(xydata, xy);
         }
     }
@@ -629,69 +624,54 @@ extract_column_profile(GwyField *dfield,
 
 static void
 extract_row_profile(GwyField *dfield,
-                    GwyField *mask, GwyMaskingType masking,
+                    GwyNield *mask, GwyMaskingType masking,
                     GArray *xydata, gint row, gint thickness)
 {
-    gint xres, yres, ifrom, ito, i, j;
-    const gdouble *d, *drow, *m, *mrow;
-    gdouble dx;
-    GwyXY *xy;
-
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    dx = gwy_field_get_dx(dfield);
-    d = gwy_field_get_data_const(dfield);
+    gint xres = gwy_field_get_xres(dfield), yres = gwy_field_get_yres(dfield);
+    gdouble dx = gwy_field_get_dx(dfield);
+    const gdouble *d = gwy_field_get_data_const(dfield);
 
     g_array_set_size(xydata, xres);
-    xy = &g_array_index(xydata, GwyXY, 0);
+    GwyXY *xy = &g_array_index(xydata, GwyXY, 0);
     gwy_clear(xy, xres);
 
-    ifrom = row - (thickness - 1)/2;
+    gint ifrom = row - (thickness - 1)/2;
     ifrom = MAX(ifrom, 0);
-    ito = row + thickness/2 + 1;
+    gint ito = row + thickness/2 + 1;
     ito = MIN(ito, yres);
 
-    m = (mask ? gwy_field_get_data_const(mask) : NULL);
+    const gint *m = (mask ? gwy_nield_get_data_const(mask) : NULL);
     if (!mask) {
-        for (j = 0; j < xres; j++)
+        for (gint j = 0; j < xres; j++)
             xy[j].x = ito - ifrom;
     }
 
-    for (i = ifrom; i < ito; i++) {
-        drow = d + i*xres;
+    for (gint i = ifrom; i < ito; i++) {
+        const gdouble *drow = d + i*xres;
         if (m) {
-            mrow = m + i*xres;
-            if (masking == GWY_MASK_INCLUDE) {
-                for (j = 0; j < xres; j++) {
-                    if (mrow[j] > 0.0) {
-                        xy[j].y += drow[j];
-                        xy[j].x += 1.0;
-                    }
-                }
-            }
-            else {
-                for (j = 0; j < xres; j++) {
-                    if (mrow[j] <= 0.0) {
-                        xy[j].y += drow[j];
-                        xy[j].x += 1.0;
-                    }
+            const gint *mrow = m + i*xres;
+            for (gint j = 0; j < xres; j++) {
+                if (nielded_included(mrow + j, masking)) {
+                    xy[j].y += drow[j];
+                    xy[j].x += 1.0;
                 }
             }
         }
         else {
-            for (j = 0; j < xres; j++)
+            for (gint j = 0; j < xres; j++)
                 xy[j].y += drow[j];
         }
     }
 
-    for (i = j = 0; j < xres; j++) {
+    gint n = 0;
+    for (gint j = 0; j < xres; j++) {
         if (xy[j].x > 0.0) {
-            xy[i].y = xy[j].y/xy[j].x;
-            xy[i].x = dx*j;
-            i++;
+            xy[n].y = xy[j].y/xy[j].x;
+            xy[n].x = dx*j;
+            n++;
         }
     }
-    g_array_set_size(xydata, i);
+    g_array_set_size(xydata, n);
 }
 
 static void
@@ -751,7 +731,7 @@ update_curve(GwyToolCprofile *tool, gint i)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyDirectionFlags mode = gwy_params_get_enum(tool->params, PARAM_MODE);
     gboolean zero_cross = gwy_params_get_boolean(tool->params, PARAM_ZERO_CROSS);
     gint thickness = gwy_params_get_int(tool->params, PARAM_THICKNESS);
