@@ -1,5 +1,5 @@
 /*
- *  $Id: crop.c 28858 2025-11-13 14:32:56Z yeti-dn $
+ *  $Id: crop.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003-2023 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -257,17 +257,12 @@ gwy_tool_crop_selection_changed(GwyPlainTool *plain_tool,
 }
 
 static void
-crop_one_field(GwyField *field,
-               const gint *isel,
-               const gdouble *sel,
-               gboolean keep_offsets)
+set_offsets(GwyField *field, const gdouble *sel, gdouble xoff, gdouble yoff, gboolean keep_off)
 {
-    gdouble xoff = (keep_offsets ? gwy_field_get_xoffset(field) + sel[0] : 0.0);
-    gdouble yoff = (keep_offsets ? gwy_field_get_yoffset(field) + sel[1] : 0.0);
-
-    gwy_field_crop(field, isel[0], isel[1], isel[2]+1 - isel[0], isel[3]+1 - isel[0]);
-    gwy_field_set_xoffset(field, xoff);
-    gwy_field_set_yoffset(field, yoff);
+    if (keep_off) {
+        gwy_field_set_xoffset(field, xoff + sel[0]);
+        gwy_field_set_yoffset(field, yoff + sel[1]);
+    }
 }
 
 static void
@@ -276,17 +271,19 @@ crop_into_new_channel(GwyToolCrop *tool)
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyFile *file = GWY_FILE(plain_tool->container);
     gboolean keep_off = gwy_params_get_boolean(tool->params, PARAM_KEEP_OFFSETS);
-    GwyField *field = plain_tool->field, *mask = plain_tool->mask_field, *show = plain_tool->show_field;
+    GwyField *field = plain_tool->field, *show = plain_tool->show_field, *newfield;
+    GwyNield *mask = plain_tool->mask_field;
     gint id, oldid = plain_tool->id;
-    gint isel[4];
+    gint col = tool->isel[0], row = tool->isel[1];
+    gint width = tool->isel[2]+1 - tool->isel[0], height = tool->isel[3]+1 - tool->isel[0];
+    gdouble xoff = gwy_field_get_xoffset(field), yoff = gwy_field_get_yoffset(field);
     gdouble rsel[4];
 
-    gwy_assign(isel, tool->isel, 4);
     gwy_assign(rsel, tool->rsel, 4);
 
-    field = gwy_field_copy(field);
-    crop_one_field(field, isel, rsel, keep_off);
-    id = gwy_file_add_image(file, field);
+    newfield = gwy_field_area_extract(field, col, row, width, height);
+    set_offsets(newfield, tool->rsel, xoff, yoff, keep_off);
+    id = gwy_file_add_image(file, newfield);
     gwy_file_set_visible(file, GWY_FILE_IMAGE, id, TRUE);
     g_object_unref(field);
     gwy_file_sync_items(file, GWY_FILE_IMAGE, oldid,
@@ -297,15 +294,14 @@ crop_into_new_channel(GwyToolCrop *tool)
     gwy_log_add_full(file, GWY_FILE_IMAGE, oldid, id, "tool::GwyToolCrop", NULL);
 
     if (mask) {
-        mask = gwy_field_copy(mask);
-        crop_one_field(mask, isel, rsel, keep_off);
+        mask = gwy_nield_area_extract(mask, col, row, width, height);
         gwy_file_pass_image_mask(file, id, mask);
     }
 
     if (show) {
-        show = gwy_field_copy(show);
-        crop_one_field(show, isel, rsel, keep_off);
-        gwy_container_pass_object(GWY_CONTAINER(file), gwy_file_key_image_picture(id), show);
+        newfield = gwy_field_area_extract(show, col, row, width, height);
+        set_offsets(newfield, tool->rsel, xoff, yoff, keep_off);
+        gwy_dict_pass_object(GWY_DICT(file), gwy_file_key_image_picture(id), show);
     }
 }
 
@@ -314,18 +310,15 @@ crop_in_place_maybe_all(GwyToolCrop *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyFile *file = GWY_FILE(plain_tool->container);
-    GwyField *field = plain_tool->field, *otherfield;
+    GwyField *field = plain_tool->field;
     gboolean keep_off = gwy_params_get_boolean(tool->params, PARAM_KEEP_OFFSETS);
     gboolean crop_all = gwy_params_get_boolean(tool->params, PARAM_ALL);
-    guint i, n;
     gint *ids;
-    GArray *undo_quarks;
     gchar *qualname;
-    GQuark quark;
-    gint isel[4];
+    gint col = tool->isel[0], row = tool->isel[1];
+    gint width = tool->isel[2]+1 - tool->isel[0], height = tool->isel[3]+1 - tool->isel[0];
     gdouble rsel[4];
 
-    gwy_assign(isel, tool->isel, 4);
     gwy_assign(rsel, tool->rsel, 4);
 
     if (!crop_all) {
@@ -336,34 +329,46 @@ crop_in_place_maybe_all(GwyToolCrop *tool)
     else
         ids = gwy_file_get_ids(file, GWY_FILE_IMAGE);
 
-    undo_quarks = g_array_new(FALSE, FALSE, sizeof(GQuark));
-    for (i = n = 0; ids[i] > -1; i++) {
-        quark = gwy_file_key_image(ids[i]);
-        otherfield = gwy_file_get_image(file, ids[i]);
-        if (gwy_field_is_incompatible(field, otherfield, GWY_DATA_MISMATCH_ALL))
+    GArray *undo_quarks = g_array_new(FALSE, FALSE, sizeof(GQuark));
+    gint n = 0;
+    for (gint i = 0; ids[i] > -1; i++) {
+        GQuark quark = gwy_file_key_image(ids[i]);
+        GwyField *otherfield = gwy_file_get_image(file, ids[i]);
+        if (gwy_field_is_incompatible(field, otherfield, GWY_DATA_MISMATCH_LATERAL))
             continue;
 
         g_array_append_val(undo_quarks, quark);
 
         quark = gwy_file_key_image_mask(ids[i]);
-        if (gwy_container_contains(plain_tool->container, quark))
+        if (gwy_dict_contains(plain_tool->container, quark))
             g_array_append_val(undo_quarks, quark);
 
         quark = gwy_file_key_image_picture(ids[i]);
-        if (gwy_container_contains(plain_tool->container, quark))
+        if (gwy_dict_contains(plain_tool->container, quark))
             g_array_append_val(undo_quarks, quark);
 
         ids[n++] = ids[i];
     }
     ids[n] = -1;
     gwy_app_undo_qcheckpointv(plain_tool->container, undo_quarks->len, &g_array_index(undo_quarks, GQuark, 0));
-    for (i = 0; i < undo_quarks->len; i++) {
-        field = gwy_container_get_object(plain_tool->container, g_array_index(undo_quarks, GQuark, i));
-        crop_one_field(field, isel, rsel, keep_off);
-        gwy_field_data_changed(field);
+
+    for (gint i = 0; i < undo_quarks->len; i++) {
+        GObject *object = gwy_dict_get_object(plain_tool->container, g_array_index(undo_quarks, GQuark, i));
+        if (GWY_IS_FIELD(object)) {
+            field = GWY_FIELD(object);
+            gdouble xoff = gwy_field_get_xoffset(field), yoff = gwy_field_get_yoffset(field);
+            gwy_field_crop(field, col, row, width, height);
+            set_offsets(field, tool->rsel, xoff, yoff, keep_off);
+            gwy_field_data_changed(field);
+        }
+        else if (GWY_IS_NIELD(object)) {
+            GwyNield *nield = GWY_NIELD(object);
+            gwy_nield_crop(nield, col, row, width, height);
+            gwy_nield_data_changed(nield);
+        }
     }
     qualname = g_strconcat("tool::", G_OBJECT_TYPE_NAME(plain_tool), NULL);
-    for (i = 0; ids[i] > -1; i++) {
+    for (gint i = 0; ids[i] > -1; i++) {
         gwy_file_remove_selections(file, GWY_FILE_IMAGE, ids[i]);
         gwy_log_add_full(file, GWY_FILE_IMAGE, ids[i], ids[i], qualname, NULL);
     }
