@@ -1,5 +1,5 @@
 /*
- *  $Id: distance.c 28788 2025-11-04 17:13:02Z yeti-dn $
+ *  $Id: distance.c 29407 2026-01-30 15:34:09Z yeti-dn $
  *  Copyright (C) 2003-2022 Nenad Ocelic, David Necas (Yeti), Petr Klapetek.
  *  E-mail: ocelic@biochem.mpg.de, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -423,7 +423,7 @@ format_report(gpointer user_data)
         dx = gwy_field_get_dx(plain_tool->field);
         dy = gwy_field_get_dy(plain_tool->field);
         vf_dist = gwy_unit_get_format(xyunit, style, fmin(dx, dy), NULL);
-        gwy_field_get_min_max(plain_tool->field, &dx, &dy);
+        gwy_field_min_max(plain_tool->field, &dx, &dy);
         vf_dz = gwy_unit_get_format(zunit, style, fmax(fabs(dx), fabs(dy))/120.0, NULL);
         vf_phi = gwy_value_format_new(G_PI/180.0, 0, _("deg"));
     }
