@@ -1,6 +1,6 @@
 /*
- *  $Id: filter.c 28844 2025-11-10 16:07:51Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: filter.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -93,10 +93,6 @@ static void         filter_area_sharpen              (GwyField *dfield,
                                                       gint row,
                                                       gint width,
                                                       gint height);
-static void         apply_masking                    (GwyField *dfield,
-                                                      GwyField *orig,
-                                                      GwyField *mask,
-                                                      GwyMaskingType masking);
 static gboolean     filter_is_sized                  (FilterType type);
 static gboolean     filter_is_float_sized            (FilterType type);
 static gboolean     filter_needs_kernel              (FilterType type);
@@ -107,7 +103,7 @@ static GwyModuleInfo module_info = {
     N_("Filter tool, processes selected part of data with a filter (conservative denoise, mean, median, "
        "Kuwahara, minimum, maximum)."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "4.0",
+    "4.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -367,8 +363,9 @@ gwy_tool_filter_apply(GwyToolFilter *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
-    GwyField *origfield = NULL, *kernel = NULL;
+    GwyNield *mask = plain_tool->mask_field;
+    GwyField *origfield = NULL;
+    GwyNield *kernel = NULL;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     FilterType filter_type = gwy_params_get_enum(tool->params, PARAM_FILTER_TYPE);
     gdouble sigma = gwy_params_get_double(tool->params, PARAM_SIZE_GAUSS);
@@ -385,10 +382,8 @@ gwy_tool_filter_apply(GwyToolFilter *tool)
     gwy_app_undo_qcheckpoint(plain_tool->container, gwy_file_key_image(plain_tool->id), 0);
 
     if (filter_needs_kernel(filter_type)) {
-        kernel = gwy_field_new(size, size, size, size, TRUE);
-        n = gwy_field_elliptic_area_fill(kernel, 0, 0, size, size, 1.0);
-        if (filter_type == FILTER_MEAN)
-            gwy_field_multiply(kernel, 1.0/n);
+        kernel = gwy_nield_new(size, size);
+        n = gwy_nield_elliptic_fill(kernel);
     }
 
     /*
@@ -403,8 +398,12 @@ gwy_tool_filter_apply(GwyToolFilter *tool)
     if (mask)
         origfield = gwy_field_copy(field);
 
-    if (filter_type == FILTER_MEAN)
-        gwy_field_area_ext_convolve(field, col, row, w, h, field, kernel, GWY_EXTERIOR_BORDER, 0.0, FALSE);
+    if (filter_type == FILTER_MEAN) {
+        GwyField *convkernel = gwy_field_new(size, size, size, size, FALSE);
+        gwy_field_fill_mask(convkernel, kernel, 0.0, 1.0/n);
+        gwy_field_area_ext_convolve(field, col, row, w, h, field, convkernel, GWY_EXTERIOR_BORDER, 0.0, FALSE);
+        g_object_unref(convkernel);
+    }
     else if (filter_type == FILTER_MEDIAN)
         gwy_field_area_filter_kth_rank(field, kernel, col, row, w, h, n/2, NULL);
     else if (filter_type == FILTER_MINIMUM)
@@ -434,7 +433,8 @@ gwy_tool_filter_apply(GwyToolFilter *tool)
     }
 
     if (origfield) {
-        apply_masking(field, origfield, plain_tool->mask_field, masking);
+        GwyMaskingType invmasking = (masking == GWY_MASK_INCLUDE ? GWY_MASK_EXCLUDE : GWY_MASK_INCLUDE);
+        gwy_field_copy_data_mask(origfield, field, mask, invmasking);
         g_object_unref(origfield);
     }
 
@@ -466,33 +466,6 @@ filter_area_sharpen(GwyField *dfield, gdouble sigma,
     g_object_unref(origpart);
 }
 
-static void
-apply_masking(GwyField *dfield, GwyField *orig, GwyField *mask,
-              GwyMaskingType masking)
-{
-    const gdouble *r = gwy_field_get_data_const(orig);
-    const gdouble *m = gwy_field_get_data_const(mask);
-    gdouble *d = gwy_field_get_data(dfield);
-    gint xres = gwy_field_get_xres(dfield);
-    gint yres = gwy_field_get_yres(dfield);
-    gint k;
-
-    if (masking == GWY_MASK_INCLUDE) {
-        for (k = 0; k < xres*yres; k++) {
-            if (m[k] <= 0.0)
-                d[k] = r[k];
-        }
-    }
-    else {
-        for (k = 0; k < xres*yres; k++) {
-            if (m[k] > 0.0)
-                d[k] = r[k];
-        }
-    }
-
-    gwy_field_invalidate(dfield);
-}
-
 static gboolean
 filter_is_float_sized(FilterType type)
 {
