@@ -1,6 +1,6 @@
 /*
- *  $Id: grainremover.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: grainremover.c 29447 2026-02-07 12:14:37Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -67,19 +67,24 @@ static void         gwy_tool_grain_remover_data_switched     (GwyTool *gwytool,
 static void         gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool);
 static void         param_changed                            (GwyToolGrainRemover *tool,
                                                               gint id);
+static void         expand_bbox                              (GwyNield *nield,
+                                                              gint *bbox);
 static void         laplace_interpolation                    (GwyField *field,
-                                                              GwyField *grain);
+                                                              GwyNield *grain,
+                                                              const gint *bbox);
 static void         fractal_laplace_interpolation            (GwyField *field,
-                                                              GwyField *grain);
+                                                              GwyNield *grain,
+                                                              const gint *bbox);
 static void         fill_with_zero                           (GwyField *field,
-                                                              GwyField *grain);
+                                                              GwyNield *grain,
+                                                              const gint *bbox);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Grain removal tool, removes continuous parts of mask and/or underlying data."),
     "Petr Klapetek <klapetek@gwyddion.net>, Yeti <yeti@gwyddion.net>",
-    "4.0",
+    "5.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -228,8 +233,7 @@ gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool)
     RemoveMode mode = gwy_params_get_enum(tool->params, PARAM_MODE);
     RemoveAlgorithm method = gwy_params_get_enum(tool->params, PARAM_METHOD);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
-    GwyField *tmp;
+    GwyNield *mask = plain_tool->mask_field;
     gint col, row;
     gdouble point[2];
     GQuark quarks[2];
@@ -237,9 +241,9 @@ gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool)
     if (!mask || !gwy_selection_get_object(plain_tool->selection, 0, point))
         return;
 
-    row = floor(gwy_field_rtoi(mask, point[1]));
-    col = floor(gwy_field_rtoj(mask, point[0]));
-    if (!gwy_field_get_val(mask, col, row))
+    row = floor(gwy_field_rtoi(field, point[1]));
+    col = floor(gwy_field_rtoj(field, point[0]));
+    if (!gwy_nield_get_val(mask, col, row))
         return;
 
     quarks[0] = quarks[1] = 0;
@@ -250,16 +254,19 @@ gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool)
 
     gwy_app_undo_qcheckpointv(plain_tool->container, 2, quarks);
     if (mode & GRAIN_REMOVE_DATA) {
-        tmp = gwy_field_copy(mask);
-        gwy_field_grains_extract_grain(tmp, col, row);
+        GwyNield *tmp = gwy_nield_copy(mask);
+        gint bbox[4];
+        gwy_nield_isolate_at(tmp, col, row, bbox);
+        expand_bbox(mask, bbox);
+
         if (method == GRAIN_REMOVE_LAPLACE)
-            laplace_interpolation(field, tmp);
+            laplace_interpolation(field, tmp, bbox);
         else if (method == GRAIN_REMOVE_FRACTAL)
             gwy_field_fractal_correction(field, tmp, GWY_INTERPOLATION_LINEAR);
         else if (method == GRAIN_REMOVE_FRACTAL_LAPLACE)
-            fractal_laplace_interpolation(field, tmp);
+            fractal_laplace_interpolation(field, tmp, bbox);
         else if (method == GRAIN_REMOVE_ZERO)
-            fill_with_zero(field, tmp);
+            fill_with_zero(field, tmp, bbox);
         else {
             g_assert_not_reached();
         }
@@ -267,8 +274,8 @@ gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool)
         gwy_field_data_changed(field);
     }
     if (mode & GRAIN_REMOVE_MASK) {
-        gwy_field_grains_remove_grain(mask, col, row);
-        gwy_field_data_changed(mask);
+        gwy_nield_clear_at(mask, col, row);
+        gwy_nield_data_changed(mask);
     }
     gwy_params_save_to_settings(tool->params);   /* Ensure correct parameters in the log. */
     gwy_plain_tool_log_add(plain_tool);
@@ -276,50 +283,30 @@ gwy_tool_grain_remover_selection_finished(GwyPlainTool *plain_tool)
 }
 
 static void
-find_grain_bbox(GwyField *mask,
-                gint *col, gint *row, gint *w, gint *h)
+expand_bbox(GwyNield *nield, gint *bbox)
 {
-    gint xres, yres, xmin, xmax, ymin, ymax, i, j;
-    const gdouble *data;
-
-    /* Find mask bounds */
-    xmin = ymin = G_MAXINT;
-    xmax = ymax = -1;
-    xres = gwy_field_get_xres(mask);
-    yres = gwy_field_get_yres(mask);
-    data = gwy_field_get_data_const(mask);
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
-            if (data[i*xres + j]) {
-                if (i < ymin)
-                    ymin = i;
-                if (i > ymax)
-                    ymax = i;
-                if (j < xmin)
-                    xmin = j;
-                if (j > xmax)
-                    xmax = j;
-            }
-        }
+    if (bbox[0] > 0) {
+        bbox[0]--;
+        bbox[2]++;
     }
-    g_return_if_fail(xmax > -1 && ymax > -1);
-    *col = MAX(0, xmin-1);
-    *row = MAX(0, ymin-1);
-    *w = MIN(xres, xmax+2) - *col;
-    *h = MIN(yres, ymax+2) - *row;
+    if (bbox[1] > 0) {
+        bbox[1]--;
+        bbox[3]++;
+    }
+    if (bbox[0] + bbox[2] < gwy_nield_get_xres(nield))
+        bbox[2]++;
+    if (bbox[1] + bbox[3] < gwy_nield_get_yres(nield))
+        bbox[3]++;
 }
 
 static void
-laplace_interpolation(GwyField *field,
-                      GwyField *grain)
+laplace_interpolation(GwyField *field, GwyNield *grain, const gint *bbox)
 {
-    GwyField *area, *mask;
-    gint col, row, w, h;
+    gint col = bbox[0], row = bbox[1], w = bbox[2], h = bbox[3];
 
     /* Work on extracted area for better memory locality. */
-    find_grain_bbox(grain, &col, &row, &w, &h);
-    area = gwy_field_area_extract(field, col, row, w, h);
-    mask = gwy_field_area_extract(grain, col, row, w, h);
+    GwyField *area = gwy_field_area_extract(field, col, row, w, h);
+    GwyNield *mask = gwy_nield_area_extract(grain, col, row, w, h);
     gwy_field_laplace_solve(area, mask, 1, 2.0);
     g_object_unref(mask);
     gwy_field_area_copy(area, field, 0, 0, w, h, col, row);
@@ -329,62 +316,59 @@ laplace_interpolation(GwyField *field,
 /* XXX: Common with spotremove.c */
 static void
 blend_fractal_and_laplace(GwyField *field,
-                          GwyField *area,
+                          GwyField *laplace_area,
                           GwyField *distances,
                           gint col, gint row)
 {
-    gint xres, w, h, i, j, k, kk;
-    const gdouble *a, *e;
-    gdouble *d;
-    gdouble t;
+    gint xres = gwy_field_get_xres(field);
+    gint w = gwy_field_get_xres(laplace_area);
+    gint h = gwy_field_get_yres(laplace_area);
+    const gdouble *a = gwy_field_get_data_const(laplace_area);
+    const gdouble *e = gwy_field_get_data_const(distances);
+    gdouble *d = gwy_field_get_data(field) + row*xres + col;
 
-    xres = gwy_field_get_xres(field);
-    w = gwy_field_get_xres(area);
-    h = gwy_field_get_yres(area);
-    a = gwy_field_get_data_const(area);
-    e = gwy_field_get_data_const(distances);
-    d = gwy_field_get_data(field) + row*xres + col;
-
-    for (i = k = kk = 0; i < h; i++) {
-        for (j = 0; j < w; j++, k++, kk++) {
-            if (e[k] <= 0.0)
+#ifdef _OPENMP
+#pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
+            shared(a,e,d,xres,h,w)
+#endif
+    for (gint i = 0; i < h; i++) {
+        gdouble *drow = d + xres*i;
+        const gdouble *arow = a + w*i;
+        const gdouble *erow = e + w*i;
+        for (gint j = 0; j < w; j++) {
+            if (erow[j] <= 0.0)
                 continue;
 
-            t = exp(0.167*(1.0 - e[k]));
-            d[kk] *= (1.0 - t);
-            d[kk] += t*a[k];
+            gdouble t = exp(0.167*(1.0 - erow[j]));
+            drow[j] *= (1.0 - t);
+            drow[j] += t*arow[j];
         }
-        kk += xres - w;
     }
 }
 
 static void
-fractal_laplace_interpolation(GwyField *field,
-                              GwyField *grain)
+fractal_laplace_interpolation(GwyField *field, GwyNield *grain, const gint *bbox)
 {
-    GwyField *area, *mask;
-    gint col, row, w, h;
+    gint col = bbox[0], row = bbox[1], w = bbox[2], h = bbox[3];
 
     /* Extract the area for Laplace.  Then overwrite it with fractal interpolation. */
-    find_grain_bbox(grain, &col, &row, &w, &h);
-    area = gwy_field_area_extract(field, col, row, w, h);
-    mask = gwy_field_area_extract(grain, col, row, w, h);
-    gwy_field_laplace_solve(area, mask, 1, 1.0);
-    gwy_field_grain_distance_transform(mask);
+    GwyField *laplace = gwy_field_area_extract(field, col, row, w, h);
+    GwyNield *mask = gwy_nield_area_extract(grain, col, row, w, h);
+    gwy_field_laplace_solve(laplace, mask, 1, 1.0);
+    GwyField *distances = gwy_field_new_alike(laplace, FALSE);
+    gwy_nield_distance_transform(mask, distances, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
+    g_object_unref(mask);
 
     gwy_field_fractal_correction(field, grain, GWY_INTERPOLATION_LINEAR);
-    blend_fractal_and_laplace(field, area, mask, col, row);
-    g_object_unref(mask);
-    g_object_unref(area);
+    blend_fractal_and_laplace(field, laplace, distances, col, row);
+    g_object_unref(laplace);
+    g_object_unref(distances);
 }
 
 static void
-fill_with_zero(GwyField *field,
-               GwyField *grain)
+fill_with_zero(GwyField *field, GwyNield *grain, const gint *bbox)
 {
-    gint col, row, w, h;
-
-    find_grain_bbox(grain, &col, &row, &w, &h);
+    gint col = bbox[0], row = bbox[1], w = bbox[2], h = bbox[3];
     gwy_field_area_fill(field, grain, GWY_MASK_INCLUDE, col, row, w, h, 0.0);
 }
 
