@@ -1,6 +1,6 @@
 /*
- *  $Id: icolorange.c 29092 2026-01-06 16:14:51Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: icolorange.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -130,7 +130,7 @@ static GwyModuleInfo module_info = {
     N_("Interactive color range tool, allows selecting the data range false color scale should map to, "
        "either on data or on height distribution histogram."),
     "Yeti <yeti@gwyddion.net>",
-    "4.3",
+    "4.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -202,11 +202,11 @@ static void
 gwy_tool_color_range_init(GwyToolColorRange *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
-    GwyContainer *settings = gwy_app_settings_get();
+    GwyDict *settings = gwy_app_settings_get();
 
     tool->params = gwy_params_new_from_settings(define_module_params());
-    if (!gwy_container_contains_by_name(settings, APP_RANGE_KEY))
-        gwy_container_set_enum_by_name(settings, APP_RANGE_KEY, GWY_COLOR_MAPPING_FULL);
+    if (!gwy_dict_contains_by_name(settings, APP_RANGE_KEY))
+        gwy_dict_set_enum_by_name(settings, APP_RANGE_KEY, GWY_COLOR_MAPPING_FULL);
 
     plain_tool->unit_style = GWY_UNIT_FORMAT_VFMARKUP;
 
@@ -342,7 +342,7 @@ gwy_tool_color_range_init_dialog(GwyToolColorRange *tool)
     gwy_help_add_to_tool_dialog(dialog, GWY_TOOL(tool), GWY_HELP_DEFAULT);
 
     /* Switch to the default */
-    gwy_container_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &mapping);
+    gwy_dict_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &mapping);
     gwy_radio_buttons_set_current(tool->modelist, mapping);
     type_changed(NULL, tool);
 
@@ -565,7 +565,7 @@ type_changed(GtkWidget *radio,
     gwy_param_table_set_sensitive(tool->table, PARAM_USE_SELECTION, fixed_sens);
 
     old_mode = -1;
-    gwy_container_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &old_mode);
+    gwy_dict_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &old_mode);
     gtk_widget_set_sensitive(tool->is_default, old_mode != mapping);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->is_default), old_mode == mapping);
     gwy_tool_color_range_mask_changed(plain_tool);
@@ -578,7 +578,7 @@ set_default_mode(GtkToggleButton *check,
     if (!gtk_toggle_button_get_active(check))
         return;
 
-    gwy_container_set_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, get_range_type(tool));
+    gwy_dict_set_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, get_range_type(tool));
     /* This is a bit silly.  However unchecking the check box has not defined meaning, so just don't allow it. */
     gtk_widget_set_sensitive(tool->is_default, FALSE);
 }
@@ -593,7 +593,7 @@ get_range_type(GwyToolColorRange *tool)
     if (plain_tool->data_view)
         mapping = gwy_data_view_get_color_mapping(plain_tool->data_view);
     else
-        gwy_container_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &mapping);
+        gwy_dict_gis_enum_by_name(gwy_app_settings_get(), APP_RANGE_KEY, &mapping);
 
     return mapping;
 }
@@ -604,7 +604,7 @@ set_range_type(GwyToolColorRange *tool,
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     g_return_if_fail(plain_tool->data_view);
-    gwy_container_set_enum(plain_tool->container, gwy_file_key_image_color_mapping(plain_tool->id), mapping);
+    gwy_dict_set_enum(plain_tool->container, gwy_file_key_image_color_mapping(plain_tool->id), mapping);
 }
 
 static void
@@ -617,8 +617,8 @@ get_min_max(GwyToolColorRange *tool,
     g_return_if_fail(plain_tool->data_view && plain_tool->field);
 
     for (i = 0; i < 2; i++) {
-        selection[i] = gwy_field_get_min(plain_tool->field);
-        gwy_container_gis_double(plain_tool->container, tool->key_min_max[i], &selection[i]);
+        selection[i] = gwy_field_min(plain_tool->field);
+        gwy_dict_gis_double(plain_tool->container, tool->key_min_max[i], &selection[i]);
     }
 }
 
@@ -648,8 +648,7 @@ set_min_max(GwyToolColorRange *tool)
         if (!plain_tool->selection || !gwy_selection_get_data(plain_tool->selection, NULL) || w <= 1 || h <= 1)
             clear = TRUE;
         else {
-            gwy_field_area_get_min_max(plain_tool->field, NULL, GWY_MASK_IGNORE, col, row, w, h,
-                                       &sel[0], &sel[1]);
+            gwy_field_area_min_max(plain_tool->field, NULL, GWY_MASK_IGNORE, col, row, w, h, &sel[0], &sel[1]);
         }
     }
     else if (tool->range_source == USE_HISTOGRAM) {
@@ -664,12 +663,12 @@ set_min_max(GwyToolColorRange *tool)
 
     if (clear) {
         for (i = 0; i < 2; i++)
-            gwy_container_remove(plain_tool->container, tool->key_min_max[i]);
-        gwy_field_get_min_max(plain_tool->field, &sel[0], &sel[1]);
+            gwy_dict_remove(plain_tool->container, tool->key_min_max[i]);
+        gwy_field_min_max(plain_tool->field, &sel[0], &sel[1]);
     }
     else {
         for (i = 0; i < 2; i++)
-            gwy_container_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
+            gwy_dict_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
     }
 
     if (!tool->programmatic_update) {
@@ -691,7 +690,7 @@ update_fullrange(GwyToolColorRange *tool)
     gchar buf[64];
 
     if (plain_tool->container) {
-        gwy_field_get_min_max(plain_tool->field, &min, &max);
+        gwy_field_min_max(plain_tool->field, &min, &max);
         g_snprintf(buf, sizeof(buf), "%.*f%s%s", vf->precision, min/vf->magnitude, *vf->units ? " " : "", vf->units);
         gwy_param_table_info_set_valuestr(tool->table, INFO_MINIMUM, buf);
         g_snprintf(buf, sizeof(buf), "%.*f%s%s", vf->precision, max/vf->magnitude, *vf->units ? " " : "", vf->units);
@@ -716,7 +715,7 @@ update_histogram(GwyToolColorRange *tool)
         return;
     }
 
-    gwy_field_dh(plain_tool->field, tool->heightdist, 0);
+    gwy_field_height_dist(plain_tool->field, tool->heightdist, 0);
     /* rescale to sqrt to make more readable  */
     gwy_line_sqrt(tool->heightdist);
 
@@ -743,7 +742,7 @@ param_changed(GwyToolColorRange *tool, gint id)
 
     for (i = 0; i < 2; i++) {
         sel[i] = gwy_params_get_double(tool->params, PARAM_START + i)*vf->magnitude;
-        gwy_container_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
+        gwy_dict_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
     }
 
     tool->programmatic_update = TRUE;
@@ -755,7 +754,8 @@ static void
 set_range_using_mask(GwyToolColorRange *tool, GwyMaskingType masking)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
-    GwyField *dfield = plain_tool->field, *mask = plain_tool->mask_field;
+    GwyField *dfield = plain_tool->field;
+    GwyNield *mask = plain_tool->mask_field;
     const GwyValueFormat *vf = plain_tool->value_format;
     gdouble sel[2];
     gint i;
@@ -763,13 +763,13 @@ set_range_using_mask(GwyToolColorRange *tool, GwyMaskingType masking)
     if (!dfield)
         return;
 
-    gwy_field_area_get_min_max(dfield, mask, masking, 0, 0, dfield->xres, dfield->yres, &sel[0], &sel[1]);
+    gwy_field_area_min_max(dfield, mask, masking, 0, 0, dfield->xres, dfield->yres, &sel[0], &sel[1]);
     /* No valid pixels? */
     if (sel[1] < sel[0])
-        gwy_field_get_min_max(dfield, &sel[0], &sel[1]);
+        gwy_field_min_max(dfield, &sel[0], &sel[1]);
 
     for (i = 0; i < 2; i++)
-        gwy_container_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
+        gwy_dict_set_double(plain_tool->container, tool->key_min_max[i], sel[i]);
 
     tool->programmatic_update = TRUE;
     gwy_selection_set_data(tool->graph_selection, 1, sel);
