@@ -1,6 +1,6 @@
 /*
- *  $Id: linestats.c 29023 2025-12-19 13:06:16Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: linestats.c 29543 2026-02-24 14:07:07Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -49,8 +49,6 @@ struct _GwyToolLineStats {
 
     GwyRectSelectionLabels *rlabels;
 
-    GwyLine *line;
-    GwyLine *weights;
     gint isel[4];
     gint isel_prev[4];
 
@@ -191,8 +189,6 @@ gwy_tool_line_stats_finalize(GObject *object)
 
     gwy_params_save_to_settings(tool->params);
     g_clear_object(&tool->params);
-    g_clear_object(&tool->line);
-    g_clear_object(&tool->weights);
     g_clear_object(&tool->gmodel);
 
     G_OBJECT_CLASS(gwy_tool_line_stats_parent_class)->finalize(object);
@@ -207,8 +203,6 @@ gwy_tool_line_stats_init(GwyToolLineStats *tool)
     plain_tool->lazy_updates = TRUE;
 
     tool->params = gwy_params_new_from_settings(define_module_params());
-    tool->line = gwy_line_new(4, 1.0, FALSE);
-    tool->weights = gwy_line_new(4, 1.0, FALSE);
     memset(tool->isel_prev, 0xff, 4*sizeof(gint));
 
     gwy_plain_tool_connect_selection(plain_tool, GWY_TYPE_LAYER_RECTANGLE, "rectangle");
@@ -374,11 +368,10 @@ update_curve(GwyToolLineStats *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     GwyOrientation dir = gwy_params_get_enum(tool->params, PARAM_DIRECTION);
     GwyLineStatQuantity quantity = gwy_params_get_enum(tool->params, PARAM_OUTPUT_TYPE);
-    GwyGraphCurveModel *gcmodel;
     gchar *result;
     gint nsel, col, row, w, h;
     const gchar *title;
@@ -411,31 +404,28 @@ update_curve(GwyToolLineStats *tool)
     if (nsel == 0)
         return;
 
-    gwy_field_area_get_line_stats(field, plain_tool->mask_field, masking, tool->line, tool->weights,
-                                  col, row, w, h, quantity, dir);
+    GwyLine *weights = gwy_line_new(1, 1.0, FALSE);
+    GwyLine *stats = gwy_field_area_line_stats(field, mask, masking, col, row, w, h, quantity, dir, weights);
+    GwyGraphCurveModel *gcmodel = gwy_graph_curve_model_new();
+    if (!set_data_from_line_filtered(gcmodel, stats, weights, 5.0))
+        goto finalise;
 
-    gcmodel = gwy_graph_curve_model_new();
-    if (!set_data_from_line_filtered(gcmodel, tool->line, tool->weights, 5.0)) {
-        g_object_unref(gcmodel);
-        return;
-    }
     gwy_graph_model_add_curve(tool->gmodel, gcmodel);
     g_object_set(gcmodel, "mode", GWY_GRAPH_CURVE_LINE, NULL);
-    g_object_unref(gcmodel);
 
     title = _(gwy_enum_to_string(quantity, quantities, G_N_ELEMENTS(quantities)));
     g_object_set(gcmodel, "description", title, NULL);
     g_object_set(tool->gmodel, "title", title, NULL);
-    gwy_graph_model_set_units_from_line(tool->gmodel, tool->line);
+    gwy_graph_model_set_units_from_line(tool->gmodel, stats);
     gwy_param_table_data_id_refilter(tool->table_options, PARAM_TARGET_GRAPH);
 
-    siunit = gwy_line_get_unit_y(tool->line);
-    format = gwy_unit_get_format(siunit, GWY_UNIT_FORMAT_MARKUP, gwy_line_avg(tool->line), NULL);
+    siunit = gwy_line_get_unit_y(stats);
+    format = gwy_unit_get_format(siunit, GWY_UNIT_FORMAT_MARKUP, gwy_line_mean(stats), NULL);
     if (quantity == GWY_LINE_STAT_RMS)
-        calculate_avg_rms_for_rms(tool->line, &avg, &rms);
+        calculate_avg_rms_for_rms(stats, &avg, &rms);
     else {
-        avg = gwy_line_avg(tool->line);
-        rms = gwy_line_rms(tool->line);
+        avg = gwy_line_mean(stats);
+        rms = gwy_line_rms(stats);
     }
 
     if (*format->units)
@@ -446,6 +436,11 @@ update_curve(GwyToolLineStats *tool)
     gwy_param_table_info_set_valuestr(tool->table_quantity, INFO_AVERAGE, result);
     g_free(result);
     gtk_dialog_set_response_sensitive(GTK_DIALOG(GWY_TOOL(tool)->dialog), GTK_RESPONSE_APPLY, TRUE);
+
+finalise:
+    g_object_unref(gcmodel);
+    g_object_unref(stats);
+    g_object_unref(weights);
 }
 
 static void
