@@ -1,6 +1,6 @@
 /*
- *  $Id: maskedit.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: maskedit.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -81,10 +81,10 @@ typedef enum {
     MASK_TOOL_FILL_ERASE  = 3,
 } MaskEditTool;
 
-typedef void  (*FieldFillFunc)      (GwyField*, gint, gint, gint, gint, gdouble);
-typedef void  (*FieldExtractFunc)   (GwyField*, gint, gint, gint, gint, gdouble*);
-typedef void  (*FieldUnextractFunc) (GwyField*, gint, gint, gint, gint, const gdouble*);
-typedef gsize (*FieldSizeFunc)      (gint, gint);
+typedef gsize (*FillFunc)    (GwyNield *mask, gint col, gint row, gint width, gint height, gint value);
+typedef gsize (*ExtractFunc) (GwyNield *mask, gint col, gint row, gint width, gint height, gint *data);
+typedef void  (*InsertFunc)  (GwyNield *mask, gint col, gint row, gint width, gint height, const gint *data);
+typedef gsize (*SizeFunc)    (gint col, gint row, gint width, gint height);
 
 #define GWY_TYPE_TOOL_MASK_EDITOR            (gwy_tool_mask_editor_get_type())
 #define GWY_TOOL_MASK_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GWY_TYPE_TOOL_MASK_EDITOR, GwyToolMaskEditor))
@@ -112,32 +112,32 @@ struct _GwyToolMaskEditorClass {
     GwyPlainToolClass parent_class;
 };
 
-static gboolean     module_register                        (void);
-static GwyParamDef* define_module_params                   (void);
-static GType        gwy_tool_mask_editor_get_type          (void)                      G_GNUC_CONST;
-static void         gwy_tool_mask_editor_finalize          (GObject *object);
-static void         gwy_tool_mask_editor_init_dialog       (GwyToolMaskEditor *tool);
-static void         gwy_tool_mask_editor_data_switched     (GwyTool *gwytool,
-                                                            GwyDataView *data_view);
-static void         gwy_tool_mask_editor_mask_changed      (GwyPlainTool *plain_tool);
-static void         gwy_tool_mask_editor_selection_changed (GwyPlainTool *plain_tool,
-                                                            gint hint);
-static void         gwy_tool_mask_editor_selection_finished(GwyPlainTool *plain_tool);
-static void         terrible_hack                          (GwyToolMaskEditor *tool);
-static GtkWidget*   create_actions                         (gpointer user_data);
-static GtkWidget*   create_fill_voids                      (gpointer user_data);
-static GtkWidget*   create_grow_shrink                     (gpointer user_data);
-static void         connect_selection                      (GwyToolMaskEditor *tool);
-static void         setup_layer                            (GwyToolMaskEditor *tool);
-static void         param_changed                          (GwyToolMaskEditor *tool,
-                                                            gint id);
-static void         fill_nonsimple_changed                 (GwyToolMaskEditor *tool,
-                                                            GtkToggleButton *toggle);
-static void         run_action                             (GwyToolMaskEditor *tool,
-                                                            GtkButton *button);
-static void         bucket_fill                            (GwyToolMaskEditor *tool,
-                                                            gint j,
-                                                            gint i);
+static gboolean     module_register                   (void);
+static GwyParamDef* define_module_params              (void);
+static GType        gwy_tool_mask_editor_get_type     (void)                      G_GNUC_CONST;
+static void         gwy_tool_mask_editor_finalize     (GObject *object);
+static void         gwy_tool_mask_editor_init_dialog  (GwyToolMaskEditor *tool);
+static void         gwy_tool_mask_editor_data_switched(GwyTool *gwytool,
+                                                       GwyDataView *data_view);
+static void         gwy_tool_mask_editor_mask_changed (GwyPlainTool *plain_tool);
+static void         selection_changed                 (GwyPlainTool *plain_tool,
+                                                       gint hint);
+static void         selection_finished                (GwyPlainTool *plain_tool);
+static void         terrible_hack                     (GwyToolMaskEditor *tool);
+static GtkWidget*   create_actions                    (gpointer user_data);
+static GtkWidget*   create_fill_voids                 (gpointer user_data);
+static GtkWidget*   create_grow_shrink                (gpointer user_data);
+static void         connect_selection                 (GwyToolMaskEditor *tool);
+static void         setup_layer                       (GwyToolMaskEditor *tool);
+static void         param_changed                     (GwyToolMaskEditor *tool,
+                                                       gint id);
+static void         fill_nonsimple_changed            (GwyToolMaskEditor *tool,
+                                                       GtkToggleButton *toggle);
+static void         run_action                        (GwyToolMaskEditor *tool,
+                                                       GtkButton *button);
+static void         bucket_fill                       (GwyToolMaskEditor *tool,
+                                                       gint j,
+                                                       gint i);
 
 static GType layer_types[MASK_NLAYER_TYPES];
 
@@ -146,7 +146,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Mask editor tool, allows interactive modification of parts of the mask."),
     "Yeti <yeti@gwyddion.net>",
-    "4.2",
+    "5.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -255,8 +255,8 @@ gwy_tool_mask_editor_class_init(GwyToolMaskEditorClass *klass)
     tool_class->data_switched = gwy_tool_mask_editor_data_switched;
 
     ptool_class->mask_changed = gwy_tool_mask_editor_mask_changed;
-    ptool_class->selection_changed = gwy_tool_mask_editor_selection_changed;
-    ptool_class->selection_finished = gwy_tool_mask_editor_selection_finished;
+    ptool_class->selection_changed = selection_changed;
+    ptool_class->selection_finished = selection_finished;
 }
 
 static void
@@ -502,10 +502,9 @@ static void
 gwy_tool_mask_editor_mask_changed(GwyPlainTool *plain_tool)
 {
     GwyToolMaskEditor *tool = GWY_TOOL_MASK_EDITOR(plain_tool);
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
 
-    gwy_sensitivity_group_set_state(tool->sensgroup, SENS_MASK,
-                                    mask && gwy_field_get_max(mask) > 0.0 ? SENS_MASK : 0);
+    gwy_sensitivity_group_set_state(tool->sensgroup, SENS_MASK, mask && gwy_nield_max(mask) > 0.0 ? SENS_MASK : 0);
 }
 
 static void
@@ -577,12 +576,12 @@ setup_layer(GwyToolMaskEditor *tool)
     gwy_selection_set_max_objects(plain_tool->selection, 1);
 }
 
-static GwyField*
+static GwyNield*
 ensure_mask(GwyPlainTool *plain_tool)
 {
     if (!plain_tool->mask_field) {
-        GwyField *mask = gwy_field_new_alike(plain_tool->field, TRUE);
-        gwy_container_pass_object(plain_tool->container, gwy_file_key_image_mask(plain_tool->id), mask);
+        GwyNield *mask = gwy_field_new_nield_alike(plain_tool->field);
+        gwy_file_pass_image_mask(GWY_FILE(plain_tool->container), plain_tool->id, mask);
     }
     g_assert(plain_tool->mask_field);
     return plain_tool->mask_field;
@@ -594,7 +593,7 @@ run_action(GwyToolMaskEditor *tool, GtkButton *button)
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     MaskEditAction action = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button), "action"));
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     gint gsamount = gwy_params_get_int(tool->params, PARAM_GSAMOUNT);
     GwyDistanceTransformType dist_type = gwy_params_get_enum(tool->params, PARAM_DIST_TYPE);
     gboolean prevent_merge = gwy_params_get_boolean(tool->params, PARAM_PREVENT_MERGE);
@@ -602,229 +601,153 @@ run_action(GwyToolMaskEditor *tool, GtkButton *button)
     gboolean fill_nonsimple = gwy_params_get_boolean(tool->params, PARAM_FILL_NONSIMPLE);
     GQuark quark;
 
-    g_return_if_fail(action == ACTION_FILL ? field : mask);
+    g_return_if_fail(action == ACTION_FILL ? !!field : !!mask);
 
     quark = gwy_file_key_image_mask(plain_tool->id);
     gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
 
     if (action == ACTION_FILL) {
         mask = ensure_mask(plain_tool);
-        gwy_field_fill(mask, 1.0);
+        gwy_nield_fill(mask, 1);
     }
     else if (action == ACTION_REMOVE)
-        gwy_container_remove(plain_tool->container, quark);
+        gwy_dict_remove(plain_tool->container, quark);
     else if (action == ACTION_INVERT)
-        gwy_field_grains_invert(mask);
+        gwy_nield_invert(mask);
     else if (action == ACTION_GROW)
-        gwy_field_grains_grow(mask, gsamount, dist_type, prevent_merge);
+        gwy_nield_grow(mask, gsamount, dist_type, prevent_merge);
     else if (action == ACTION_SHRINK)
-        gwy_field_grains_shrink(mask, gsamount, dist_type, from_border);
+        gwy_nield_shrink(mask, gsamount, dist_type, TRUE, from_border);
     else if (action == ACTION_FILL_VOIDS)
-        gwy_field_fill_voids(mask, fill_nonsimple);
+        gwy_nield_fill_voids(mask, fill_nonsimple);
     else {
         g_assert_not_reached();
     }
 
     if (action != ACTION_REMOVE)
-        gwy_field_data_changed(plain_tool->mask_field);
+        gwy_nield_data_changed(plain_tool->mask_field);
 
     gwy_params_save_to_settings(tool->params);
     gwy_plain_tool_log_add(plain_tool);
 }
 
-typedef enum {
-    MASK_COUNT,
-    MASK_FILL,
-    MASK_EXTRACT,
-    MASK_UNEXTRACT,
-} MaskPixelOp;
-
-static inline void
-mask_pixel_op(gdouble *field, gint i,
-              gdouble *values, gint *j,
-              MaskPixelOp op)
-{
-    if (op == MASK_EXTRACT)
-        values[(*j)++] = field[i];
-    else if (op == MASK_UNEXTRACT)
-        field[i] = values[(*j)++];
-    else if (op == MASK_FILL)
-        field[i] = *values;
-    else
-        (*j)++;
-}
-
-/* Width is always positive; height can be negative to indicate line direction. */
-static void
-gwy_field_general_linear_area_operation(GwyField *dfield,
-                                        gint col, gint row,
-                                        gint width, gint height,
-                                        gdouble *data,
-                                        const gboolean is_4_connected,
-                                        const MaskPixelOp op)
-{
-    gboolean is_const = (op == MASK_COUNT || op == MASK_EXTRACT);
-    gint i, j, q, xres, yres;
-    gdouble *d;
-
-    xres = gwy_field_get_xres(dfield);
-    yres = gwy_field_get_yres(dfield);
-    col = CLAMP(col, 0, xres-1);
-    row = CLAMP(row, 0, yres-1);
-    width = CLAMP(width, 0, xres-col);
-    height = (height >= 0 ? CLAMP(height, 0, yres-row) : CLAMP(height, -row, 0));
-    d = (is_const ? (gdouble*)gwy_field_get_data_const(dfield) : gwy_field_get_data(dfield));
-
-    j = 0;
-    if (ABS(height) >= width) {
-        q = width/2;
-        if (height > 0) {
-            for (i = 0; i < height-1; i++) {
-                mask_pixel_op(d, (row + i)*xres + col + q/height, data, &j, op);
-                if (is_4_connected && q/height != (q + width)/height) {
-                    if (q % height >= height/2)
-                        mask_pixel_op(d, (row + i)*xres + col + q/height+1, data, &j, op);
-                    else
-                        mask_pixel_op(d, (row + i+1)*xres + col + q/height, data, &j, op);
-                }
-                q += width;
-            }
-            mask_pixel_op(d, (row + i)*xres + col + q/height, data, &j, op);
-        }
-        else {
-            height = ABS(height);
-            for (i = 0; i < height-1; i++) {
-                mask_pixel_op(d, (row - i)*xres + col + q/height, data, &j, op);
-                if (is_4_connected && q/height != (q + width)/height) {
-                    if (q % height >= height/2)
-                        mask_pixel_op(d, (row - i)*xres + col + q/height+1, data, &j, op);
-                    else
-                        mask_pixel_op(d, (row - i-1)*xres + col + q/height, data, &j, op);
-                }
-                q += width;
-            }
-            mask_pixel_op(d, (row - i)*xres + col + q/height, data, &j, op);
-        }
-    }
-    else {
-        q = height/2;
-        for (i = 0; i < width-1; i++) {
-            mask_pixel_op(d, (row + q/width)*xres + col + i, data, &j, op);
-            if (is_4_connected && q/width != (q + height)/width) {
-                if (q % width >= width/2)
-                    mask_pixel_op(d, (row + q/width + 1)*xres + col + i, data, &j, op);
-                else
-                    mask_pixel_op(d, (row + q/width)*xres + col + i+1, data, &j, op);
-            }
-            q += height;
-        }
-        mask_pixel_op(d, (row + q/width)*xres + col + i, data, &j, op);
-    }
-
-    if (!is_const)
-        gwy_field_invalidate(dfield);
-}
-
 /* Adaptors. */
-static void
-rectangular_area_fill(GwyField *dfield,
-                      gint col, gint row,
-                      gint width, gint height,
-                      gdouble value)
-{
-    gwy_field_area_fill(dfield, NULL, GWY_MASK_IGNORE, col, row, width, height, value);
-}
-
-static void
-elliptic_area_fill(GwyField *dfield,
-                   gint col, gint row,
-                   gint width, gint height,
-                   gdouble value)
-{
-    gwy_field_elliptic_area_fill(dfield, col, row, width, height, value);
-}
-
-static void
-elliptic_area_extract(GwyField *dfield,
-                      gint col, gint row,
-                      gint width, gint height,
-                      gdouble *data)
-{
-    gwy_field_elliptic_area_extract(dfield, col, row, width, height, data);
-}
-
-/* 8-continuous lines. */
 static gsize
-gwy_field_get_linear_area_size(gint width, gint height)
+rectangular_area_fill(GwyNield *nield,
+                      gint col, gint row, gint width, gint height,
+                      gint value)
 {
-    return MAX(ABS(width), ABS(height));
+    gwy_nield_area_fill(nield, NULL, GWY_MASK_IGNORE, col, row, width, height, value);
+    return width*height;
 }
 
-static void
-gwy_field_linear_area_fill(GwyField *dfield,
-                           gint col, gint row,
-                           gint width, gint height,
-                           gdouble value)
-{
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, &value, FALSE, MASK_FILL);
-}
-
-static void
-gwy_field_linear_area_extract(GwyField *dfield,
-                              gint col, gint row,
-                              gint width, gint height,
-                              gdouble *values)
-{
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, values, FALSE, MASK_EXTRACT);
-}
-
-static void
-gwy_field_linear_area_unextract(GwyField *dfield,
-                                gint col, gint row,
-                                gint width, gint height,
-                                const gdouble *values)
-{
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, (gdouble*)values,
-                                            FALSE, MASK_UNEXTRACT);
-}
-
-/* 4-continuous lines. */
 static gsize
-gwy_field_get_clinear_area_size(gint width, gint height)
+rectangular_area_extract(GwyNield *nield,
+                         gint col, gint row, gint width, gint height,
+                         gint *data)
 {
-    return ABS(width) + ABS(height) - 1;
+    const gint *d = gwy_nield_get_data(nield);
+    gint xres = gwy_nield_get_xres(nield);
+    for (gint i = 0; i < height; i++)
+        gwy_assign(data + i*width, d + (row + i)*xres + col, width);
+    return width*height;
 }
 
 static void
-gwy_field_clinear_area_fill(GwyField *dfield,
-                            gint col, gint row,
-                            gint width, gint height,
-                            gdouble value)
+rectangular_area_insert(GwyNield *nield,
+                        gint col, gint row, gint width, gint height,
+                        const gint *data)
 {
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, &value, TRUE, MASK_FILL);
+    gint *d = gwy_nield_get_data(nield);
+    gint xres = gwy_nield_get_xres(nield);
+    for (gint i = 0; i < height; i++)
+        gwy_assign(d + (row + i)*xres + col, data + i*width, width);
+}
+
+static gsize
+rectangular_area_size(G_GNUC_UNUSED gint col, G_GNUC_UNUSED gint row, gint width, gint height)
+{
+    return width*height;
+}
+
+static gsize
+elliptic_area_extract(GwyNield *nield,
+                      gint col, gint row, gint width, gint height,
+                      gint *data)
+{
+    return gwy_nield_elliptic_area_extract(nield, col, row, width, height, data, NULL, NULL);
+}
+
+static gsize
+elliptic_area_size(G_GNUC_UNUSED gint col, G_GNUC_UNUSED gint row, gint width, gint height)
+{
+    return width*height;
+}
+
+/* 8-connected lines. */
+static gsize
+linear8_area_size(gint col1, gint row1, gint col2, gint row2)
+{
+    return gwy_linear_area_size(col1, row1, col2, row2, FALSE);
+}
+
+static gsize
+linear8_area_fill(GwyNield *nield,
+                  gint col1, gint row1, gint col2, gint row2,
+                  gint value)
+{
+    return gwy_nield_linear_area_fill(nield, col1, row1, col2, row2, FALSE, value);
+}
+
+static gsize
+linear8_area_extract(GwyNield *nield,
+                     gint col1, gint row1, gint col2, gint row2,
+                     gint *values)
+{
+    return gwy_nield_linear_area_extract(nield, col1, row1, col2, row2, FALSE, values, NULL, NULL);
 }
 
 static void
-gwy_field_clinear_area_extract(GwyField *dfield,
-                               gint col, gint row,
-                               gint width, gint height,
-                               gdouble *values)
+linear8_area_insert(GwyNield *nield,
+                    gint col1, gint row1, gint col2, gint row2,
+                    const gint *values)
 {
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, values, TRUE, MASK_EXTRACT);
+    gwy_nield_linear_area_insert(nield, col1, row1, col2, row2, FALSE, values);
+}
+
+/* 4-connected lines. */
+static gsize
+linear4_area_size(gint col1, gint row1, gint col2, gint row2)
+{
+    return gwy_linear_area_size(col1, row1, col2, row2, TRUE);
+}
+
+static gsize
+linear4_area_fill(GwyNield *nield,
+                  gint col1, gint row1, gint col2, gint row2,
+                  gint value)
+{
+    return gwy_nield_linear_area_fill(nield, col1, row1, col2, row2, TRUE, value);
+}
+
+static gsize
+linear4_area_extract(GwyNield *nield,
+                     gint col1, gint row1, gint col2, gint row2,
+                     gint *values)
+{
+    return gwy_nield_linear_area_extract(nield, col1, row1, col2, row2, TRUE, values, NULL, NULL);
 }
 
 static void
-gwy_field_clinear_area_unextract(GwyField *dfield,
-                                 gint col, gint row,
-                                 gint width, gint height,
-                                 const gdouble *values)
+linear4_area_insert(GwyNield *nield,
+                    gint col1, gint row1, gint col2, gint row2,
+                    const gint *values)
 {
-    gwy_field_general_linear_area_operation(dfield, col, row, width, height, (gdouble*)values,
-                                            TRUE, MASK_UNEXTRACT);
+    gwy_nield_linear_area_insert(nield, col1, row1, col2, row2, TRUE, values);
 }
 
 static void
-gwy_tool_mask_editor_selection_finished(GwyPlainTool *plain_tool)
+selection_finished(GwyPlainTool *plain_tool)
 {
     GwyToolMaskEditor *tool = GWY_TOOL_MASK_EDITOR(plain_tool);
     MaskEditStyle style = gwy_params_get_enum(tool->params, PARAM_STYLE);
@@ -833,25 +756,29 @@ gwy_tool_mask_editor_selection_finished(GwyPlainTool *plain_tool)
     MaskEditLogicalOp mode = gwy_params_get_enum(tool->params, PARAM_MODE);
     gboolean lines_4_connected = gwy_params_get_boolean(tool->params, PARAM_LINES_4_CONNECTED);
     GwySelection *selection = plain_tool->selection;
-    GwyField *mask = plain_tool->mask_field;
-    FieldFillFunc fill_func = NULL;
-    FieldExtractFunc extract_func = NULL;
-    FieldUnextractFunc unextract_func = NULL;
-    FieldSizeFunc size_func = NULL;
+    GwyNield *mask = plain_tool->mask_field;
+    GwyField *field = plain_tool->field;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    FillFunc fill_func = NULL;
+    ExtractFunc extract_func = NULL;
+    InsertFunc insert_func = NULL;
+    SizeFunc size_func = NULL;
     gboolean log_it_anyway = FALSE;
-    gint col, row, width, height;
     GQuark quark;
     gdouble sel[4];
-    gint isel[4];
 
-    g_return_if_fail(plain_tool->field);
+    g_return_if_fail(field);
 
     tool->drawing_started = FALSE;
     if (!gwy_selection_get_object(selection, 0, sel))
         return;
 
-    isel[0] = floor(gwy_field_rtoj(plain_tool->field, sel[0]));
-    isel[1] = floor(gwy_field_rtoi(plain_tool->field, sel[1]));
+    gint isel[4] = {
+        (gint)floor(gwy_field_rtoj(field, sel[0])),
+        (gint)floor(gwy_field_rtoi(field, sel[1])),
+        (gint)floor(gwy_field_rtoj(field, sel[2])),
+        (gint)floor(gwy_field_rtoi(field, sel[3])),
+    };
 
     if (style == MASK_EDIT_STYLE_DRAWING) {
         if (drawtool == MASK_TOOL_PAINT_DRAW || drawtool == MASK_TOOL_PAINT_ERASE) {
@@ -862,104 +789,88 @@ gwy_tool_mask_editor_selection_finished(GwyPlainTool *plain_tool)
         }
         bucket_fill(tool, isel[0], isel[1]);
         if (plain_tool->mask_field)
-            gwy_field_data_changed(plain_tool->mask_field);
+            gwy_nield_data_changed(plain_tool->mask_field);
         return;
     }
 
-    if (shape == MASK_SHAPE_RECTANGLE)
+    if (shape == MASK_SHAPE_RECTANGLE) {
         fill_func = rectangular_area_fill;
+        extract_func = rectangular_area_extract;
+        insert_func = rectangular_area_insert;
+        size_func = rectangular_area_size;
+    }
     else if (shape == MASK_SHAPE_ELLIPSE) {
-        fill_func = elliptic_area_fill;
+        fill_func = gwy_nield_elliptic_area_fill;
         extract_func = elliptic_area_extract;
-        unextract_func = gwy_field_elliptic_area_unextract;
-        size_func = gwy_field_get_elliptic_area_size;
+        insert_func = gwy_nield_elliptic_area_insert;
+        size_func = elliptic_area_size;
     }
     else if (shape == MASK_SHAPE_LINE) {
         if (lines_4_connected) {
-            fill_func = gwy_field_clinear_area_fill;
-            extract_func = gwy_field_clinear_area_extract;
-            unextract_func = gwy_field_clinear_area_unextract;
-            size_func = gwy_field_get_clinear_area_size;
+            fill_func = linear4_area_fill;
+            extract_func = linear4_area_extract;
+            insert_func = linear4_area_insert;
+            size_func = linear4_area_size;
         }
         else {
-            fill_func = gwy_field_linear_area_fill;
-            extract_func = gwy_field_linear_area_extract;
-            unextract_func = gwy_field_linear_area_unextract;
-            size_func = gwy_field_get_linear_area_size;
+            fill_func = linear8_area_fill;
+            extract_func = linear8_area_extract;
+            insert_func = linear8_area_insert;
+            size_func = linear8_area_size;
         }
     }
     else {
         g_return_if_reached();
     }
 
-    isel[2] = floor(gwy_field_rtoj(plain_tool->field, sel[2]));
-    isel[3] = floor(gwy_field_rtoi(plain_tool->field, sel[3]));
-    if (shape == MASK_SHAPE_LINE) {
-        if (isel[2] < isel[0]) {
-            GWY_SWAP(gdouble, isel[0], isel[2]);
-            GWY_SWAP(gdouble, isel[1], isel[3]);
-        }
+    /* Lines are given using enpoints, so keep isel[] as-is for lines. For the rest, transform to width and height. */
+    if (shape != MASK_SHAPE_LINE) {
+        GWY_ORDER(gint, isel[0], isel[2]);
+        GWY_ORDER(gint, isel[1], isel[3]);
+        isel[2] = isel[2]+1 - isel[0];
+        isel[3] = isel[3]+1 - isel[1];
     }
-    else {
-        GWY_ORDER(gdouble, isel[0], isel[2]);
-        GWY_ORDER(gdouble, isel[1], isel[3]);
-    }
-    col = isel[0];
-    row = isel[1];
-    width = isel[2] - isel[0];
-    height = isel[3] - isel[1];  /* This one can be negative for lines. */
-    gwy_debug("(%d,%d) (%d,%d)", col, row, width, height);
+    gwy_debug("(%d,%d) (%d,%d)", isel[0], isel[1], isel[2], isel[3]);
 
     quark = gwy_file_key_image_mask(plain_tool->id);
     if (mode == MASK_EDIT_OP_SET) {
         gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
         mask = ensure_mask(plain_tool);
-        gwy_field_clear(mask);
-        fill_func(mask, col, row, width, height, 1.0);
+        gwy_nield_clear(mask);
+        fill_func(mask, isel[0], isel[1], isel[2], isel[3], 1);
     }
-    else if (mode == MASK_EDIT_OP_ADD && (!mask || gwy_field_get_min(mask) < 1.0)) {
+    else if (mode == MASK_EDIT_OP_ADD && (!mask || gwy_nield_count(mask) < xres*yres)) {
         gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
         mask = ensure_mask(plain_tool);
-        fill_func(mask, col, row, width, height, 1.0);
+        fill_func(mask, isel[0], isel[1], isel[2], isel[3], 1);
     }
-    else if (mode == MASK_EDIT_OP_REMOVE && mask && gwy_field_get_max(mask) > 0.0) {
+    else if (mode == MASK_EDIT_OP_REMOVE && mask && gwy_nield_count(mask)) {
         gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
-        fill_func(mask, col, row, width, height, 0.0);
-        if (!(gwy_field_get_max(mask) > 0.0)) {
-            gwy_container_remove(plain_tool->container, quark);
+        fill_func(mask, isel[0], isel[1], isel[2], isel[3], 0);
+        if (!gwy_nield_count(mask)) {
+            gwy_dict_remove(plain_tool->container, quark);
             mask = NULL;
         }
     }
-    else if (mode == MASK_EDIT_OP_INTERSECT && mask && gwy_field_get_max(mask) > 0.0) {
-        gdouble *data;
-        gint n;
-
+    else if (mode == MASK_EDIT_OP_INTERSECT && mask && gwy_nield_count(mask)) {
         gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
-        gwy_field_clamp(mask, 0.0, 1.0);
-        if (shape == MASK_SHAPE_RECTANGLE)
-            gwy_field_area_add(mask, col, row, width, height, 1.0);
-        else {
-            n = size_func(width, height);
-            data = g_new(gdouble, n);
-            extract_func(mask, col, row, width, height, data);
-            while (n)
-                data[--n] += 1.0;
-            unextract_func(mask, col, row, width, height, data);
-            g_free(data);
-        }
-        gwy_field_add(mask, -1.0);
-        gwy_field_clamp(mask, 0.0, 1.0);
-        if (!(gwy_field_get_max(mask) > 0.0)) {
-            gwy_container_remove(plain_tool->container, quark);
+
+        gsize size = size_func(isel[0], isel[1], isel[2], isel[3]);
+        gint *data = g_new(gint, size);
+        extract_func(mask, isel[0], isel[1], isel[2], isel[3], data);
+        gwy_nield_clear(mask);
+        insert_func(mask, isel[0], isel[1], isel[2], isel[3], data);
+        if (!gwy_nield_count(mask)) {
+            gwy_dict_remove(plain_tool->container, quark);
             log_it_anyway = TRUE;
             mask = NULL;
         }
     }
 
     gwy_selection_clear(selection);
-    if (mask) {
-        gwy_field_data_changed(mask);
-    }
+    if (mask)
+        gwy_nield_data_changed(mask);
+
     if (mask || log_it_anyway) {
         gwy_params_save_to_settings(tool->params);
         gwy_plain_tool_log_add(plain_tool);
@@ -971,27 +882,21 @@ bucket_fill(GwyToolMaskEditor *tool, gint j, gint i)
 {
     MaskEditTool drawtool = gwy_params_get_enum(tool->params, PARAM_TOOL);
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
-    GwyField *mask;
-    gint xres, yres, k, gno;
-    gint *g, *grains = NULL;
+    GwyNield *mask = plain_tool->mask_field;
     gboolean draw;
-    gdouble *data;
-    GQuark quark;
 
-    plain_tool = GWY_PLAIN_TOOL(tool);
-    mask = plain_tool->mask_field;
     if (!mask) {
         if (drawtool != MASK_TOOL_FILL_DRAW)
             return;
-        quark = gwy_file_key_image_mask(plain_tool->id);
+
+        GQuark quark = gwy_file_key_image_mask(plain_tool->id);
         gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
         mask = ensure_mask(plain_tool);
-        gwy_field_fill(mask, 1.0);
+        gwy_nield_fill(mask, 1);
         goto end;
     }
 
-    xres = gwy_field_get_xres(mask);
-    yres = gwy_field_get_yres(mask);
+    gint xres = gwy_nield_get_xres(mask), yres = gwy_nield_get_yres(mask);
     if (i < 0 || i >= yres || j < 0 || j >= xres)
         return;
 
@@ -1003,27 +908,20 @@ bucket_fill(GwyToolMaskEditor *tool, gint j, gint i)
         g_return_if_reached();
     }
 
-    data = gwy_field_get_data(mask);
-    if ((data[i*xres + j] && draw) || (!data[i*xres + j] && !draw))
+    gint gno = gwy_nield_get_val(mask, j, i);
+    if ((gno > 0 && draw) || (gno <= 0 && !draw))
         return;
 
-    quark = gwy_file_key_image_mask(plain_tool->id);
+    GQuark quark = gwy_file_key_image_mask(plain_tool->id);
     gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
 
-    g = grains = g_new0(gint, xres*yres);
     if (draw)
-        gwy_field_grains_invert(mask);
-    gwy_field_number_grains(mask, grains);
-    gno = grains[i*xres + j];
-
-    for (k = xres*yres; k; k--, data++, g++) {
-        if (*g == gno)
-            *data = 0.0;
-    }
+        gwy_nield_invert(mask);
+    gwy_nield_number_contiguous(mask);
+    gwy_nield_clear_by_number(mask, gwy_nield_get_val(mask, j, i), FALSE);
     if (draw)
-        gwy_field_grains_invert(mask);
+        gwy_nield_invert(mask);
 
-    g_free(grains);
 end:
     gwy_params_save_to_settings(tool->params);
     gwy_plain_tool_log_add(plain_tool);
@@ -1031,58 +929,52 @@ end:
 
 /* FIXME: This is woefully inefficient. */
 static void
-gwy_field_paint_wide_line(GwyField *dfield,
-                          gint col, gint row,
-                          gint width, gint height,
-                          gdouble radius, gdouble value)
+paint_wide_line(GwyNield *nield,
+                gint col, gint row,
+                gint width, gint height,
+                gdouble radius, gint value)
 {
-    gint i, q;
-
     if (!width && !height) {
-        gwy_field_circular_area_fill(dfield, col, row, radius, value);
+        gwy_nield_circular_area_fill(nield, col, row, radius, value);
         return;
     }
 
     if (ABS(height) >= width) {
-        q = width/2;
+        gint q = width/2;
         if (height > 0) {
-            for (i = 0; i <= height; i++) {
-                gwy_field_circular_area_fill(dfield, col + q/height, row + i, radius, value);
+            for (gint i = 0; i <= height; i++) {
+                gwy_nield_circular_area_fill(nield, col + q/height, row + i, radius, value);
                 q += width;
             }
         }
         else {
             height = ABS(height);
-            for (i = 0; i <= height; i++) {
-                gwy_field_circular_area_fill(dfield, col + q/height, row - i, radius, value);
+            for (gint i = 0; i <= height; i++) {
+                gwy_nield_circular_area_fill(nield, col + q/height, row - i, radius, value);
                 q += width;
             }
         }
     }
     else {
-        q = height/2;
-        for (i = 0; i <= width; i++) {
-            gwy_field_circular_area_fill(dfield, col+i, row + q/width, radius, value);
+        gint q = height/2;
+        for (gint i = 0; i <= width; i++) {
+            gwy_nield_circular_area_fill(nield, col+i, row + q/width, radius, value);
             q += height;
         }
     }
 }
 
 static void
-gwy_tool_mask_editor_selection_changed(GwyPlainTool *plain_tool,
-                                       G_GNUC_UNUSED gint hint)
+selection_changed(GwyPlainTool *plain_tool, G_GNUC_UNUSED gint hint)
 {
     GwyToolMaskEditor *tool = GWY_TOOL_MASK_EDITOR(plain_tool);
-    GwyField *mask = plain_tool->mask_field;
     GwyField *field = plain_tool->field;
+    GwyNield *mask = plain_tool->mask_field;
     MaskEditStyle style = gwy_params_get_enum(tool->params, PARAM_STYLE);
     MaskEditTool drawtool = gwy_params_get_enum(tool->params, PARAM_TOOL);
     gint radius = gwy_params_get_int(tool->params, PARAM_RADIUS);
     GwySelection *selection = plain_tool->selection;
-    GQuark quark;
-    gint xres, yres;
     gdouble sel[2];
-    gdouble fillvalue, r;
     gint isel[2];
 
     gwy_debug("selection %s", selection ? g_type_name(G_TYPE_FROM_INSTANCE(selection)) : "(null)");
@@ -1092,26 +984,26 @@ gwy_tool_mask_editor_selection_changed(GwyPlainTool *plain_tool,
         return;
     }
 
+    gint fillvalue;
     if (drawtool == MASK_TOOL_PAINT_DRAW)
-        fillvalue = 1.0;
+        fillvalue = 1;
     else if (drawtool == MASK_TOOL_PAINT_ERASE)
-        fillvalue = 0.0;
+        fillvalue = 0;
     else
         return;
 
-    isel[0] = floor(gwy_field_rtoj(plain_tool->field, sel[0]));
-    isel[1] = floor(gwy_field_rtoi(plain_tool->field, sel[1]));
+    isel[0] = floor(gwy_field_rtoj(field, sel[0]));
+    isel[1] = floor(gwy_field_rtoi(field, sel[1]));
 
-    quark = gwy_file_key_image_mask(plain_tool->id);
-    xres = gwy_field_get_xres(plain_tool->field);
-    yres = gwy_field_get_yres(plain_tool->field);
+    GQuark quark = gwy_file_key_image_mask(plain_tool->id);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
 
-    r = radius - 0.5;
+    gdouble r = radius - 0.5;
     if (isel[0] >= 0 && isel[0] < xres && isel[1] >= 0 && isel[1] < yres) {
         if (!tool->drawing_started) {
             gwy_app_undo_qcheckpointv(plain_tool->container, 1, &quark);
             mask = ensure_mask(plain_tool);
-            gwy_field_circular_area_fill(mask, isel[0], isel[1], r, fillvalue);
+            gwy_nield_circular_area_fill(mask, isel[0], isel[1], r, fillvalue);
         }
         else {
             gint xy[4];
@@ -1126,9 +1018,9 @@ gwy_tool_mask_editor_selection_changed(GwyPlainTool *plain_tool,
             }
             xy[2] -= xy[0];
             xy[3] -= xy[1];
-            gwy_field_paint_wide_line(mask, xy[0], xy[1], xy[2], xy[3], r, fillvalue);
+            paint_wide_line(mask, xy[0], xy[1], xy[2], xy[3], r, fillvalue);
         }
-        gwy_field_data_changed(mask);
+        gwy_nield_data_changed(mask);
         tool->oldisel[0] = isel[0];
         tool->oldisel[1] = isel[1];
         tool->drawing_started = TRUE;
