@@ -1,6 +1,6 @@
 /*
- *  $Id: profile.c 28805 2025-11-05 12:28:20Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: profile.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -113,7 +113,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Profile tool, creates profile graphs from selected lines."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "5.1",
+    "5.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -480,7 +480,7 @@ update_curve(GwyToolProfile *tool, gint i)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     gint thickness = gwy_params_get_int(tool->params, PARAM_THICKNESS);
     gboolean fixres = gwy_params_get_boolean(tool->params, PARAM_FIXRES);
@@ -507,9 +507,9 @@ update_curve(GwyToolProfile *tool, gint i)
         res = MAX(res, 4);
     }
 
-    xydata = gwy_field_get_profile_mask(field, &res, mask, masking,
-                                        line[0], line[1], line[2], line[3],
-                                        res, thickness, interp);
+    xydata = gwy_field_profile_mask(field, mask, masking,
+                                    line[0], line[1], line[2], line[3],
+                                    res, thickness, interp, &res);
     if (!xydata) {
         xydata = g_new(GwyXY, 1);
         xydata[0].x = 0.0;
@@ -654,8 +654,8 @@ estimate_orthogonal_variation(GwyField *dfield,
         if (yl2 < 0.5*dy || yl2 > yreal - 0.5*dy)
             continue;
 
-        xy = gwy_field_get_profile_mask(dfield, &nxy, NULL, GWY_MASK_IGNORE, xl1, yl1, xl2, yl2,
-                                        res, 1, GWY_INTERPOLATION_LINEAR);
+        xy = gwy_field_profile_mask(dfield, NULL, GWY_MASK_IGNORE, xl1, yl1, xl2, yl2,
+                                    res, 1, GWY_INTERPOLATION_LINEAR, &nxy);
         if (!xy)
             continue;
 
