@@ -1,6 +1,6 @@
 /*
- *  $Id: readvalue.c 28860 2025-11-14 12:59:38Z yeti-dn $
- *  Copyright (C) 2003-2023 David Necas (Yeti), Petr Klapetek.
+ *  $Id: readvalue.c 29477 2026-02-14 13:29:30Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -61,7 +61,7 @@ struct _GwyToolReadValue {
     GwyResults *results;
 
     GwyField *detail;
-    GwyField *detail_mask;
+    GwyNield *detail_mask;
 
     gdouble avg;
     gdouble bx;
@@ -143,7 +143,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Pointer tool, reads value under pointer."),
     "Yeti <yeti@gwyddion.net>",
-    "4.3",
+    "4.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -229,7 +229,7 @@ gwy_tool_read_value_init(GwyToolReadValue *tool)
     tool->params = gwy_params_new_from_settings(define_module_params());
     gwy_plain_tool_connect_selection(plain_tool, GWY_TYPE_LAYER_POINT, "pointer");
     tool->detail = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, PREVIEW_SIZE, PREVIEW_SIZE, TRUE);
-    tool->detail_mask = gwy_field_new(PREVIEW_SIZE, PREVIEW_SIZE, PREVIEW_SIZE, PREVIEW_SIZE, TRUE);
+    tool->detail_mask = gwy_nield_new(PREVIEW_SIZE, PREVIEW_SIZE);
 
     GwyResults *results = tool->results = gwy_results_new();
     gwy_results_add_value_z(results, "z", "Z");
@@ -350,7 +350,7 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
 }
 
 static gulong
-connect_to_item(GwyContainer *container, GQuark key1,
+connect_to_item(GwyDict *container, GQuark key1,
                 GCallback callback, gpointer callback_data)
 {
     gchar *sigdetail = g_strconcat("item-changed::", g_quark_to_string(key1), NULL);
@@ -474,14 +474,14 @@ resize_detail(GwyToolReadValue *tool)
     gwy_field_resize(tool->detail, newdxres, newdyres);
     gwy_field_clear(tool->detail);
 
-    gwy_field_resize(tool->detail_mask, newdxres, newdyres);
-    gwy_field_clear(tool->detail_mask);
+    gwy_nield_resize(tool->detail_mask, newdxres, newdyres);
+    gwy_nield_clear(tool->detail_mask);
 
     newzoom = (gdouble)SCALE/MAX(newdxres, newdyres)*PREVIEW_SIZE;
     gwy_debug("updating zoom to %g", newzoom);
     gwy_data_view_set_zoom(GWY_DATA_VIEW(tool->zoomview), newzoom);
     gwy_field_data_changed(tool->detail);
-    gwy_field_data_changed(tool->detail_mask);
+    gwy_nield_data_changed(tool->detail_mask);
 }
 
 static void
@@ -668,18 +668,18 @@ draw_zoom(GwyToolReadValue *tool)
 
     if (tool->xr.from < 0 || tool->yr.from < 0) {
         gwy_field_clear(tool->detail);
-        gwy_field_clear(tool->detail_mask);
+        gwy_nield_clear(tool->detail_mask);
         adapt_colour_range(tool, TRUE);
     }
     else {
         plain_tool = GWY_PLAIN_TOOL(tool);
         if (!tool->complete) {
-            min = gwy_field_area_get_min(plain_tool->field, NULL, GWY_MASK_IGNORE,
-                                         tool->xr.from, tool->yr.from,
-                                         tool->xr.to - tool->xr.from,
-                                         tool->yr.to - tool->yr.from);
+            min = gwy_field_area_min(plain_tool->field, NULL, GWY_MASK_IGNORE,
+                                     tool->xr.from, tool->yr.from,
+                                     tool->xr.to - tool->xr.from,
+                                     tool->yr.to - tool->yr.from);
             gwy_field_fill(tool->detail, min);
-            gwy_field_clear(tool->detail_mask);
+            gwy_nield_clear(tool->detail_mask);
         }
         gwy_field_area_copy(plain_tool->field, tool->detail,
                             tool->xr.from, tool->yr.from,
@@ -687,16 +687,16 @@ draw_zoom(GwyToolReadValue *tool)
                             tool->xr.dest, tool->yr.dest);
         adapt_colour_range(tool, FALSE);
         if (plain_tool->mask_field) {
-            gwy_field_area_copy(plain_tool->mask_field, tool->detail_mask,
+            gwy_nield_area_copy(plain_tool->mask_field, tool->detail_mask,
                                 tool->xr.from, tool->yr.from,
                                 tool->xr.to - tool->xr.from, tool->yr.to - tool->yr.from,
                                 tool->xr.dest, tool->yr.dest);
         }
         else
-            gwy_field_clear(tool->detail_mask);
+            gwy_nield_clear(tool->detail_mask);
     }
     gwy_field_data_changed(tool->detail);
-    gwy_field_data_changed(tool->detail_mask);
+    gwy_nield_data_changed(tool->detail_mask);
 }
 
 static void
@@ -721,14 +721,14 @@ adapt_colour_range(GwyToolReadValue *tool, gboolean make_empty)
         return;
     }
 
-    gwy_container_gis_enum(plain_tool->container, gwy_file_key_image_color_mapping(id), &range_type);
+    gwy_dict_gis_enum(plain_tool->container, gwy_file_key_image_color_mapping(id), &range_type);
     if (range_type == GWY_COLOR_MAPPING_AUTO)
-        gwy_field_get_autorange(field, &min, &max);
+        gwy_field_autorange(field, &min, &max);
     else {
-        gwy_field_get_min_max(field, &min, &max);
+        gwy_field_min_max(field, &min, &max);
         if (range_type == GWY_COLOR_MAPPING_FIXED) {
-            gwy_container_gis_double(plain_tool->container, gwy_file_key_image_range_min(id), &min);
-            gwy_container_gis_double(plain_tool->container, gwy_file_key_image_range_max(id), &max);
+            gwy_dict_gis_double(plain_tool->container, gwy_file_key_image_range_min(id), &min);
+            gwy_dict_gis_double(plain_tool->container, gwy_file_key_image_range_max(id), &max);
         }
         /* FIXME: Adaptive mapping using the distribution of different data field is currently not possible. */
     }
@@ -740,11 +740,11 @@ static void
 copy_mask_colour(GwyToolReadValue *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
-    GwyContainer *data = plain_tool->container;
+    GwyDict *data = plain_tool->container;
     gint id = plain_tool->id;
     GwyRGBA colour;
 
-    if (!data || !gwy_container_gis_boxed(data, GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &colour))
+    if (!data || !gwy_dict_gis_boxed(data, GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &colour))
         gwy_app_settings_get_default_mask_color(&colour);
     gwy_data_view_set_mask_color(GWY_DATA_VIEW(tool->zoomview), &colour);
 }
@@ -848,22 +848,21 @@ calculate(GwyToolReadValue *tool, gint col, gint row)
 
     if (radius == 1) {
         tool->avg = gwy_field_get_val(dfield, col, row);
-        tool->bx = gwy_field_get_xder(dfield, col, row);
-        tool->by = gwy_field_get_yder(dfield, col, row);
+        tool->bx = gwy_field_xder(dfield, col, row);
+        tool->by = gwy_field_yder(dfield, col, row);
         tool->k1 = tool->k2 = 0.0;
         return;
     }
 
     /* Create the arrays the first time radius > 1 is requested */
     if (!tool->values) {
-        n = gwy_field_get_circular_area_size(RADIUS_MAX - 0.5);
+        n = gwy_circular_area_size(RADIUS_MAX - 0.5);
         tool->values = g_new(gdouble, n);
         tool->xpos = g_new(gint, n);
         tool->ypos = g_new(gint, n);
     }
 
-    n = gwy_field_circular_area_extract_with_pos(dfield, col, row, radius - 0.5, tool->values,
-                                                 tool->xpos, tool->ypos);
+    n = gwy_field_circular_area_extract(dfield, col, row, radius - 0.5, tool->values, tool->xpos, tool->ypos);
     tool->avg = 0.0;
     if (!n) {
         tool->bx = tool->by = 0.0;
