@@ -1,5 +1,5 @@
 /*
- *  $Id: roughness.c 29059 2026-01-02 14:27:52Z yeti-dn $
+ *  $Id: roughness.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2006-2022 Martin Hason, David Necas (Yeti), Petr Klapetek.
  *  E-mail: hasonm@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -880,7 +880,7 @@ recalculate(GwyToolRoughness *tool)
                             "x1", line[0] + xoff, "y1", line[1] + yoff,
                             "x2", line[2] + xoff, "y2", line[3] + yoff,
                             NULL);
-    tool->line = gwy_field_get_profile(field, tool->line, xl1, yl1, xl2, yl2, lineres, thickness, interpolation);
+    tool->line = gwy_field_profile(field, tool->line, xl1, yl1, xl2, yl2, lineres, thickness, interpolation);
 
     gwy_results_fill_filename(results, "file", GWY_FILE(plain_tool->container));
     gwy_results_fill_data_name(results, "image", GWY_FILE(plain_tool->container), GWY_FILE_IMAGE, plain_tool->id);
@@ -922,11 +922,11 @@ update_parameters(GwyToolRoughness *tool)
 
     /* This definitely does something because we do not have form removed. Not sure; it affects only RP which seems to
      * be defined for zero-mean profiles. */
-    gwy_line_add(texture, -gwy_line_avg(texture));
+    gwy_line_add(texture, -gwy_line_mean(texture));
     /* This definitely does something because we do not have form removed and it should be also correct. */
-    gwy_line_add(waviness, -gwy_line_avg(waviness));
+    gwy_line_add(waviness, -gwy_line_mean(waviness));
     /* This should essentially do nothing but it is safe. */
-    gwy_line_add(roughness, -gwy_line_avg(roughness));
+    gwy_line_add(roughness, -gwy_line_mean(roughness));
 
     ra = gwy_line_ra(roughness);
     rq = gwy_line_rms(roughness);
