@@ -1,6 +1,6 @@
 /*
- *  $Id: rprofile.c 28905 2025-11-24 15:51:18Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: rprofile.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -61,7 +61,6 @@ struct _GwyToolRprofile {
     GtkTreeView *treeview;
     GtkTreeModel *model;
 
-    GwyLine *line;
     GwyGraphModel *gmodel;
 
     GtkWidget *options;
@@ -108,7 +107,7 @@ static void         render_color                       (GtkCellLayout *layout,
                                                         GtkTreeIter *iter,
                                                         gpointer user_data);
 static gdouble      angular_average_mismatch           (GwyField *field,
-                                                        GwyField *mask,
+                                                        GwyNield *mask,
                                                         GwyMaskingType masking,
                                                         gdouble x,
                                                         gdouble y,
@@ -120,7 +119,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates angularly averaged profile graphs."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2018",
 };
@@ -188,7 +187,6 @@ gwy_tool_rprofile_finalize(GObject *object)
 
     gwy_params_save_to_settings(tool->params);
     g_clear_object(&tool->params);
-    g_clear_object(&tool->line);
     if (tool->model) {
         gtk_tree_view_set_model(tool->treeview, NULL);
         g_clear_object(&tool->model);
@@ -470,7 +468,7 @@ update_curve(GwyToolRprofile *tool, gint i)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     GwyGraphCurveModel *gcmodel;
     gdouble xc, yc, r, line[4];
@@ -488,15 +486,13 @@ update_curve(GwyToolRprofile *tool, gint i)
     r = 0.5*hypot(line[2] - line[0], line[3] - line[1]);
 
     /* Just create some line when there is none. */
-    if (!tool->line)
-        tool->line = gwy_line_new(1, 1.0, FALSE);
     r = fmax(r, hypot(gwy_field_get_dx(field), gwy_field_get_dy(field)));
-    gwy_field_angular_average(field, mask, masking, tool->line, xc, yc, r, lineres);
+    GwyLine *profile = gwy_field_angular_average(field, mask, masking, xc, yc, r, lineres);
 
     n = gwy_graph_model_get_n_curves(tool->gmodel);
     if (i < n) {
         gcmodel = gwy_graph_model_get_curve(tool->gmodel, i);
-        gwy_graph_curve_model_set_data_from_line(gcmodel, tool->line, 0, 0);
+        gwy_graph_curve_model_set_data_from_line(gcmodel, profile, 0, 0);
     }
     else {
         gcmodel = gwy_graph_curve_model_new();
@@ -508,7 +504,7 @@ update_curve(GwyToolRprofile *tool, gint i)
                      "color", color,
                      NULL);
         g_free(desc);
-        gwy_graph_curve_model_set_data_from_line(gcmodel, tool->line, 0, 0);
+        gwy_graph_curve_model_set_data_from_line(gcmodel, profile, 0, 0);
         gwy_graph_model_add_curve(tool->gmodel, gcmodel);
         g_object_unref(gcmodel);
 
@@ -517,6 +513,7 @@ update_curve(GwyToolRprofile *tool, gint i)
             gwy_param_table_data_id_refilter(tool->table, PARAM_TARGET_GRAPH);
         }
     }
+    g_object_unref(profile);
 }
 
 static void
@@ -570,9 +567,20 @@ update_all_curves(GwyToolRprofile *tool)
         update_curve(tool, i);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static gdouble
 angular_average_mismatch(GwyField *field,
-                         GwyField *mask,
+                         GwyNield *mask,
                          GwyMaskingType masking,
                          gdouble x,
                          gdouble y,
@@ -581,7 +589,6 @@ angular_average_mismatch(GwyField *field,
 {
     gint ifrom, ito, jfrom, jto, k, xres, yres, i, j;
     gdouble xreal, yreal, dx, dy, xoff, yoff, h, mismatch;
-    const gdouble *d, *m;
     gdouble *target, *weight, *sum2;
 
     g_return_val_if_fail(GWY_IS_FIELD(field), G_MAXDOUBLE);
@@ -590,7 +597,7 @@ angular_average_mismatch(GwyField *field,
     yres = field->yres;
 
     if (mask) {
-        g_return_val_if_fail(GWY_IS_FIELD(mask), G_MAXDOUBLE);
+        g_return_val_if_fail(GWY_IS_NIELD(mask), G_MAXDOUBLE);
         g_return_val_if_fail(mask->xres == xres, G_MAXDOUBLE);
         g_return_val_if_fail(mask->yres == yres, G_MAXDOUBLE);
     }
@@ -617,8 +624,8 @@ angular_average_mismatch(GwyField *field,
     }
     h = r/nstats;
 
-    d = gwy_field_get_data_const(field);
-    m = mask ? gwy_field_get_data_const(mask) : NULL;
+    const gdouble *d = gwy_field_get_data_const(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
 
     /* Just return something for single-point lines. */
     if (nstats < 2 || r == 0.0)
@@ -640,17 +647,13 @@ angular_average_mismatch(GwyField *field,
     for (i = ifrom; i < ito; i++) {
         gdouble yy = (i + 0.5)*dy - y;
         for (j = jfrom; j <= jto; j++) {
-            gdouble xx = (j + 0.5)*dx - x;
-            gdouble v = d[i*xres + j];
-            gdouble rr;
-            gint kk;
-
-            if ((masking == GWY_MASK_INCLUDE && m[i*xres + j] <= 0.0)
-                || (masking == GWY_MASK_EXCLUDE && m[i*xres + j] >= 1.0))
+            if (!nielded_included(m + i*xres + j, masking))
                 continue;
 
-            rr = sqrt(xx*xx + yy*yy)/h;
-            kk = floor(rr);
+            gdouble xx = (j + 0.5)*dx - x;
+            gdouble v = d[i*xres + j];
+            gdouble rr = sqrt(xx*xx + yy*yy)/h;
+            gint kk = floor(rr);
             if (kk+1 >= nstats) {
                 if (kk+1 == nstats) {
                     sum2[3*kk + 0] += v*v;
@@ -689,7 +692,7 @@ angular_average_mismatch(GwyField *field,
 
 static gdouble
 calculate_angular_mismatch(GwyField *dfield,
-                           GwyField *mask, GwyMaskingType masking,
+                           GwyNield *mask, GwyMaskingType masking,
                            const gdouble *line, gint lineres)
 {
     gdouble xc, yc, r;
@@ -703,7 +706,7 @@ calculate_angular_mismatch(GwyField *dfield,
 
 static gboolean
 optimize_profile_at_scale(GwyField *dfield,
-                          GwyField *mask,
+                          GwyNield *mask,
                           GwyMaskingType masking,
                           gdouble r,
                           gdouble *line,
@@ -713,7 +716,7 @@ optimize_profile_at_scale(GwyField *dfield,
     enum { GRID_H = 3, GRID_N = 2*GRID_H + 1, GRID_NN = GRID_N*GRID_N };
 
     gdouble xreal = dfield->xreal, yreal = dfield->yreal;
-    gint ij, besti = 0, bestj = 0;
+    gint besti = 0, bestj = 0;
     gdouble dx = gwy_field_get_dx(dfield);
     gdouble dy = gwy_field_get_dy(dfield);
     gdouble allvar[GRID_NN];
@@ -721,14 +724,13 @@ optimize_profile_at_scale(GwyField *dfield,
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
-            shared(allvar,line,dfield,mask,masking,r,xreal,yreal,lineres) \
-            private(ij)
+            shared(allvar,line,dfield,mask,masking,r,xreal,yreal,lineres)
 #endif
     {
         gint ijfrom = gwy_omp_chunk_start(GRID_NN);
         gint ijto = gwy_omp_chunk_end(GRID_NN);
 
-        for (ij = ijfrom; ij < ijto; ij++) {
+        for (gint ij = ijfrom; ij < ijto; ij++) {
             gint i = ij/GRID_N - GRID_H, j = ij % GRID_N - GRID_H;
             gdouble offline[4] = {
                 line[0] + j*r, line[1] + i*r, line[2] + j*r, line[3] + i*r,
@@ -746,7 +748,7 @@ optimize_profile_at_scale(GwyField *dfield,
         }
     }
 
-    for (ij = 0; ij < GRID_NN; ij++) {
+    for (gint ij = 0; ij < GRID_NN; ij++) {
         gint i = ij/GRID_N - GRID_H, j = ij % GRID_N - GRID_H;
 
         if (i*i + j*j <= 2*2 + 3*3 && allvar[ij] < bestvar) {
@@ -771,7 +773,7 @@ symmetrize_profile(GwyToolRprofile *tool, gint id)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *dfield = GWY_PLAIN_TOOL(tool)->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     gdouble line_coarse[4], line_fine[4];
     gdouble r, dx, dy, h, mismatch_fine, mismatch_coarse;
