@@ -1,5 +1,5 @@
 /*
- *  $Id: selectionmanager.c 29097 2026-01-07 13:50:22Z yeti-dn $
+ *  $Id: selectionmanager.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -86,7 +86,7 @@ static void         data_switched              (GwyTool *gwytool,
                                                 GwyDataView *data_view);
 static void         file_item_changed          (GwyToolSelectionManager *tool,
                                                 GQuark key,
-                                                GwyContainer *data);
+                                                GwyDict *data);
 static void         update_selection_item      (GwyToolSelectionManager *tool,
                                                 GQuark quark,
                                                 gboolean addit);
@@ -241,7 +241,7 @@ render_name(G_GNUC_UNUSED GtkTreeViewColumn *column,
     gtk_tree_model_get(model, iter, COLUMN_KEY, &quark, -1);
     s = g_quark_to_string(quark);
     g_return_if_fail(s);
-    s = strrchr(s, GWY_CONTAINER_PATHSEP);
+    s = strrchr(s, GWY_DICT_PATHSEP);
     g_return_if_fail(s);
     g_object_set(renderer, "text", s+1, NULL);
 }
@@ -405,7 +405,7 @@ data_switched(GwyTool *gwytool, GwyDataView *data_view)
     gtk_list_store_clear(tool->model);
     if (data_view) {
         tool->prefix = g_quark_to_string(gwy_file_key_image_selection(plain_tool->id, NULL));
-        gwy_container_foreach(plain_tool->container, tool->prefix, add_selection, tool);
+        gwy_dict_foreach(plain_tool->container, tool->prefix, add_selection, tool);
     }
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tool->treeview));
@@ -415,7 +415,7 @@ data_switched(GwyTool *gwytool, GwyDataView *data_view)
 static void
 file_item_changed(GwyToolSelectionManager *tool,
                   GQuark key,
-                  G_GNUC_UNUSED GwyContainer *data)
+                  G_GNUC_UNUSED GwyDict *data)
 {
     if (tool->doing_mass_change)
         return;
@@ -446,7 +446,7 @@ update_selection_item(GwyToolSelectionManager *tool,
         return;
 
     GwySelection *sel = NULL;
-    gboolean object_exists = gwy_container_gis_object(GWY_PLAIN_TOOL(tool)->container, quark, &sel);
+    gboolean object_exists = gwy_dict_gis_object(GWY_PLAIN_TOOL(tool)->container, quark, &sel);
     if (object_exists && !GWY_IS_SELECTION(sel)) {
         gwy_debug("item which is not a Selection under /selection?");
         return;
@@ -620,7 +620,7 @@ static void
 distribute_one(GwyFile *file, gpointer user_data)
 {
     DistributeData *distdata = (DistributeData*)user_data;
-    GwyContainer *container = GWY_CONTAINER(file);
+    GwyDict *container = GWY_DICT(file);
     gint *ids;
     gint i;
 
@@ -631,7 +631,7 @@ distribute_one(GwyFile *file, gpointer user_data)
 
         /* Avoid copying to self */
         GwySelection *selection = gwy_selection_copy(distdata->selection);
-        if (gwy_container_gis_object(container, quark, &selection) && selection == distdata->selection) {
+        if (gwy_dict_gis_object(container, quark, &selection) && selection == distdata->selection) {
             gwy_debug("avoiding copy-to-self");
             continue;
         }
@@ -664,7 +664,7 @@ distribute_one(GwyFile *file, gpointer user_data)
         }
 
         if (gwy_selection_get_data(selection, NULL))
-            gwy_container_pass_object(container, quark, selection);
+            gwy_dict_pass_object(container, quark, selection);
         else {
             gwy_debug("selection empty after cropping");
             g_object_unref(selection);
@@ -782,7 +782,7 @@ delete_selection(GwyToolSelectionManager *tool)
     if (gtk_tree_selection_get_selected(treesel, &model, &iter)) {
         GQuark quark;
         gtk_tree_model_get(model, &iter, COLUMN_KEY, &quark, -1);
-        gwy_container_remove(GWY_PLAIN_TOOL(tool)->container, quark);
+        gwy_dict_remove(GWY_PLAIN_TOOL(tool)->container, quark);
     }
 }
 
@@ -799,7 +799,7 @@ setup_layer(GwyToolSelectionManager *tool,
 
     s = g_quark_to_string(quark);
     g_return_if_fail(s);
-    s = strrchr(s, GWY_CONTAINER_PATHSEP);
+    s = strrchr(s, GWY_DICT_PATHSEP);
     g_return_if_fail(s);
 
     gwy_plain_tool_connect_selection(plain_tool, selection_info[current].layer_type, s+1);
