@@ -1,6 +1,6 @@
 /*
- *  $Id: sfunctions.c 28987 2025-12-12 17:16:25Z yeti-dn $
- *  Copyright (C) 2003-2023 David Necas (Yeti), Petr Klapetek.
+ *  $Id: sfunctions.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@
 enum {
     PARAM_OUTPUT_TYPE,
     PARAM_MASKING,
-    PARAM_DIRECTION,
+    PARAM_ORIENTATION,
     PARAM_WINDOWING,
     PARAM_RESOLUTION,
     PARAM_FIXERS,
@@ -36,10 +36,10 @@ enum {
 };
 
 typedef enum {
-    GWY_SF_DH                     = 0,
-    GWY_SF_CDH                    = 1,
-    GWY_SF_DA                     = 2,
-    GWY_SF_CDA                    = 3,
+    GWY_SF_HEIGHT_DIST            = 0,
+    GWY_SF_HEIGHT_CDIST           = 1,
+    GWY_SF_ANGLE_DIST             = 2,
+    GWY_SF_ANGLE_CDIST            = 3,
     GWY_SF_ACF                    = 4,
     GWY_SF_HHCF                   = 5,
     GWY_SF_PSDF                   = 6,
@@ -77,7 +77,7 @@ struct _GwyToolSFunctions {
     gint isel_prev[4];
 
     GwyField *cached_flipped_field;
-    GwyField *cached_flipped_mask; /* Always INCLUDE, possibly flipped. */
+    GwyNield *cached_flipped_mask; /* Always INCLUDE, possibly flipped. */
 
     GwyGraphModel *gmodel;
 
@@ -111,7 +111,7 @@ static void         param_changed                        (GwyToolSFunctions *too
 static void         update_target_graphs                 (GwyToolSFunctions *tool);
 static void         gwy_tool_sfunctions_apply            (GwyToolSFunctions *tool);
 static void         make_angular_spectrum                (GwyField *field,
-                                                          GwyField *mask,
+                                                          GwyNield *mask,
                                                           GwyMaskingType masking,
                                                           gint col,
                                                           gint row,
@@ -130,6 +130,7 @@ static void         gwy_field_area_range                 (GwyField *dfield,
                                                           GwyOrientation direction,
                                                           gint lineres);
 static gboolean     sfunction_supports_masking           (GwySFOutputType type);
+static gboolean     sfunction_makes_new_line             (GwySFOutputType type);
 static gboolean     sfunction_has_native_sampling        (GwySFOutputType type);
 static gboolean     sfunction_has_direction              (GwySFOutputType type);
 static gboolean     sfunction_is_only_row_wise           (GwySFOutputType type);
@@ -141,16 +142,16 @@ static GwyModuleInfo module_info = {
     N_("Statistical function tool, calculates one-dimensional statistical functions (height distribution, "
        "correlations, PSDF, Minkowski functionals) of selected part of data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "3.5",
+    "4.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
 static const GwyEnum quantities[] =  {
-    { N_("Height distribution"),         GWY_SF_DH,                     },
-    { N_("Cum. height distribution"),    GWY_SF_CDH,                    },
-    { N_("Distribution of angles"),      GWY_SF_DA,                     },
-    { N_("Cum. distribution of angles"), GWY_SF_CDA,                    },
+    { N_("Height distribution"),         GWY_SF_HEIGHT_DIST,                     },
+    { N_("Cum. height distribution"),    GWY_SF_HEIGHT_CDIST,                    },
+    { N_("Distribution of angles"),      GWY_SF_ANGLE_DIST,                     },
+    { N_("Cum. distribution of angles"), GWY_SF_ANGLE_CDIST,                    },
     { N_("ACF"),                         GWY_SF_ACF,                    },
     { N_("HHCF"),                        GWY_SF_HHCF,                   },
     { N_("PSDF"),                        GWY_SF_PSDF,                   },
@@ -190,9 +191,9 @@ define_module_params(void)
     paramdef = gwy_param_def_new();
     gwy_param_def_set_function_name(paramdef, "sfunctions");
     gwy_param_def_add_gwyenum(paramdef, PARAM_OUTPUT_TYPE, "output_type", _("_Quantity"),
-                              quantities, G_N_ELEMENTS(quantities), GWY_SF_DH);
+                              quantities, G_N_ELEMENTS(quantities), GWY_SF_HEIGHT_DIST);
     gwy_param_def_add_enum(paramdef, PARAM_MASKING, "masking", NULL, GWY_TYPE_MASKING_TYPE, GWY_MASK_IGNORE);
-    gwy_param_def_add_enum(paramdef, PARAM_DIRECTION, "direction", NULL, GWY_TYPE_ORIENTATION,
+    gwy_param_def_add_enum(paramdef, PARAM_ORIENTATION, "orientation", NULL, GWY_TYPE_ORIENTATION,
                            GWY_ORIENTATION_HORIZONTAL);
     gwy_param_def_add_enum(paramdef, PARAM_WINDOWING, "windowing", NULL, GWY_TYPE_WINDOWING_TYPE,
                            GWY_WINDOWING_BLACKMANN);
@@ -306,7 +307,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
     gwy_param_table_append_checkbox(table, PARAM_INSTANT_UPDATE);
     gwy_param_table_append_slider(table, PARAM_RESOLUTION);
     gwy_param_table_add_enabler(table, PARAM_FIXERS, PARAM_RESOLUTION);
-    gwy_param_table_append_combo(table, PARAM_DIRECTION);
+    gwy_param_table_append_combo(table, PARAM_ORIENTATION);
     gwy_param_table_append_combo(table, PARAM_MASKING);
     gwy_param_table_append_combo(table, PARAM_WINDOWING);
     gwy_param_table_append_target_graph(table, PARAM_TARGET_GRAPH, tool->gmodel);
@@ -427,7 +428,7 @@ update_sensitivity(GwyToolSFunctions *tool)
 
     gtk_widget_set_sensitive(tool->update, !gwy_params_get_boolean(params, PARAM_INSTANT_UPDATE));
     gwy_param_table_set_sensitive(table, PARAM_RESOLUTION, !sfunction_has_native_sampling(output_type));
-    gwy_param_table_set_sensitive(table, PARAM_DIRECTION, sfunction_has_direction(output_type));
+    gwy_param_table_set_sensitive(table, PARAM_ORIENTATION, sfunction_has_direction(output_type));
     gwy_param_table_set_sensitive(table, PARAM_WINDOWING, sfunction_has_windowing(output_type));
     gwy_param_table_set_sensitive(table, PARAM_MASKING, sfunction_supports_masking(output_type));
 }
@@ -446,9 +447,9 @@ update_curve(GwyToolSFunctions *tool)
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyParams *params = tool->params;
     GwyField *dfield = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
-    GwyField *mask_to_use = NULL, *field_to_use, *levelled;
-    GwyOrientation dir = gwy_params_get_enum(params, PARAM_DIRECTION);
+    GwyNield *mask = plain_tool->mask_field, *mask_to_use = NULL;
+    GwyField *field_to_use, *levelled;
+    GwyOrientation orientation = gwy_params_get_enum(params, PARAM_ORIENTATION);
     GwyWindowingType windowing = gwy_params_get_enum(params, PARAM_WINDOWING);
     GwyMaskingType masking = gwy_params_get_masking(params, PARAM_MASKING, &mask);
     GwySFOutputType output_type = gwy_params_get_enum(params, PARAM_OUTPUT_TYPE);
@@ -493,21 +494,18 @@ update_curve(GwyToolSFunctions *tool)
      * masking.  */
     if (sfunction_supports_masking(output_type) && mask) {
         if (!tool->cached_flipped_mask) {
-            if (sfunction_is_only_row_wise(output_type) && dir == GWY_ORIENTATION_VERTICAL) {
-                tool->cached_flipped_mask = gwy_field_new_alike(mask, FALSE);
-                gwy_field_transpose(mask, tool->cached_flipped_mask, FALSE);
+            if (sfunction_is_only_row_wise(output_type) && orientation == GWY_ORIENTATION_VERTICAL) {
+                tool->cached_flipped_mask = gwy_nield_new_alike(mask);
+                gwy_nield_transpose(mask, tool->cached_flipped_mask, FALSE);
             }
             else
-                tool->cached_flipped_mask = gwy_field_copy(mask);
-
-            if (masking == GWY_MASK_EXCLUDE)
-                gwy_field_grains_invert(tool->cached_flipped_mask);
+                tool->cached_flipped_mask = g_object_ref(mask);
         }
         mask_to_use = tool->cached_flipped_mask;
     }
 
     field_to_use = dfield;
-    if (sfunction_is_only_row_wise(output_type) && dir == GWY_ORIENTATION_VERTICAL) {
+    if (sfunction_is_only_row_wise(output_type) && orientation == GWY_ORIENTATION_VERTICAL) {
         if (!tool->cached_flipped_field) {
             tool->cached_flipped_field = gwy_field_new_alike(dfield, FALSE);
             gwy_field_transpose(dfield, tool->cached_flipped_field, FALSE);
@@ -517,59 +515,60 @@ update_curve(GwyToolSFunctions *tool)
         GWY_SWAP(gint, w, h);
     }
 
-    if (output_type == GWY_SF_DH)
-        gwy_field_area_dh(field_to_use, mask_to_use, GWY_MASK_INCLUDE, tool->line, col, row, w, h, lineres);
-    else if (output_type == GWY_SF_CDH) {
-        gwy_field_area_dh(field_to_use, mask_to_use, GWY_MASK_INCLUDE, tool->line, col, row, w, h, lineres);
-        gwy_line_cumulate(tool->line, TRUE);
+    if (sfunction_makes_new_line(output_type))
+        g_clear_object(&tool->line);
+
+    if (output_type == GWY_SF_HEIGHT_DIST || output_type == GWY_SF_HEIGHT_CDIST) {
+        gwy_field_area_height_dist(field_to_use, mask_to_use, masking, tool->line, col, row, w, h, lineres);
+        if (output_type == GWY_SF_HEIGHT_CDIST)
+            gwy_line_cumulate(tool->line, TRUE);
     }
-    else if (output_type == GWY_SF_DA)
-        gwy_field_area_da(field_to_use, mask_to_use, GWY_MASK_INCLUDE, tool->line, col, row, w, h, dir, lineres);
-    else if (output_type == GWY_SF_CDA) {
-        gwy_field_area_da(field_to_use, mask_to_use, GWY_MASK_INCLUDE, tool->line, col, row, w, h, dir, lineres);
-        gwy_line_cumulate(tool->line, TRUE);
+    else if (output_type == GWY_SF_ANGLE_DIST || output_type == GWY_SF_ANGLE_CDIST) {
+        gwy_field_area_angle_dist(field_to_use, mask_to_use, masking, tool->line, col, row, w, h, orientation, lineres);
+        if (output_type == GWY_SF_ANGLE_CDIST)
+            gwy_line_cumulate(tool->line, TRUE);
     }
     else if (output_type == GWY_SF_ACF) {
-        g_object_unref(tool->line);
-        tool->line = gwy_field_area_row_acf(field_to_use, mask_to_use, GWY_MASK_INCLUDE, col, row, w, h, 1, NULL);
+        tool->line = gwy_field_area_row_acf(field_to_use, mask_to_use, masking, col, row, w, h, 1, NULL);
     }
     else if (output_type == GWY_SF_HHCF) {
-        g_object_unref(tool->line);
-        tool->line = gwy_field_area_row_hhcf(field_to_use, mask_to_use, GWY_MASK_INCLUDE, col, row, w, h, 1, NULL);
+        tool->line = gwy_field_area_row_hhcf(field_to_use, mask_to_use, masking, col, row, w, h, 1, NULL);
     }
     else if (output_type == GWY_SF_PSDF) {
-        g_object_unref(tool->line);
-        tool->line = gwy_field_area_row_psdf(field_to_use, mask_to_use, GWY_MASK_INCLUDE, col, row, w, h, windowing, 1);
+        tool->line = gwy_field_area_row_psdf(field_to_use, mask_to_use, masking, col, row, w, h, windowing, 1);
+    }
+    else if (output_type == GWY_SF_MINKOWSKI_VOLUME
+             || output_type == GWY_SF_MINKOWSKI_BOUNDARY
+             || output_type == GWY_SF_MINKOWSKI_CONNECTIVITY) {
+        GwyMinkowskiFunctional functype;
+        if (output_type == GWY_SF_MINKOWSKI_VOLUME)
+            functype = GWY_MINKOWSKI_VOLUME;
+        else if (output_type == GWY_SF_MINKOWSKI_BOUNDARY)
+            functype = GWY_MINKOWSKI_BOUNDARY;
+        else if (output_type == GWY_SF_MINKOWSKI_CONNECTIVITY)
+            functype = GWY_MINKOWSKI_CONNECTIVITY;
+        tool->line = gwy_field_area_minkowski(field_to_use, mask_to_use, masking, col, row, w, h, functype, lineres,
+                                              G_MAXDOUBLE, -G_MAXDOUBLE);
     }
-    else if (output_type == GWY_SF_MINKOWSKI_VOLUME)
-        gwy_field_area_minkowski_volume(field_to_use, tool->line, col, row, w, h, lineres);
-    else if (output_type == GWY_SF_MINKOWSKI_BOUNDARY)
-        gwy_field_area_minkowski_boundary(field_to_use, tool->line, col, row, w, h, lineres);
-    else if (output_type == GWY_SF_MINKOWSKI_CONNECTIVITY)
-        gwy_field_area_minkowski_euler(field_to_use, tool->line, col, row, w, h, lineres);
     else if (output_type == GWY_SF_RPSDF)
         gwy_field_area_rpsdf(field_to_use, tool->line, col, row, w, h, windowing, lineres);
     else if (output_type == GWY_SF_IPSDF)
         gwy_field_area_ipsdf(field_to_use, tool->line, col, row, w, h, windowing, lineres);
-    else if (output_type == GWY_SF_ANGSPEC) {
-        make_angular_spectrum(field_to_use, mask_to_use, GWY_MASK_INCLUDE,
-                              col, row, w, h, lineres, windowing, 1, tool->line);
-    }
+    else if (output_type == GWY_SF_ANGSPEC)
+        make_angular_spectrum(field_to_use, mask_to_use, masking, col, row, w, h, lineres, windowing, 1, tool->line);
     else if (output_type == GWY_SF_RACF) {
         levelled = gwy_field_area_extract(field_to_use, col, row, w, h);
-        gwy_field_add(levelled, -gwy_field_get_avg(levelled));
+        gwy_field_add(levelled, -gwy_field_mean(levelled));
         gwy_field_racf(levelled, tool->line, lineres);
         g_object_unref(levelled);
     }
     else if (output_type == GWY_SF_RANGE)
-        gwy_field_area_range(field_to_use, tool->line, col, row, w, h, dir, lineres);
+        gwy_field_area_range(field_to_use, tool->line, col, row, w, h, orientation, lineres);
     else if (output_type == GWY_SF_ASG) {
-        g_object_unref(tool->line);
-        tool->line = gwy_field_area_row_asg(field_to_use, mask_to_use, GWY_MASK_INCLUDE, col, row, w, h, 1);
+        tool->line = gwy_field_area_row_asg(field_to_use, mask_to_use, masking, col, row, w, h, 1);
     }
     else if (output_type == GWY_SF_IDF) {
-        GwyLine *tmp = gwy_field_area_row_hhcf(field_to_use, mask_to_use, GWY_MASK_INCLUDE,
-                                               col, row, w, h, 1, NULL);
+        GwyLine *tmp = gwy_field_area_row_hhcf(field_to_use, mask_to_use, masking, col, row, w, h, 1, NULL);
         gwy_line_filter_slope(tmp, tool->line);
         gwy_line_assign(tmp, tool->line);
         gwy_line_filter_slope(tmp, tool->line);
@@ -603,7 +602,7 @@ update_curve(GwyToolSFunctions *tool)
     funcname = _(gwy_enum_to_string(output_type, quantities, G_N_ELEMENTS(quantities)));
     if (sfunction_has_direction(output_type)) {
         /* This is not completely language agnostic, but probably good enough for all LTR. */
-        dirname = g_utf8_strdown(gwy_enum_to_string(dir, gwy_orientation_get_enum(), -1), -1);
+        dirname = g_utf8_strdown(gwy_enum_to_string(orientation, gwy_orientation_get_enum(), -1), -1);
         title = g_strdup_printf("%s (%s)", funcname, gwy_C(dirname));
         g_free(dirname);
     }
@@ -636,7 +635,7 @@ param_changed(GwyToolSFunctions *tool, gint id)
         if (do_update)
             g_clear_object(&tool->cached_flipped_mask);
     }
-    if (id < 0 || id == PARAM_DIRECTION)
+    if (id < 0 || id == PARAM_ORIENTATION)
         g_clear_object(&tool->cached_flipped_mask);
 
     if (id < 0 || id == PARAM_INSTANT_UPDATE || id == PARAM_OUTPUT_TYPE)
@@ -676,7 +675,7 @@ gwy_tool_sfunctions_apply(GwyToolSFunctions *tool)
 
 static void
 make_angular_spectrum(GwyField *field,
-                      GwyField *mask, GwyMaskingType masking,
+                      GwyNield *mask, GwyMaskingType masking,
                       gint col, gint row, gint w, gint h,
                       gint lineres,
                       GwyWindowingType windowing, gint level,
@@ -777,9 +776,22 @@ gwy_field_area_range(GwyField *dfield,
 static gboolean
 sfunction_supports_masking(GwySFOutputType type)
 {
-    return (type == GWY_SF_DH || type == GWY_SF_CDH || type == GWY_SF_DA || type == GWY_SF_CDA
+    return (type == GWY_SF_HEIGHT_DIST || type == GWY_SF_HEIGHT_CDIST
+            || type == GWY_SF_ANGLE_DIST || type == GWY_SF_ANGLE_CDIST
             || type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
-            || type == GWY_SF_PSDF || type == GWY_SF_ANGSPEC || type == GWY_SF_IDF);
+            || type == GWY_SF_PSDF || type == GWY_SF_ANGSPEC || type == GWY_SF_IDF
+            || type == GWY_SF_MINKOWSKI_VOLUME
+            || type == GWY_SF_MINKOWSKI_BOUNDARY
+            || type == GWY_SF_MINKOWSKI_CONNECTIVITY);
+}
+
+static gboolean
+sfunction_makes_new_line(GwySFOutputType type)
+{
+    return (type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG || type == GWY_SF_PSDF
+            || type == GWY_SF_MINKOWSKI_VOLUME
+            || type == GWY_SF_MINKOWSKI_BOUNDARY
+            || type == GWY_SF_MINKOWSKI_CONNECTIVITY);
 }
 
 static gboolean
@@ -792,8 +804,9 @@ sfunction_has_native_sampling(GwySFOutputType type)
 static gboolean
 sfunction_has_direction(GwySFOutputType type)
 {
-    return (type == GWY_SF_DA || type == GWY_SF_CDA || type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
-            || type == GWY_SF_PSDF || type == GWY_SF_IDF);
+    return (type == GWY_SF_ANGLE_DIST || type == GWY_SF_ANGLE_CDIST
+            || type == GWY_SF_ACF || type == GWY_SF_HHCF
+            || type == GWY_SF_ASG || type == GWY_SF_PSDF || type == GWY_SF_IDF);
 }
 
 static gboolean
