@@ -1,6 +1,6 @@
 /*
- *  $Id: spotremove.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: spotremove.c 29553 2026-02-28 14:35:37Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -138,16 +138,16 @@ static void         blend_fractal_and_laplace          (GwyField *field,
                                                         gint col,
                                                         gint row);
 static void         pseudo_laplace_average             (GwyField *field,
-                                                        GwyField *mask);
+                                                        GwyNield *mask);
 static void         hyperbolic_average                 (GwyField *field,
-                                                        GwyField *mask);
+                                                        GwyNield *mask);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Spot removal tool, interpolates small parts of data (displayed on a zoomed view) using selected algorithm."),
     "Yeti <yeti@gwyddion.net>",
-    "4.2",
+    "5.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -352,7 +352,7 @@ create_selection_info_table(GwyToolSpotRemover *tool)
 }
 
 static gulong
-connect_to_item(GwyContainer *container, GQuark key1,
+connect_to_item(GwyDict *container, GQuark key1,
                 GCallback callback, gpointer callback_data)
 {
     gchar *sigdetail = g_strconcat("item-changed::", g_quark_to_string(key1), NULL);
@@ -645,9 +645,9 @@ draw_zoom(GwyToolSpotRemover *tool)
     }
     else {
         if (!tool->complete) {
-            min = gwy_field_area_get_min(plain_tool->field, NULL, GWY_MASK_IGNORE,
-                                         tool->xr.from, tool->yr.from,
-                                         tool->xr.to - tool->xr.from, tool->yr.to - tool->yr.from);
+            min = gwy_field_area_min(plain_tool->field, NULL, GWY_MASK_IGNORE,
+                                     tool->xr.from, tool->yr.from,
+                                     tool->xr.to - tool->xr.from, tool->yr.to - tool->yr.from);
             gwy_field_fill(tool->detail, min);
         }
         gwy_field_area_copy(plain_tool->field, tool->detail,
@@ -680,14 +680,14 @@ adapt_colour_range(GwyToolSpotRemover *tool, gboolean make_empty)
         return;
     }
 
-    gwy_container_gis_enum(plain_tool->container, gwy_file_key_image_color_mapping(id), &range_type);
+    gwy_dict_gis_enum(plain_tool->container, gwy_file_key_image_color_mapping(id), &range_type);
     if (range_type == GWY_COLOR_MAPPING_AUTO)
-        gwy_field_get_autorange(field, &min, &max);
+        gwy_field_autorange(field, &min, &max);
     else {
-        gwy_field_get_min_max(field, &min, &max);
+        gwy_field_min_max(field, &min, &max);
         if (range_type == GWY_COLOR_MAPPING_FIXED) {
-            gwy_container_gis_double(plain_tool->container, gwy_file_key_image_range_min(id), &min);
-            gwy_container_gis_double(plain_tool->container, gwy_file_key_image_range_max(id), &max);
+            gwy_dict_gis_double(plain_tool->container, gwy_file_key_image_range_min(id), &min);
+            gwy_dict_gis_double(plain_tool->container, gwy_file_key_image_range_max(id), &max);
         }
         /* FIXME: Adaptive mapping using the distribution of different data field is currently not possible. */
     }
@@ -754,22 +754,22 @@ param_changed(GwyToolSpotRemover *tool, gint id)
 
         setup_zoom_vector_layer(tool);
         if (restore_sel)
-            gwy_selection_set_data(zselection, 1, sel);
+            gwy_selection_set_data(tool->zselection, 1, sel);
     }
     if (id < 0 || id == PARAM_ADAPT_COLOR_RANGE)
         adapt_colour_range(tool, FALSE);
 }
 
 static void
-fill_shaped_area(GwyField *mask,
+fill_shaped_area(GwyNield *mask,
                  gint col, gint row, gint width, gint height,
-                 gdouble value,
+                 gint value,
                  SpotRemoveShape shape)
 {
     if (shape == GWY_SPOT_REMOVE_ELLIPSE)
-        gwy_field_elliptic_area_fill(mask, col, row, width, height, value);
+        gwy_nield_elliptic_area_fill(mask, col, row, width, height, value);
     else
-        gwy_field_area_fill(mask, NULL, GWY_MASK_IGNORE, col, row, width, height, value);
+        gwy_nield_area_fill(mask, NULL, GWY_MASK_IGNORE, col, row, width, height, value);
 }
 
 static void
@@ -778,8 +778,8 @@ gwy_tool_spot_remover_apply(GwyToolSpotRemover *tool)
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     SpotRemoveMethod method = gwy_params_get_enum(tool->params, PARAM_METHOD);
     SpotRemoveShape shape = gwy_params_get_enum(tool->params, PARAM_SHAPE);
-    GwyField *field = GWY_PLAIN_TOOL(tool)->field;
-    GwyField *area, *mask = NULL;
+    GwyField *field = GWY_PLAIN_TOOL(tool)->field, *area, *distances;
+    GwyNield *mask = NULL;
     gint xmin, xmax, ymin, ymax, w, h;
 
     g_return_if_fail(plain_tool->id >= 0 && field);
@@ -794,32 +794,37 @@ gwy_tool_spot_remover_apply(GwyToolSpotRemover *tool)
     h = ymax - ymin;
     if (method == GWY_SPOT_REMOVE_FRACTAL_LAPLACE) {
         /* Fractal interpolation is full-size because it analyses the entire data field. */
-        mask = gwy_field_new_alike(field, TRUE);
+        mask = gwy_field_new_nield_alike(field);
         fill_shaped_area(mask, xmin, ymin, w, h, 1.0, shape);
         gwy_field_fractal_correction(field, mask, GWY_INTERPOLATION_LINEAR);
         g_object_unref(mask);
 
         area = gwy_field_area_extract(field, xmin-1, ymin-1, w+2, h+2);
-        mask = gwy_field_new_alike(area, TRUE);
+        mask = gwy_field_new_nield_alike(area);
         fill_shaped_area(mask, 1, 1, w, h, 1.0, shape);
         gwy_field_laplace_solve(area, mask, 1, 1.0);
 
-        gwy_field_grain_distance_transform(mask);
-        blend_fractal_and_laplace(field, area, mask, xmin-1, ymin-1);
+        distances = gwy_field_new_alike(area, FALSE);
+        gwy_nield_distance_transform(mask, distances, GWY_DISTANCE_TRANSFORM_EUCLIDEAN, TRUE, FALSE);
+        blend_fractal_and_laplace(field, area, distances, xmin-1, ymin-1);
+        g_object_unref(distances);
         g_object_unref(area);
     }
     else if (method == GWY_SPOT_REMOVE_FRACTAL) {
         /* Fractal interpolation is full-size because it analyses the entire data field. */
-        mask = gwy_field_new_alike(field, TRUE);
+        mask = gwy_field_new_nield_alike(field);
         fill_shaped_area(mask, xmin, ymin, w, h, 1.0, shape);
         gwy_field_fractal_correction(field, mask, GWY_INTERPOLATION_LINEAR);
     }
     else if (method == GWY_SPOT_REMOVE_ZERO) {
-        fill_shaped_area(field, xmin, ymin, w, h, 0.0, shape);
+        if (shape == GWY_SPOT_REMOVE_ELLIPSE)
+            gwy_field_elliptic_area_fill(field, xmin, ymin, w, h, 0.0);
+        else
+            gwy_field_area_fill(field, NULL, GWY_MASK_IGNORE, xmin, ymin, w, h, 0.0);
     }
     else {
         area = gwy_field_area_extract(field, xmin-1, ymin-1, w+2, h+2);
-        mask = gwy_field_new_alike(area, TRUE);
+        mask = gwy_field_new_nield_alike(area);
         fill_shaped_area(mask, 1, 1, w, h, 1.0, shape);
 
         if (method == GWY_SPOT_REMOVE_LAPLACE)
@@ -876,32 +881,28 @@ blend_fractal_and_laplace(GwyField *field,
 
 static void
 find_hyperbolic_lines(GwyField *field,
-                      GwyField *mask,
+                      GwyNield *mask,
                       gint *itop, gdouble *ztop,
                       gint *jleft, gdouble *zleft,
                       gint *jright, gdouble *zright,
                       gint *ibot, gdouble *zbot)
 {
-    gint xres, yres, i, j;
-    const gdouble *d, *m;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    const gdouble *d = gwy_field_get_data_const(field);
+    const gint *m = gwy_nield_get_data_const(mask);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    d = gwy_field_get_data_const(field);
-    m = gwy_field_get_data_const(mask);
-
-    for (j = 0; j < xres; j++) {
+    for (gint j = 0; j < xres; j++) {
         itop[j] = G_MAXINT;
         ibot[j] = -1;
     }
-    for (i = 0; i < yres; i++) {
+    for (gint i = 0; i < yres; i++) {
         jleft[i] = G_MAXINT;
         jright[i] = -1;
     }
 
-    for (i = 1; i < yres-1; i++) {
-        for (j = 1; j < xres-1; j++) {
-            if (m[i*xres + j] <= 0.0)
+    for (gint i = 1; i < yres-1; i++) {
+        for (gint j = 1; j < xres-1; j++) {
+            if (m[i*xres + j] <= 0)
                 continue;
 
             if (i < itop[j])
@@ -915,7 +916,7 @@ find_hyperbolic_lines(GwyField *field,
         }
     }
 
-    for (j = 1; j < xres-1; j++) {
+    for (gint j = 1; j < xres-1; j++) {
         g_assert(itop[j] < yres);
         itop[j]--;
         ztop[j] = d[itop[j]*xres + j];
@@ -924,7 +925,7 @@ find_hyperbolic_lines(GwyField *field,
         ibot[j]++;
         zbot[j] = d[ibot[j]*xres + j];
     }
-    for (i = 1; i < yres-1; i++) {
+    for (gint i = 1; i < yres-1; i++) {
         g_assert(jleft[i] < xres);
         jleft[i]--;
         zleft[i] = d[i*xres + jleft[i]];
@@ -936,36 +937,29 @@ find_hyperbolic_lines(GwyField *field,
 }
 
 static void
-hyperbolic_average(GwyField *field, GwyField *mask)
+hyperbolic_average(GwyField *field, GwyNield *mask)
 {
-    const gdouble *m;
-    gdouble *d, *ztop, *zbot, *zleft, *zright;
-    gint *itop, *ibot, *jleft, *jright;
-    gint i, j, xres, yres;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
+    gdouble *ztop = g_new(gdouble, 2*(xres + yres));
+    gdouble *zleft = ztop + xres;
+    gdouble *zright = zleft + yres;
+    gdouble *zbot = zright + yres;
 
-    ztop = g_new(gdouble, 2*(xres + yres));
-    zleft = ztop + xres;
-    zright = zleft + yres;
-    zbot = zright + yres;
+    gint *itop = g_new(gint, 2*(xres + yres));
+    gint *jleft = itop + xres;
+    gint *jright = jleft + yres;
+    gint *ibot = jright + yres;
 
-    itop = g_new(gint, 2*(xres + yres));
-    jleft = itop + xres;
-    jright = jleft + yres;
-    ibot = jright + yres;
+    find_hyperbolic_lines(field, mask, itop, ztop, jleft, zleft, jright, zright, ibot, zbot);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = gwy_nield_get_data_const(mask);
 
-    find_hyperbolic_lines(field, mask,
-                          itop, ztop, jleft, zleft, jright, zright, ibot, zbot);
-    d = gwy_field_get_data(field);
-    m = gwy_field_get_data_const(mask);
-
-    for (i = 1; i < yres-1; i++) {
-        for (j = 1; j < xres-1; j++) {
+    for (gint i = 1; i < yres-1; i++) {
+        for (gint j = 1; j < xres-1; j++) {
             gint pos = i*xres + j;
 
-            if (m[pos] > 0.0) {
+            if (m[pos] > 0) {
                 gdouble px = zleft[i], qx = zright[i];
                 gdouble y = (gdouble)(i - itop[j])/(ibot[j] - itop[j]);
                 gdouble wx = 1.0/y + 1.0/(1.0 - y);
@@ -988,26 +982,22 @@ hyperbolic_average(GwyField *field, GwyField *mask)
 
 static void
 find_bounary_pixel_values(GwyField *field,
-                          GwyField *mask,
+                          GwyNield *mask,
                           GArray *pvals)
 {
-    gint xres, yres, i, j, k;
-    const gdouble *d, *m;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    d = gwy_field_get_data_const(field);
-    m = gwy_field_get_data_const(mask);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    const gdouble *d = gwy_field_get_data_const(field);
+    const gint *m = gwy_nield_get_data_const(mask);
     g_array_set_size(pvals, 0);
 
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
-            k = i*xres + j;
-            if (m[k] > 0.0)
+    for (gint i = 0; i < yres; i++) {
+        for (gint j = 0; j < xres; j++) {
+            gint k = i*xres + j;
+            if (m[k] > 0)
                 continue;
 
-            if ((i && m[k-xres] > 0.0) || (j && m[k-1] > 0.0)
-                || (j < xres-1 && m[k+1] > 0.0) || (i < yres-1 && m[k+xres] > 0.0)) {
+            if ((i && m[k-xres] > 0) || (j && m[k-1] > 0)
+                || (j < xres-1 && m[k+1] > 0) || (i < yres-1 && m[k+xres] > 0)) {
                 PixelValue pv = { d[k], i, j };
                 g_array_append_val(pvals, pv);
             }
@@ -1016,36 +1006,28 @@ find_bounary_pixel_values(GwyField *field,
 }
 
 static void
-pseudo_laplace_average(GwyField *field, GwyField *mask)
+pseudo_laplace_average(GwyField *field, GwyNield *mask)
 {
-    gint i, j, n, xres, yres;
-    GArray *boundary;
-    PixelValue *pvals;
-    const gdouble *m;
-    gdouble *d;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    GArray *boundary = g_array_new(FALSE, FALSE, sizeof(PixelValue));
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-
-    boundary = g_array_new(FALSE, FALSE, sizeof(PixelValue));
     find_bounary_pixel_values(field, mask, boundary);
-    n = boundary->len;
-    pvals = (PixelValue*)g_array_free(boundary, FALSE);
+    gint n = boundary->len;
+    PixelValue *pvals = (PixelValue*)g_array_free(boundary, FALSE);
 
-    d = gwy_field_get_data(field);
-    m = gwy_field_get_data_const(mask);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = gwy_nield_get_data_const(mask);
 
 #ifdef _OPENMP
 #pragma omp parallel for if (gwy_threads_are_enabled()) default(none) \
-            private(i,j) \
             shared(d,m,pvals,n,xres,yres)
 #endif
-    for (i = 1; i < yres-1; i++) {
-        for (j = 1; j < xres-1; j++) {
+    for (gint i = 1; i < yres-1; i++) {
+        for (gint j = 1; j < xres-1; j++) {
             gint k, pos = i*xres + j;
             gdouble s = 0.0, sz = 0.0;
 
-            if (m[pos] <= 0.0)
+            if (m[pos] <= 0)
                 continue;
 
             for (k = 0; k < n; k++) {
