@@ -1,6 +1,6 @@
 /*
- *  $Id: stats.c 28978 2025-12-11 10:41:31Z yeti-dn $
- *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
+ *  $Id: stats.c 29416 2026-01-30 16:49:54Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -104,7 +104,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Statistics tool."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "4.3",
+    "4.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -408,58 +408,53 @@ update_labels(GwyToolStats *tool)
     }
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static gdouble
 gwy_field_scan_line_discrepancy(GwyField *field,
-                                GwyField *mask,
+                                GwyNield *mask,
                                 GwyMaskingType masking,
                                 gint col, gint row,
                                 gint width, gint height)
 {
-    gint xres = field->xres, yres = field->yres, i, j, n;
-    const gdouble *drow, *drowp, *drown, *mrow;
-    gdouble v, s2 = 0.0;
-
-    if (masking == GWY_MASK_IGNORE)
-        mask = NULL;
-    if (!mask)
-        masking = GWY_MASK_IGNORE;
+    gint xres = field->xres, yres = field->yres;
 
     /* Cannot calculate discrepancy with only one scan line. */
     if (yres < 2)
         return 0.0;
 
-    n = 0;
+    gdouble s2 = 0.0;
+    gint n = 0;
     const gdouble *data = gwy_field_get_data_const(field);
-    const gdouble *mdata = mask ? gwy_field_get_data_const(mask) : NULL;
-    for (i = 0; i < height; i++) {
+    const gint *mdata = mask ? gwy_nield_get_data_const(mask) : NULL;
+    for (gint i = 0; i < height; i++) {
         /* Take the two neighbour rows, except for the first and last one, where we simply calculate the difference
          * from the sole neigbour. */
-        drow = data + (row + i)*xres + col;
-        drowp = (row + i > 0) ? drow - xres : drow + xres;
-        drown = (row + i < yres-1) ? drow + xres : drow - xres;
-        if (masking == GWY_MASK_INCLUDE) {
-            mrow = mdata + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                if (mrow[j] > 0.0) {
-                    v = drow[j] - 0.5*(drowp[j] + drown[j]);
-                    s2 += v*v;
-                    n++;
-                }
-            }
-        }
-        else if (masking == GWY_MASK_EXCLUDE) {
-            mrow = mdata + (row + i)*xres + col;
-            for (j = 0; j < width; j++) {
-                if (mrow[j] <= 0.0) {
-                    v = drow[j] - 0.5*(drowp[j] + drown[j]);
+        const gdouble *drow = data + (row + i)*xres + col;
+        const gdouble *drowp = (row + i > 0) ? drow - xres : drow + xres;
+        const gdouble *drown = (row + i < yres-1) ? drow + xres : drow - xres;
+        if (mask) {
+            const gint *mrow = mdata + (row + i)*xres + col;
+            for (gint j = 0; j < width; j++) {
+                if (nielded_included(mrow + j, masking)) {
+                    gdouble v = drow[j] - 0.5*(drowp[j] + drown[j]);
                     s2 += v*v;
                     n++;
                 }
             }
         }
         else {
-            for (j = 0; j < width; j++) {
-                v = drow[j] - 0.5*(drowp[j] + drown[j]);
+            for (gint j = 0; j < width; j++) {
+                gdouble v = drow[j] - 0.5*(drowp[j] + drown[j]);
                 s2 += v*v;
             }
             n += width;
@@ -474,62 +469,59 @@ calculate(GwyToolStats *tool)
 {
     GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(tool);
     GwyField *field = plain_tool->field;
-    GwyField *mask = plain_tool->mask_field;
+    GwyNield *mask = plain_tool->mask_field;
     GwyMaskingType masking = gwy_params_get_masking(tool->params, PARAM_MASKING, &mask);
     GwyResults *results = tool->results;
-    gdouble xoff, yoff, q;
-    gdouble min, max, avg, median, Sa, rms, rms_gw, skew, kurtosis;
-    gdouble projarea, area = 0.0, Sdq, volume, var, phi = 0.0, theta = 0.0, linedis;
     gboolean have_inclination = FALSE;
-    gint nn, col, row, w, h;
 
     gwy_param_table_set_sensitive(tool->table_results, PARAM_REPORT_STYLE, FALSE);
     gwy_assign(tool->isel_prev, tool->isel, 4);
-    col = tool->isel[0];
-    row = tool->isel[1];
-    w = tool->isel[2]+1 - tool->isel[0];
-    h = tool->isel[3]+1 - tool->isel[1];
+    gint col = tool->isel[0];
+    gint row = tool->isel[1];
+    gint w = tool->isel[2]+1 - tool->isel[0];
+    gint h = tool->isel[3]+1 - tool->isel[1];
     gwy_debug("%d x %d at (%d, %d)", w, h, col, row);
 
     if (!w || !h)
         return FALSE;
 
-    xoff = gwy_field_get_xoffset(field);
-    yoff = gwy_field_get_yoffset(field);
+    gdouble xoff = gwy_field_get_xoffset(field), yoff = gwy_field_get_yoffset(field);
 
-    q = gwy_field_get_dx(field) * gwy_field_get_dy(field);
+    gdouble q = gwy_field_get_dx(field) * gwy_field_get_dy(field);
+    gint nn = w*h;
     if (mask) {
-        if (masking == GWY_MASK_INCLUDE)
-            gwy_field_area_count_in_range(mask, NULL, GWY_MASK_IGNORE, col, row, w, h, 0.0, 0.0, &nn, NULL);
-        else
-            gwy_field_area_count_in_range(mask, NULL, GWY_MASK_IGNORE, col, row, w, h, 1.0, 1.0, NULL, &nn);
-        nn = w*h - nn;
+        nn = gwy_nield_area_count(mask, NULL, GWY_MASK_IGNORE, col, row, w, h);
+        if (masking == GWY_MASK_EXCLUDE)
+            nn = w*h - nn;
     }
-    else
-        nn = w*h;
-    projarea = nn * q;
+    gdouble projarea = nn * q;
     /* TODO: do something more reasonable when nn == 0 */
 
-    gwy_field_area_get_min_max(field, mask, masking, col, row, w, h, &min, &max);
-    gwy_field_area_get_stats(field, mask, masking, col, row, w, h, &avg, &Sa, &rms, &skew, &kurtosis);
-    /* TODO Nield: grainwise rms only makes sense in INCLUDE mode. The new function does not have modes. */
-    rms_gw = gwy_field_area_get_grainwise_rms(field, mask, masking, col, row, w, h);
-    median = gwy_field_area_get_median(field, mask, masking, col, row, w, h);
-    var = gwy_field_area_get_variation(field, mask, masking, col, row, w, h);
-    Sdq = gwy_field_area_get_surface_slope(field, mask, masking, col, row, w, h);
+    gdouble min, max, avg, Sa, rms, skew, kurtosis;
+    gwy_field_area_min_max(field, mask, masking, col, row, w, h, &min, &max);
+    gwy_field_area_stats(field, mask, masking, col, row, w, h, &avg, &Sa, &rms, &skew, &kurtosis);
+    gdouble rms_gw = rms;
+    if (masking == GWY_MASK_INCLUDE)
+        rms_gw = gwy_field_area_grainwise_rms(field, mask, col, row, w, h);
 
-    linedis = gwy_field_scan_line_discrepancy(field, mask, masking, col, row, w, h);
+    gdouble median = gwy_field_area_median(field, mask, masking, col, row, w, h);
+    gdouble var = gwy_field_area_variation(field, mask, masking, col, row, w, h);
+    gdouble Sdq = gwy_field_area_rms_slope(field, mask, masking, col, row, w, h);
+
+    gdouble linedis = gwy_field_scan_line_discrepancy(field, mask, masking, col, row, w, h);
     if (linedis > 0.0)
-        linedis /= sqrt(gwy_field_area_get_mean_square(field, mask, masking, col, row, w, h));
+        linedis /= sqrt(gwy_field_area_mean_square(field, mask, masking, col, row, w, h));
 
+    gdouble area = 0.0;
     if (tool->same_units)
-        area = gwy_field_area_get_surface_area(field, mask, masking, col, row, w, h);
-    volume = gwy_field_area_get_volume(field, NULL, mask, masking, col, row, w, h);
+        area = gwy_field_area_surface_area(field, mask, masking, col, row, w, h);
+    gdouble volume = gwy_field_area_volume(field, mask, masking, GWY_FIELD_VOLUME_DEFAULT, col, row, w, h);
 
+    gdouble theta = 0.0, phi = 0.0;
     if (tool->same_units) {
         gdouble nx, ny, nz;
-        if ((have_inclination = gwy_field_area_get_normal_coeffs(field, mask, masking, col, row, w, h,
-                                                                 &nx, &ny, &nz))) {
+        if ((have_inclination = gwy_field_area_normal_coeffs(field, mask, masking, col, row, w, h,
+                                                             &nx, &ny, &nz))) {
             theta = atan2(hypot(nx, ny), nz);
             /* Inclination is upslope, not down. It is not the normal. */
             phi = atan2(ny, nx) + G_PI;
@@ -579,6 +571,8 @@ calculate(GwyToolStats *tool)
         gwy_results_set_na(results, "phi", "theta", NULL);
     if (!tool->same_units)
         gwy_results_set_na(tool->results, "area", "theta", "phi", NULL);
+    if (mask && masking == GWY_MASK_EXCLUDE)
+        gwy_results_set_na(tool->results, "rms_gw", NULL);
 
     gwy_results_fill_filename(results, "file", GWY_FILE(plain_tool->container));
     gwy_results_fill_data_name(results, "image", GWY_FILE(plain_tool->container), GWY_FILE_IMAGE, plain_tool->id);
