@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_1dfft.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: volume_1dfft.c 29435 2026-02-03 16:04:57Z yeti-dn $
  *  Copyright (C) 2015-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -174,7 +174,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.brick = brick;
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -479,7 +479,7 @@ calculate_weights(ModuleArgs *args, GwySelection *selection)
         for (k = 0; k < res; k++)
             w[k] = 1.0 - w[k];
 
-        gwy_line_correct_laplace(buf, weights);
+        gwy_line_laplace_solve(buf, weights);
         b = gwy_line_get_data(buf);
         m = gwy_line_get_data(modulus);
 
