@@ -1,6 +1,6 @@
 /*
- *  $Id: volume_arithmetic.c 28906 2025-11-24 16:45:11Z yeti-dn $
- *  Copyright (C) 2018-2025 David Necas (Yeti).
+ *  $Id: volume_arithmetic.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2018-2026 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -136,7 +136,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Simple arithmetic operations with volume data."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti)",
     "2018",
 };
@@ -195,7 +195,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     g_return_if_fail(mode & RUN_MODES);
     gwy_clear1(args);
     gwy_data_browser_get_current(GWY_APP_BRICK_ID, &dataid.id,
-                                 GWY_APP_CONTAINER_ID, &dataid.datano,
+                                 GWY_APP_FILE_ID, &dataid.datano,
                                  0);
 
     g_return_if_fail(gwy_app_data_id_verify_volume(&dataid));
@@ -685,20 +685,20 @@ fix_nans(ModuleArgs *args)
     gdouble filler_value = gwy_params_get_double(params, PARAM_FILLER_VALUE);
     GwyBrick *result = args->result;
     gint xres = gwy_brick_get_xres(result), yres = gwy_brick_get_yres(result), zres = gwy_brick_get_zres(result);
-    GwyField *plane = args->preview, *mask;
+    GwyField *plane = args->preview;
     gint i;
 
     plane = gwy_field_new(xres, yres, 1.0, 1.0, FALSE);
     for (i = 0; i < zres; i++) {
         gwy_brick_extract_xy_plane(result, plane, i);
-        mask = gwy_app_channel_mask_of_nans(plane, FALSE);
+        GwyNield *mask = gwy_mask_nans_in_field(plane, FALSE);
         if (!mask)
             continue;
 
         if (fixed_filler)
             gwy_field_area_fill(plane, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, filler_value);
         else
-            gwy_field_laplace_solve(plane, mask, -1, 0.25);
+            gwy_field_laplace_solve(plane, mask, GWY_LAPLACE_MASKED, 0.25);
         gwy_brick_set_xy_plane(result, plane, i);
         g_object_unref(mask);
     }
