@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_calibrate.c 28808 2025-11-05 18:26:20Z yeti-dn $
+ *  $Id: volume_calibrate.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2013-2022 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -299,8 +299,8 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.xoffset = gwy_brick_get_xoffset(brick);
     args.yoffset = gwy_brick_get_yoffset(brick);
     args.zoffset = gwy_brick_get_zoffset(brick);
-    args.wmin = gwy_brick_get_min(brick);
-    args.wmax = gwy_brick_get_max(brick);
+    args.wmin = gwy_brick_min(brick);
+    args.wmax = gwy_brick_max(brick);
     args.xyunit = gwy_brick_get_unit_x(brick);
     args.zunit = gwy_brick_get_unit_z(brick);
     args.wunit = gwy_brick_get_unit_w(brick);
@@ -310,7 +310,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     init_zparams(&args);
     init_wparams(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -321,11 +321,11 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     if (new_channel)
         brick = gwy_brick_copy(brick);
     else
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     calibrate_one_brick(brick, params);
 
-    preview = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(oldid));
+    preview = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(oldid));
     if (new_channel) {
         preview = gwy_field_copy(preview);
         calibrate_one_image(preview, params);
