@@ -1,6 +1,6 @@
 /*
  *  $Id: volume_cluster.c 26744 2024-10-18 15:03:29Z yeti-dn $
- *  Copyright (C) 2014-2025 David Necas (Yeti), Petr Klapetek, Daniil Bratashov, Evgeniy Ryabov.
+ *  Copyright (C) 2014-2026 David Necas (Yeti), Petr Klapetek, Daniil Bratashov, Evgeniy Ryabov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com, k1u2r3ka@mail.ru.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -32,7 +32,6 @@
 #define METHOD_FUNCS(name) \
     define_params_##name, append_gui_##name, cluster_##name
 
-
 enum {
     PREVIEW_SIZE = 360,
 };
@@ -117,12 +116,12 @@ typedef struct {
     GwyParams *params;
     GwyBrick *brick;
     GwyBrick *prepbrick;
-    GwyField *result;
+    GwyField *result; // FIXME: This is the classification, and should be a Nield. One day.
     GwyField *scale;
     GwyField *errormap;
     GwyLine *calibration;
     GwyField *preview;
-    GwyField *mask;
+    GwyNield *mask;
     GwyGraphModel *gmodel;
     gdouble value;
 } ModuleArgs;
@@ -211,7 +210,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Splits data into clusters"),
     "Petr Klapetek <klapetek@gwyddion.net> & Daniil Bratashov <dn2010@gmail.com> & Evgeniy Ryabov <k1u2r3ka@mail.ru>",
-    "1.0",
+    "1.1",
     "Petr Klapetek & David Nečas (Yeti) & Daniil Bratashov & Evgeniy Ryabov",
     "2025",
 };
@@ -339,8 +338,8 @@ cluster(GwyFile *data, GwyRunModeFlags mode)
     sanitise_params(&args);
     args.prepbrick = gwy_brick_copy(brick);
 
-    args.preview = gwy_field_copy(gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(id)));
-    args.mask = gwy_field_new_alike(args.preview, TRUE);
+    args.preview = gwy_field_copy(gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(id)));
+    args.mask = gwy_field_new_nield_alike(args.preview);
 
     outcome = run_gui(&args, data, id);
     gwy_params_save_to_settings(args.params);
@@ -359,10 +358,10 @@ cluster(GwyFile *data, GwyRunModeFlags mode)
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE); //was result
     gwy_file_pass_title(data, GWY_FILE_IMAGE, newid, g_strdup_printf(_("%s: cluster map"), description));
     gwy_file_set_palette(data, GWY_FILE_IMAGE, newid, "Clusters");
-    gwy_container_set_enum(GWY_CONTAINER(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_FIXED);
-    gwy_container_set_double(GWY_CONTAINER(data), gwy_file_key_image_range_min(newid), 0); //-0.1
-    gwy_container_set_double(GWY_CONTAINER(data), gwy_file_key_image_range_max(newid),
-                             gwy_field_get_max(args.result));
+    gwy_dict_set_enum(GWY_DICT(data), gwy_file_key_image_color_mapping(newid), GWY_COLOR_MAPPING_FIXED);
+    gwy_dict_set_double(GWY_DICT(data), gwy_file_key_image_range_min(newid), 0); //-0.1
+    gwy_dict_set_double(GWY_DICT(data), gwy_file_key_image_range_max(newid),
+                        gwy_field_max(args.result));
     gwy_log_add_full(data, GWY_FILE_IMAGE, -1, newid, "volume::volume_cluster", NULL);
 
     if (gwy_params_get_boolean(args.params, PARAM_OUTPUT_OUTLIERS))
@@ -384,18 +383,17 @@ cluster(GwyFile *data, GwyRunModeFlags mode)
             GwyGraphCurveModel *gcmodel;
             gint nc = gwy_graph_model_get_n_curves(args.gmodel);
             gint n, c, col, row, lev, npix;
-            gdouble *newydata, *labeldata, *maskdata, *bdata;
             const gdouble *xdata;
             gint xres = gwy_brick_get_xres(brick);
             gint yres = gwy_brick_get_yres(brick);
-            labeldata = gwy_field_get_data(args.result);
-            maskdata = gwy_field_get_data(args.mask);
-            bdata = gwy_brick_get_data(args.brick);
+            const gdouble *labeldata = gwy_field_get_data(args.result);
+            const gint *maskdata = gwy_nield_get_data_const(args.mask);
+            const gdouble *bdata = gwy_brick_get_data_const(args.brick);
             for (c = 1; c <= nc; c++) {
                 gcmodel = gwy_graph_model_get_curve(args.gmodel, c-1);
                 n = gwy_graph_curve_model_get_ndata(gcmodel);
                 xdata = gwy_graph_curve_model_get_xdata(gcmodel);
-                newydata = g_new0(gdouble, n);
+                gdouble *newydata = g_new0(gdouble, n);
                 npix = 0;
                 for (row = 0; row < yres; row++) {
                     for (col = 0; col < xres; col++) {
@@ -409,6 +407,7 @@ cluster(GwyFile *data, GwyRunModeFlags mode)
                 for (lev = 0; lev < n; lev++)
                     newydata[lev] /= npix;
                 gwy_graph_curve_model_set_data(gcmodel, xdata, newydata, n);
+                g_free(newydata);
             }
         }
         g_object_set(args.gmodel,
@@ -602,7 +601,7 @@ update_display(ModuleGUI *gui)
         }
         else {
             gwy_field_assign(gui->showfield, args->result);
-            gwy_data_view_set_fixed_color_range(dataview, 0.0/*-0.1*/, gwy_field_get_max(args->result));
+            gwy_data_view_set_fixed_color_range(dataview, 0.0/*-0.1*/, gwy_field_max(args->result));
         }
         gwy_data_view_set_color_mapping(dataview, GWY_COLOR_MAPPING_FIXED);
 
@@ -722,7 +721,7 @@ update_graph_colors(GwyGraphModel *gmodel, GwyField *clusters, GwyGradient *grad
 {
     gint nc = gwy_graph_model_get_n_curves(gmodel);
     gdouble cfrom = 0; //our range is always from 0 (unclassified points)
-    gdouble cto = gwy_field_get_max(clusters);
+    gdouble cto = gwy_field_max(clusters);
     GwyRGBA color;
     gdouble val;
 
@@ -757,8 +756,8 @@ preview(gpointer user_data)
             gtk_dialog_set_response_sensitive(GTK_DIALOG(gui->dialog), GTK_RESPONSE_OK, TRUE);
 
             gchar *message = g_strdup_printf(_("%.0f clusters, error: %g"),
-                                             gwy_field_get_max(args->result),
-                                             gwy_field_get_avg(args->errormap));
+                                             gwy_field_max(args->result),
+                                             gwy_field_mean(args->errormap));
             gwy_param_table_info_set_valuestr(gui->table_output, LABEL_RESULT, message);
             g_free(message);
         }
@@ -773,8 +772,8 @@ static gboolean
 preprocess(ModuleArgs *args, GtkWindow *wait_window)
 {
     gwy_brick_transpose(args->brick, args->prepbrick, GWY_BRICK_TRANSPOSE_YZX, FALSE, FALSE, FALSE);
-    gwy_field_fill(args->mask, 0);
-    gwy_field_data_changed(args->mask);
+    gwy_nield_clear(args->mask);
+    gwy_nield_data_changed(args->mask);
 
     if (!outliers(args, wait_window))
         return FALSE;
@@ -910,7 +909,7 @@ outliers(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
 {
     GwyBrick* brick = args->prepbrick;
     ClusterOutliers outliers = gwy_params_get_enum(args->params, PARAM_OUTLIERS);
-    gint col, row, lev, i;
+    gint col, row, lev;
     gint xres = gwy_brick_get_xres(brick);
     gint yres = gwy_brick_get_yres(brick);
     gint zres = gwy_brick_get_zres(brick);
@@ -918,7 +917,7 @@ outliers(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
     gdouble *bdata = gwy_brick_get_data(brick);
     GwyLine *xline, *xavline;
     GwyField *distances, *amad;
-    gdouble *xavdata, *mdata, *ddata;
+    gdouble *xavdata;
     gdouble dist, median, mad;
 
     if (outliers == OUTLIERS_NONE)
@@ -947,22 +946,17 @@ outliers(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
     }
 
     if (outliers == OUTLIERS_MEAN3) {
-        gwy_field_mask_outliers(distances, args->mask, 3);
-        gwy_field_data_changed(args->mask);
+        gwy_field_mark_outliers(distances, args->mask, 3);
+        gwy_nield_data_changed(args->mask);
     }
     else if (outliers == OUTLIERS_MAD) {
-        median = gwy_field_get_median(distances);
+        median = gwy_field_median(distances);
         amad = gwy_field_copy(distances);
         gwy_field_add(amad, -median);
         gwy_field_abs(amad);
-        mad = gwy_field_get_median(amad);
-        mdata = gwy_field_get_data(args->mask);
-        ddata = gwy_field_get_data(distances);
-        for (i = 0; i < (yres*zres); i++) {
-            if (ddata[i] < (median - 3*mad) || ddata[i] > (median + 3*mad))
-                mdata[i] = 1;
-        }
-        gwy_field_data_changed(args->mask);
+        mad = gwy_field_median(amad);
+        gwy_nield_mark_range(args->mask, distances, median + 3*mad, median - 3*mad);
+        gwy_nield_data_changed(args->mask);
         g_object_unref(amad);
     }
 
@@ -993,7 +987,7 @@ background(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
         for (lev = 0; lev < zres; lev++) {
             for (row = 0; row < yres; row++) {
                 brick_extract_x_line(brick, xline, row, lev);
-                gwy_line_add(xline, -gwy_line_avg(xline));
+                gwy_line_add(xline, -gwy_line_mean(xline));
                 brick_insert_x_line(brick, xline, row, lev);
             }
         }
@@ -1068,7 +1062,7 @@ transform(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
             for (row = 0; row < yres; row++) {
                 brick_extract_x_line(brick, xline, row, lev);
                 for (i = 0; i < xres; i++)
-                    xtldata[i] = gwy_line_get_der(xline, i);
+                    xtldata[i] = gwy_line_der(xline, i);
                 brick_insert_x_line(brick, xtline, row, lev);
             }
         }
@@ -1123,7 +1117,7 @@ scale(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
             for (row = 0; row < yres; row++) {
                 brick_extract_x_line(brick, xline, row, lev);
                 rms = gwy_line_rms(xline);
-                gwy_line_add(xline, -gwy_line_avg(xline));
+                gwy_line_add(xline, -gwy_line_mean(xline));
                 if (rms > 0)
                     gwy_line_multiply(xline, 1.0/rms);
                 else
@@ -1137,7 +1131,7 @@ scale(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
             for (row = 0; row < yres; row++) {
                 brick_extract_x_line(brick, xline, row, lev);
                 rms = gwy_line_rms(xline);
-                gwy_line_add(xline, -gwy_line_avg(xline));
+                gwy_line_add(xline, -gwy_line_mean(xline));
                 if (rms > 0)
                     gwy_line_multiply(xline, 1.0/sqrt(rms));
                 else
@@ -1151,7 +1145,7 @@ scale(ModuleArgs *args, G_GNUC_UNUSED GtkWindow *wait_window)
             for (row = 0; row < yres; row++) {
                 brick_extract_x_line(brick, xline, row, lev);
                 rms = gwy_line_rms(xline);
-                avg = gwy_line_avg(xline);
+                avg = gwy_line_mean(xline);
                 gwy_line_add(xline, -avg);
                 if (rms > 0)
                     gwy_line_multiply(xline, avg/(rms*rms));
@@ -1298,19 +1292,18 @@ create_error_map(GwyBrick *brick, GwyField *errormap, GwyField *labelmap,
 
 
 static void
-init_cluster_centers(GwyBrick *brick, GwyField *mask, gdouble *centers, gint nclusters, gint seed)
+init_cluster_centers(GwyBrick *brick, GwyNield *mask, gdouble *centers, gint nclusters, gint seed)
 {
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     gint i, j, k, c, ca, startj, startk;
     gdouble *probdata = g_new0(gdouble, yres*zres);
-    gdouble *maskdata = gwy_field_get_data(mask);
-    gdouble *data = gwy_brick_get_data(brick);
+    gint *maskdata = gwy_nield_get_data(mask);
+    const gdouble *data = gwy_brick_get_data_const(brick);
     gdouble dist, mindist, max;
-    GRand *rand;
+    GRand *rand = g_rand_new();
 
     //k-means++ initialisation
     //pick first center randomly
-    rand = g_rand_new();
     g_rand_set_seed(rand, seed);
 
     do {
@@ -1336,8 +1329,8 @@ init_cluster_centers(GwyBrick *brick, GwyField *mask, gdouble *centers, gint ncl
                 for (ca = 0; ca < c; ca++) {
                     dist = 0;
                     for (i = 0; i < xres; i++) { //distance to closest
-                        dist += ((data[k*xres*yres + j*xres + i] - centers[ca*xres + i])
-                                 * (data[k*xres*yres + j*xres + i] - centers[ca*xres + i]));
+                        gdouble d = (data[k*xres*yres + j*xres + i] - centers[ca*xres + i]);
+                        dist += d*d;
                     }
                     if (dist < mindist)
                         mindist = dist;
@@ -1473,13 +1466,11 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
     gdouble outliers_threshold = gwy_params_get_double(params, PARAM_KMEANS_OUTLIERS_THRESHOLD);
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     GwyField *clusters = NULL, *errormap = NULL;
-    GwyField *mask = args->mask;
+    GwyNield *mask = args->mask;
     const gdouble *data;
-    gdouble *centers, *oldcenters, *labeldata, *maskdata, *variance, *sum;
-    gdouble min, dist, d;
+    gdouble min, dist;
     gboolean ok = FALSE, cancelled = FALSE, converged = FALSE;
     gint i, j, k, c, iterations = 0;
-    gint *npix, *nnpix;
 
     /* NB: brick == args->prepbrick is transposed wrt args->brick. Try to not mix them in a confusing manner… */
     clusters = gwy_brick_new_field_like_xy_plane(args->brick, FALSE);
@@ -1490,13 +1481,13 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
 
     data = gwy_brick_get_data_const(brick);
 
-    centers = g_new0(gdouble, nclusters*xres);
-    oldcenters = g_new(gdouble, nclusters*xres);
-    sum = g_new(gdouble, xres*nclusters);
-    npix = g_new(gint, nclusters);
-    variance = g_new(gdouble, nclusters);
-    labeldata = gwy_field_get_data(clusters);
-    maskdata = gwy_field_get_data(mask);
+    gdouble *centers = g_new0(gdouble, nclusters*xres);
+    gdouble *oldcenters = g_new(gdouble, nclusters*xres);
+    gdouble *sum = g_new(gdouble, xres*nclusters);
+    gdouble *variance = g_new(gdouble, nclusters);
+    gint *npix = g_new(gint, nclusters);
+    gdouble *labeldata = gwy_field_get_data(clusters);
+    gint *maskdata = gwy_nield_get_data(mask);
 
     //kmeans++ initialisation
     init_cluster_centers(brick, mask, centers, nclusters, gwy_params_get_int(params, PARAM_SEED));
@@ -1522,8 +1513,8 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
                     dist = 0;
                     for (i = 0; i < xres; i++) {
                         oldcenters[c*xres + i] = centers[c*xres + i];
-                        dist += ((data[k*xres*yres + j*xres + i] - centers[c*xres + i])
-                                 * (data[k*xres*yres + j*xres + i] - centers[c*xres + i]));
+                        gdouble d = (data[k*xres*yres + j*xres + i] - centers[c*xres + i]);
+                        dist += d*d;
                     }
                     if (dist < min) {
                         min = dist;
@@ -1590,7 +1581,7 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
                     for (c = 0; c < nclusters; c++) {
                         dist = 0;
                         for (i = 0; i < xres; i++) {
-                            d = data[k*xres*yres + j*xres + i] - centers[c*xres + i];
+                            gdouble d = data[k*xres*yres + j*xres + i] - centers[c*xres + i];
                             oldcenters[c*xres + i] = centers[c*xres + i];
                             dist += d*d;
                         }
@@ -1614,7 +1605,7 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
                     npix[c] += 1;
                     dist = 0;
                     for (i = 0; i < xres; i++) {
-                        d = data[k*xres*yres + j*xres + i] - centers[c*xres + i];
+                        gdouble d = data[k*xres*yres + j*xres + i] - centers[c*xres + i];
                         dist += d*d;
                     }
                     variance[c] += dist;
@@ -1679,7 +1670,7 @@ cluster_kmeans(ModuleArgs *args, GtkWindow *wait_window)
     }
     create_error_map(brick, errormap, clusters, centers, nclusters);
 
-    nnpix = g_new0(gint, nclusters);
+    gint *nnpix = g_new0(gint, nclusters);
     resort_clusters_by_size(clusters, centers, nclusters, xres, npix, nnpix);
 
     gwy_field_add(clusters, 1); //shift clusters to start at 1
@@ -1695,6 +1686,8 @@ fail:
     g_clear_object(&errormap);
     g_clear_object(&clusters);
     g_free(npix);
+    g_free(sum);
+    g_free(variance);
     g_free(oldcenters);
     g_free(centers);
 
@@ -1738,13 +1731,11 @@ cluster_kmedians(ModuleArgs *args, GtkWindow *wait_window)
     gdouble epsilon = -log10(gwy_params_get_double(params, PARAM_KMEDIANS_LOG_EPSILON));
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     GwyField *clusters = NULL, *errormap = NULL;
-    GwyField *mask = args->mask;
+    GwyNield *mask = args->mask;
     const gdouble *data;
-    gdouble *centers, *oldcenters, *plane, *labeldata, *maskdata;
     gdouble min, dist, d;
     gboolean ok = FALSE, cancelled = FALSE, converged = FALSE;
     gint i, j, k, c, iterations = 0;
-    gint *npix, *nnpix;
 
     clusters = gwy_field_new(yres, zres,
                              gwy_brick_get_xreal(args->brick), gwy_brick_get_yreal(args->brick),
@@ -1760,12 +1751,12 @@ cluster_kmedians(ModuleArgs *args, GtkWindow *wait_window)
 
     data = gwy_brick_get_data_const(brick);
 
-    centers = g_new0(gdouble, nclusters*xres);
-    oldcenters = g_new(gdouble, nclusters*xres);
-    plane = g_new(gdouble, yres*zres*nclusters);
-    npix = g_new(gint, nclusters);
-    labeldata = gwy_field_get_data(clusters);
-    maskdata = gwy_field_get_data(mask);
+    gdouble *centers = g_new0(gdouble, nclusters*xres);
+    gdouble *oldcenters = g_new(gdouble, nclusters*xres);
+    gdouble *plane = g_new(gdouble, yres*zres*nclusters);
+    gint *npix = g_new(gint, nclusters);
+    gdouble *labeldata = gwy_field_get_data(clusters);
+    gint *maskdata = gwy_nield_get_data(mask);
 
     //kmeans++ initialisation
     init_cluster_centers(brick, mask, centers, nclusters, gwy_params_get_int(params, PARAM_SEED));
@@ -1837,7 +1828,7 @@ cluster_kmedians(ModuleArgs *args, GtkWindow *wait_window)
     }
     create_error_map(brick, errormap, clusters, centers, nclusters);
 
-    nnpix = g_new0(gint, nclusters);
+    gint *nnpix = g_new0(gint, nclusters);
     resort_clusters_by_size(clusters, centers, nclusters, xres, npix, nnpix);
 
     gwy_field_add(clusters, 1); //shift clusters to start at 1
@@ -1921,14 +1912,10 @@ cluster_dbscan(ModuleArgs *args, GtkWindow *wait_window)
     gint minpts = gwy_params_get_int(params, PARAM_DBSCAN_NEIGHBORS);
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     GwyField *clusters = NULL, *errormap = NULL;
-    GwyField *mask = args->mask;
-    const gdouble *data;
-    gdouble *centers;
+    GwyNield *mask = args->mask;
     gboolean ok = FALSE, cancelled = FALSE;
     gchar message[100];
     gint i, j, k, si, m, nseed, npos, ic, found, nclusters, ndone, nvalid;
-    gint *nblistj, *nblistk, *seedlistj, *seedlistk, nnbs, *npix, *nnpix;
-    gdouble *labeldata, *mcdist, *maskdata, *mc;
 
     clusters = gwy_field_new(yres, zres, gwy_brick_get_xreal(args->brick), gwy_brick_get_yreal(args->brick), TRUE);
     gwy_field_set_xoffset(clusters, gwy_brick_get_xoffset(args->brick));
@@ -1937,21 +1924,21 @@ cluster_dbscan(ModuleArgs *args, GtkWindow *wait_window)
 
     gwy_app_wait_start(wait_window, _("Initializing..."));
 
-    data = gwy_brick_get_data_const(brick);
+    const gdouble *data = gwy_brick_get_data_const(brick);
     npos = yres*zres;
 
     gwy_field_fill(clusters, -1);             //unassigned
-    labeldata = gwy_field_get_data(clusters);
+    gdouble *labeldata = gwy_field_get_data(clusters);
 
-    nblistj = g_new(gint, npos*sizeof(gint));    //neighbors list
-    nblistk = g_new(gint, npos*sizeof(gint));
-    seedlistj = g_new(gint, npos*sizeof(gint));  //dbscan dynamic seed list
-    seedlistk = g_new(gint, npos*sizeof(gint));
-    mc = g_new0(gdouble, xres*sizeof(gdouble));  //mean curve
+    gint *nblistj = g_new(gint, npos*sizeof(gint));    //neighbors list
+    gint *nblistk = g_new(gint, npos*sizeof(gint));
+    gint *seedlistj = g_new(gint, npos*sizeof(gint));  //dbscan dynamic seed list
+    gint *seedlistk = g_new(gint, npos*sizeof(gint));
+    gdouble *mc = g_new0(gdouble, xres*sizeof(gdouble));  //mean curve
 
     errormap = gwy_field_new_alike(clusters, TRUE);
-    mcdist = gwy_field_get_data(errormap);
-    maskdata = gwy_field_get_data(mask);
+    gdouble *mcdist = gwy_field_get_data(errormap);
+    gint *maskdata = gwy_nield_get_data(mask);
 
     //get some normalisation for range: a mean curve and variance of all the curves from it
     //mark points that are under mask, not to be used for clustering
@@ -1988,7 +1975,7 @@ cluster_dbscan(ModuleArgs *args, GtkWindow *wait_window)
     }
 
     gwy_field_data_changed(errormap);
-    range = 10*range*gwy_field_area_get_rms(errormap, mask, GWY_MASK_EXCLUDE, 0, 0, yres, zres);
+    range = 10*range*gwy_field_area_rms(errormap, mask, GWY_MASK_EXCLUDE, 0, 0, yres, zres);
 
     //perform clustering
     if (!(gwy_app_wait_set_message(_("Clustering...")) && gwy_app_wait_set_fraction(0.0))) {
@@ -2003,7 +1990,7 @@ cluster_dbscan(ModuleArgs *args, GtkWindow *wait_window)
             if (labeldata[j + yres*k] != -1)
                 continue;
 
-            nnbs = get_neighbors(brick, labeldata, j, k, range, nblistj, nblistk);
+            gint nnbs = get_neighbors(brick, labeldata, j, k, range, nblistj, nblistk);
             //printf("curve %d, %d has %d neighbors:\n", j, k, nnbs);
             //for (i=0; i<nnbs; i++)
             //    printf("%d %d %d\n", i, nblistj[i], nblistk[i]);
@@ -2105,12 +2092,12 @@ cluster_dbscan(ModuleArgs *args, GtkWindow *wait_window)
     //create cluster centers
     //printf("%d clusters in total\n", ic);
     nclusters = ic + 1;
-    centers = g_new0(gdouble, nclusters*xres);
-    npix = g_new0(gint, nclusters);
+    gdouble *centers = g_new0(gdouble, nclusters*xres);
+    gint *npix = g_new0(gint, nclusters);
     create_cluster_centers(brick, clusters, centers, nclusters, npix);
     create_error_map(brick, errormap, clusters, centers, nclusters);
 
-    nnpix = g_new0(gint, nclusters);
+    gint *nnpix = g_new0(gint, nclusters);
     resort_clusters_by_size(clusters, centers, nclusters, xres, npix, nnpix);
 
     gwy_field_add(clusters, 1); //shift clusters to start at 1
