@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_drift.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: volume_drift.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2015-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -252,7 +252,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
         args.zdrift_z[k] = k;
     }
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -542,10 +542,10 @@ calculate_zdrift_data(ModuleArgs *args, GtkWindow *wait_window)
         gwy_brick_extract_xy_plane(brick, dfield, k);
         if (k == 0) {
             zdrift[k] = 0;
-            zerodrift = gwy_field_get_avg(dfield);
+            zerodrift = gwy_field_mean(dfield);
         }
         else
-            zdrift[k] = gwy_field_get_avg(dfield) - zerodrift;
+            zdrift[k] = gwy_field_mean(dfield) - zerodrift;
 
         if (!gwy_app_wait_set_fraction((gdouble)k/zres)) {
             clear_data(args);
@@ -652,7 +652,7 @@ calculate_xydrift_data(ModuleArgs *args, GtkWindow *wait_window)
                 gwy_field_correlation_search(dfieldp, kernel, NULL, score, GWY_CORRELATION_POC,
                                              0.1, GWY_EXTERIOR_MIRROR, 0);
 
-                rotscore = gwy_field_get_max(score);
+                rotscore = gwy_field_max(score);
                 rotdata[m] = rotscore;
                 //printf("%g %g\n", gwy_rad2deg(angle), rotscore);
                 if (rotscore > bestrotscore) {
@@ -905,7 +905,7 @@ subpixel_area_copy(GwyField *dfield, GwyField *cropfield,
     }
 
     gwy_field_sample_distorted(dfield, cropfield, coords,
-                               GWY_INTERPOLATION_SCHAUM, GWY_EXTERIOR_FIXED_VALUE, gwy_field_get_avg(dfield));
+                               GWY_INTERPOLATION_SCHAUM, GWY_EXTERIOR_FIXED_VALUE, gwy_field_mean(dfield));
 
     g_free(coords);
 }
@@ -943,7 +943,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
             gwy_brick_extract_xy_plane(original, dfield, k);
 
         if (xdo || ydo) {
-            gwy_field_fill(cropfield, gwy_field_get_avg(dfield));
+            gwy_field_fill(cropfield, gwy_field_mean(dfield));
         }
 
         if (xdo)
