@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_equiplane.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: volume_equiplane.c 29431 2026-02-03 00:36:52Z yeti-dn $
  *  Copyright (C) 2019-2023 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -236,7 +236,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     extract_xyplane(&gui);
 
     gui.vf = gwy_unit_get_format_with_digits(gwy_brick_get_unit_w(brick), GWY_UNIT_FORMAT_VFMARKUP,
-                                             gwy_brick_get_max(brick) - gwy_brick_get_min(brick), 5, /* 5 digits */
+                                             gwy_brick_max(brick) - gwy_brick_min(brick), 5, /* 5 digits */
                                              NULL);
 
     gui.gmodel = gwy_graph_model_new();
@@ -451,7 +451,7 @@ isosurface_nearest(ModuleArgs *args)
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     gint zpos = gwy_params_get_int(args->params, PARAM_ZPOS);
     gint scan_dir = (gint)gwy_params_get_enum(args->params, PARAM_SEARCH_DIR);
-    gint k, dist, lev, dir;
+    gint dist, lev, dir;
     gdouble const_value = get_constant_value(args);
     const gdouble *lowerplane, *upperplane, *d = gwy_brick_get_data_const(brick);
     gdouble *f = gwy_field_get_data(field);
@@ -461,7 +461,7 @@ isosurface_nearest(ModuleArgs *args)
 
     decide_intersection_signs(args, &find_increasing, &find_decreasing);
     n = xres*yres;
-    for (k = 0; k < n; k++)
+    for (gint k = 0; k < n; k++)
         intersection[k] = G_MAXINT;
 
     dist = (scan_dir < 0 ? 1 : 0);
@@ -478,10 +478,9 @@ isosurface_nearest(ModuleArgs *args)
 #ifdef _OPENMP
 #pragma omp parallel for if(gwy_threads_are_enabled()) default(none) \
             shared(lowerplane,upperplane,intersection,lev,n,const_value,find_increasing,find_decreasing) \
-            private(k) \
             reduction(+:intersections_in_plane)
 #endif
-        for (k = 0; k < n; k++) {
+        for (gint k = 0; k < n; k++) {
             gdouble lower = lowerplane[k], upper = upperplane[k];
 
             if (intersection[k] != G_MAXINT)
@@ -511,7 +510,7 @@ next_iter:
         remaining -= intersections_in_plane;
     }
 
-    for (k = 0; k < n; k++) {
+    for (gint k = 0; k < n; k++) {
         gdouble lower, upper, lev_interp;
 
         lev = intersection[k];
