@@ -1,6 +1,6 @@
 /*
- *  $Id: volume_fdfit.c 29023 2025-12-19 13:06:16Z yeti-dn $
- *  Copyright (C) 2003-2025 David Necas (Yeti), Petr Klapetek.
+ *  $Id: volume_fdfit.c 29521 2026-02-23 10:24:50Z yeti-dn $
+ *  Copyright (C) 2003-2026 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -145,7 +145,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Evaluate volume force-distance data"),
     "Petr Klapetek <klapetek@gwyddion.net>, David Nečas <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2013",
 };
@@ -266,7 +266,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gui.args = args;
     gui.parent_data = data;
 
-    GwyField *field = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(id));
+    GwyField *field = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(id));
 
     gui.dialog = gwy_dialog_new(_("FD Fit of Volume Data"));
     GwyDialog *dialog = GWY_DIALOG(gui.dialog);
@@ -688,17 +688,17 @@ point_selection_changed(ModuleGUI *gui,
 }
 
 static void
-create_output_field(GwyField *field, GwyField *mask, GwyFile *data, gchar *title)
+create_output_field(GwyField *field, GwyNield *mask, GwyFile *data, gchar *title)
 {
     /* Do this before adding anything to the data browser to avoid uninitialised values. */
     if (mask)
-        gwy_field_laplace_solve(field, mask, -1, 1.0);
+        gwy_field_laplace_solve(field, mask, GWY_LAPLACE_MASKED, 1.0);
     gint newid = gwy_file_add_image(data, field);
     gwy_file_set_visible(data, GWY_FILE_IMAGE, newid, TRUE);
     gwy_file_set_title(data, GWY_FILE_IMAGE, newid, title, TRUE);
     g_free(title);
     if (mask)
-        gwy_file_pass_image_mask(data, newid, gwy_field_copy(mask));
+        gwy_file_pass_image_mask(data, newid, gwy_nield_copy(mask));
     gwy_log_add_full(data, GWY_FILE_IMAGE, -1, newid, "volume::volume_fdfit", NULL);
 }
 
@@ -742,9 +742,8 @@ execute_brick_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
         g_object_unref(unit);
         m++;
     }
-    GwyField *mask = gwy_field_new_alike(resid_field, FALSE);
-    gwy_field_fill(mask, 1.0);
-    gwy_unit_clear(gwy_field_get_unit_z(mask));
+    GwyNield *mask = gwy_field_new_nield_alike(resid_field);
+    gwy_nield_fill(mask, 1);
 
     gboolean always_estimate = gwy_params_get_boolean(args->params, PARAM_ESTIMATE);
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick);
@@ -779,7 +778,7 @@ execute_brick_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
                 m++;
             }
             gwy_field_set_val(resid_field, j, i, sqrt(gwy_math_nlfit_get_dispersion(fitter)));
-            gwy_field_set_val(mask, j, i, 0.0);
+            gwy_nield_set_val(mask, j, i, 0);
         }
         if (!gwy_app_wait_set_fraction((gdouble)i/xres)) {
             gwy_app_wait_finish();
@@ -789,7 +788,7 @@ execute_brick_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
 
     gwy_app_wait_finish();
 
-    if (gwy_field_get_max(mask) <= 0.0)
+    if (!gwy_nield_count(mask))
         g_clear_object(&mask);
 
     OutputFlags output_flags = gwy_params_get_flags(args->params, PARAM_OUTPUT_TYPE);
