@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_flattenbase.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: volume_flattenbase.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2018-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -205,7 +205,7 @@ param_changed(ModuleGUI *gui, gint id)
 }
 
 static gboolean
-find_base_peak(GwyField *dfield,
+find_base_peak(GwyField *field,
                GwyNLFitter *fitter, GwyLine *dh,
                GArray *xydata,
                gdouble *mean, gdouble *rms)
@@ -216,7 +216,7 @@ find_base_peak(GwyField *dfield,
     gint i, res, from, to, ndata, m = 0;
     gboolean retval;
 
-    gwy_field_dh(dfield, dh, 0);
+    gwy_field_height_dist(field, dh, 0);
     d = gwy_line_get_data(dh);
     res = gwy_line_get_res(dh);
     real = gwy_line_get_real(dh);
@@ -267,82 +267,72 @@ find_base_peak(GwyField *dfield,
 }
 
 static gboolean
-polylevel_with_mask(GwyField *dfield, GwyField *mask,
+polylevel_with_mask(GwyField *field, GwyNield *mask,
                     gint max_degree,
                     gdouble mean, gdouble rms)
 {
     gint nterms = (max_degree + 1)*(max_degree + 2)/2;
     gint *term_powers = g_new(gint, 2*nterms);
-    gint i, j, k;
-    gdouble min, max, threshold, threshval;
-    gdouble *coeffs;
 
-    gwy_field_get_min_max(dfield, &min, &max);
-    if (max <= min)
-        return FALSE;
+    gdouble threshold = mean + 3*rms;
+    gwy_nield_mark_by_threshold(mask, field, threshold, TRUE);
+    gwy_nield_grow(mask, 1 + max_degree/2, GWY_DISTANCE_TRANSFORM_CONN4, FALSE);
 
-    threshold = mean + 3*rms;
-    threshval = 100.0*(threshold - min)/(max - min);
-    gwy_debug("min %g, max %g, threshold %g => threshval %g",
-              min, max, threshold, threshval);
-    gwy_field_grains_mark_height(dfield, mask, threshval, FALSE);
-    gwy_field_grains_grow(mask, 1 + max_degree/2, GWY_DISTANCE_TRANSFORM_CONN4, FALSE);
-
-    k = 0;
-    for (i = 0; i <= max_degree; i++) {
-        for (j = 0; j <= max_degree - i; j++) {
+    gint k = 0;
+    for (gint i = 0; i <= max_degree; i++) {
+        for (gint j = 0; j <= max_degree - i; j++) {
             term_powers[k++] = i;
             term_powers[k++] = j;
         }
     }
 
-    coeffs = gwy_field_fit_poly(dfield, mask, GWY_MASK_EXCLUDE, nterms, term_powers, NULL);
-    gwy_field_subtract_poly(dfield, nterms, term_powers, coeffs);
+    gdouble *coeffs = gwy_field_fit_poly(field, mask, GWY_MASK_EXCLUDE, nterms, term_powers, NULL);
+    gwy_field_subtract_poly(field, nterms, term_powers, coeffs);
     g_free(coeffs);
 
     return TRUE;
 }
 
 static void
-gwy_field_flatten_base(GwyField *dfield, gint max_degree,
+gwy_field_flatten_base(GwyField *field, gint max_degree,
                        GwyNLFitter *fitter, GwyLine *dh, GArray *xydata)
 {
-    GwyField *mfield = NULL;
     gdouble mean, sigma, min, a, bx, by;
     gboolean found_peak;
     gint i;
 
-    found_peak = find_base_peak(dfield, fitter, dh, xydata, &mean, &sigma);
+    found_peak = find_base_peak(field, fitter, dh, xydata, &mean, &sigma);
     gwy_debug("initial peak: %s (mean=%g, rms=%g)",
               found_peak ? "OK" : "NOT FOUND", mean, sigma);
 
     for (i = 0; i < 5; i++) {
-        if (!gwy_field_fit_facet_plane(dfield, NULL, GWY_MASK_IGNORE, &a, &bx, &by))
+        if (!gwy_field_fit_facet_plane(field, NULL, GWY_MASK_IGNORE, &a, &bx, &by))
             break;
 
-        gwy_field_plane_level(dfield, a, bx, by);
-        found_peak = find_base_peak(dfield, fitter, dh, xydata, &mean, &sigma);
+        gwy_field_plane_level(field, a, bx, by);
+        found_peak = find_base_peak(field, fitter, dh, xydata, &mean, &sigma);
         gwy_debug("facet[%d] peak: %s (mean=%g, rms=%g)",
                   i, found_peak ? "OK" : "NOT FOUND", mean, sigma);
         if (!found_peak)
             break;
     }
 
-    mfield = gwy_field_new_alike(dfield, FALSE);
+    GwyNield *mask = gwy_field_new_nield_alike(field);
     for (i = 2; i <= max_degree; i++) {
-        polylevel_with_mask(dfield, mfield, i, mean, sigma);
-        found_peak = find_base_peak(dfield, fitter, dh, xydata, &mean, &sigma);
+        polylevel_with_mask(field, mask, i, mean, sigma);
+        found_peak = find_base_peak(field, fitter, dh, xydata, &mean, &sigma);
         gwy_debug("poly[%d] peak: %s (mean=%g, rms=%g)",
                   i, found_peak ? "OK" : "NOT FOUND", mean, sigma);
         if (!found_peak)
             break;
     }
+    g_object_unref(mask);
 
     if (found_peak)
-        gwy_field_add(dfield, -mean);
+        gwy_field_add(field, -mean);
 
-    if ((min = gwy_field_get_min(dfield)) > 0.0)
-        gwy_field_add(dfield, -min);
+    if ((min = gwy_field_min(field)) > 0.0)
+        gwy_field_add(field, -min);
 }
 
 static gboolean
@@ -365,7 +355,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
 #endif
     {
         GwyNLFitter *fitter;
-        GwyField *dfield = gwy_field_new(xres, yres, xres, yres, FALSE);
+        GwyField *field = gwy_field_new(xres, yres, xres, yres, FALSE);
         GwyLine *dh = gwy_line_new(1, 1.0, FALSE);
         GArray *xydata = g_array_new(FALSE, FALSE, sizeof(gdouble));
         gint kfrom = gwy_omp_chunk_start(zres), kto = gwy_omp_chunk_end(zres);
@@ -374,19 +364,19 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
         fitter = gwy_nlfit_preset_create_fitter(gaussian);
 
         for (k = kfrom; k < kto; k++) {
-            gwy_brick_extract_xy_plane(brick, dfield, k);
+            gwy_brick_extract_xy_plane(brick, field, k);
             if (inverted)
-                gwy_field_multiply(dfield, -1.0);
-            gwy_field_flatten_base(dfield, max_degree, fitter, dh, xydata);
+                gwy_field_multiply(field, -1.0);
+            gwy_field_flatten_base(field, max_degree, fitter, dh, xydata);
             if (inverted)
-                gwy_field_multiply(dfield, -1.0);
-            gwy_brick_set_xy_plane(brick, dfield, k);
+                gwy_field_multiply(field, -1.0);
+            gwy_brick_set_xy_plane(brick, field, k);
 
             if (gwy_omp_set_fraction_check_cancel(gwy_app_wait_set_fraction, k, kfrom, kto, pcancelled))
                 break;
         }
 
-        g_object_unref(dfield);
+        g_object_unref(field);
         g_object_unref(dh);
         g_array_free(xydata, TRUE);
         gwy_math_nlfit_free(fitter);
