@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_linelevel.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: volume_linelevel.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2015-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -84,25 +84,25 @@ static void             preview                  (gpointer user_data);
 static void             update_image             (ModuleGUI *gui,
                                                   gint z);
 static void             linematch_do_trimmed_mean(GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking,
                                                   gdouble trim_fraction);
 static void             linematch_do_trimmed_diff(GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking,
                                                   gdouble trim_fraction);
 static void             linematch_do_modus       (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             linematch_do_match       (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             linematch_do_facet_tilt  (GwyField *field,
-                                                  GwyField *mask,
+                                                  GwyNield *mask,
                                                   GwyLine *shifts,
                                                   GwyMaskingType masking);
 static void             zero_level_row_shifts    (GwyLine *shifts);
@@ -124,7 +124,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Performe line leveling for all the volume data levels."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "2.0",
     "Petr Klapetek & David Nečas (Yeti)",
     "2023",
 };
@@ -184,7 +184,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.brick = brick;
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -370,7 +370,7 @@ execute(ModuleArgs *args)
 }
 
 static void
-linematch_do_trimmed_mean(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_trimmed_mean(GwyField *field, GwyNield *mask, GwyLine *shifts,
                           GwyMaskingType masking, gdouble trimfrac)
 {
     GwyLine *myshifts;
@@ -380,8 +380,9 @@ linematch_do_trimmed_mean(GwyField *field, GwyField *mask, GwyLine *shifts,
     gwy_line_assign(shifts, myshifts);
     g_object_unref(myshifts);
 }
+
 static void
-linematch_do_trimmed_diff(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_trimmed_diff(GwyField *field, GwyNield *mask, GwyLine *shifts,
                           GwyMaskingType masking, gdouble trimfrac)
 {
     GwyLine *myshifts;
@@ -392,20 +393,26 @@ linematch_do_trimmed_diff(GwyField *field, GwyField *mask, GwyLine *shifts,
     g_object_unref(myshifts);
 }
 
+/* See libgwyddion/internal.h */
+static inline gint
+nielded_included(const gint *m, GwyMaskingType masking)
+{
+    if (masking == GWY_MASK_INCLUDE)
+        return *m > 0;
+    if (masking == GWY_MASK_EXCLUDE)
+        return *m <= 0;
+    return 1;
+}
+
 static void
-linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
+linematch_do_modus(GwyField *field, GwyNield *mask, GwyLine *modi,
                    GwyMaskingType masking)
 {
-    gint xres, yres;
-    const gdouble *d, *m;
-    gdouble total_median;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble total_median = gwy_field_area_median(field, mask, masking, 0, 0, xres, yres);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    total_median = gwy_field_area_get_median(field, mask, masking, 0, 0, xres, yres);
-
-    d = gwy_field_get_data(field);
-    m = mask ? gwy_field_get_data_const(mask) : NULL;
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
             shared(d,m,modi,xres,yres,masking,total_median)
@@ -414,22 +421,18 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
         GwyLine *line = gwy_line_new(xres, 1.0, FALSE);
         gdouble *buf = gwy_line_get_data(line);
         gint ifrom = gwy_omp_chunk_start(yres), ito = gwy_omp_chunk_end(yres);
-        gint i;
 
-        for (i = ifrom; i < ito; i++) {
+        for (gint i = ifrom; i < ito; i++) {
             const gdouble *row = d + i*xres;
-            const gdouble *mrow = m ? m + i*xres : NULL;
-            gdouble modus;
-            gint count = 0, j;
+            const gint *mrow = m ? m + i*xres : NULL;
+            gint count = 0;
 
-            for (j = 0; j < xres; j++) {
-                if ((masking == GWY_MASK_INCLUDE && mrow[j] <= 0.0)
-                    || (masking == GWY_MASK_EXCLUDE && mrow[j] >= 1.0))
-                    continue;
-
-                buf[count++] = row[j];
+            for (gint j = 0; j < xres; j++) {
+                if (nielded_included(mrow + j, masking))
+                    buf[count++] = row[j];
             }
 
+            gdouble modus;
             if (!count)
                 modus = total_median;
             else if (count < 9)
@@ -439,7 +442,7 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
                 gdouble diff, bestdiff = G_MAXDOUBLE;
 
                 gwy_math_sort(buf, count);
-                for (j = 0; j + seglen-1 < count; j++) {
+                for (gint j = 0; j + seglen-1 < count; j++) {
                     diff = buf[j + seglen-1] - buf[j];
                     if (diff < bestdiff) {
                         bestdiff = diff;
@@ -448,7 +451,7 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
                 }
                 modus = 0.0;
                 count = 0;
-                for (j = seglen/3; j < seglen - seglen/3; j++, count++)
+                for (gint j = seglen/3; j < seglen - seglen/3; j++, count++)
                     modus += buf[bestj + j];
                 modus /= count;
             }
@@ -464,18 +467,13 @@ linematch_do_modus(GwyField *field, GwyField *mask, GwyLine *modi,
 }
 
 static void
-linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_match(GwyField *field, GwyNield *mask, GwyLine *shifts,
                    GwyMaskingType masking)
 {
-    gint xres, yres, k;
-    const gdouble *d, *m;
-    gdouble *s;
-
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    d = gwy_field_get_data(field);
-    m = mask ? gwy_field_get_data_const(mask) : NULL;
-    s = gwy_line_get_data(shifts);
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble *d = gwy_field_get_data(field);
+    const gint *m = mask ? gwy_nield_get_data_const(mask) : NULL;
+    gdouble *s = gwy_line_get_data(shifts);
 
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
@@ -485,54 +483,46 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
         gint ifrom = gwy_omp_chunk_start(yres-1) + 1;
         gint ito = gwy_omp_chunk_end(yres-1) + 1;
         gdouble *w = g_new(gdouble, xres-1);
-        const gdouble *a, *b, *ma, *mb;
-        gdouble q, wsum, lambda, x;
-        gint i, j;
 
-        for (i = ifrom; i < ito; i++) {
-            a = d + xres*(i - 1);
-            b = d + xres*i;
-            ma = m + xres*(i - 1);
-            mb = m + xres*i;
+        for (gint i = ifrom; i < ito; i++) {
+            const gdouble *a = d + xres*(i - 1);
+            const gdouble *b = d + xres*i;
+            const gint *ma = m + xres*(i - 1);
+            const gint *mb = m + xres*i;
 
             /* Diffnorm */
-            wsum = 0.0;
-            for (j = 0; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0)))
-                    continue;
-
-                x = a[j+1] - a[j] - b[j+1] + b[j];
-                wsum += fabs(x);
+            gdouble wsum = 0.0;
+            for (gint j = 0; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking)) {
+                    gdouble x = a[j+1] - a[j] - b[j+1] + b[j];
+                    wsum += fabs(x);
+                }
             }
             if (wsum == 0) {
                 s[i] = 0.0;
                 continue;
             }
-            q = wsum/(xres-1);
+            gdouble q = wsum/(xres-1);
 
             /* Weights */
             wsum = 0.0;
-            for (j = 0; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0))) {
+            for (gint j = 0; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking)) {
+                    gdouble x = a[j+1] - a[j] - b[j+1] + b[j];
+                    w[j] = exp(-(x*x/(2.0*q)));
+                    wsum += w[j];
+                }
+                else {
                     w[j] = 0.0;
                     continue;
                 }
-
-                x = a[j+1] - a[j] - b[j+1] + b[j];
-                w[j] = exp(-(x*x/(2.0*q)));
-                wsum += w[j];
             }
 
             /* Correction */
-            lambda = (a[0] - b[0])*w[0];
-            for (j = 1; j < xres-1; j++) {
-                if ((masking == GWY_MASK_INCLUDE && (ma[j] <= 0.0 || mb[j] <= 0.0))
-                    || (masking == GWY_MASK_EXCLUDE && (ma[j] >= 1.0 || mb[j] >= 1.0)))
-                    continue;
-
-                lambda += (a[j] - b[j])*(w[j-1] + w[j]);
+            gdouble lambda = (a[0] - b[0])*w[0];
+            for (gint j = 1; j < xres-1; j++) {
+                if (nielded_included(ma + j, masking) && nielded_included(mb + j, masking))
+                    lambda += (a[j] - b[j])*(w[j-1] + w[j]);
             }
             lambda += (a[xres-1] - b[xres-1])*w[xres-2];
             lambda /= 2.0*wsum;
@@ -546,7 +536,7 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
     }
 
     s[0] = 0.0;
-    for (k = 1; k < yres; k++)
+    for (gint k = 1; k < yres; k++)
         s[k] += s[k-1];
 
     zero_level_row_shifts(shifts);
@@ -555,39 +545,27 @@ linematch_do_match(GwyField *field, GwyField *mask, GwyLine *shifts,
 
 static gdouble
 row_fit_facet_tilt(const gdouble *drow,
-                   const gdouble *mrow,
+                   const gint *mrow,
                    GwyMaskingType masking,
                    guint res, gdouble dx,
                    guint mincount)
 {
     const gdouble c = 1.0/200.0;
 
-    gdouble vx, q, sumvx, sumvz, sigma2;
-    guint i, n;
-
-    sigma2 = 0.0;
-    n = 0;
-    if (mrow && masking == GWY_MASK_INCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] >= 1.0 && mrow[i+1] >= 1.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                sigma2 += vx*vx;
-                n++;
-            }
-        }
-    }
-    else if (mrow && masking == GWY_MASK_EXCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] <= 0.0 && mrow[i+1] <= 0.0) {
-                vx = (drow[i+1] - drow[i])/dx;
+    gdouble sigma2 = 0.0;
+    gint n = 0;
+    if (mrow) {
+        for (gint i = 0; i < res-1; i++) {
+            if (nielded_included(mrow + i, masking) && nielded_included(mrow + i+1, masking)) {
+                gdouble vx = (drow[i+1] - drow[i])/dx;
                 sigma2 += vx*vx;
                 n++;
             }
         }
     }
     else {
-        for (i = 0; i < res-1; i++) {
-            vx = (drow[i+1] - drow[i])/dx;
+        for (gint i = 0; i < res-1; i++) {
+            gdouble vx = (drow[i+1] - drow[i])/dx;
             sigma2 += vx*vx;
         }
         n = res-1;
@@ -598,31 +576,22 @@ row_fit_facet_tilt(const gdouble *drow,
         return 0.0;
 
     sigma2 = c*sigma2/n;
-    sumvx = sumvz = 0.0;
-    if (mrow && masking == GWY_MASK_INCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] >= 1.0 && mrow[i+1] >= 1.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                q = exp(vx*vx/sigma2);
-                sumvx += vx/q;
-                sumvz += 1.0/q;
-            }
-        }
-    }
-    else if (mrow && masking == GWY_MASK_EXCLUDE) {
-        for (i = 0; i < res-1; i++) {
-            if (mrow[i] <= 0.0 && mrow[i+1] <= 0.0) {
-                vx = (drow[i+1] - drow[i])/dx;
-                q = exp(vx*vx/sigma2);
+
+    gdouble sumvx = 0.0, sumvz = 0.0;
+    if (mrow) {
+        for (gint i = 0; i < res-1; i++) {
+            if (nielded_included(mrow + i, masking) && nielded_included(mrow + i+1, masking)) {
+                gdouble vx = (drow[i+1] - drow[i])/dx;
+                gdouble q = exp(vx*vx/sigma2);
                 sumvx += vx/q;
                 sumvz += 1.0/q;
             }
         }
     }
     else {
-        for (i = 0; i < res-1; i++) {
-            vx = (drow[i+1] - drow[i])/dx;
-            q = exp(vx*vx/sigma2);
+        for (gint i = 0; i < res-1; i++) {
+            gdouble vx = (drow[i+1] - drow[i])/dx;
+            gdouble q = exp(vx*vx/sigma2);
             sumvx += vx/q;
             sumvz += 1.0/q;
         }
@@ -647,41 +616,35 @@ untilt_row(gdouble *drow, guint res, gdouble bx)
 }
 
 static void
-linematch_do_facet_tilt(GwyField *field, GwyField *mask, GwyLine *shifts,
+linematch_do_facet_tilt(GwyField *field, GwyNield *mask, GwyLine *shifts,
                         GwyMaskingType masking)
 {
-    guint xres, yres, i, j, mincount;
-    const gdouble *mdata, *mrow;
-    gdouble *data, *drow;
-    gdouble dx, tilt;
+    gint xres = gwy_field_get_xres(field), yres = gwy_field_get_yres(field);
+    gdouble dx = gwy_field_get_dx(field);
+    gint mincount = GWY_ROUND(log(xres) + 1);
 
-    xres = gwy_field_get_xres(field);
-    yres = gwy_field_get_yres(field);
-    dx = gwy_field_get_dx(field);
-    mincount = GWY_ROUND(log(xres) + 1);
-
-    data = gwy_field_get_data(field);
-    mdata = mask ? gwy_field_get_data_const(mask) : NULL;
-    for (i = 0; i < yres; i++) {
-        drow = data + i*xres;
-        mrow = mdata ? mdata + i*xres : NULL;
-        for (j = 0; j < 30; j++) {
-            tilt = row_fit_facet_tilt(drow, mrow, masking, xres, dx, mincount);
+    gdouble *data = gwy_field_get_data(field);
+    const gint *mdata = mask ? gwy_nield_get_data_const(mask) : NULL;
+    for (gint i = 0; i < yres; i++) {
+        gdouble *drow = data + i*xres;
+        const gint *mrow = mdata ? mdata + i*xres : NULL;
+        for (gint j = 0; j < 30; j++) {
+            gdouble tilt = row_fit_facet_tilt(drow, mrow, masking, xres, dx, mincount);
             untilt_row(drow, xres, tilt);
             if (fabs(tilt/dx) < 1e-6)
                 break;
         }
     }
 
-    /* FIXME: Should we put the tilts there to confuse the user?  We need to
-     * make sure all functions set the units correctly in such case. */
+    /* FIXME: Should we put the tilts there to confuse the user?  We need to make sure all functions set the units
+     * correctly in such case. */
     gwy_line_clear(shifts);
 }
 
 static void
 zero_level_row_shifts(GwyLine *shifts)
 {
-    gwy_line_add(shifts, -gwy_line_avg(shifts));
+    gwy_line_add(shifts, -gwy_line_mean(shifts));
 }
 
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
