@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_linestat.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: volume_linestat.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2015-2021 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -129,7 +129,7 @@ static void                        sanitise_params        (ModuleArgs *args);
 
 /* XXX: This is more or less identical to tools/linestat.c. */
 static const LineStatQuantityInfo quantities[] =  {
-    { N_("Mean"),              GWY_LINE_STAT_MEAN,      gwy_line_avg,       },
+    { N_("Mean"),              GWY_LINE_STAT_MEAN,      gwy_line_mean,       },
     { N_("Median"),            GWY_LINE_STAT_MEDIAN,    gwy_line_median,    },
     { N_("Minimum"),           GWY_LINE_STAT_MINIMUM,   gwy_line_min,       },
     { N_("Maximum"),           GWY_LINE_STAT_MAXIMUM,   gwy_line_max,       },
@@ -230,7 +230,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.result = gwy_brick_new_field_like_xy_plane(args.brick, TRUE);
     sanitise_params(&args);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -250,7 +250,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     }
     else if (output_type == OUTPUT_PREVIEW) {
         /* FIXME: add undo */
-        gwy_container_set_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(oldid), args.result);
+        gwy_dict_set_object(GWY_DICT(data), gwy_file_key_volume_picture(oldid), args.result);
     }
     else {
         g_assert_not_reached();
@@ -600,14 +600,14 @@ get_line_maxpos_i(GwyLine *line)
 static gdouble
 get_line_Rt(GwyLine *line)
 {
-    gwy_line_add(line, -gwy_line_avg(line));
+    gwy_line_add(line, -gwy_line_mean(line));
     return gwy_line_xtm(line, 1, 1);
 }
 
 static gdouble
 get_line_Rz(GwyLine *line)
 {
-    gwy_line_add(line, -gwy_line_avg(line));
+    gwy_line_add(line, -gwy_line_mean(line));
     return gwy_line_xtm(line, 5, 1);
 }
 
@@ -633,7 +633,6 @@ execute(ModuleArgs *args)
     gint xres = gwy_brick_get_xres(brick), yres = gwy_brick_get_yres(brick), zres = gwy_brick_get_zres(brick);
     LineStatFunc lsfunc = NULL;
     gint i, j;
-    guint k;
     gdouble *data, val, zreal, zoffset;
 
     /* Quantities we handle (somewhat inefficiently) by using Line statistics. */
@@ -649,7 +648,6 @@ execute(ModuleArgs *args)
      * brick by larger blocks, gaining a speedup about 3 from the much improved memory access pattern. */
 #ifdef _OPENMP
 #pragma omp parallel if(gwy_threads_are_enabled()) default(none) \
-            private(k) \
             shared(brick,xres,yres,zfrom,zto,field,lsfunc)
 #endif
     {
@@ -659,7 +657,7 @@ execute(ModuleArgs *args)
         guint kto = gwy_omp_chunk_end(xres*yres);
 
         line_stat_iter_init(&iter, brick, kfrom, kto, zfrom, zto);
-        for (k = kfrom; k < kto; k++) {
+        for (guint k = kfrom; k < kto; k++) {
             line_stat_iter_next(&iter);
             d[k] = lsfunc(iter.dline);
         }
