@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_localdetect.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: volume_localdetect.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2015-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -142,7 +142,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     args.brick = brick;
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -218,7 +218,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
 
     gwy_param_table_append_slider(table, PARAM_HEIGHT);
     gwy_param_table_slider_set_mapping(table, PARAM_HEIGHT, GWY_SCALE_MAPPING_LINEAR);
-    gwy_field_get_min_max(dfield, &min, &max);
+    gwy_field_min_max(dfield, &min, &max);
     vf = gwy_unit_get_format(gwy_field_get_unit_z(dfield), GWY_UNIT_FORMAT_VFMARKUP, max-min, NULL);
     vf->precision++;
     gwy_param_table_slider_set_factor(table, PARAM_HEIGHT, 1.0/vf->magnitude);
@@ -364,12 +364,15 @@ execute(ModuleArgs *args, GtkWindow *wait_window, gboolean resample)
     for (k = 0; k < zres; k++) {
         gwy_brick_extract_xy_plane(brick, dfield, k);
         gwy_field_filter_gaussian(dfield, threshold);  //run pre-filtering
-        gwy_field_add(dfield, -gwy_field_get_min(dfield)); //shift to minimum to enable height threshold
+        gwy_field_add(dfield, -gwy_field_min(dfield)); //shift to minimum to enable height threshold
 
         if (upscale != 1)   //if requested, work with upsampled images
             gwy_field_resample(dfield, upscale*xres, upscale*yres, GWY_INTERPOLATION_SCHAUM);
 
-        gwy_field_mark_extrema(dfield, maxs, TRUE);    //find maxima mask
+        GwyNield *mask = gwy_field_new_nield_alike(dfield);
+        gwy_field_mark_extrema(dfield, mask, TRUE);    //find maxima mask
+        gwy_field_fill_mask(maxs, mask, 0.0, 1.0);
+        g_object_unref(mask);
         filter_extrema_field(dfield, maxs, height); //add height information there
 
         if (method == METHOD_PIXEL) {
