@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_mfmrecalc.c 28809 2025-11-05 18:36:20Z yeti-dn $
+ *  $Id: volume_mfmrecalc.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2017-2023 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -186,9 +186,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     else {
         quarks[0] = gwy_file_key_volume(oldid);
         quarks[1] = gwy_file_key_volume_picture(oldid);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 2, quarks);
-        gwy_container_set_object(GWY_CONTAINER(data), quarks[0], args.result);
-        gwy_container_set_object(GWY_CONTAINER(data), quarks[1], preview);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 2, quarks);
+        gwy_dict_set_object(GWY_DICT(data), quarks[0], args.result);
+        gwy_dict_set_object(GWY_DICT(data), quarks[1], preview);
         gwy_log_add(data, GWY_FILE_VOLUME, oldid, oldid);
     }
 
