@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_planestat.c 29059 2026-01-02 14:27:52Z yeti-dn $
+ *  $Id: volume_planestat.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2015-2025 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -165,19 +165,19 @@ static void                      sanitise_params          (ModuleArgs *args);
 
 static const PlaneStatQuantInfo quantities[] = {
     {
-        GWY_PLANE_STAT_MEAN, 0, 0, 0, 1, gwy_field_get_avg,
+        GWY_PLANE_STAT_MEAN, 0, 0, 0, 1, gwy_field_mean,
         N_("Mean"), "μ",
     },
     {
-        GWY_PLANE_STAT_RMS, 0, 0, 0, 1, gwy_field_get_rms,
+        GWY_PLANE_STAT_RMS, 0, 0, 0, 1, gwy_field_rms,
         N_("RMS"), "σ",
     },
     {
-        GWY_PLANE_STAT_MIN, 0, 0, 0, 1, gwy_field_get_min,
+        GWY_PLANE_STAT_MIN, 0, 0, 0, 1, gwy_field_min,
         N_("Minimum"), "v<sub>min</sub>",
     },
     {
-        GWY_PLANE_STAT_MAX, 0, 0, 0, 1, gwy_field_get_max,
+        GWY_PLANE_STAT_MAX, 0, 0, 0, 1, gwy_field_max,
         N_("Maximum"), "v<sub>min</sub>",
     },
     {
@@ -201,11 +201,11 @@ static const PlaneStatQuantInfo quantities[] = {
         N_("Median"), "m",
     },
     {
-        GWY_PLANE_STAT_VARIATION, GWY_PLANE_STAT_LATERAL_EQUAL, 1, 0, 1, gwy_field_get_variation,
+        GWY_PLANE_STAT_VARIATION, GWY_PLANE_STAT_LATERAL_EQUAL, 1, 0, 1, gwy_field_variation,
         N_("Variation"), "var",
     },
     {
-        GWY_PLANE_STAT_ENTROPY, 0, 0, 0, 0, gwy_field_get_entropy,
+        GWY_PLANE_STAT_ENTROPY, 0, 0, 0, 0, gwy_field_entropy,
         N_("Entropy"), "H",
     },
     {
@@ -337,7 +337,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gui.args = args;
     gui.xvf = gwy_brick_get_value_format_x(args->brick, GWY_UNIT_FORMAT_VFMARKUP, NULL);
     gui.yvf = gwy_brick_get_value_format_y(args->brick, GWY_UNIT_FORMAT_VFMARKUP, NULL);
-    gui.orig_preview = gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(id));
+    gui.orig_preview = gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(id));
 
     gui.dialog = gwy_dialog_new(_("Summarize Volume Planes"));
     dialog = GWY_DIALOG(gui.dialog);
@@ -797,7 +797,7 @@ get_plane_range(GwyField *field)
 {
     gdouble min, max;
 
-    gwy_field_get_min_max(field, &min, &max);
+    gwy_field_min_max(field, &min, &max);
     return max - min;
 }
 
@@ -806,7 +806,7 @@ get_plane_Sa(GwyField *field)
 {
     gdouble Sa;
 
-    gwy_field_get_stats(field, NULL, &Sa, NULL, NULL, NULL);
+    gwy_field_stats(field, NULL, &Sa, NULL, NULL, NULL);
 
     return Sa;
 }
@@ -826,7 +826,7 @@ get_plane_skew(GwyField *field)
 {
     gdouble rms, skew;
 
-    gwy_field_get_stats(field, NULL, NULL, &rms, &skew, NULL);
+    gwy_field_stats(field, NULL, NULL, &rms, &skew, NULL);
 
     return rms > 0.0 ? skew : 0.0;
 }
@@ -836,7 +836,7 @@ get_plane_kurtosis(GwyField *field)
 {
     gdouble rms, kurtosis;
 
-    gwy_field_get_stats(field, NULL, NULL, &rms, NULL, &kurtosis);
+    gwy_field_stats(field, NULL, NULL, &rms, NULL, &kurtosis);
 
     return rms > 0.0 ? kurtosis : 0.0;
 }
@@ -844,8 +844,8 @@ get_plane_kurtosis(GwyField *field)
 static gdouble
 get_plane_entropy_deficit(GwyField *field)
 {
-    gdouble H = gwy_field_get_entropy(field);
-    gdouble rms = gwy_field_get_rms(field);
+    gdouble H = gwy_field_entropy(field);
+    gdouble rms = gwy_field_rms(field);
 
     if (rms > 10.0*G_MINDOUBLE && H < 0.1*G_MAXDOUBLE)
         return ENTROPY_NORMAL + log(rms) - H;
