@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_psf.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: volume_psf.c 29416 2026-01-30 16:49:54Z yeti-dn $
  *  Copyright (C) 2017-2023 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -157,6 +157,7 @@ static gboolean         method_is_full_sized           (PSFMethodType method);
 static void             estimate_tf_region             (GwyField *wmeas,
                                                         GwyField *wideal,
                                                         GwyField *psf,
+                                                        GwyNield *mask,
                                                         gint *col,
                                                         gint *row,
                                                         gint *width,
@@ -491,17 +492,18 @@ dialog_response(ModuleGUI *gui, gint response)
 
     if (response == RESPONSE_ESTIMATE) {
         GwyField *ideal = gwy_params_get_image(params, PARAM_IDEAL);
-        GwyField *wmeas, *wideal, *psf;
         GwyWindowingType windowing = gwy_params_get_enum(params, PARAM_WINDOWING);
         gint col, row, width, height, txres, tyres, border;
 
-        wmeas = gwy_field_new_alike(gui->xyplane, FALSE);
-        wideal = gwy_field_new_alike(ideal, FALSE);
+        GwyField *wmeas = gwy_field_new_alike(gui->xyplane, FALSE);
+        GwyField *wideal = gwy_field_new_alike(ideal, FALSE);
         prepare_field(gui->xyplane, wmeas, windowing);
         prepare_field(ideal, wideal, windowing);
 
-        psf = gwy_field_new_alike(gui->xyplane, TRUE);
-        estimate_tf_region(wmeas, wideal, psf, &col, &row, &width, &height);
+        GwyField *psf = gwy_field_new_alike(gui->xyplane, TRUE);
+        GwyNield *mask = gwy_field_new_nield_alike(psf);
+        estimate_tf_region(wmeas, wideal, psf, mask, &col, &row, &width, &height);
+        g_object_unref(mask);
         g_object_unref(psf);
         g_object_unref(wideal);
         g_object_unref(wmeas);
@@ -546,7 +548,7 @@ calculate_l2_norm(GwyField *field, gboolean as_integral,
 {
     gdouble l2norm, q;
 
-    l2norm = gwy_field_get_mean_square(field);
+    l2norm = gwy_field_mean_square(field);
 
     /* In the integral formulation, we calculate the integral of squared values and units of dx dy are reflected in
      * the result.  In non-integral, we calculate a mere sum of squared values and the result has the same units as
@@ -585,9 +587,9 @@ preview(gpointer user_data)
     g_object_unref(wfield2);
 
     gwy_field_assign(convolved, field2);
-    gwy_field_add(convolved, -gwy_field_get_avg(convolved));
+    gwy_field_add(convolved, -gwy_field_mean(convolved));
     field_convolve_default(convolved, psf);
-    gwy_field_add(convolved, gwy_field_get_avg(field1));
+    gwy_field_add(convolved, gwy_field_mean(field1));
 
     gwy_field_assign(difference, field1);
     gwy_field_subtract_fields(difference, field1, convolved);
@@ -601,7 +603,7 @@ preview(gpointer user_data)
     gwy_results_set_unit(results, "x", gwy_field_get_unit_xy(psf));
     gwy_results_set_unit(results, "y", gwy_field_get_unit_xy(psf));
     gwy_results_set_unit(results, "z", gwy_field_get_unit_z(psf));
-    gwy_field_get_min_max(psf, &min, &max);
+    gwy_field_min_max(psf, &min, &max);
     unit = gwy_unit_new(NULL);
     l2norm = calculate_l2_norm(psf, as_integral, unit);
     gwy_results_set_unit(results, "u", unit);
@@ -640,8 +642,8 @@ switch_display(ModuleGUI *gui)
             gdouble min, max, dispmin, dispmax;
 
             mapping = GWY_COLOR_MAPPING_FIXED;
-            gwy_field_get_min_max(gui->difference, &min, &max);
-            gwy_field_get_autorange(gui->difference, &dispmin, &dispmax);
+            gwy_field_min_max(gui->difference, &min, &max);
+            gwy_field_autorange(gui->difference, &dispmin, &dispmax);
             gwy_set_gradient_for_residuals(gui->diff_gradient, min, max, &dispmin, &dispmax);
             gwy_data_view_set_fixed_color_range(dataview, dispmin, dispmax);
             gwy_data_view_set_gradient(dataview, gui->diff_gradient);
@@ -729,7 +731,7 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
 #endif
     {
         gint kfrom = gwy_omp_chunk_start(zres), kto = gwy_omp_chunk_end(zres);
-        GwyField *measured, *psf, *buf, *convolved = NULL, *wmeas = NULL;
+        GwyField *buf, *convolved = NULL, *wmeas = NULL;
         GwyParams *tparams = gwy_params_duplicate(args->params);
         gboolean estimate_tres = gwy_params_get_boolean(tparams, PARAM_ESTIMATE_TRES);
         gboolean estimate_sigma = gwy_params_get_boolean(tparams, PARAM_ESTIMATE_SIGMA);
@@ -741,8 +743,9 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
         gint k;
 
         /* Measured does not have correct units here yet. */
-        psf = gwy_field_new_alike(ideal, FALSE);
-        measured = gwy_field_new(xres, yres, gwy_brick_get_xreal(brick), gwy_brick_get_yreal(brick), FALSE);
+        GwyField *psf = gwy_field_new_alike(ideal, FALSE);
+        GwyNield *mask = gwy_field_new_nield_alike(psf);
+        GwyField *measured = gwy_field_new(xres, yres, gwy_brick_get_xreal(brick), gwy_brick_get_yreal(brick), FALSE);
         for (k = kfrom; k < kto; k++) {
             gwy_brick_extract_xy_plane(brick, measured, k);
             if (estimate_tres) {
@@ -751,7 +754,7 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
                 if (!wmeas)
                     wmeas = gwy_field_new_alike(measured, FALSE);
                 prepare_field(measured, wmeas, windowing);
-                estimate_tf_region(wmeas, wideal, psf, &col, &row, &width, &height);
+                estimate_tf_region(wmeas, wideal, psf, mask, &col, &row, &width, &height);
                 symmetrise_tf_region(col, width, xres, &txres);
                 symmetrise_tf_region(row, height, yres, &tyres);
                 gwy_params_set_int(tparams, PARAM_TXRES, txres);
@@ -800,10 +803,10 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
                 if (!convolved)
                     convolved = gwy_field_new_alike(ideal, FALSE);
                 gwy_field_assign(convolved, ideal);
-                gwy_field_add(convolved, -gwy_field_get_avg(convolved));
+                gwy_field_add(convolved, -gwy_field_mean(convolved));
                 field_convolve_default(convolved, psf);
                 gwy_field_subtract_fields(convolved, measured, convolved);
-                gwy_field_add(convolved, gwy_field_get_avg(measured));
+                gwy_field_add(convolved, gwy_field_mean(measured));
                 gwy_line_set_val(plots[3], k, calculate_l2_norm(convolved, as_integral, unit));
                 if (unit) {
                     gwy_unit_assign(gwy_line_get_unit_y(plots[3]), unit);
@@ -816,7 +819,7 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
             if (plots[1]) {
                 if (!k)
                     gwy_unit_assign(gwy_line_get_unit_y(plots[1]), gwy_field_get_unit_z(psf));
-                gwy_field_get_min_max(psf, &min, &max);
+                gwy_field_min_max(psf, &min, &max);
                 gwy_line_set_val(plots[1], k, fmax(fabs(min), fabs(max)));
             }
             /* PSF_OUTPUT_TF_NORM */
@@ -845,6 +848,7 @@ execute_and_create_outputs(ModuleArgs *args, GwyFile *data, gint id)
         }
 
         g_object_unref(measured);
+        g_object_unref(mask);
         g_object_unref(psf);
         g_object_unref(tparams);
         g_clear_object(&convolved);
@@ -920,7 +924,7 @@ prepare_field(GwyField *field, GwyField *wfield,
     /* Prepare field in place if requested. */
     if (wfield != field)
         gwy_field_assign(wfield, field);
-    gwy_field_add(wfield, -gwy_field_get_avg(wfield));
+    gwy_field_add(wfield, -gwy_field_mean(wfield));
     gwy_field_fft_window(wfield, window);
 }
 
@@ -1001,24 +1005,21 @@ adjust_tf_brick_to_non_integral(GwyBrick *psf)
 static gdouble
 measure_tf_width(GwyField *psf)
 {
-    GwyField *mask, *abspsf;
-    gint xres, yres;
-    gdouble s2;
+    gint xres = gwy_field_get_xres(psf), yres = gwy_field_get_yres(psf);
+    GwyField *abspsf = gwy_field_copy(psf);
+    gwy_field_abs(abspsf);
 
-    xres = gwy_field_get_xres(psf);
-    yres = gwy_field_get_yres(psf);
-    mask = gwy_field_copy(psf);
-    gwy_field_threshold(mask, 0.15*gwy_field_get_max(mask), 0.0, 1.0);
-    if (gwy_field_get_val(mask, xres/2, yres/2) == 0.0) {
+    GwyNield *mask = gwy_field_new_nield_alike(psf);
+    gwy_nield_mark_by_threshold(mask, abspsf, 0.15*gwy_field_max(abspsf), TRUE);
+    if (!gwy_nield_get_val(mask, xres/2, yres/2)) {
         g_object_unref(mask);
+        g_object_unref(abspsf);
         return 0.0;
     }
 
-    gwy_field_grains_extract_grain(mask, xres/2, yres/2);
-    gwy_field_grains_grow(mask, 0.5*log(xres*yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
-    abspsf = gwy_field_copy(psf);
-    gwy_field_abs(abspsf);
-    s2 = gwy_field_area_get_dispersion(abspsf, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, NULL, NULL);
+    gwy_nield_isolate_at(mask, xres/2, yres/2, NULL);
+    gwy_nield_grow(mask, 0.5*log(xres*yres), GWY_DISTANCE_TRANSFORM_EUCLIDEAN, FALSE);
+    gdouble s2 = gwy_field_area_dispersion(abspsf, mask, GWY_MASK_INCLUDE, 0, 0, xres, yres, NULL, NULL);
     g_object_unref(mask);
     g_object_unref(abspsf);
 
@@ -1033,60 +1034,35 @@ method_is_full_sized(PSFMethodType method)
 
 static void
 estimate_tf_region(GwyField *wmeas, GwyField *wideal,
-                   GwyField *psf,  /* scratch buffer */
+                   GwyField *psf, GwyNield *mask, /* scratch buffers */
                    gint *col, gint *row, gint *width, gint *height)
 {
-    gint xres, yres, i, j, imin, jmin, imax, jmax, ext;
-    const gdouble *d;
-    gdouble m;
+    gint xres = gwy_field_get_xres(wmeas), yres = gwy_field_get_yres(wmeas);
 
-    xres = gwy_field_get_xres(wmeas);
-    yres = gwy_field_get_yres(wmeas);
     *col = xres/3;
     *row = yres/3;
     *width = xres - 2*(*col);
     *height = yres - 2*(*row);
     /* Use a fairly large but not yet insane sigma value 4.0 to estimate the width.  We want to err on the side of
-     * size overestimation here. XXX: We might want to use a proportional to 1/sqrt(xres*yres) here. */
+     * size overestimation here.
+     * XXX: We might want to use a proportional to 1/sqrt(xres*yres) here. */
     gwy_field_deconvolve_regularized(wmeas, wideal, psf, 4.0);
-    d = gwy_field_get_data_const(psf);
+    gwy_field_abs(psf);
 
-    /* FIXME: From here it the same as to libgwyddion/filter.c psf_sigmaopt_estimate_size(). */
-    imax = yres/2;
-    jmax = xres/2;
-    m = 0.0;
-    for (i = *row; i < *row + *height; i++) {
-        for (j = *col; j < *col + *width; j++) {
-            if (d[i*xres + j] > m) {
-                m = d[i*xres + j];
-                imax = i;
-                jmax = j;
-            }
-        }
-    }
-    gwy_debug("maximum %g at (%d,%d)", m, imax, jmax);
-    gwy_field_threshold(psf, 0.05*m, 0.0, 1.0);
-    g_return_if_fail(d[imax*xres + jmax] > 0.0);
-    gwy_field_grains_extract_grain(psf, jmax, imax);
+    /* FIXME: From here it the same as to libgwyddion/filters--convdeconv.c psf_sigmaopt_estimate_size(). */
+    gdouble xmax = xres/2, ymax = yres/2;
+    gwy_field_local_maximum(psf, &xmax, &ymax, xres/5 + 1, yres/5 + 1);
+    gint imax = GWY_ROUND(ymax), jmax = GWY_ROUND(xmax);
+    gwy_debug("maximum at (%d,%d)", imax, jmax);
 
-    imin = imax;
-    jmin = jmax;
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++) {
-            if (d[i*xres + j] > 0.0) {
-                if (i < imin)
-                    imin = i;
-                if (i > imax)
-                    imax = i;
-                if (j < jmin)
-                    jmin = j;
-                if (j > jmax)
-                    jmax = j;
-            }
-        }
-    }
+    gwy_nield_mark_by_threshold(mask, psf, 0.05*gwy_field_get_val(psf, jmax, imax), TRUE);
+    gint bbox[4];
+    gwy_nield_isolate_at(mask, imax, jmax, bbox);
+    gint jmin = bbox[0], imin = bbox[1];
+    jmax = jmin + bbox[2]-1;
+    imax = imin + bbox[3]-1;
 
-    ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
+    gint ext = GWY_ROUND(0.5*log(xres*yres)) + 1;
     *col = jmin - ext;
     *row = imin - ext;
     *width = jmax+1 - jmin + 2*ext;
@@ -1104,11 +1080,12 @@ estimate_tf_region(GwyField *wmeas, GwyField *wideal,
     if (*row + *height > yres)
         *height = yres - *row;
 
-    gwy_debug("estimated region: %dx%d centered at (%d,%d)", *width, *height, *col + *width/2, *row + *height/2);
+    gwy_debug("estimated region: %dx%d centered at (%d,%d)",
+              *width, *height, *col + *width/2, *row + *height/2);
 
     /* Use some default reasonable size when things get out of hand... */
-    *width = MIN(*width, xres/4);
-    *height = MIN(*height, yres/4);
+    *width = MIN(*width, xres/6);
+    *height = MIN(*height, yres/6);
 }
 
 static void
@@ -1124,6 +1101,7 @@ typedef struct {
     GwyField *psf;         /* Real-space PSF */
     GwyField *wideal;      /* Windowed ideal. */
     GwyField *wmeas;       /* Windowed measured. */
+    GwyNield *mask;
     gint col, row;
     gint width, height;
 } PSFSigmaOptData;
@@ -1144,8 +1122,9 @@ psf_sigmaopt_prepare(GwyField *measured, GwyField *ideal,
     prepare_field(ideal, sodata->wideal, windowing);
     if (method == PSF_METHOD_PSEUDO_WIENER) {
         sodata->psf = gwy_field_new_alike(measured, FALSE);
-        estimate_tf_region(sodata->wmeas, sodata->wideal, sodata->psf, &sodata->col, &sodata->row,
-                           &sodata->width, &sodata->height);
+        sodata->mask = gwy_field_new_nield_alike(sodata->psf);
+        estimate_tf_region(sodata->wmeas, sodata->wideal, sodata->psf, sodata->mask,
+                           &sodata->col, &sodata->row, &sodata->width, &sodata->height);
     }
 }
 
@@ -1170,8 +1149,8 @@ psf_sigmaopt_evaluate(gdouble logsigma, gpointer user_data)
     sigma = exp(logsigma);
     psf_deconvolve_wiener(sodata->wmeas, sodata->wideal, psf, sigma);
     gwy_field_area_abs(psf, sodata->col, sodata->row, sodata->width, sodata->height);
-    w = gwy_field_area_get_dispersion(psf, NULL, GWY_MASK_IGNORE,
-                                      sodata->col, sodata->row, sodata->width, sodata->height, NULL, NULL);
+    w = gwy_field_area_dispersion(psf, NULL, GWY_MASK_IGNORE,
+                                  sodata->col, sodata->row, sodata->width, sodata->height, NULL, NULL);
     return sqrt(w);
 }
 
@@ -1248,8 +1227,8 @@ psf_deconvolve_wiener(GwyField *field,
     g_return_if_fail(operand->yres == yres);
     gwy_field_resize(out, xres, yres);
 
-    orms = gwy_field_get_rms(operand);
-    frms = gwy_field_get_rms(field);
+    orms = gwy_field_rms(operand);
+    frms = gwy_field_rms(field);
     if (!orms) {
         g_warning("Deconvolution by zero.");
         gwy_field_clear(out);
