@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_xystitch.c 28905 2025-11-24 15:51:18Z yeti-dn $
+ *  $Id: volume_xystitch.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2023-2024 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -152,7 +152,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     gwy_data_browser_get_current(GWY_APP_BRICK, &brick,
                                  GWY_APP_BRICK_ID, &oldid,
-                                 GWY_APP_CONTAINER_ID, &graph_id.datano,
+                                 GWY_APP_FILE_ID, &graph_id.datano,
                                  GWY_APP_GRAPH_MODEL_ID, &graph_id.id,
                                  0);
     g_return_if_fail(GWY_IS_BRICK(brick));
@@ -163,7 +163,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_params_set_graph_id(args.params, PARAM_XOFFSETS, graph_id);
     gwy_params_set_graph_id(args.params, PARAM_YOFFSETS, graph_id);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, oldid);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -403,8 +403,8 @@ recalc(gpointer user_data)
         return;
     }
 
-    gwy_surface_get_xrange(gui->args->result, &xmin, &xmax);
-    gwy_surface_get_yrange(gui->args->result, &ymin, &ymax);
+    gwy_surface_xrange(gui->args->result, &xmin, &xmax);
+    gwy_surface_yrange(gui->args->result, &ymin, &ymax);
     xrange = xmax - xmin;
     yrange = ymax - ymin;
 
@@ -818,8 +818,8 @@ get_shifts(GwyBrick *brick, gdouble *xoff, gdouble *yoff, gdouble *xshift, gdoub
                 }
              }
              if (doz) {
-                mh = gwy_field_area_get_sum(mfield, NULL, GWY_MASK_IGNORE, col1, row1, width, height);
-                nh = gwy_field_area_get_sum(nfield, NULL, GWY_MASK_IGNORE, col2, row2, width, height);
+                mh = gwy_field_area_sum(mfield, NULL, GWY_MASK_IGNORE, col1, row1, width, height);
+                nh = gwy_field_area_sum(nfield, NULL, GWY_MASK_IGNORE, col2, row2, width, height);
                 zs[m][n] = mh - nh;
                 zs[n][m] = nh - mh;
               }
@@ -1039,8 +1039,7 @@ execute(ModuleArgs *args, GtkWindow *wait_window)
     }
 
     /*first get shifts in lateral direction and then in z, using already known xy offsets*/
-    for (k = 0; k < 15; k++)
-        poly[k] = 0;
+    gwy_clear(poly, 15);
 
     if (dox || doy) {
         if (!get_shifts(brick, xoffset, yoffset, xshift, yshift, zshift, poly, dox, doy, FALSE, 0, 0))
