@@ -1,5 +1,5 @@
 /*
- *  $Id: volume_zposlevel.c 29023 2025-12-19 13:06:16Z yeti-dn $
+ *  $Id: volume_zposlevel.c 29543 2026-02-24 14:07:07Z yeti-dn $
  *  Copyright (C) 2019-2023 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -206,7 +206,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     extract_xyplane(&gui);
 
     gui.vf = gwy_unit_get_format_with_digits(gwy_brick_get_unit_w(brick), GWY_UNIT_FORMAT_VFMARKUP,
-                                             gwy_brick_get_max(brick) - gwy_brick_get_min(brick), 5, /* 5 digits */
+                                             gwy_brick_max(brick) - gwy_brick_min(brick), 5, /* 5 digits */
                                              NULL);
 
     gui.gmodel = gwy_graph_model_new();
@@ -450,7 +450,7 @@ get_constant_value(ModuleArgs *args)
 
     line = gwy_line_new(1, 1.0, FALSE);
     gwy_brick_extract_line(brick, line, xpos, ypos, zfrom, xpos, ypos, zto, FALSE);
-    avg = gwy_line_avg(line);
+    avg = gwy_line_mean(line);
     g_object_unref(line);
 
     return avg;
