@@ -1,5 +1,5 @@
 /*
- *  $Id: volumeops.c 28848 2025-11-10 18:54:08Z yeti-dn $
+ *  $Id: volumeops.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -71,7 +71,7 @@ extract_preview(GwyFile *data, GwyRunModeFlags mode)
 
     gwy_data_browser_get_current(GWY_APP_BRICK_ID, &id, 0);
 
-    dfield = gwy_field_copy(gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(id)));
+    dfield = gwy_field_copy(gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(id)));
 
     g_return_if_fail(GWY_IS_FIELD(dfield));
 
@@ -96,7 +96,7 @@ volume_invert(GwyFile *data, GwyRunModeFlags mode)
                                  GWY_APP_BRICK_ID, &id,
                                  0);
 
-    dfield = gwy_field_copy(gwy_container_get_object(GWY_CONTAINER(data), gwy_file_key_volume_picture(id)));
+    dfield = gwy_field_copy(gwy_dict_get_object(GWY_DICT(data), gwy_file_key_volume_picture(id)));
     brick = gwy_brick_copy(brick);
 
     g_return_if_fail(GWY_IS_BRICK(brick));
