@@ -13,15 +13,16 @@ static GwyModuleInfo module_info = {
 GWY_MODULE_QUERY(module_info)
 
 GwyModuleInfo* _gwy_module_query__xyz_autocrop(void);
-GwyModuleInfo* _gwy_module_query__xyz_average (void);
-GwyModuleInfo* _gwy_module_query__xyz_crop    (void);
-GwyModuleInfo* _gwy_module_query__xyz_fft     (void);
-GwyModuleInfo* _gwy_module_query__xyz_level   (void);
-GwyModuleInfo* _gwy_module_query__xyz_merge   (void);
-GwyModuleInfo* _gwy_module_query__xyz_raster  (void);
-GwyModuleInfo* _gwy_module_query__xyz_reduce  (void);
-GwyModuleInfo* _gwy_module_query__xyz_split   (void);
-GwyModuleInfo* _gwy_module_query__xyz_tcut    (void);
+GwyModuleInfo* _gwy_module_query__xyz_average(void);
+GwyModuleInfo* _gwy_module_query__xyz_crop(void);
+GwyModuleInfo* _gwy_module_query__xyz_fft(void);
+GwyModuleInfo* _gwy_module_query__xyz_level(void);
+GwyModuleInfo* _gwy_module_query__xyz_merge(void);
+GwyModuleInfo* _gwy_module_query__xyz_raster(void);
+GwyModuleInfo* _gwy_module_query__xyz_reduce(void);
+GwyModuleInfo* _gwy_module_query__xyz_split(void);
+GwyModuleInfo* _gwy_module_query__xyz_tcut(void);
+GwyModuleInfo* _gwy_module_query__xyz_volumize(void);
 
 static const GwyModuleRecord modules[] = {
   { _gwy_module_query__xyz_autocrop, "xyz_autocrop", },
@@ -34,6 +35,7 @@ static const GwyModuleRecord modules[] = {
   { _gwy_module_query__xyz_reduce, "xyz_reduce", },
   { _gwy_module_query__xyz_split, "xyz_split", },
   { _gwy_module_query__xyz_tcut, "xyz_tcut", },
+  { _gwy_module_query__xyz_volumize, "xyz_volumize", },
   { NULL, NULL, },
 };
 
