@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_autocrop.c 28945 2025-12-03 10:10:57Z yeti-dn $
+ *  $Id: xyz_autocrop.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -69,7 +69,7 @@ module_main(GwyFile *data, G_GNUC_UNUSED GwyRunModeFlags mode)
     g_return_if_fail(GWY_IS_SURFACE(surface));
 
     quark = gwy_file_key_xyz(id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     newxyz = pick_points(surface, &n);
     newsurface = gwy_surface_new_from_data(newxyz, n);
@@ -165,8 +165,8 @@ pick_points(GwySurface *surface, int *newn)
     GwyLine *xline, *yline;
     GwyXYZ *xyz, *newxyz;
 
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
+    gwy_surface_yrange(surface, &ymin, &ymax);
 
     dfield = gwy_field_new(xres, yres, xmax - xmin, ymax - ymin, FALSE);
     mapfield = gwy_field_new_alike(dfield, FALSE);
