@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_fft.c 28990 2025-12-12 17:49:45Z yeti-dn $
+ *  $Id: xyz_fft.c 29435 2026-02-03 16:04:57Z yeti-dn $
  *  Copyright (C) 2016-2023 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -186,7 +186,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 
     args.params = gwy_params_new_from_settings(define_module_params());
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -573,7 +573,7 @@ calculate_weights(GwyLine *weights, GwyLine *modulus, ModuleArgs *args)
         for (k = 0; k < res; k++)
             w[k] = 1.0 - w[k];
 
-        gwy_line_correct_laplace(buf, weights);
+        gwy_line_laplace_solve(buf, weights);
         b = gwy_line_get_data(buf);
         m = gwy_line_get_data(modulus);
 
