@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_level.c 28808 2025-11-05 18:26:20Z yeti-dn $
+ *  $Id: xyz_level.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2016-2023 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -151,9 +151,9 @@ xyzfixzero(GwyFile *data, G_GNUC_UNUSED GwyRunModeFlags mode)
     g_return_if_fail(GWY_IS_SURFACE(surface));
 
     quark = gwy_file_key_xyz(id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
-    gwy_surface_get_min_max(surface, &zmin, &zmax);
+    gwy_surface_min_max(surface, &zmin, &zmax);
     xyz = gwy_surface_get_data(surface);
     n = gwy_surface_get_npoints(surface);
     for (k = 0; k < n; k++)
@@ -179,7 +179,7 @@ xyzzeromean(GwyFile *data, G_GNUC_UNUSED GwyRunModeFlags mode)
     g_return_if_fail(GWY_IS_SURFACE(surface));
 
     quark = gwy_file_key_xyz(id);
-    gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+    gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     xyz = gwy_surface_get_data(surface);
     n = gwy_surface_get_npoints(surface);
@@ -213,7 +213,7 @@ xyzlevel(GwyFile *data, GwyRunModeFlags mode)
         gwy_params_set_enum(args.params, PARAM_METHOD, XYZ_LEVEL_SUBTRACT);
         gwy_params_set_enum(args.params, PARAM_UPDATE_ALL, FALSE);
     }
-    if (mode ==GWY_RUN_INTERACTIVE && args.same_units) {
+    if (mode == GWY_RUN_INTERACTIVE && args.same_units) {
         outcome = run_gui(&args);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -304,7 +304,7 @@ execute(ModuleArgs *args,
     gint *ids = NULL;
 
     if (method == XYZ_LEVEL_SUBTRACT) {
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
         find_plane_coeffs(surface, &a, &bx, &by, &c);
         gwy_debug("b %g %g", bx, by);
         xyz = gwy_surface_get_data(surface);
@@ -329,11 +329,11 @@ execute(ModuleArgs *args,
         allquarks = g_new(GQuark, nq);
         for (kq = 0; kq < nq; kq++)
             allquarks[kq] = gwy_file_key_xyz(ids[kq]);
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), nq, allquarks);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), nq, allquarks);
         g_free(allquarks);
     }
     else
-        gwy_app_undo_qcheckpointv(GWY_CONTAINER(data), 1, &quark);
+        gwy_app_undo_qcheckpointv(GWY_DICT(data), 1, &quark);
 
     /* find_plane_coeffs() calculates the mean plane in ordinary least-squares sense.  But this is not self-consistent
      * with rotation that should use total least squares.  Perform a few iterations. */
