@@ -1,6 +1,6 @@
 /*
- *  $Id: xyz_raster.c 28910 2025-11-24 18:11:09Z yeti-dn $
- *  Copyright (C) 2016-2023 David Necas (Yeti).
+ *  $Id: xyz_raster.c 29431 2026-02-03 00:36:52Z yeti-dn $
+ *  Copyright (C) 2016-2026 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
  *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
@@ -88,7 +88,7 @@ typedef struct {
     GwySurface *surface;
     GwyField *regular;
     GwyField *raster;
-    GwyField *nilmask;
+    GwyNield *nilmask;
     XYZRasData rdata;
     XYZRasRange full_range; /* Real, not scaled. */
     GwyValueFormat *vf;
@@ -122,7 +122,7 @@ static gboolean         execute                    (ModuleArgs *args,
                                                     gchar **error);
 static void             set_raster_field_properties(ModuleArgs *args);
 static void             add_field_to_data          (GwyField *field,
-                                                    GwyField *mask,
+                                                    GwyNield *mask,
                                                     GwyFile *data,
                                                     gint id);
 static GwyDialogOutcome run_gui                    (ModuleArgs *args,
@@ -162,7 +162,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Rasterizes XYZ data to images."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti)",
     "2016",
 };
@@ -293,7 +293,7 @@ end:
 }
 
 static void
-add_field_to_data(GwyField *field, GwyField *mask,
+add_field_to_data(GwyField *field, GwyNield *mask,
                   GwyFile *data, gint id)
 {
     gint newid = gwy_file_add_image(data, field);
@@ -618,7 +618,7 @@ execute(ModuleArgs *args, GtkWindow *window, gchar **error)
     gboolean mask_empty = gwy_params_get_boolean(params, PARAM_MASK_EMPTY);
     GwyTriangulation *triangulation = rdata->triangulation;
     GArray *points = rdata->points;
-    GwyField *field = args->raster, *mask;
+    GwyField *field = args->raster;
     GwySetMessageFunc set_message = (window ? gwy_app_wait_set_message : NULL);
     GwySetFractionFunc set_fraction = (window ? gwy_app_wait_set_fraction : NULL);
     gboolean ok = TRUE, extended;
@@ -644,10 +644,11 @@ execute(ModuleArgs *args, GtkWindow *window, gchar **error)
     else if ((gint)interpolation == GWY_INTERPOLATION_AVERAGE) {
         extend_borders(args, FALSE, EPSREL);
         if (mask_empty) {
-            args->nilmask = mask = gwy_field_new_alike(field, FALSE);
-            gwy_unit_clear(gwy_field_get_unit_z(mask));
-            gwy_field_average_xyz(field, mask, (const GwyXYZ*)points->data, points->len);
-            gwy_field_threshold(mask, G_MINDOUBLE, 1.0, 0.0);
+            GwyField *density = gwy_field_new_alike(field, FALSE);
+            gwy_field_average_xyz(field, density, (const GwyXYZ*)points->data, points->len);
+            args->nilmask = gwy_field_new_nield_alike(field);
+            gwy_nield_mark_by_threshold(args->nilmask, density, 0.999, FALSE);
+            g_object_unref(density);
         }
         else {
             gwy_field_average_xyz(field, NULL, (const GwyXYZ*)points->data, points->len);
@@ -835,8 +836,8 @@ extend_borders(ModuleArgs *args,
         return noldext > 0 || !check_for_changes;
     }
 
-    gwy_surface_get_xrange(surface, &sxmin, &sxmax);
-    gwy_surface_get_yrange(surface, &symin, &symax);
+    gwy_surface_xrange(surface, &sxmin, &sxmax);
+    gwy_surface_yrange(surface, &symin, &symax);
     xreal = sxmax - sxmin;
     yreal = symax - symin;
 
@@ -973,9 +974,9 @@ initialise_range(ModuleArgs *args)
     GwySurface *surface = args->surface;
     XYZRasRange *range = &args->full_range;
 
-    gwy_surface_get_xrange(surface, &range->min.x, &range->max.x);
+    gwy_surface_xrange(surface, &range->min.x, &range->max.x);
     round_to_nice(&range->min.x, &range->max.x);
-    gwy_surface_get_yrange(surface, &range->min.y, &range->max.y);
+    gwy_surface_yrange(surface, &range->min.y, &range->max.y);
     round_to_nice(&range->min.y, &range->max.y);
     gwy_debug("%g %g :: %g %g", range->min.x, range->max.x, range->min.y, range->max.y);
 }
@@ -1099,8 +1100,8 @@ analyse_points(ModuleArgs *args, double epsrel)
     /* Calculate data ranges */
     npoints = rdata->norigpoints = surface->n;
     points = gwy_surface_get_data_const(surface);
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
+    gwy_surface_yrange(surface, &ymin, &ymax);
 
     xreal = xmax - xmin;
     yreal = ymax - ymin;
