@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_zdrift.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: xyz_zdrift.c 29431 2026-02-03 00:36:52Z yeti-dn $
  *  Copyright (C) 2016-2023 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -24,7 +24,7 @@
 
 enum {
     PREVIEW_SIZE = 360,
-    MAXORDER = 10,
+    MAXDEGREE = 10,
     MAXN = 1000
 };
 
@@ -38,7 +38,7 @@ enum {
     PARAM_FROM,
     PARAM_TO,
     PARAM_DIST,
-    PARAM_ORDER,
+    PARAM_DEGREE,
 };
 
 typedef enum {
@@ -51,7 +51,7 @@ typedef struct {
     GwySurface *surface;
     GwySurface *result;
     gint tmax;
-    gdouble fitcoeffs[MAXORDER + 1];
+    gdouble fitcoeffs[MAXDEGREE + 1];
 } ModuleArgs;
 
 typedef struct {
@@ -129,7 +129,7 @@ define_module_params(void)
                               methods, G_N_ELEMENTS(methods), METHOD_FULL);
     gwy_param_def_add_int(paramdef, PARAM_FROM, "from", _("From index"), -1, G_MAXINT, -1);
     gwy_param_def_add_int(paramdef, PARAM_TO, "to", _("To index"), -1, G_MAXINT, -1);
-    gwy_param_def_add_int(paramdef, PARAM_ORDER, "order", _("Polynomial degree"), 0, MAXORDER, 1);
+    gwy_param_def_add_int(paramdef, PARAM_DEGREE, "degree", _("Polynomial degree"), 0, MAXDEGREE, 1);
     gwy_param_def_add_double(paramdef, PARAM_DIST, "dist", _("Neighbor distance"), 0, 10, 0.001);
 
     return paramdef;
@@ -140,7 +140,7 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
 {
     GwyDialogOutcome outcome = GWY_DIALOG_PROCEED;
     ModuleArgs args;
-    gint id, newid, k;
+    gint id, newid;
 
     g_return_if_fail(mode & RUN_MODES);
 
@@ -155,10 +155,9 @@ module_main(GwyFile *data, GwyRunModeFlags mode)
     gwy_params_set_int(args.params, PARAM_FROM, -1); //FIXME, trying to prevent confusion in initi
     gwy_params_set_int(args.params, PARAM_TO, -1);
 
-    for (k = 0; k <= MAXORDER; k++)
-        args.fitcoeffs[k] = 0;
+    gwy_clear(args.fitcoeffs, MAXDEGREE+1);
 
-    if (mode ==GWY_RUN_INTERACTIVE) {
+    if (mode == GWY_RUN_INTERACTIVE) {
         outcome = run_gui(&args, data, id);
         gwy_params_save_to_settings(args.params);
         if (outcome == GWY_DIALOG_CANCEL)
@@ -236,7 +235,7 @@ run_gui(ModuleArgs *args, GwyFile *data, gint id)
     gwy_param_table_append_slider(table, PARAM_DIST);
     gwy_param_table_set_unitstr(table, PARAM_DIST, "‰");
     //gwy_param_table_slider_set_mapping(table, PARAM_DIST, GWY_SCALE_MAPPING_LOG);
-    gwy_param_table_append_slider(table, PARAM_ORDER);
+    gwy_param_table_append_slider(table, PARAM_DEGREE);
     gwy_dialog_add_param_table(dialog, table);
     gwy_dialog_add_content(dialog, gwy_param_table_widget(table), FALSE, TRUE, 0);
 
@@ -342,7 +341,7 @@ fit_polynom(gint degree, const gdouble *z, const gdouble *drift, gdouble *fit,
         for (k = 0; k < n; k++)
             fit[k] = polynom(degree, coeffs, z[k]);
 
-        for (k = 0; k < MAXORDER; k++) {
+        for (k = 0; k < MAXDEGREE; k++) {
             if (k <= degree)
                 fitcoeffs[k] = coeffs[k];
             else
@@ -357,10 +356,9 @@ update_drift_curve(ModuleGUI *gui)
 {
     GwyGraphCurveModel *gcmodel = gwy_graph_model_get_curve(gui->gmodel, 0);
     GwySurface *surface = gui->args->surface;
-    GwyField *sfield, *mfield;
-    GwyLine *avg, *weights;
+    GwyLine *avg = NULL, *weights = NULL;
     const GwyXYZ *xyz;
-    gdouble *linedata, *xlinedata, *sdata, *mdata, *adata;
+    gdouble *linedata, *xlinedata, *adata;
     gint k, n, m, l, linen, foundn;
     gint method = gwy_params_get_enum(gui->args->params, PARAM_METHOD);
     gdouble dist = gwy_params_get_double(gui->args->params, PARAM_DIST);
@@ -368,7 +366,7 @@ update_drift_curve(ModuleGUI *gui)
     gdouble tolerance, stol, xmin, xmax;
     GRand *rng = NULL;
 
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
+    gwy_surface_xrange(surface, &xmin, &xmax);
     tolerance = 0.001*dist*(xmax - xmin);
     stol = tolerance*tolerance;
 
@@ -401,13 +399,11 @@ update_drift_curve(ModuleGUI *gui)
     }
     else {
         printf("linen %d MAXN %d\n", linen, MAXN);
-        sfield = gwy_field_new(linen, MAXN, linen, MAXN, TRUE);
-        mfield = gwy_field_new_alike(sfield, TRUE);
-        avg = gwy_line_new(linen, linen, TRUE);
-        weights = gwy_line_new(linen, linen, TRUE);
+        GwyField *sfield = gwy_field_new(linen, MAXN, linen, MAXN, TRUE);
+        GwyNield *mask = gwy_field_new_nield_alike(sfield);
 
-        sdata = gwy_field_get_data(sfield);
-        mdata = gwy_field_get_data(mfield);
+        gdouble *sdata = gwy_field_get_data(sfield);
+        gint *mdata = gwy_nield_get_data(mask);
 
         foundn = 0;
         rng = g_rand_new();
@@ -441,9 +437,10 @@ update_drift_curve(ModuleGUI *gui)
         gwy_app_wait_finish();
 
         if (foundn > 0) {
-            gwy_field_area_get_line_stats(sfield, mfield, GWY_MASK_INCLUDE,
-                                          avg, weights, 0, 0, linen, foundn,
-                                          GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL);
+            weights = gwy_line_new(linen, linen, TRUE);
+            avg = gwy_field_area_line_stats(sfield, mask, GWY_MASK_INCLUDE,
+                                            0, 0, linen, foundn,
+                                            GWY_LINE_STAT_MEAN, GWY_ORIENTATION_VERTICAL, weights);
             adata = gwy_line_get_data(avg);
             //wdata = gwy_line_get_data(weights);
 
@@ -457,9 +454,9 @@ update_drift_curve(ModuleGUI *gui)
         }
 
         g_object_unref(sfield);
-        g_object_unref(mfield);
-        g_object_unref(avg);
-        g_object_unref(weights);
+        g_object_unref(mask);
+        g_clear_object(&avg);
+        g_clear_object(&weights);
     }
 
     gwy_graph_curve_model_set_data(gcmodel, xlinedata, linedata, linen);
@@ -475,7 +472,7 @@ update_fit_curve(ModuleGUI *gui)
 {
     GwyGraphCurveModel *gcmodel = gwy_graph_model_get_curve(gui->gmodel, 0);
     GwyGraphCurveModel *fitmodel = gwy_graph_model_get_curve(gui->gmodel, 1);
-    gint degree = gwy_params_get_int(gui->args->params, PARAM_ORDER);
+    gint degree = gwy_params_get_int(gui->args->params, PARAM_DEGREE);
     gint from = gwy_params_get_int(gui->args->params, PARAM_FROM);
     gint to = gwy_params_get_int(gui->args->params, PARAM_TO);
     const gdouble *linedata, *xlinedata;
@@ -514,7 +511,7 @@ execute(ModuleArgs *args)
     const GwyXYZ *xyz;
     GwyXYZ *xyz_result;
     guint k, n;
-    gint degree = gwy_params_get_int(args->params, PARAM_ORDER);
+    gint degree = gwy_params_get_int(args->params, PARAM_DEGREE);
 
     xyz = gwy_surface_get_data_const(surface);
     n = gwy_surface_get_npoints(surface);
