@@ -1,5 +1,5 @@
 /*
- *  $Id: file.c 29061 2026-01-02 15:01:53Z yeti-dn $
+ *  $Id: file.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2025 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -23,10 +23,10 @@ enum {
 
 typedef GQuark  (*GetKeyFunc)(gint id);
 typedef void    (*SetObjectFunc)(GwyFile *file,
-                 gint id,
-                 gpointer obj);
+                                 gint id,
+                                 gpointer obj);
 typedef gpointer(*GetObjectFunc)(GwyFile *file,
-                 gint id);
+                                 gint id);
 
 static void
 assert_file_idsv(GwyFile *file, GwyDataKind data_kind, GArray *ids_ref)
@@ -76,7 +76,7 @@ file_assert_equal(GObject *object, GObject *reference)
         g_free(ids);
     }
     /* Extra check the links are correct. */
-    const gchar **strkeys = gwy_container_keys_by_name(GWY_CONTAINER(reference));
+    const gchar **strkeys = gwy_dict_keys_by_name(GWY_DICT(reference));
     if (strkeys) {
         for (gsize i = 0; strkeys[i]; i++) {
             g_assert_true(!gwy_file_value_is_link(file, strkeys[i]) == !gwy_file_value_is_link(file_ref, strkeys[i]));
@@ -91,13 +91,13 @@ static GwyFile*
 create_file_for_serialization(void)
 {
     GwyFile *file = gwy_file_new();
-    GwyContainer *dict = GWY_CONTAINER(file);
-    gwy_container_pass_object(dict, gwy_file_key_image(4), gwy_field_new(2, 3, 1.0, 1.0, TRUE));
-    gwy_container_pass_object(dict, gwy_file_key_image(5), gwy_field_new(3, 4, 1.0, 1.0, TRUE));
-    gwy_container_pass_object(dict, gwy_file_key_image(0), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
-    gwy_container_pass_object(dict, gwy_file_key_volume(0), gwy_brick_new(2, 2, 2, 1.0, 1.0, 1.0, TRUE));
-    gwy_container_pass_object(dict, gwy_file_key_graph(0), gwy_graph_model_new());
-    gwy_container_pass_object(dict, gwy_file_key_cmap(3), gwy_lawn_new(3, 1, 1.0, 1.0, 2, 0));
+    GwyDict *dict = GWY_DICT(file);
+    gwy_dict_pass_object(dict, gwy_file_key_image(4), gwy_field_new(2, 3, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(5), gwy_field_new(3, 4, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(0), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_volume(0), gwy_brick_new(2, 2, 2, 1.0, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_graph(0), gwy_graph_model_new());
+    gwy_dict_pass_object(dict, gwy_file_key_cmap(3), gwy_lawn_new(3, 1, 1.0, 1.0, 2, 0));
     return file;
 }
 
@@ -154,14 +154,14 @@ test_file_in_construction(void)
 
     file = gwy_file_new();
     g_assert_true(GWY_IS_FILE(file));
-    g_assert_false(gwy_container_is_being_constructed(GWY_CONTAINER(file)));
+    g_assert_false(gwy_dict_is_being_constructed(GWY_DICT(file)));
     g_assert_finalize_object(file);
 
     file = gwy_file_new_in_construction();
     g_assert_true(GWY_IS_FILE(file));
-    g_assert_true(gwy_container_is_being_constructed(GWY_CONTAINER(file)));
-    gwy_container_finish_construction(GWY_CONTAINER(file));
-    g_assert_false(gwy_container_is_being_constructed(GWY_CONTAINER(file)));
+    g_assert_true(gwy_dict_is_being_constructed(GWY_DICT(file)));
+    gwy_dict_finish_construction(GWY_DICT(file));
+    g_assert_false(gwy_dict_is_being_constructed(GWY_DICT(file)));
     g_assert_finalize_object(file);
 }
 
@@ -169,22 +169,22 @@ void
 test_file_ids(void)
 {
     GwyFile *file = gwy_file_new();
-    GwyContainer *dict = GWY_CONTAINER(file);
+    GwyDict *dict = GWY_DICT(file);
 
-    gwy_container_pass_object(dict, gwy_file_key_image(4), gwy_field_new(2, 3, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(4), gwy_field_new(2, 3, 1.0, 1.0, TRUE));
     assert_file_ids(file, GWY_FILE_IMAGE, 4, -1);
-    gwy_container_pass_object(dict, gwy_file_key_image(5), gwy_field_new(3, 4, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(5), gwy_field_new(3, 4, 1.0, 1.0, TRUE));
     assert_file_ids(file, GWY_FILE_IMAGE, 4, 5, -1);
-    gwy_container_pass_object(dict, gwy_file_key_image(0), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(0), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
     assert_file_ids(file, GWY_FILE_IMAGE, 0, 4, 5, -1);
-    gwy_container_pass_object(dict, gwy_file_key_image(0), gwy_field_new(2, 2, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(0), gwy_field_new(2, 2, 1.0, 1.0, TRUE));
     assert_file_ids(file, GWY_FILE_IMAGE, 0, 4, 5, -1);
-    gwy_container_pass_object(dict, gwy_file_key_image(2), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
+    gwy_dict_pass_object(dict, gwy_file_key_image(2), gwy_field_new(1, 1, 1.0, 1.0, TRUE));
     assert_file_ids(file, GWY_FILE_IMAGE, 0, 2, 4, 5, -1);
 
-    gwy_container_remove(dict, gwy_file_key_image(4));
+    gwy_dict_remove(dict, gwy_file_key_image(4));
     assert_file_ids(file, GWY_FILE_IMAGE, 0, 2, 5, -1);
-    gwy_container_remove(dict, gwy_file_key_image(0));
+    gwy_dict_remove(dict, gwy_file_key_image(0));
     assert_file_ids(file, GWY_FILE_IMAGE, 2, 5, -1);
 
     gint newid;
@@ -262,13 +262,13 @@ test_file_set_link(void)
     g_assert_true(!gwy_file_value_is_link(file, "/image/2/title"));
     g_assert_true(gwy_file_value_is_link(file, "/image/3/title"));
 
-    gwy_container_set_const_string_by_name(GWY_CONTAINER(file), "/image/0/title", "Title");
+    gwy_dict_set_const_string_by_name(GWY_DICT(file), "/image/0/title", "Title");
     g_assert_true(!gwy_file_value_is_link(file, "/image/0/title"));
     g_assert_true(gwy_file_value_is_link(file, "/image/1/title"));
     g_assert_true(!gwy_file_value_is_link(file, "/image/2/title"));
     g_assert_true(gwy_file_value_is_link(file, "/image/3/title"));
 
-    gwy_container_remove_by_name(GWY_CONTAINER(file), "/image/1/title");
+    gwy_dict_remove_by_name(GWY_DICT(file), "/image/1/title");
     g_assert_true(!gwy_file_value_is_link(file, "/image/0/title"));
     g_assert_true(!gwy_file_value_is_link(file, "/image/1/title"));
     g_assert_true(!gwy_file_value_is_link(file, "/image/2/title"));
@@ -382,13 +382,13 @@ test_file_object_key(GwyDataKind data_kind, GwySerializable *template_obj,
     for (guint itr = 0; itr < n; itr++) {
         GArray *ids_added = g_array_new(FALSE, FALSE, sizeof(gint));
         GwyFile *file = gwy_file_new_in_construction();
-        GwyContainer *container = GWY_CONTAINER(file);
+        GwyDict *container = GWY_DICT(file);
         GwySerializable *objects[nobjects];
         gwy_clear(objects, nobjects);
 
         for (guint j = 0; j < nobjects+1; j++) {
-            if (gwy_container_is_being_constructed(container) && g_test_rand_int_range(0, 1 << nobjects) == 0)
-                gwy_container_finish_construction(container);
+            if (gwy_dict_is_being_constructed(container) && g_test_rand_int_range(0, 1 << nobjects) == 0)
+                gwy_dict_finish_construction(container);
 
             /* Put objects into the file in a random order. */
             guint iobj = g_test_rand_int_range(0, nobjects);
@@ -401,12 +401,12 @@ test_file_object_key(GwyDataKind data_kind, GwySerializable *template_obj,
             /* And using a random method. */
             gint method = g_test_rand_int_range(0, 4);
             if (method == 0)
-                gwy_container_set_object(container, get_key(iobj), objects[iobj]);
+                gwy_dict_set_object(container, get_key(iobj), objects[iobj]);
             else if (method == 1) {
                 GwyFileKeyParsed parsed = {
                     .id = iobj, .data_kind = data_kind, .piece = GWY_FILE_PIECE_NONE, .suffix = NULL
                 };
-                gwy_container_set_object(container, gwy_file_form_key(&parsed), objects[iobj]);
+                gwy_dict_set_object(container, gwy_file_form_key(&parsed), objects[iobj]);
             }
             else if (method == 2) {
                 set_object(file, iobj, objects[iobj]);
@@ -416,8 +416,8 @@ test_file_object_key(GwyDataKind data_kind, GwySerializable *template_obj,
                 pass_object(file, iobj, objects[iobj]);
             }
         }
-        if (gwy_container_is_being_constructed(container))
-            gwy_container_finish_construction(container);
+        if (gwy_dict_is_being_constructed(container))
+            gwy_dict_finish_construction(container);
 
         /* Now check if we get the same objects back using different methods. */
         gwy_guint_sort(&g_array_index(ids_added, guint, 0), ids_added->len);
@@ -426,18 +426,18 @@ test_file_object_key(GwyDataKind data_kind, GwySerializable *template_obj,
         for (guint iobj = 0; iobj < nobjects; iobj++) {
             g_assert_true(get_object(file, iobj) == objects[iobj]);
             if (objects[iobj]) {
-                g_assert_true(gwy_container_get_object(container, get_key(iobj)) == objects[iobj]);
+                g_assert_true(gwy_dict_get_object(container, get_key(iobj)) == objects[iobj]);
                 GwyFileKeyParsed parsed = {
                     .id = iobj, .data_kind = data_kind, .piece = GWY_FILE_PIECE_NONE, .suffix = NULL
                 };
-                g_assert_true(gwy_container_get_object(container, gwy_file_form_key(&parsed)) == objects[iobj]);
+                g_assert_true(gwy_dict_get_object(container, gwy_file_form_key(&parsed)) == objects[iobj]);
             }
             else {
-                g_assert_false(gwy_container_contains(container, get_key(iobj)));
+                g_assert_false(gwy_dict_contains(container, get_key(iobj)));
                 GwyFileKeyParsed parsed = {
                     .id = iobj, .data_kind = data_kind, .piece = GWY_FILE_PIECE_NONE, .suffix = NULL
                 };
-                g_assert_false(gwy_container_contains(container, gwy_file_form_key(&parsed)));
+                g_assert_false(gwy_dict_contains(container, gwy_file_form_key(&parsed)));
             }
         }
 
@@ -525,7 +525,7 @@ test_file_remove_image(void)
 {
     enum { n = 5 };
     GwyFile *file = gwy_file_new();
-    GwyContainer *dict = GWY_CONTAINER(file);
+    GwyDict *dict = GWY_DICT(file);
     GArray *ids_array = g_array_new(FALSE, FALSE, sizeof(gint));
     GPtrArray *objects = g_ptr_array_new();
     GwyDataKind data_kind = GWY_FILE_IMAGE;
@@ -540,36 +540,36 @@ test_file_remove_image(void)
         gwy_file_set_color_mapping(file, data_kind, id, GWY_COLOR_MAPPING_ADAPT);
         gwy_file_set_fixed_range(file, data_kind, id, -1.0, 1.0);
         GwyRGBA color = { 1.0, 1.0, 1.0, 0.5 };
-        gwy_container_set_boxed(dict, GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
-        gwy_container_set_boolean(dict, gwy_file_key_image_real_square(id), TRUE);
+        gwy_dict_set_boxed(dict, GWY_TYPE_RGBA, gwy_file_key_image_mask_color(id), &color);
+        gwy_dict_set_boolean(dict, gwy_file_key_image_real_square(id), TRUE);
         g_ptr_array_add(objects, gwy_selection_line_new());
-        gwy_container_set_object(dict, gwy_file_key_image_selection(id, "line"),
+        gwy_dict_set_object(dict, gwy_file_key_image_selection(id, "line"),
                                  g_ptr_array_index(objects, objects->len-1));
         g_ptr_array_add(objects, gwy_selection_point_new());
-        gwy_container_set_object(dict, gwy_file_key_image_selection(id, "point"),
+        gwy_dict_set_object(dict, gwy_file_key_image_selection(id, "point"),
                                  g_ptr_array_index(objects, objects->len-1));
         g_ptr_array_add(objects, gwy_field_new(2, 2, 1.0, 1.0, TRUE));
-        gwy_container_set_object(dict, gwy_file_key_image_mask(id), g_ptr_array_index(objects, objects->len-1));
-        gwy_file_pass_meta(file, data_kind, id, gwy_container_new());
+        gwy_dict_set_object(dict, gwy_file_key_image_mask(id), g_ptr_array_index(objects, objects->len-1));
+        gwy_file_pass_meta(file, data_kind, id, gwy_dict_new());
         /* Fake the log entirely. We are not running any module function and we need a pretty complete app setup for
          * logging to work correctly. */
         GwyFileKeyParsed parsed = { .data_kind = data_kind, .id = id, .piece = GWY_FILE_PIECE_LOG, .suffix = NULL };
         g_ptr_array_add(objects, gwy_string_list_new());
-        gwy_container_set_object(dict, gwy_file_form_key(&parsed), g_ptr_array_index(objects, objects->len-1));
+        gwy_dict_set_object(dict, gwy_file_form_key(&parsed), g_ptr_array_index(objects, objects->len-1));
     }
-    g_assert_true(gwy_container_get_n_items(dict) % n == 0);
-    gint nperimage = gwy_container_get_n_items(dict)/n;
+    g_assert_true(gwy_dict_get_n_items(dict) % n == 0);
+    gint nperimage = gwy_dict_get_n_items(dict)/n;
 
-    gwy_container_foreach(dict, NULL, assert_image_ids, ids_array);
+    gwy_dict_foreach(dict, NULL, assert_image_ids, ids_array);
 
     while (ids_array->len) {
         guint idx = g_test_rand_int_range(0, ids_array->len);
         gint id = g_array_index(ids_array, gint, idx);
         g_array_remove_index_fast(ids_array, idx);
         gwy_file_remove(file, data_kind, id);
-        gwy_container_foreach(dict, NULL, assert_image_ids, ids_array);
+        gwy_dict_foreach(dict, NULL, assert_image_ids, ids_array);
         /* A proxy for checking that we have not removed anything else. */
-        g_assert_cmpint(gwy_container_get_n_items(dict), ==, nperimage*(gint)ids_array->len);
+        g_assert_cmpint(gwy_dict_get_n_items(dict), ==, nperimage*(gint)ids_array->len);
     }
 
     g_array_free(ids_array, TRUE);
@@ -591,10 +591,10 @@ test_file_sync_items_image_nodelete(void)
     gint id2 = gwy_file_add_image(file, field2);
     g_assert_cmpint(id1, !=, id2);
 
-    GwyContainer *container = GWY_CONTAINER(file);
-    gwy_container_set_enum(container, gwy_file_key_image_color_mapping(id1), GWY_COLOR_MAPPING_AUTO);
-    gwy_container_set_const_string(container, gwy_file_key_image_palette(id1), GWY_GRADIENT_DEFAULT);
-    gwy_container_set_boolean(container, gwy_file_key_image_real_square(id2), TRUE);
+    GwyDict *container = GWY_DICT(file);
+    gwy_dict_set_enum(container, gwy_file_key_image_color_mapping(id1), GWY_COLOR_MAPPING_AUTO);
+    gwy_dict_set_const_string(container, gwy_file_key_image_palette(id1), GWY_GRADIENT_DEFAULT);
+    gwy_dict_set_boolean(container, gwy_file_key_image_real_square(id2), TRUE);
     gwy_file_set_title(file, GWY_FILE_IMAGE, id1, "Title", FALSE);
 
     gwy_file_sync_items(file, GWY_FILE_IMAGE, id1, file, GWY_FILE_IMAGE, id2,
@@ -604,18 +604,18 @@ test_file_sync_items_image_nodelete(void)
                         | GWY_FILE_ITEM_TITLE,
                         FALSE);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_color_mapping(id2)));
-    g_assert_cmpuint(gwy_container_get_enum(container, gwy_file_key_image_color_mapping(id2)),
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_color_mapping(id2)));
+    g_assert_cmpuint(gwy_dict_get_enum(container, gwy_file_key_image_color_mapping(id2)),
                      ==, GWY_COLOR_MAPPING_AUTO);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_palette(id2)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_palette(id2)), ==, GWY_GRADIENT_DEFAULT);
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_palette(id2)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_palette(id2)), ==, GWY_GRADIENT_DEFAULT);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_title(id2)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_title(id2)), ==, "Title");
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_title(id2)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_title(id2)), ==, "Title");
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_real_square(id2)));
-    g_assert_true(gwy_container_get_boolean(container, gwy_file_key_image_real_square(id2)));
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_real_square(id2)));
+    g_assert_true(gwy_dict_get_boolean(container, gwy_file_key_image_real_square(id2)));
 
     g_assert_finalize_object(file);
     g_assert_finalize_object(field2);
@@ -633,10 +633,10 @@ test_file_sync_items_image_delete(void)
     gint id2 = gwy_file_add_image(file, field2);
     g_assert_cmpint(id1, !=, id2);
 
-    GwyContainer *container = GWY_CONTAINER(file);
-    gwy_container_set_enum(container, gwy_file_key_image_color_mapping(id1), GWY_COLOR_MAPPING_AUTO);
-    gwy_container_set_const_string(container, gwy_file_key_image_palette(id1), GWY_GRADIENT_DEFAULT);
-    gwy_container_set_boolean(container, gwy_file_key_image_real_square(id2), TRUE);
+    GwyDict *container = GWY_DICT(file);
+    gwy_dict_set_enum(container, gwy_file_key_image_color_mapping(id1), GWY_COLOR_MAPPING_AUTO);
+    gwy_dict_set_const_string(container, gwy_file_key_image_palette(id1), GWY_GRADIENT_DEFAULT);
+    gwy_dict_set_boolean(container, gwy_file_key_image_real_square(id2), TRUE);
     gwy_file_set_title(file, GWY_FILE_IMAGE, id1, "Title", FALSE);
 
     gwy_file_sync_items(file, GWY_FILE_IMAGE, id1, file, GWY_FILE_IMAGE, id2,
@@ -646,17 +646,17 @@ test_file_sync_items_image_delete(void)
                         | GWY_FILE_ITEM_TITLE,
                         TRUE);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_color_mapping(id2)));
-    g_assert_cmpuint(gwy_container_get_enum(container, gwy_file_key_image_color_mapping(id2)),
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_color_mapping(id2)));
+    g_assert_cmpuint(gwy_dict_get_enum(container, gwy_file_key_image_color_mapping(id2)),
                      ==, GWY_COLOR_MAPPING_AUTO);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_palette(id2)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_palette(id2)), ==, GWY_GRADIENT_DEFAULT);
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_palette(id2)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_palette(id2)), ==, GWY_GRADIENT_DEFAULT);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_title(id2)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_title(id2)), ==, "Title");
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_title(id2)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_title(id2)), ==, "Title");
 
-    g_assert_false(gwy_container_contains(container, gwy_file_key_image_real_square(id2)));
+    g_assert_false(gwy_dict_contains(container, gwy_file_key_image_real_square(id2)));
 
     g_assert_finalize_object(file);
     g_assert_finalize_object(field2);
@@ -671,27 +671,27 @@ test_file_copy_data_image(void)
     GwyField *field = gwy_field_new(3, 5, 1.0, 1.0, TRUE);
     gint id = gwy_file_add_image(file, field);
 
-    GwyContainer *container = GWY_CONTAINER(file);
-    gwy_container_set_enum(container, gwy_file_key_image_color_mapping(id), GWY_COLOR_MAPPING_AUTO);
-    gwy_container_set_const_string(container, gwy_file_key_image_palette(id), GWY_GRADIENT_DEFAULT);
-    gwy_container_set_boolean(container, gwy_file_key_image_real_square(id), TRUE);
+    GwyDict *container = GWY_DICT(file);
+    gwy_dict_set_enum(container, gwy_file_key_image_color_mapping(id), GWY_COLOR_MAPPING_AUTO);
+    gwy_dict_set_const_string(container, gwy_file_key_image_palette(id), GWY_GRADIENT_DEFAULT);
+    gwy_dict_set_boolean(container, gwy_file_key_image_real_square(id), TRUE);
     gwy_file_set_title(file, GWY_FILE_IMAGE, id, "Title", FALSE);
 
     gint newid = gwy_file_copy_data(file, GWY_FILE_IMAGE, id, file);
     g_assert_cmpint(newid, !=, id);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_color_mapping(id)));
-    g_assert_cmpuint(gwy_container_get_enum(container, gwy_file_key_image_color_mapping(id)),
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_color_mapping(id)));
+    g_assert_cmpuint(gwy_dict_get_enum(container, gwy_file_key_image_color_mapping(id)),
                      ==, GWY_COLOR_MAPPING_AUTO);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_palette(id)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_palette(id)), ==, GWY_GRADIENT_DEFAULT);
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_palette(id)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_palette(id)), ==, GWY_GRADIENT_DEFAULT);
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_title(id)));
-    g_assert_cmpstr(gwy_container_get_string(container, gwy_file_key_image_title(id)), ==, "Title");
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_title(id)));
+    g_assert_cmpstr(gwy_dict_get_string(container, gwy_file_key_image_title(id)), ==, "Title");
 
-    g_assert_true(gwy_container_contains(container, gwy_file_key_image_real_square(id)));
-    g_assert_true(gwy_container_get_boolean(container, gwy_file_key_image_real_square(id)));
+    g_assert_true(gwy_dict_contains(container, gwy_file_key_image_real_square(id)));
+    g_assert_true(gwy_dict_get_boolean(container, gwy_file_key_image_real_square(id)));
 
     g_assert_finalize_object(file);
     g_assert_finalize_object(field);
