@@ -1,6 +1,6 @@
 /*
- *  $Id: line.c 29061 2026-01-02 15:01:53Z yeti-dn $
- *  Copyright (C) 2025 David Nečas (Yeti).
+ *  $Id: line.c 29543 2026-02-24 14:07:07Z yeti-dn $
+ *  Copyright (C) 2025-2026 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
@@ -228,36 +228,32 @@ test_line_crop(void)
     }
 }
 
-#if 0
-/* There is no gwy_line_part_copy(). */
 void
-test_line_area_copy(void)
+test_line_part_copy(void)
 {
     guint n = g_test_slow() ? 1000 : 100;
 
     for (guint k = 0; k < n; k++) {
         GwyLine *line = make_i_line();
         gint res = gwy_line_get_res(line);
-        gint width = g_test_rand_int_range(1, res);
-        gint pos = g_test_rand_int_range(0, res-width);
-        gint res2 = g_test_rand_int_range(width, 25);
-        gint destpos = g_test_rand_int_range(0, res2-width+1);
+        gint len = g_test_rand_int_range(1, res);
+        gint pos = g_test_rand_int_range(0, res-len+1);
+        gint res2 = g_test_rand_int_range(len, 25);
+        gint destpos = g_test_rand_int_range(0, res2-len+1);
         GwyLine *destline = gwy_line_new(res2, res2, FALSE);
         gwy_line_fill(destline, G_PI);
-        gwy_line_part_copy(line, destline, pos, width, destpos);
+        gwy_line_part_copy(line, destline, pos, len, destpos);
         const gdouble *d = gwy_line_get_data_const(destline);
-        for (gint i = 0; i < res2; i++) {
-            if (i >= destpos && i-destpos < width)
-                g_assert_cmpfloat(d[i], ==, SOME_NUMBER*(i + pos - destpos));
+        for (gint j = 0; j < res2; j++) {
+            if (j >= destpos && j-destpos < len)
+                g_assert_cmpfloat(d[j], ==, SOME_NUMBER*(j + pos - destpos));
             else
-                g_assert_cmpfloat(d[i], ==, G_PI);
-            }
+                g_assert_cmpfloat(d[j], ==, G_PI);
         }
         g_assert_finalize_object(destline);
         g_assert_finalize_object(line);
     }
 }
-#endif
 
 void
 test_line_flip(void)
@@ -277,8 +273,6 @@ test_line_flip(void)
     }
 }
 
-/* This test fails because Line has still (from, to)-style arguments instead of (pos, len).
- * It will stop failing when we switch the API. */
 void
 test_line_clear_part(void)
 {
@@ -646,6 +640,50 @@ test_line_extend_connect(void)
     }
 }
 
+static GwyLine*
+make_random_linear_line(gdouble *pa, gdouble *pb)
+{
+    gint res = g_test_rand_int_range(2, 20);
+    gdouble dx = exp(2*g_test_rand_double() - 1);
+    GwyLine *line = gwy_line_new(res, res*dx, TRUE);
+    gdouble a = g_test_rand_double_range(-5.0, 5.0);
+    gdouble b = g_test_rand_double_range(-1.0, 1.0);
+    gwy_line_line_level(line, -a, -b);
+
+    if (pa)
+        *pa = a;
+    if (pb)
+        *pb = b;
+
+    return line;
+}
+
+void
+test_line_extend_undefined(void)
+{
+    guint n = g_test_slow() ? 1000 : 100;
+
+    for (guint i = 0; i < n; i++) {
+        GwyLine *line = make_random_linear_line(NULL, NULL);
+        gint left = g_test_rand_int_range(0, 20);
+        gint right = g_test_rand_int_range(0, 20);
+        gint res = gwy_line_get_res(line);
+        GwyLine *extended = gwy_line_extend(line, left, right,
+                                            GWY_EXTERIOR_UNDEFINED, G_MAXDOUBLE, FALSE);
+        GwyLine *extracted = gwy_line_part_extract(extended, left, res);
+        /* There may be rounding errors in the real size, unfortunately. Test it with an ε and then just make the two
+         * dimensions exactly equal. */
+        g_assert_cmpfloat_with_epsilon(gwy_line_get_real(extracted), gwy_line_get_real(line),
+                                       2*(res + left + right)*DBL_EPSILON);
+        gwy_line_set_real(extracted, gwy_line_get_real(line));
+        line_assert_equal(G_OBJECT(extracted), G_OBJECT(line));
+
+        g_assert_finalize_object(line);
+        g_assert_finalize_object(extracted);
+        g_assert_finalize_object(extended);
+    }
+}
+
 void
 test_line_cumulate_plain(void)
 {
@@ -709,24 +747,6 @@ test_line_line_level(void)
     g_assert_finalize_object(line1);
 }
 
-static GwyLine*
-make_random_linear_line(gdouble *pa, gdouble *pb)
-{
-    gint res = g_test_rand_int_range(2, 20);
-    gdouble dx = exp(2*g_test_rand_double() - 1);
-    GwyLine *line = gwy_line_new(res, res*dx, TRUE);
-    gdouble a = g_test_rand_double_range(-5.0, 5.0);
-    gdouble b = g_test_rand_double_range(-1.0, 1.0);
-    gwy_line_line_level(line, -a, -b);
-
-    if (pa)
-        *pa = a;
-    if (pb)
-        *pb = b;
-
-    return line;
-}
-
 void
 test_line_fit_line_random(void)
 {
@@ -772,7 +792,7 @@ test_line_stats_avg_linear(void)
         GwyLine *line = make_random_linear_line(&a, &b);
         gint res = gwy_line_get_res(line);
         gdouble expected = a + b*(res - 1.0)/2.0;
-        g_assert_cmpfloat_with_epsilon(gwy_line_avg(line), expected, 4*DBL_EPSILON*res);
+        g_assert_cmpfloat_with_epsilon(gwy_line_mean(line), expected, 4*DBL_EPSILON*res);
         g_assert_finalize_object(line);
     }
 }
@@ -852,7 +872,7 @@ test_line_stats_skew_linear(void)
         /* Use a large tolerance. We are getting relatively large errors, for not very clear reasons. Sure, for linear
          * line data, the natural summation order of (y_i - y_mean)³ is about the worst possible for rounding errors.
          * Is it the entire reason? */
-        g_assert_cmpfloat_with_epsilon(gwy_line_skew(line), expected, 60*DBL_EPSILON*res);
+        g_assert_cmpfloat_with_epsilon(gwy_line_skew(line), expected, 1000*DBL_EPSILON*res);
         g_assert_finalize_object(line);
     }
 }
@@ -1164,4 +1184,49 @@ test_line_peaks_kth_valleys_none(void)
     }
 }
 
+void
+test_line_laplace_solve(void)
+{
+    guint n = g_test_slow() ? 100 : 20;
+
+    for (guint i = 0; i < n; i++) {
+        gint res = g_test_rand_int_range(2, 40);
+        GwyLine *line = gwy_line_new(res, res, FALSE);
+        GwyLine *mask_line = gwy_line_new(res, res, FALSE);
+        gdouble *d = gwy_line_get_data(line);
+        gdouble *m = gwy_line_get_data(mask_line);
+        for (gint k = 0; k < res; k++) {
+            d[k] = g_test_rand_double();
+            m[k] = g_test_rand_int_range(0, 3);
+        }
+        GwyLine *interpolated = gwy_line_copy(line);
+        gwy_line_laplace_solve(interpolated, mask_line);
+
+        const gdouble *r = gwy_line_get_data(interpolated);
+        for (gint k = 0; k < res; k++) {
+            if (m[k] > 0.0) {
+                gint nn = 0;
+                gdouble sn = 0.0;
+                if (k) {
+                    sn += r[k-1];
+                    nn++;
+                }
+                if (k < res-1) {
+                    sn += r[k+1];
+                    nn++;
+                }
+                gdouble nnavg = sn/nn;
+                g_assert_cmpfloat_with_epsilon(r[k], nnavg, 1e-14);
+            }
+            else {
+                g_assert_cmpfloat(r[k], ==, d[k]);
+            }
+        }
+
+        g_assert_finalize_object(interpolated);
+        g_assert_finalize_object(mask_line);
+        g_assert_finalize_object(line);
+    }
+}
+
 /* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
