@@ -1,5 +1,5 @@
 /*
- *  $Id: serialization.c 28514 2025-09-04 17:58:57Z yeti-dn $
+ *  $Id: serialization.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2009-2025 David Nečas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -660,8 +660,8 @@ values_are_equal(const GValue *value1,
             return !obj1 && !obj2;
         if (G_OBJECT_TYPE(obj1) != G_OBJECT_TYPE(obj2))
             return FALSE;
-        if (GWY_IS_CONTAINER(obj1))
-            return compare_containers(GWY_CONTAINER(obj1), GWY_CONTAINER(obj2));
+        if (GWY_IS_DICT(obj1))
+            return compare_dicts(GWY_DICT(obj1), GWY_DICT(obj2));
         return assert_properties_equal(obj1, obj2);
     }
 
