@@ -18,6 +18,17 @@ g_test_add_func("/testlibgwy/math/powi/zero", test_math_powi_zero);
 g_test_add_func("/testlibgwy/math/powi/basic", test_math_powi_basic);
 g_test_add_func("/testlibgwy/math/deg2rad", test_math_deg2rad);
 g_test_add_func("/testlibgwy/math/rad2deg", test_math_rad2deg);
+g_test_add_func("/testlibgwy/math/mean", test_math_mean);
+g_test_add_func("/testlibgwy/math/sort/double", test_math_sort_double);
+g_test_add_func("/testlibgwy/math/trimmed-mean", test_math_trimmed_mean);
+g_test_add_func("/testlibgwy/math/curvature/apex/straight", test_math_curvature_apex_straight);
+g_test_add_func("/testlibgwy/math/curvature/apex/parabolic", test_math_curvature_apex_parabolic);
+g_test_add_func("/testlibgwy/math/curvature/apex/askew", test_math_curvature_apex_askew);
+g_test_add_func("/testlibgwy/math/is-in-polygon/square", test_math_is_in_polygon_square);
+g_test_add_func("/testlibgwy/math/is-in-polygon/bowtie", test_math_is_in_polygon_bowtie);
+g_test_add_func("/testlibgwy/math/refine-maximum/1d", test_math_refine_maximum_1d);
+g_test_add_func("/testlibgwy/math/refine-maximum/2d", test_math_refine_maximum_2d);
+g_test_add_func("/testlibgwy/math/accumulate-counts", test_math_accumulate_counts);
 g_test_add_func("/testlibgwy/error-list/basic", test_error_list_basic);
 g_test_add_func("/testlibgwy/error-list/propagation", test_error_list_propagation);
 g_test_add_func("/testlibgwy/raw-data/size-consistency", test_raw_data_size_consistency);
@@ -217,29 +228,29 @@ g_test_add_func("/testlibgwy/unit/serialize/random", test_unit_serialize_random)
 g_test_add_func("/testlibgwy/unit/assign", test_unit_assign);
 g_test_add_func("/testlibgwy/unit/copy", test_unit_copy);
 g_test_add_func("/testlibgwy/unit/garbage", test_unit_garbage);
-g_test_add_func("/testlibgwy/container/in-construction", test_container_in_construction);
-g_test_add_func("/testlibgwy/container/data/boolean", test_container_data_boolean);
-g_test_add_func("/testlibgwy/container/data/int32", test_container_data_int32);
-g_test_add_func("/testlibgwy/container/data/int64", test_container_data_int64);
-g_test_add_func("/testlibgwy/container/data/double", test_container_data_double);
-g_test_add_func("/testlibgwy/container/data/string", test_container_data_string);
-g_test_add_func("/testlibgwy/container/gvalue", test_container_gvalue);
-g_test_add_func("/testlibgwy/container/notify/boolean", test_container_notify_boolean);
-g_test_add_func("/testlibgwy/container/notify/int32", test_container_notify_int32);
-g_test_add_func("/testlibgwy/container/notify/string", test_container_notify_string);
-g_test_add_func("/testlibgwy/container/notify/object", test_container_notify_object);
-g_test_add_func("/testlibgwy/container/notify/boxed", test_container_notify_boxed);
-g_test_add_func("/testlibgwy/container/prefix", test_container_prefix);
-g_test_add_func("/testlibgwy/container/transfer/object/default", test_container_transfer_object_default);
-g_test_add_func("/testlibgwy/container/transfer/object/force", test_container_transfer_object_force);
-g_test_add_func("/testlibgwy/container/transfer/object/deep", test_container_transfer_object_deep);
-g_test_add_func("/testlibgwy/container/refcount", test_container_refcount);
-g_test_add_func("/testlibgwy/container/keys", test_container_keys);
-g_test_add_func("/testlibgwy/container/copy", test_container_copy);
-g_test_add_func("/testlibgwy/container/assign", test_container_assign);
-g_test_add_func("/testlibgwy/container/serialize/simple", test_container_serialize_simple);
-g_test_add_func("/testlibgwy/container/serialize/nested", test_container_serialize_nested);
-g_test_add_func("/testlibgwy/container/serialize/text", test_container_serialize_text);
+g_test_add_func("/testlibgwy/dict/in-construction", test_dict_in_construction);
+g_test_add_func("/testlibgwy/dict/data/boolean", test_dict_data_boolean);
+g_test_add_func("/testlibgwy/dict/data/int32", test_dict_data_int32);
+g_test_add_func("/testlibgwy/dict/data/int64", test_dict_data_int64);
+g_test_add_func("/testlibgwy/dict/data/double", test_dict_data_double);
+g_test_add_func("/testlibgwy/dict/data/string", test_dict_data_string);
+g_test_add_func("/testlibgwy/dict/gvalue", test_dict_gvalue);
+g_test_add_func("/testlibgwy/dict/notify/boolean", test_dict_notify_boolean);
+g_test_add_func("/testlibgwy/dict/notify/int32", test_dict_notify_int32);
+g_test_add_func("/testlibgwy/dict/notify/string", test_dict_notify_string);
+g_test_add_func("/testlibgwy/dict/notify/object", test_dict_notify_object);
+g_test_add_func("/testlibgwy/dict/notify/boxed", test_dict_notify_boxed);
+g_test_add_func("/testlibgwy/dict/prefix", test_dict_prefix);
+g_test_add_func("/testlibgwy/dict/transfer/object/default", test_dict_transfer_object_default);
+g_test_add_func("/testlibgwy/dict/transfer/object/force", test_dict_transfer_object_force);
+g_test_add_func("/testlibgwy/dict/transfer/object/deep", test_dict_transfer_object_deep);
+g_test_add_func("/testlibgwy/dict/refcount", test_dict_refcount);
+g_test_add_func("/testlibgwy/dict/keys", test_dict_keys);
+g_test_add_func("/testlibgwy/dict/copy", test_dict_copy);
+g_test_add_func("/testlibgwy/dict/assign", test_dict_assign);
+g_test_add_func("/testlibgwy/dict/serialize/simple", test_dict_serialize_simple);
+g_test_add_func("/testlibgwy/dict/serialize/nested", test_dict_serialize_nested);
+g_test_add_func("/testlibgwy/dict/serialize/text", test_dict_serialize_text);
 g_test_add_func("/testlibgwy/xy/boxed/serialization", test_xy_boxed_serialization);
 g_test_add_func("/testlibgwy/xy/boxed/equal", test_xy_boxed_equal);
 g_test_add_func("/testlibgwy/xy/boxed/assign", test_xy_boxed_assign);
@@ -279,6 +290,7 @@ g_test_add_func("/testlibgwy/line/assign", test_line_assign);
 g_test_add_func("/testlibgwy/line/resize", test_line_resize);
 g_test_add_func("/testlibgwy/line/part-extract", test_line_part_extract);
 g_test_add_func("/testlibgwy/line/crop", test_line_crop);
+g_test_add_func("/testlibgwy/line/part-copy", test_line_part_copy);
 g_test_add_func("/testlibgwy/line/flip", test_line_flip);
 g_test_add_func("/testlibgwy/line/clear/part", test_line_clear_part);
 g_test_add_func("/testlibgwy/line/fill/part", test_line_fill_part);
@@ -294,6 +306,7 @@ g_test_add_func("/testlibgwy/line/extend/periodic", test_line_extend_periodic);
 g_test_add_func("/testlibgwy/line/extend/fixed", test_line_extend_fixed);
 g_test_add_func("/testlibgwy/line/extend/laplace", test_line_extend_laplace);
 g_test_add_func("/testlibgwy/line/extend/connect", test_line_extend_connect);
+g_test_add_func("/testlibgwy/line/extend/undefined", test_line_extend_undefined);
 g_test_add_func("/testlibgwy/line/cumulate/plain", test_line_cumulate_plain);
 g_test_add_func("/testlibgwy/line/cumulate/to-cdist", test_line_cumulate_to_cdist);
 g_test_add_func("/testlibgwy/line/line-level", test_line_line_level);
@@ -319,6 +332,7 @@ g_test_add_func("/testlibgwy/line/peaks/kth/valleys/basic", test_line_peaks_kth_
 g_test_add_func("/testlibgwy/line/peaks/kth/valleys/average", test_line_peaks_kth_valleys_average);
 g_test_add_func("/testlibgwy/line/peaks/kth/valleys/too-few", test_line_peaks_kth_valleys_too_few);
 g_test_add_func("/testlibgwy/line/peaks/kth/valleys/none", test_line_peaks_kth_valleys_none);
+g_test_add_func("/testlibgwy/line/laplace-solve", test_line_laplace_solve);
 g_test_add_func("/testlibgwy/field/basic", test_field_basic);
 g_test_add_func("/testlibgwy/field/invalidate", test_field_invalidate);
 g_test_add_func("/testlibgwy/field/data-changed", test_field_data_changed);
@@ -344,12 +358,14 @@ g_test_add_func("/testlibgwy/field/transpose/minor", test_field_transpose_minor)
 g_test_add_func("/testlibgwy/field/clear/area", test_field_clear_area);
 g_test_add_func("/testlibgwy/field/fill/area", test_field_fill_area);
 g_test_add_func("/testlibgwy/field/fill/area-mask", test_field_fill_area_mask);
+g_test_add_func("/testlibgwy/field/fill/mask-01", test_field_fill_mask_01);
 g_test_add_func("/testlibgwy/field/extend/border", test_field_extend_border);
 g_test_add_func("/testlibgwy/field/extend/mirror", test_field_extend_mirror);
 g_test_add_func("/testlibgwy/field/extend/periodic", test_field_extend_periodic);
 g_test_add_func("/testlibgwy/field/extend/fixed", test_field_extend_fixed);
 g_test_add_func("/testlibgwy/field/extend/laplace", test_field_extend_laplace);
 g_test_add_func("/testlibgwy/field/extend/connect", test_field_extend_connect);
+g_test_add_func("/testlibgwy/field/extend/undefined", test_field_extend_undefined);
 g_test_add_func("/testlibgwy/field/plane-level", test_field_plane_level);
 g_test_add_func("/testlibgwy/field/fit-plane/random", test_field_fit_plane_random);
 g_test_add_func("/testlibgwy/field/fit-plane/degenerate", test_field_fit_plane_degenerate);
@@ -384,9 +400,9 @@ g_test_add_func("/testlibgwy/field/stats/rms/planar", test_field_stats_rms_plana
 g_test_add_func("/testlibgwy/field/stats/rms/bilinear", test_field_stats_rms_bilinear);
 g_test_add_func("/testlibgwy/field/stats/rms/area", test_field_stats_rms_area);
 g_test_add_func("/testlibgwy/field/stats/rms/masked", test_field_stats_rms_masked);
-g_test_add_func("/testlibgwy/field/stats/get-stats/planar", test_field_stats_get_stats_planar);
-g_test_add_func("/testlibgwy/field/stats/get-stats/bilinear", test_field_stats_get_stats_bilinear);
-g_test_add_func("/testlibgwy/field/stats/get-stats/area", test_field_stats_get_stats_area);
+g_test_add_func("/testlibgwy/field/stats/stats/planar", test_field_stats_stats_planar);
+g_test_add_func("/testlibgwy/field/stats/stats/bilinear", test_field_stats_stats_bilinear);
+g_test_add_func("/testlibgwy/field/stats/stats/area", test_field_stats_stats_area);
 g_test_add_func("/testlibgwy/field/stats/area/square", test_field_stats_area_square);
 g_test_add_func("/testlibgwy/field/stats/area/nonsquare", test_field_stats_area_nonsquare);
 g_test_add_func("/testlibgwy/field/stats/variation/square", test_field_stats_variation_square);
@@ -396,6 +412,33 @@ g_test_add_func("/testlibgwy/field/stats/volume/planar", test_field_stats_volume
 g_test_add_func("/testlibgwy/field/stats/height-dist/full", test_field_stats_height_dist_full);
 g_test_add_func("/testlibgwy/field/stats/height-dist/area", test_field_stats_height_dist_area);
 g_test_add_func("/testlibgwy/field/stats/height-dist/masked", test_field_stats_height_dist_masked);
+g_test_add_func("/testlibgwy/field/stats/minkowski/black/auto", test_field_stats_minkowski_black_auto);
+g_test_add_func("/testlibgwy/field/stats/minkowski/white/auto", test_field_stats_minkowski_white_auto);
+g_test_add_func("/testlibgwy/field/stats/minkowski/connectivity/auto", test_field_stats_minkowski_connectivity_auto);
+g_test_add_func("/testlibgwy/field/line-stats/rows/mean", test_field_line_stats_rows_mean);
+g_test_add_func("/testlibgwy/field/line-stats/columns/mean", test_field_line_stats_columns_mean);
+g_test_add_func("/testlibgwy/field/filter/square/minimum", test_field_filter_square_minimum);
+g_test_add_func("/testlibgwy/field/filter/square/maximum", test_field_filter_square_maximum);
+g_test_add_func("/testlibgwy/field/filter/minmax/minimum", test_field_filter_minmax_minimum);
+g_test_add_func("/testlibgwy/field/filter/minmax/maximum", test_field_filter_minmax_maximum);
+g_test_add_func("/testlibgwy/field/filter/minmax/range", test_field_filter_minmax_range);
+g_test_add_func("/testlibgwy/field/filter/minmax/normalization", test_field_filter_minmax_normalization);
+g_test_add_func("/testlibgwy/field/filter/minmax/dilation", test_field_filter_minmax_dilation);
+g_test_add_func("/testlibgwy/field/filter/minmax/frosion", test_field_filter_minmax_frosion);
+g_test_add_func("/testlibgwy/field/filter/rank", test_field_filter_rank);
+g_test_add_func("/testlibgwy/field/filter/trimmed-mean", test_field_filter_trimmed_mean);
+g_test_add_func("/testlibgwy/field/local-maximum/subpixel", test_field_local_maximum_subpixel);
+g_test_add_func("/testlibgwy/field/local-maximum/search", test_field_local_maximum_search);
+g_test_add_func("/testlibgwy/field/local-maximum/edge", test_field_local_maximum_edge);
+g_test_add_func("/testlibgwy/field/local-maximum/stripe", test_field_local_maximum_stripe);
+g_test_add_func("/testlibgwy/field/laplace-solve/scattered", test_field_laplace_solve_scattered);
+g_test_add_func("/testlibgwy/field/laplace-solve/numbered", test_field_laplace_solve_numbered);
+g_test_add_func("/testlibgwy/field/laplace-solve/masked", test_field_laplace_solve_masked);
+g_test_add_func("/testlibgwy/field/laplace-solve/unmasked", test_field_laplace_solve_unmasked);
+g_test_add_func("/testlibgwy/field/laplace-solve/all-grains", test_field_laplace_solve_all_grains);
+g_test_add_func("/testlibgwy/field/tip/dilation", test_field_tip_dilation);
+g_test_add_func("/testlibgwy/field/tip/erosion/spike", test_field_tip_erosion_spike);
+g_test_add_func("/testlibgwy/field/tip/blind-estimate", test_field_tip_blind_estimate);
 g_test_add_func("/testlibgwy/nield/basic", test_nield_basic);
 g_test_add_func("/testlibgwy/nield/data-changed", test_nield_data_changed);
 g_test_add_func("/testlibgwy/nield/serialization", test_nield_serialization);
@@ -410,28 +453,161 @@ g_test_add_func("/testlibgwy/nield/flip/y", test_nield_flip_y);
 g_test_add_func("/testlibgwy/nield/flip/xy", test_nield_flip_xy);
 g_test_add_func("/testlibgwy/nield/transpose/major", test_nield_transpose_major);
 g_test_add_func("/testlibgwy/nield/transpose/minor", test_nield_transpose_minor);
-g_test_add_func("/testlibgwy/nield/number-contiguous/simple", test_nield_number_contiguous_simple);
-g_test_add_func("/testlibgwy/nield/number-contiguous/spiral", test_nield_number_contiguous_spiral);
-g_test_add_func("/testlibgwy/nield/number-contiguous/negative", test_nield_number_contiguous_negative);
-g_test_add_func("/testlibgwy/nield/clear-at", test_nield_clear_at);
-g_test_add_func("/testlibgwy/nield/isolate", test_nield_isolate);
-g_test_add_func("/testlibgwy/nield/isolate-at", test_nield_isolate_at);
+g_test_add_func("/testlibgwy/nield/grain/number-contiguous/simple", test_nield_grain_number_contiguous_simple);
+g_test_add_func("/testlibgwy/nield/grain/number-contiguous/spiral", test_nield_grain_number_contiguous_spiral);
+g_test_add_func("/testlibgwy/nield/grain/number-contiguous/negative", test_nield_grain_number_contiguous_negative);
+g_test_add_func("/testlibgwy/nield/grain/clear-at", test_nield_grain_clear_at);
+g_test_add_func("/testlibgwy/nield/grain/isolate/reconstruction", test_nield_grain_isolate_reconstruction);
+g_test_add_func("/testlibgwy/nield/grain/isolate/bbox", test_nield_grain_isolate_bbox);
+g_test_add_func("/testlibgwy/nield/grain/isolate-at/reconstruction", test_nield_grain_isolate_at_reconstruction);
+g_test_add_func("/testlibgwy/nield/grain/isolate-at/bbox", test_nield_grain_isolate_at_bbox);
 g_test_add_func("/testlibgwy/nield/compatibility/res", test_nield_compatibility_res);
 g_test_add_func("/testlibgwy/nield/count/full", test_nield_count_full);
 g_test_add_func("/testlibgwy/nield/count/area", test_nield_count_area);
 g_test_add_func("/testlibgwy/nield/count/masked", test_nield_count_masked);
-g_test_add_func("/testlibgwy/nield/distance-transform/conn4/noborder", test_nield_distance_transform_conn4_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/conn4/border", test_nield_distance_transform_conn4_border);
-g_test_add_func("/testlibgwy/nield/distance-transform/conn8/noborder", test_nield_distance_transform_conn8_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/conn8/border", test_nield_distance_transform_conn8_border);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/noborder", test_nield_distance_transform_octagonal48_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/border", test_nield_distance_transform_octagonal48_border);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/noborder", test_nield_distance_transform_octagonal84_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/border", test_nield_distance_transform_octagonal84_border);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/noborder", test_nield_distance_transform_octagonal_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/border", test_nield_distance_transform_octagonal_border);
-g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/noborder", test_nield_distance_transform_euclidean_noborder);
-g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/border", test_nield_distance_transform_euclidean_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn4/merged/noborder", test_nield_distance_transform_conn4_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn4/merged/border", test_nield_distance_transform_conn4_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn8/merged/noborder", test_nield_distance_transform_conn8_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn8/merged/border", test_nield_distance_transform_conn8_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/merged/noborder", test_nield_distance_transform_octagonal48_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/merged/border", test_nield_distance_transform_octagonal48_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/merged/noborder", test_nield_distance_transform_octagonal84_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/merged/border", test_nield_distance_transform_octagonal84_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/merged/noborder", test_nield_distance_transform_octagonal_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/merged/border", test_nield_distance_transform_octagonal_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/merged/noborder", test_nield_distance_transform_euclidean_merged_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/merged/border", test_nield_distance_transform_euclidean_merged_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn4/split/noborder", test_nield_distance_transform_conn4_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn4/split/border", test_nield_distance_transform_conn4_split_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn8/split/noborder", test_nield_distance_transform_conn8_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/conn8/split/border", test_nield_distance_transform_conn8_split_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/split/noborder", test_nield_distance_transform_octagonal48_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/split/border", test_nield_distance_transform_octagonal48_split_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/split/noborder", test_nield_distance_transform_octagonal84_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/split/border", test_nield_distance_transform_octagonal84_split_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/split/noborder", test_nield_distance_transform_octagonal_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/split/border", test_nield_distance_transform_octagonal_split_border);
+g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/split/noborder", test_nield_distance_transform_euclidean_split_noborder);
+g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/split/border", test_nield_distance_transform_euclidean_split_border);
+g_test_add_func("/testlibgwy/nield/resample/down", test_nield_resample_down);
+g_test_add_func("/testlibgwy/nield/resample/up", test_nield_resample_up);
+g_test_add_func("/testlibgwy/nield/extend/border", test_nield_extend_border);
+g_test_add_func("/testlibgwy/nield/extend/mirror", test_nield_extend_mirror);
+g_test_add_func("/testlibgwy/nield/extend/periodic", test_nield_extend_periodic);
+g_test_add_func("/testlibgwy/nield/extend/fixed", test_nield_extend_fixed);
+g_test_add_func("/testlibgwy/nield/extend/undefined", test_nield_extend_undefined);
+g_test_add_func("/testlibgwy/nield/grain/sizes", test_nield_grain_sizes);
+g_test_add_func("/testlibgwy/nield/grain/bounding-boxes", test_nield_grain_bounding_boxes);
+g_test_add_func("/testlibgwy/nield/grain/bounding-boxes-periodic", test_nield_grain_bounding_boxes_periodic);
+g_test_add_func("/testlibgwy/nield/grain/inscribed-boxes", test_nield_grain_inscribed_boxes);
+g_test_add_func("/testlibgwy/nield/grain/fill-voids/simple", test_nield_grain_fill_voids_simple);
+g_test_add_func("/testlibgwy/nield/grain/fill-voids/nonsimple", test_nield_grain_fill_voids_nonsimple);
+g_test_add_func("/testlibgwy/nield/grain/fill-voids/unchanged", test_nield_grain_fill_voids_unchanged);
+g_test_add_func("/testlibgwy/nield/clear-touching-border/touching", test_nield_clear_touching_border_touching);
+g_test_add_func("/testlibgwy/nield/clear-touching-border/completely", test_nield_clear_touching_border_completely);
+g_test_add_func("/testlibgwy/nield/autocrop/normal", test_nield_autocrop_normal);
+g_test_add_func("/testlibgwy/nield/autocrop/empty", test_nield_autocrop_empty);
+g_test_add_func("/testlibgwy/nield/filter/minmax/minimum", test_nield_filter_minmax_minimum);
+g_test_add_func("/testlibgwy/nield/filter/minmax/maximum", test_nield_filter_minmax_maximum);
+g_test_add_func("/testlibgwy/nield/filter/minmax/range", test_nield_filter_minmax_range);
+g_test_add_func("/testlibgwy/nield/filter/minmax/dilation", test_nield_filter_minmax_dilation);
+g_test_add_func("/testlibgwy/nield/filter/minmax/frosion", test_nield_filter_minmax_frosion);
+g_test_add_func("/testlibgwy/nield/boundary-pixels/border", test_nield_boundary_pixels_border);
+g_test_add_func("/testlibgwy/nield/boundary-pixels/noborder", test_nield_boundary_pixels_noborder);
+g_test_add_func("/testlibgwy/nield/convex-hull/tightness", test_nield_convex_hull_tightness);
+g_test_add_func("/testlibgwy/nield/convex-hull/convexity", test_nield_convex_hull_convexity);
+g_test_add_func("/testlibgwy/nield/convex-hull/coverage", test_nield_convex_hull_coverage);
+g_test_add_func("/testlibgwy/nield/mark-range/inclusive", test_nield_mark_range_inclusive);
+g_test_add_func("/testlibgwy/nield/mark-range/exclusive", test_nield_mark_range_exclusive);
+g_test_add_func("/testlibgwy/nield/mark-by-threshold/above", test_nield_mark_by_threshold_above);
+g_test_add_func("/testlibgwy/nield/mark-by-threshold/below", test_nield_mark_by_threshold_below);
+g_test_add_func("/testlibgwy/nield/merge/clear", test_nield_merge_clear);
+g_test_add_func("/testlibgwy/nield/merge/fill", test_nield_merge_fill);
+g_test_add_func("/testlibgwy/nield/merge/min", test_nield_merge_min);
+g_test_add_func("/testlibgwy/nield/merge/max", test_nield_merge_max);
+g_test_add_func("/testlibgwy/nield/merge/keep", test_nield_merge_keep);
+g_test_add_func("/testlibgwy/nield/merge/copy", test_nield_merge_copy);
+g_test_add_func("/testlibgwy/nield/merge/subtract", test_nield_merge_subtract);
+g_test_add_func("/testlibgwy/nield/merge/revsubtract", test_nield_merge_revsubtract);
+g_test_add_func("/testlibgwy/nield/merge/xor", test_nield_merge_xor);
+g_test_add_func("/testlibgwy/nield/merge/equal", test_nield_merge_equal);
+g_test_add_func("/testlibgwy/nield/merge/outside", test_nield_merge_outside);
+g_test_add_func("/testlibgwy/nield/merge/not", test_nield_merge_not);
+g_test_add_func("/testlibgwy/nield/merge/ncopy", test_nield_merge_ncopy);
+g_test_add_func("/testlibgwy/nield/merge/nor", test_nield_merge_nor);
+g_test_add_func("/testlibgwy/nield/merge/nand", test_nield_merge_nand);
+g_test_add_func("/testlibgwy/nield/merge/implies", test_nield_merge_implies);
+g_test_add_func("/testlibgwy/nield/merge/converse", test_nield_merge_converse);
+g_test_add_func("/testlibgwy/nield/grain-quantity/pixel-area", test_nield_grain_quantity_pixel_area);
+g_test_add_func("/testlibgwy/nield/grain-quantity/projected-area", test_nield_grain_quantity_projected_area);
+g_test_add_func("/testlibgwy/nield/grain-quantity/equiv-disc-radius", test_nield_grain_quantity_equiv_disc_radius);
+g_test_add_func("/testlibgwy/nield/grain-quantity/maximum", test_nield_grain_quantity_maximum);
+g_test_add_func("/testlibgwy/nield/grain-quantity/minimum", test_nield_grain_quantity_minimum);
+g_test_add_func("/testlibgwy/nield/grain-quantity/mean", test_nield_grain_quantity_mean);
+g_test_add_func("/testlibgwy/nield/grain-quantity/rms", test_nield_grain_quantity_rms);
+g_test_add_func("/testlibgwy/nield/grain-quantity/median", test_nield_grain_quantity_median);
+g_test_add_func("/testlibgwy/nield/grain-quantity/surface-area", test_nield_grain_quantity_surface_area);
+g_test_add_func("/testlibgwy/nield/grain-quantity/center-x", test_nield_grain_quantity_center_x);
+g_test_add_func("/testlibgwy/nield/grain-quantity/center-y", test_nield_grain_quantity_center_y);
+g_test_add_func("/testlibgwy/nield/grain-quantity/slope-theta", test_nield_grain_quantity_slope_theta);
+g_test_add_func("/testlibgwy/nield/grain-quantity/slope-phi", test_nield_grain_quantity_slope_phi);
+g_test_add_func("/testlibgwy/nield/grain-quantity/volume-0", test_nield_grain_quantity_volume_0);
+g_test_add_func("/testlibgwy/nield/grain-quantity/volume-min", test_nield_grain_quantity_volume_min);
+g_test_add_func("/testlibgwy/nield/grain-quantity/volume-laplace", test_nield_grain_quantity_volume_laplace);
+g_test_add_func("/testlibgwy/nield/grain-quantity/half-height-area", test_nield_grain_quantity_half_height_area);
+g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-minimum", test_nield_grain_quantity_boundary_minimum);
+g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-maximum", test_nield_grain_quantity_boundary_maximum);
+g_test_add_func("/testlibgwy/nield/grain-quantity/maximum-project-size", test_nield_grain_quantity_maximum_project_size);
+g_test_add_func("/testlibgwy/nield/grain-quantity/maximum-project-angle", test_nield_grain_quantity_maximum_project_angle);
+g_test_add_func("/testlibgwy/nield/grain-quantity/minimum-project-size", test_nield_grain_quantity_minimum_project_size);
+g_test_add_func("/testlibgwy/nield/grain-quantity/minimum-project-angle", test_nield_grain_quantity_minimum_project_angle);
+g_test_add_func("/testlibgwy/nield/grain-quantity/equiv-ellipse", test_nield_grain_quantity_equiv_ellipse);
+g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-length", test_nield_grain_quantity_boundary_length);
+g_test_add_func("/testlibgwy/nield/grain-quantity/convex-hull-area", test_nield_grain_quantity_convex_hull_area);
+g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-r", test_nield_grain_quantity_circumcircle_r);
+g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-x", test_nield_grain_quantity_circumcircle_x);
+g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-y", test_nield_grain_quantity_circumcircle_y);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/tall1", test_shaped_elliptic_nield_fill_tall1);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/flat1", test_shaped_elliptic_nield_fill_flat1);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/tall2", test_shaped_elliptic_nield_fill_tall2);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/flat2", test_shaped_elliptic_nield_fill_flat2);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/tall1", test_shaped_elliptic_field_fill_tall1);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/flat1", test_shaped_elliptic_field_fill_flat1);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/tall2", test_shaped_elliptic_field_fill_tall2);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/flat2", test_shaped_elliptic_field_fill_flat2);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/small", test_shaped_elliptic_nield_fill_small);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/small", test_shaped_elliptic_field_fill_small);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/xysym", test_shaped_elliptic_nield_fill_xysym);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/xysym", test_shaped_elliptic_field_fill_xysym);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/intersect", test_shaped_elliptic_nield_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/intersect", test_shaped_elliptic_field_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/extract/data", test_shaped_elliptic_nield_extract_data);
+g_test_add_func("/testlibgwy/shaped/elliptic/nield/extract/coords", test_shaped_elliptic_nield_extract_coords);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/extract/data", test_shaped_elliptic_field_extract_data);
+g_test_add_func("/testlibgwy/shaped/elliptic/field/extract/coords", test_shaped_elliptic_field_extract_coords);
+g_test_add_func("/testlibgwy/shaped/circular/nield/fill/small", test_shaped_circular_nield_fill_small);
+g_test_add_func("/testlibgwy/shaped/circular/field/fill/small", test_shaped_circular_field_fill_small);
+g_test_add_func("/testlibgwy/shaped/circular/nield/fill/intersect", test_shaped_circular_nield_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/circular/field/fill/intersect", test_shaped_circular_field_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/circular/nield/extract/data", test_shaped_circular_nield_extract_data);
+g_test_add_func("/testlibgwy/shaped/circular/nield/extract/coords", test_shaped_circular_nield_extract_coords);
+g_test_add_func("/testlibgwy/shaped/circular/field/extract/data", test_shaped_circular_field_extract_data);
+g_test_add_func("/testlibgwy/shaped/circular/field/extract/coords", test_shaped_circular_field_extract_coords);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/small", test_shaped_linear8_nield_fill_small);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/connected", test_shaped_linear8_nield_fill_connected);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/xysym", test_shaped_linear8_nield_fill_xysym);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/signsym", test_shaped_linear8_nield_fill_signsym);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/intersect", test_shaped_linear8_nield_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/extract/data", test_shaped_linear8_nield_extract_data);
+g_test_add_func("/testlibgwy/shaped/linear8/nield/extract/coords", test_shaped_linear8_nield_extract_coords);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/small", test_shaped_linear4_nield_fill_small);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/connected", test_shaped_linear4_nield_fill_connected);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/superset", test_shaped_linear4_nield_fill_superset);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/xysym", test_shaped_linear4_nield_fill_xysym);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/signsym", test_shaped_linear4_nield_fill_signsym);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/intersect", test_shaped_linear4_nield_fill_intersect);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/extract/data", test_shaped_linear4_nield_extract_data);
+g_test_add_func("/testlibgwy/shaped/linear4/nield/extract/coords", test_shaped_linear4_nield_extract_coords);
 g_test_add_func("/testlibgwy/brick/basic", test_brick_basic);
 g_test_add_func("/testlibgwy/brick/data-changed", test_brick_data_changed);
 g_test_add_func("/testlibgwy/brick/serialization", test_brick_serialization);
@@ -501,6 +677,29 @@ g_test_add_func("/testlibgwy/graph-model/basic", test_graph_model_basic);
 g_test_add_func("/testlibgwy/graph-model/serialization", test_graph_model_serialization);
 g_test_add_func("/testlibgwy/graph-model/copy", test_graph_model_copy);
 g_test_add_func("/testlibgwy/graph-model/assign", test_graph_model_assign);
+g_test_add_func("/testlibgwy/module-utils/get/gboolean8", test_module_utils_get_gboolean8);
+g_test_add_func("/testlibgwy/module-utils/get/guint16-be", test_module_utils_get_guint16_be);
+g_test_add_func("/testlibgwy/module-utils/get/guint16-le", test_module_utils_get_guint16_le);
+g_test_add_func("/testlibgwy/module-utils/get/gint16-be", test_module_utils_get_gint16_be);
+g_test_add_func("/testlibgwy/module-utils/get/gint16-le", test_module_utils_get_gint16_le);
+g_test_add_func("/testlibgwy/module-utils/get/guint32-be", test_module_utils_get_guint32_be);
+g_test_add_func("/testlibgwy/module-utils/get/guint32-le", test_module_utils_get_guint32_le);
+g_test_add_func("/testlibgwy/module-utils/get/gint32-be", test_module_utils_get_gint32_be);
+g_test_add_func("/testlibgwy/module-utils/get/gint32-le", test_module_utils_get_gint32_le);
+g_test_add_func("/testlibgwy/module-utils/get/guint64-be", test_module_utils_get_guint64_be);
+g_test_add_func("/testlibgwy/module-utils/get/guint64-le", test_module_utils_get_guint64_le);
+g_test_add_func("/testlibgwy/module-utils/get/gint64-be", test_module_utils_get_gint64_be);
+g_test_add_func("/testlibgwy/module-utils/get/gint64-le", test_module_utils_get_gint64_le);
+g_test_add_func("/testlibgwy/module-utils/get/gfloat-be", test_module_utils_get_gfloat_be);
+g_test_add_func("/testlibgwy/module-utils/get/gfloat-le", test_module_utils_get_gfloat_le);
+g_test_add_func("/testlibgwy/module-utils/get/gdouble-be", test_module_utils_get_gdouble_be);
+g_test_add_func("/testlibgwy/module-utils/get/gdouble-le", test_module_utils_get_gdouble_le);
+g_test_add_func("/testlibgwy/module-utils/get/pascal-real-be", test_module_utils_get_pascal_real_be);
+g_test_add_func("/testlibgwy/module-utils/get/pascal-real-le", test_module_utils_get_pascal_real_le);
+g_test_add_func("/testlibgwy/module-utils/nonsquare-image", test_module_utils_nonsquare_image);
+g_test_add_func("/testlibgwy/module-utils/image-remove-bad/bad", test_module_utils_image_remove_bad_bad);
+g_test_add_func("/testlibgwy/module-utils/image-remove-bad/nobad", test_module_utils_image_remove_bad_nobad);
+g_test_add_func("/testlibgwy/module-utils/mask-nans", test_module_utils_mask_nans);
 g_test_add_func("/testlibgwy/file/in-construction", test_file_in_construction);
 g_test_add_func("/testlibgwy/file/ids", test_file_ids);
 g_test_add_func("/testlibgwy/file/parse-key", test_file_parse_key);
