@@ -18,6 +18,17 @@ void test_math_powi_zero(void);
 void test_math_powi_basic(void);
 void test_math_deg2rad(void);
 void test_math_rad2deg(void);
+void test_math_mean(void);
+void test_math_sort_double(void);
+void test_math_trimmed_mean(void);
+void test_math_curvature_apex_straight(void);
+void test_math_curvature_apex_parabolic(void);
+void test_math_curvature_apex_askew(void);
+void test_math_is_in_polygon_square(void);
+void test_math_is_in_polygon_bowtie(void);
+void test_math_refine_maximum_1d(void);
+void test_math_refine_maximum_2d(void);
+void test_math_accumulate_counts(void);
 void test_error_list_basic(void);
 void test_error_list_propagation(void);
 void test_raw_data_size_consistency(void);
@@ -217,29 +228,29 @@ void test_unit_serialize_random(void);
 void test_unit_assign(void);
 void test_unit_copy(void);
 void test_unit_garbage(void);
-void test_container_in_construction(void);
-void test_container_data_boolean(void);
-void test_container_data_int32(void);
-void test_container_data_int64(void);
-void test_container_data_double(void);
-void test_container_data_string(void);
-void test_container_gvalue(void);
-void test_container_notify_boolean(void);
-void test_container_notify_int32(void);
-void test_container_notify_string(void);
-void test_container_notify_object(void);
-void test_container_notify_boxed(void);
-void test_container_prefix(void);
-void test_container_transfer_object_default(void);
-void test_container_transfer_object_force(void);
-void test_container_transfer_object_deep(void);
-void test_container_refcount(void);
-void test_container_keys(void);
-void test_container_copy(void);
-void test_container_assign(void);
-void test_container_serialize_simple(void);
-void test_container_serialize_nested(void);
-void test_container_serialize_text(void);
+void test_dict_in_construction(void);
+void test_dict_data_boolean(void);
+void test_dict_data_int32(void);
+void test_dict_data_int64(void);
+void test_dict_data_double(void);
+void test_dict_data_string(void);
+void test_dict_gvalue(void);
+void test_dict_notify_boolean(void);
+void test_dict_notify_int32(void);
+void test_dict_notify_string(void);
+void test_dict_notify_object(void);
+void test_dict_notify_boxed(void);
+void test_dict_prefix(void);
+void test_dict_transfer_object_default(void);
+void test_dict_transfer_object_force(void);
+void test_dict_transfer_object_deep(void);
+void test_dict_refcount(void);
+void test_dict_keys(void);
+void test_dict_copy(void);
+void test_dict_assign(void);
+void test_dict_serialize_simple(void);
+void test_dict_serialize_nested(void);
+void test_dict_serialize_text(void);
 void test_xy_boxed_serialization(void);
 void test_xy_boxed_equal(void);
 void test_xy_boxed_assign(void);
@@ -279,6 +290,7 @@ void test_line_assign(void);
 void test_line_resize(void);
 void test_line_part_extract(void);
 void test_line_crop(void);
+void test_line_part_copy(void);
 void test_line_flip(void);
 void test_line_clear_part(void);
 void test_line_fill_part(void);
@@ -294,6 +306,7 @@ void test_line_extend_periodic(void);
 void test_line_extend_fixed(void);
 void test_line_extend_laplace(void);
 void test_line_extend_connect(void);
+void test_line_extend_undefined(void);
 void test_line_cumulate_plain(void);
 void test_line_cumulate_to_cdist(void);
 void test_line_line_level(void);
@@ -319,6 +332,7 @@ void test_line_peaks_kth_valleys_basic(void);
 void test_line_peaks_kth_valleys_average(void);
 void test_line_peaks_kth_valleys_too_few(void);
 void test_line_peaks_kth_valleys_none(void);
+void test_line_laplace_solve(void);
 void test_field_basic(void);
 void test_field_invalidate(void);
 void test_field_data_changed(void);
@@ -344,12 +358,14 @@ void test_field_transpose_minor(void);
 void test_field_clear_area(void);
 void test_field_fill_area(void);
 void test_field_fill_area_mask(void);
+void test_field_fill_mask_01(void);
 void test_field_extend_border(void);
 void test_field_extend_mirror(void);
 void test_field_extend_periodic(void);
 void test_field_extend_fixed(void);
 void test_field_extend_laplace(void);
 void test_field_extend_connect(void);
+void test_field_extend_undefined(void);
 void test_field_plane_level(void);
 void test_field_fit_plane_random(void);
 void test_field_fit_plane_degenerate(void);
@@ -384,9 +400,9 @@ void test_field_stats_rms_planar(void);
 void test_field_stats_rms_bilinear(void);
 void test_field_stats_rms_area(void);
 void test_field_stats_rms_masked(void);
-void test_field_stats_get_stats_planar(void);
-void test_field_stats_get_stats_bilinear(void);
-void test_field_stats_get_stats_area(void);
+void test_field_stats_stats_planar(void);
+void test_field_stats_stats_bilinear(void);
+void test_field_stats_stats_area(void);
 void test_field_stats_area_square(void);
 void test_field_stats_area_nonsquare(void);
 void test_field_stats_variation_square(void);
@@ -396,6 +412,33 @@ void test_field_stats_volume_planar(void);
 void test_field_stats_height_dist_full(void);
 void test_field_stats_height_dist_area(void);
 void test_field_stats_height_dist_masked(void);
+void test_field_stats_minkowski_black_auto(void);
+void test_field_stats_minkowski_white_auto(void);
+void test_field_stats_minkowski_connectivity_auto(void);
+void test_field_line_stats_rows_mean(void);
+void test_field_line_stats_columns_mean(void);
+void test_field_filter_square_minimum(void);
+void test_field_filter_square_maximum(void);
+void test_field_filter_minmax_minimum(void);
+void test_field_filter_minmax_maximum(void);
+void test_field_filter_minmax_range(void);
+void test_field_filter_minmax_normalization(void);
+void test_field_filter_minmax_dilation(void);
+void test_field_filter_minmax_frosion(void);
+void test_field_filter_rank(void);
+void test_field_filter_trimmed_mean(void);
+void test_field_local_maximum_subpixel(void);
+void test_field_local_maximum_search(void);
+void test_field_local_maximum_edge(void);
+void test_field_local_maximum_stripe(void);
+void test_field_laplace_solve_scattered(void);
+void test_field_laplace_solve_numbered(void);
+void test_field_laplace_solve_masked(void);
+void test_field_laplace_solve_unmasked(void);
+void test_field_laplace_solve_all_grains(void);
+void test_field_tip_dilation(void);
+void test_field_tip_erosion_spike(void);
+void test_field_tip_blind_estimate(void);
 void test_nield_basic(void);
 void test_nield_data_changed(void);
 void test_nield_serialization(void);
@@ -410,28 +453,161 @@ void test_nield_flip_y(void);
 void test_nield_flip_xy(void);
 void test_nield_transpose_major(void);
 void test_nield_transpose_minor(void);
-void test_nield_number_contiguous_simple(void);
-void test_nield_number_contiguous_spiral(void);
-void test_nield_number_contiguous_negative(void);
-void test_nield_clear_at(void);
-void test_nield_isolate(void);
-void test_nield_isolate_at(void);
+void test_nield_grain_number_contiguous_simple(void);
+void test_nield_grain_number_contiguous_spiral(void);
+void test_nield_grain_number_contiguous_negative(void);
+void test_nield_grain_clear_at(void);
+void test_nield_grain_isolate_reconstruction(void);
+void test_nield_grain_isolate_bbox(void);
+void test_nield_grain_isolate_at_reconstruction(void);
+void test_nield_grain_isolate_at_bbox(void);
 void test_nield_compatibility_res(void);
 void test_nield_count_full(void);
 void test_nield_count_area(void);
 void test_nield_count_masked(void);
-void test_nield_distance_transform_conn4_noborder(void);
-void test_nield_distance_transform_conn4_border(void);
-void test_nield_distance_transform_conn8_noborder(void);
-void test_nield_distance_transform_conn8_border(void);
-void test_nield_distance_transform_octagonal48_noborder(void);
-void test_nield_distance_transform_octagonal48_border(void);
-void test_nield_distance_transform_octagonal84_noborder(void);
-void test_nield_distance_transform_octagonal84_border(void);
-void test_nield_distance_transform_octagonal_noborder(void);
-void test_nield_distance_transform_octagonal_border(void);
-void test_nield_distance_transform_euclidean_noborder(void);
-void test_nield_distance_transform_euclidean_border(void);
+void test_nield_distance_transform_conn4_merged_noborder(void);
+void test_nield_distance_transform_conn4_merged_border(void);
+void test_nield_distance_transform_conn8_merged_noborder(void);
+void test_nield_distance_transform_conn8_merged_border(void);
+void test_nield_distance_transform_octagonal48_merged_noborder(void);
+void test_nield_distance_transform_octagonal48_merged_border(void);
+void test_nield_distance_transform_octagonal84_merged_noborder(void);
+void test_nield_distance_transform_octagonal84_merged_border(void);
+void test_nield_distance_transform_octagonal_merged_noborder(void);
+void test_nield_distance_transform_octagonal_merged_border(void);
+void test_nield_distance_transform_euclidean_merged_noborder(void);
+void test_nield_distance_transform_euclidean_merged_border(void);
+void test_nield_distance_transform_conn4_split_noborder(void);
+void test_nield_distance_transform_conn4_split_border(void);
+void test_nield_distance_transform_conn8_split_noborder(void);
+void test_nield_distance_transform_conn8_split_border(void);
+void test_nield_distance_transform_octagonal48_split_noborder(void);
+void test_nield_distance_transform_octagonal48_split_border(void);
+void test_nield_distance_transform_octagonal84_split_noborder(void);
+void test_nield_distance_transform_octagonal84_split_border(void);
+void test_nield_distance_transform_octagonal_split_noborder(void);
+void test_nield_distance_transform_octagonal_split_border(void);
+void test_nield_distance_transform_euclidean_split_noborder(void);
+void test_nield_distance_transform_euclidean_split_border(void);
+void test_nield_resample_down(void);
+void test_nield_resample_up(void);
+void test_nield_extend_border(void);
+void test_nield_extend_mirror(void);
+void test_nield_extend_periodic(void);
+void test_nield_extend_fixed(void);
+void test_nield_extend_undefined(void);
+void test_nield_grain_sizes(void);
+void test_nield_grain_bounding_boxes(void);
+void test_nield_grain_bounding_boxes_periodic(void);
+void test_nield_grain_inscribed_boxes(void);
+void test_nield_grain_fill_voids_simple(void);
+void test_nield_grain_fill_voids_nonsimple(void);
+void test_nield_grain_fill_voids_unchanged(void);
+void test_nield_clear_touching_border_touching(void);
+void test_nield_clear_touching_border_completely(void);
+void test_nield_autocrop_normal(void);
+void test_nield_autocrop_empty(void);
+void test_nield_filter_minmax_minimum(void);
+void test_nield_filter_minmax_maximum(void);
+void test_nield_filter_minmax_range(void);
+void test_nield_filter_minmax_dilation(void);
+void test_nield_filter_minmax_frosion(void);
+void test_nield_boundary_pixels_border(void);
+void test_nield_boundary_pixels_noborder(void);
+void test_nield_convex_hull_tightness(void);
+void test_nield_convex_hull_convexity(void);
+void test_nield_convex_hull_coverage(void);
+void test_nield_mark_range_inclusive(void);
+void test_nield_mark_range_exclusive(void);
+void test_nield_mark_by_threshold_above(void);
+void test_nield_mark_by_threshold_below(void);
+void test_nield_merge_clear(void);
+void test_nield_merge_fill(void);
+void test_nield_merge_min(void);
+void test_nield_merge_max(void);
+void test_nield_merge_keep(void);
+void test_nield_merge_copy(void);
+void test_nield_merge_subtract(void);
+void test_nield_merge_revsubtract(void);
+void test_nield_merge_xor(void);
+void test_nield_merge_equal(void);
+void test_nield_merge_outside(void);
+void test_nield_merge_not(void);
+void test_nield_merge_ncopy(void);
+void test_nield_merge_nor(void);
+void test_nield_merge_nand(void);
+void test_nield_merge_implies(void);
+void test_nield_merge_converse(void);
+void test_nield_grain_quantity_pixel_area(void);
+void test_nield_grain_quantity_projected_area(void);
+void test_nield_grain_quantity_equiv_disc_radius(void);
+void test_nield_grain_quantity_maximum(void);
+void test_nield_grain_quantity_minimum(void);
+void test_nield_grain_quantity_mean(void);
+void test_nield_grain_quantity_rms(void);
+void test_nield_grain_quantity_median(void);
+void test_nield_grain_quantity_surface_area(void);
+void test_nield_grain_quantity_center_x(void);
+void test_nield_grain_quantity_center_y(void);
+void test_nield_grain_quantity_slope_theta(void);
+void test_nield_grain_quantity_slope_phi(void);
+void test_nield_grain_quantity_volume_0(void);
+void test_nield_grain_quantity_volume_min(void);
+void test_nield_grain_quantity_volume_laplace(void);
+void test_nield_grain_quantity_half_height_area(void);
+void test_nield_grain_quantity_boundary_minimum(void);
+void test_nield_grain_quantity_boundary_maximum(void);
+void test_nield_grain_quantity_maximum_project_size(void);
+void test_nield_grain_quantity_maximum_project_angle(void);
+void test_nield_grain_quantity_minimum_project_size(void);
+void test_nield_grain_quantity_minimum_project_angle(void);
+void test_nield_grain_quantity_equiv_ellipse(void);
+void test_nield_grain_quantity_boundary_length(void);
+void test_nield_grain_quantity_convex_hull_area(void);
+void test_nield_grain_quantity_circumcircle_r(void);
+void test_nield_grain_quantity_circumcircle_x(void);
+void test_nield_grain_quantity_circumcircle_y(void);
+void test_shaped_elliptic_nield_fill_tall1(void);
+void test_shaped_elliptic_nield_fill_flat1(void);
+void test_shaped_elliptic_nield_fill_tall2(void);
+void test_shaped_elliptic_nield_fill_flat2(void);
+void test_shaped_elliptic_field_fill_tall1(void);
+void test_shaped_elliptic_field_fill_flat1(void);
+void test_shaped_elliptic_field_fill_tall2(void);
+void test_shaped_elliptic_field_fill_flat2(void);
+void test_shaped_elliptic_nield_fill_small(void);
+void test_shaped_elliptic_field_fill_small(void);
+void test_shaped_elliptic_nield_fill_xysym(void);
+void test_shaped_elliptic_field_fill_xysym(void);
+void test_shaped_elliptic_nield_fill_intersect(void);
+void test_shaped_elliptic_field_fill_intersect(void);
+void test_shaped_elliptic_nield_extract_data(void);
+void test_shaped_elliptic_nield_extract_coords(void);
+void test_shaped_elliptic_field_extract_data(void);
+void test_shaped_elliptic_field_extract_coords(void);
+void test_shaped_circular_nield_fill_small(void);
+void test_shaped_circular_field_fill_small(void);
+void test_shaped_circular_nield_fill_intersect(void);
+void test_shaped_circular_field_fill_intersect(void);
+void test_shaped_circular_nield_extract_data(void);
+void test_shaped_circular_nield_extract_coords(void);
+void test_shaped_circular_field_extract_data(void);
+void test_shaped_circular_field_extract_coords(void);
+void test_shaped_linear8_nield_fill_small(void);
+void test_shaped_linear8_nield_fill_connected(void);
+void test_shaped_linear8_nield_fill_xysym(void);
+void test_shaped_linear8_nield_fill_signsym(void);
+void test_shaped_linear8_nield_fill_intersect(void);
+void test_shaped_linear8_nield_extract_data(void);
+void test_shaped_linear8_nield_extract_coords(void);
+void test_shaped_linear4_nield_fill_small(void);
+void test_shaped_linear4_nield_fill_connected(void);
+void test_shaped_linear4_nield_fill_superset(void);
+void test_shaped_linear4_nield_fill_xysym(void);
+void test_shaped_linear4_nield_fill_signsym(void);
+void test_shaped_linear4_nield_fill_intersect(void);
+void test_shaped_linear4_nield_extract_data(void);
+void test_shaped_linear4_nield_extract_coords(void);
 void test_brick_basic(void);
 void test_brick_data_changed(void);
 void test_brick_serialization(void);
@@ -501,6 +677,29 @@ void test_graph_model_basic(void);
 void test_graph_model_serialization(void);
 void test_graph_model_copy(void);
 void test_graph_model_assign(void);
+void test_module_utils_get_gboolean8(void);
+void test_module_utils_get_guint16_be(void);
+void test_module_utils_get_guint16_le(void);
+void test_module_utils_get_gint16_be(void);
+void test_module_utils_get_gint16_le(void);
+void test_module_utils_get_guint32_be(void);
+void test_module_utils_get_guint32_le(void);
+void test_module_utils_get_gint32_be(void);
+void test_module_utils_get_gint32_le(void);
+void test_module_utils_get_guint64_be(void);
+void test_module_utils_get_guint64_le(void);
+void test_module_utils_get_gint64_be(void);
+void test_module_utils_get_gint64_le(void);
+void test_module_utils_get_gfloat_be(void);
+void test_module_utils_get_gfloat_le(void);
+void test_module_utils_get_gdouble_be(void);
+void test_module_utils_get_gdouble_le(void);
+void test_module_utils_get_pascal_real_be(void);
+void test_module_utils_get_pascal_real_le(void);
+void test_module_utils_nonsquare_image(void);
+void test_module_utils_image_remove_bad_bad(void);
+void test_module_utils_image_remove_bad_nobad(void);
+void test_module_utils_mask_nans(void);
 void test_file_in_construction(void);
 void test_file_ids(void);
 void test_file_parse_key(void);
