@@ -1,5 +1,5 @@
 /*
- *  $Id: gwyddion3-thumbnailer.c 28823 2025-11-06 16:01:29Z yeti-dn $
+ *  $Id: gwyddion3-thumbnailer.c 29477 2026-02-14 13:29:30Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -415,7 +415,7 @@ write_thumbnail(const FileInfo *fileinfo,
         return FALSE;
 
     data_found.file = file;
-    gwy_container_foreach(GWY_CONTAINER(file), NULL, find_some_data, &data_found);
+    gwy_dict_foreach(GWY_DICT(file), NULL, find_some_data, &data_found);
     id = data_found.visible > -1 ? data_found.visible : data_found.present;
     if (id < 0) {
         g_object_unref(file);
